# Generated from antlr_tsql/tsql.g4 by ANTLR 4.6.1
# encoding: utf-8
from antlr4 import *
from io import StringIO

def serializedATN():
    with StringIO() as buf:
        buf.write("\3\u0430\ud6d1\u8206\uad2d\u4417\uaef1\u8d80\uaadd\3\u01b9")
        buf.write("\u0c36\4\2\t\2\4\3\t\3\4\4\t\4\4\5\t\5\4\6\t\6\4\7\t\7")
        buf.write("\4\b\t\b\4\t\t\t\4\n\t\n\4\13\t\13\4\f\t\f\4\r\t\r\4\16")
        buf.write("\t\16\4\17\t\17\4\20\t\20\4\21\t\21\4\22\t\22\4\23\t\23")
        buf.write("\4\24\t\24\4\25\t\25\4\26\t\26\4\27\t\27\4\30\t\30\4\31")
        buf.write("\t\31\4\32\t\32\4\33\t\33\4\34\t\34\4\35\t\35\4\36\t\36")
        buf.write("\4\37\t\37\4 \t \4!\t!\4\"\t\"\4#\t#\4$\t$\4%\t%\4&\t")
        buf.write("&\4\'\t\'\4(\t(\4)\t)\4*\t*\4+\t+\4,\t,\4-\t-\4.\t.\4")
        buf.write("/\t/\4\60\t\60\4\61\t\61\4\62\t\62\4\63\t\63\4\64\t\64")
        buf.write("\4\65\t\65\4\66\t\66\4\67\t\67\48\t8\49\t9\4:\t:\4;\t")
        buf.write(";\4<\t<\4=\t=\4>\t>\4?\t?\4@\t@\4A\tA\4B\tB\4C\tC\4D\t")
        buf.write("D\4E\tE\4F\tF\4G\tG\4H\tH\4I\tI\4J\tJ\4K\tK\4L\tL\4M\t")
        buf.write("M\4N\tN\4O\tO\4P\tP\4Q\tQ\4R\tR\4S\tS\4T\tT\4U\tU\4V\t")
        buf.write("V\4W\tW\4X\tX\4Y\tY\4Z\tZ\4[\t[\4\\\t\\\4]\t]\4^\t^\4")
        buf.write("_\t_\4`\t`\4a\ta\4b\tb\4c\tc\4d\td\4e\te\4f\tf\4g\tg\4")
        buf.write("h\th\4i\ti\4j\tj\4k\tk\4l\tl\4m\tm\4n\tn\4o\to\4p\tp\4")
        buf.write("q\tq\4r\tr\4s\ts\4t\tt\4u\tu\4v\tv\4w\tw\4x\tx\4y\ty\4")
        buf.write("z\tz\4{\t{\4|\t|\4}\t}\4~\t~\4\177\t\177\4\u0080\t\u0080")
        buf.write("\4\u0081\t\u0081\4\u0082\t\u0082\4\u0083\t\u0083\4\u0084")
        buf.write("\t\u0084\4\u0085\t\u0085\4\u0086\t\u0086\4\u0087\t\u0087")
        buf.write("\4\u0088\t\u0088\4\u0089\t\u0089\4\u008a\t\u008a\4\u008b")
        buf.write("\t\u008b\4\u008c\t\u008c\4\u008d\t\u008d\4\u008e\t\u008e")
        buf.write("\4\u008f\t\u008f\4\u0090\t\u0090\4\u0091\t\u0091\4\u0092")
        buf.write("\t\u0092\4\u0093\t\u0093\4\u0094\t\u0094\4\u0095\t\u0095")
        buf.write("\4\u0096\t\u0096\4\u0097\t\u0097\4\u0098\t\u0098\4\u0099")
        buf.write("\t\u0099\4\u009a\t\u009a\4\u009b\t\u009b\4\u009c\t\u009c")
        buf.write("\4\u009d\t\u009d\4\u009e\t\u009e\4\u009f\t\u009f\4\u00a0")
        buf.write("\t\u00a0\4\u00a1\t\u00a1\4\u00a2\t\u00a2\4\u00a3\t\u00a3")
        buf.write("\4\u00a4\t\u00a4\4\u00a5\t\u00a5\4\u00a6\t\u00a6\4\u00a7")
        buf.write("\t\u00a7\4\u00a8\t\u00a8\3\2\7\2\u0152\n\2\f\2\16\2\u0155")
        buf.write("\13\2\3\2\3\2\3\3\3\3\5\3\u015b\n\3\3\4\3\4\5\4\u015f")
        buf.write("\n\4\6\4\u0161\n\4\r\4\16\4\u0162\3\5\3\5\3\5\3\5\5\5")
        buf.write("\u0169\n\5\3\6\3\6\3\6\3\6\5\6\u016f\n\6\3\7\3\7\3\7\3")
        buf.write("\7\3\7\3\7\3\7\3\7\3\7\3\7\3\7\3\7\3\7\3\7\3\7\5\7\u0180")
        buf.write("\n\7\3\b\3\b\5\b\u0184\n\b\3\b\5\b\u0187\n\b\3\b\3\b\5")
        buf.write("\b\u018b\n\b\3\b\3\b\5\b\u018f\n\b\3\b\3\b\5\b\u0193\n")
        buf.write("\b\3\b\3\b\3\b\5\b\u0198\n\b\3\b\3\b\3\b\5\b\u019d\n\b")
        buf.write("\3\b\3\b\3\b\3\b\3\b\5\b\u01a4\n\b\3\b\5\b\u01a7\n\b\3")
        buf.write("\b\3\b\5\b\u01ab\n\b\3\b\5\b\u01ae\n\b\3\b\3\b\3\b\3\b")
        buf.write("\3\b\3\b\5\b\u01b6\n\b\3\b\5\b\u01b9\n\b\3\b\3\b\3\b\5")
        buf.write("\b\u01be\n\b\3\b\5\b\u01c1\n\b\3\b\3\b\3\b\5\b\u01c6\n")
        buf.write("\b\3\b\3\b\3\b\5\b\u01cb\n\b\3\b\5\b\u01ce\n\b\3\b\3\b")
        buf.write("\3\b\5\b\u01d3\n\b\3\b\3\b\3\b\3\b\5\b\u01d9\n\b\3\b\3")
        buf.write("\b\3\b\3\b\3\b\5\b\u01e0\n\b\3\b\3\b\5\b\u01e4\n\b\5\b")
        buf.write("\u01e6\n\b\3\b\3\b\3\b\5\b\u01eb\n\b\3\b\3\b\3\b\3\b\3")
        buf.write("\b\3\b\3\b\3\b\3\b\7\b\u01f6\n\b\f\b\16\b\u01f9\13\b\3")
        buf.write("\b\3\b\5\b\u01fd\n\b\5\b\u01ff\n\b\3\t\3\t\3\t\3\t\3\t")
        buf.write("\3\t\3\t\5\t\u0208\n\t\3\n\5\n\u020b\n\n\3\n\3\n\3\n\3")
        buf.write("\n\3\n\3\n\5\n\u0213\n\n\5\n\u0215\n\n\3\n\5\n\u0218\n")
        buf.write("\n\3\n\3\n\5\n\u021c\n\n\3\n\5\n\u021f\n\n\3\n\3\n\5\n")
        buf.write("\u0223\n\n\3\n\3\n\3\n\3\n\3\n\5\n\u022a\n\n\3\n\3\n\5")
        buf.write("\n\u022e\n\n\5\n\u0230\n\n\5\n\u0232\n\n\3\n\5\n\u0235")
        buf.write("\n\n\3\n\5\n\u0238\n\n\3\n\5\n\u023b\n\n\3\13\3\13\3\13")
        buf.write("\3\13\5\13\u0241\n\13\3\f\5\f\u0244\n\f\3\f\3\f\3\f\3")
        buf.write("\f\3\f\3\f\5\f\u024c\n\f\5\f\u024e\n\f\3\f\5\f\u0251\n")
        buf.write("\f\3\f\3\f\5\f\u0255\n\f\3\f\5\f\u0258\n\f\3\f\3\f\3\f")
        buf.write("\3\f\5\f\u025e\n\f\3\f\5\f\u0261\n\f\3\f\3\f\5\f\u0265")
        buf.write("\n\f\3\f\5\f\u0268\n\f\3\f\5\f\u026b\n\f\3\r\3\r\3\r\3")
        buf.write("\r\3\r\5\r\u0272\n\r\3\16\5\16\u0275\n\16\3\16\3\16\5")
        buf.write("\16\u0279\n\16\3\16\5\16\u027c\n\16\3\16\5\16\u027f\n")
        buf.write("\16\3\16\5\16\u0282\n\16\3\17\5\17\u0285\n\17\3\17\3\17")
        buf.write("\3\17\3\17\3\17\3\17\5\17\u028d\n\17\5\17\u028f\n\17\3")
        buf.write("\17\3\17\5\17\u0293\n\17\3\17\5\17\u0296\n\17\3\17\3\17")
        buf.write("\3\17\3\17\7\17\u029c\n\17\f\17\16\17\u029f\13\17\3\17")
        buf.write("\5\17\u02a2\n\17\3\17\3\17\5\17\u02a6\n\17\3\17\3\17\3")
        buf.write("\17\3\17\3\17\5\17\u02ad\n\17\3\17\3\17\5\17\u02b1\n\17")
        buf.write("\5\17\u02b3\n\17\5\17\u02b5\n\17\3\17\5\17\u02b8\n\17")
        buf.write("\3\17\5\17\u02bb\n\17\3\17\5\17\u02be\n\17\3\20\3\20\3")
        buf.write("\20\3\20\7\20\u02c4\n\20\f\20\16\20\u02c7\13\20\3\20\3")
        buf.write("\20\3\20\5\20\u02cc\n\20\3\20\3\20\3\20\3\20\5\20\u02d2")
        buf.write("\n\20\5\20\u02d4\n\20\3\21\3\21\5\21\u02d8\n\21\3\21\5")
        buf.write("\21\u02db\n\21\3\21\5\21\u02de\n\21\3\22\3\22\3\22\5\22")
        buf.write("\u02e3\n\22\3\22\3\22\3\22\5\22\u02e8\n\22\3\22\5\22\u02eb")
        buf.write("\n\22\3\23\3\23\3\23\3\23\3\23\3\23\5\23\u02f3\n\23\3")
        buf.write("\23\3\23\5\23\u02f7\n\23\3\23\3\23\3\23\7\23\u02fc\n\23")
        buf.write("\f\23\16\23\u02ff\13\23\5\23\u0301\n\23\3\23\3\23\3\23")
        buf.write("\3\23\3\23\7\23\u0308\n\23\f\23\16\23\u030b\13\23\5\23")
        buf.write("\u030d\n\23\3\23\3\23\5\23\u0311\n\23\3\23\3\23\3\23\3")
        buf.write("\23\7\23\u0317\n\23\f\23\16\23\u031a\13\23\5\23\u031c")
        buf.write("\n\23\3\24\3\24\5\24\u0320\n\24\3\24\5\24\u0323\n\24\3")
        buf.write("\24\3\24\3\24\3\24\3\24\3\24\3\24\5\24\u032c\n\24\3\24")
        buf.write("\3\24\5\24\u0330\n\24\3\24\3\24\5\24\u0334\n\24\3\24\5")
        buf.write("\24\u0337\n\24\3\25\3\25\3\25\3\25\3\25\5\25\u033e\n\25")
        buf.write("\3\25\5\25\u0341\n\25\3\25\3\25\3\25\7\25\u0346\n\25\f")
        buf.write("\25\16\25\u0349\13\25\3\25\5\25\u034c\n\25\5\25\u034e")
        buf.write("\n\25\3\25\3\25\3\25\3\25\7\25\u0354\n\25\f\25\16\25\u0357")
        buf.write("\13\25\5\25\u0359\n\25\3\25\3\25\5\25\u035d\n\25\3\25")
        buf.write("\3\25\3\25\3\26\3\26\3\26\3\26\5\26\u0366\n\26\3\26\5")
        buf.write("\26\u0369\n\26\3\26\3\26\5\26\u036d\n\26\3\26\3\26\5\26")
        buf.write("\u0371\n\26\3\26\5\26\u0374\n\26\3\27\3\27\3\27\5\27\u0379")
        buf.write("\n\27\3\30\3\30\3\30\3\30\3\30\3\30\3\30\3\30\3\30\3\30")
        buf.write("\3\30\3\30\3\30\3\30\5\30\u0389\n\30\3\30\3\30\5\30\u038d")
        buf.write("\n\30\3\30\3\30\3\30\3\30\5\30\u0393\n\30\5\30\u0395\n")
        buf.write("\30\3\30\5\30\u0398\n\30\3\31\3\31\3\31\3\31\3\31\3\31")
        buf.write("\5\31\u03a0\n\31\3\31\3\31\3\31\3\31\5\31\u03a6\n\31\3")
        buf.write("\31\3\31\3\31\5\31\u03ab\n\31\3\31\5\31\u03ae\n\31\3\32")
        buf.write("\3\32\3\32\3\32\3\32\3\32\3\32\5\32\u03b7\n\32\3\32\3")
        buf.write("\32\3\32\3\32\7\32\u03bd\n\32\f\32\16\32\u03c0\13\32\5")
        buf.write("\32\u03c2\n\32\3\32\3\32\3\32\3\32\3\32\5\32\u03c9\n\32")
        buf.write("\3\32\5\32\u03cc\n\32\3\33\3\33\3\34\3\34\3\34\3\34\3")
        buf.write("\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34")
        buf.write("\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34\3\34")
        buf.write("\3\34\3\34\3\34\3\34\3\34\3\34\3\34\5\34\u03f1\n\34\3")
        buf.write("\34\5\34\u03f4\n\34\3\35\3\35\3\35\3\35\5\35\u03fa\n\35")
        buf.write("\3\35\3\35\3\35\3\35\3\35\3\35\3\35\3\35\3\35\3\35\5\35")
        buf.write("\u0406\n\35\5\35\u0408\n\35\3\35\5\35\u040b\n\35\3\36")
        buf.write("\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36")
        buf.write("\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36\3\36\5\36")
        buf.write("\u0423\n\36\3\37\3\37\3\37\3\37\3\37\3\37\3\37\3\37\3")
        buf.write("\37\5\37\u042e\n\37\3\37\3\37\3\37\3\37\3\37\3\37\5\37")
        buf.write("\u0436\n\37\3 \3 \3 \3 \3 \3 \3 \7 \u043f\n \f \16 \u0442")
        buf.write("\13 \7 \u0444\n \f \16 \u0447\13 \5 \u0449\n \3!\3!\3")
        buf.write("!\3!\3!\3!\5!\u0451\n!\3\"\3\"\3\"\3\"\3#\3#\3#\3#\5#")
        buf.write("\u045b\n#\3$\3$\3$\3%\3%\3%\3&\3&\3\'\3\'\3(\3(\3)\3)")
        buf.write("\3)\3)\3*\3*\3*\3*\3*\3*\3*\3*\5*\u0475\n*\3*\3*\3*\3")
        buf.write("*\5*\u047b\n*\3*\3*\3*\3*\3*\3*\3*\3*\3*\5*\u0486\n*\3")
        buf.write("+\3+\3+\3,\3,\3,\3-\3-\3-\3-\3-\3-\5-\u0494\n-\3.\3.\3")
        buf.write(".\3.\3.\3.\5.\u049c\n.\3/\3/\3/\3/\3/\5/\u04a3\n/\3\60")
        buf.write("\3\60\3\60\3\60\3\60\3\60\3\60\3\60\3\60\3\60\3\60\3\60")
        buf.write("\3\60\3\60\3\60\3\60\3\60\3\60\3\60\3\60\3\60\5\60\u04ba")
        buf.write("\n\60\3\61\3\61\3\61\3\61\3\61\3\62\3\62\3\62\3\62\3\62")
        buf.write("\3\62\5\62\u04c7\n\62\3\63\3\63\3\63\3\63\5\63\u04cd\n")
        buf.write("\63\3\63\3\63\3\63\5\63\u04d2\n\63\3\63\5\63\u04d5\n\63")
        buf.write("\3\64\3\64\3\64\3\64\5\64\u04db\n\64\3\64\3\64\5\64\u04df")
        buf.write("\n\64\3\65\3\65\3\65\3\65\3\65\5\65\u04e6\n\65\3\65\3")
        buf.write("\65\3\65\3\66\3\66\3\66\3\66\5\66\u04ef\n\66\3\66\3\66")
        buf.write("\5\66\u04f3\n\66\3\67\3\67\3\67\3\67\5\67\u04f9\n\67\3")
        buf.write("\67\3\67\3\67\7\67\u04fe\n\67\f\67\16\67\u0501\13\67\3")
        buf.write("\67\5\67\u0504\n\67\38\38\38\38\38\38\38\39\39\39\39\5")
        buf.write("9\u0511\n9\39\39\3:\3:\5:\u0517\n:\3;\3;\3;\3;\3;\3;\3")
        buf.write(";\3<\3<\3<\3<\3<\3<\3<\3<\5<\u0528\n<\3<\3<\5<\u052c\n")
        buf.write("<\3<\3<\3<\3=\3=\3=\5=\u0534\n=\3=\3=\5=\u0538\n=\3=\3")
        buf.write("=\3=\3=\7=\u053e\n=\f=\16=\u0541\13=\3=\5=\u0544\n=\5")
        buf.write("=\u0546\n=\3>\3>\5>\u054a\n>\3>\3>\5>\u054e\n>\3>\3>\5")
        buf.write(">\u0552\n>\3>\3>\5>\u0556\n>\3>\3>\3>\3>\5>\u055c\n>\3")
        buf.write(">\3>\5>\u0560\n>\5>\u0562\n>\3?\3?\3?\5?\u0567\n?\3?\3")
        buf.write("?\3?\3?\7?\u056d\n?\f?\16?\u0570\13?\5?\u0572\n?\3?\5")
        buf.write("?\u0575\n?\3?\3?\3?\3?\3?\7?\u057c\n?\f?\16?\u057f\13")
        buf.write("?\3?\3?\5?\u0583\n?\3?\3?\3?\5?\u0588\n?\3?\5?\u058b\n")
        buf.write("?\5?\u058d\n?\3@\3@\5@\u0591\n@\3@\3@\5@\u0595\n@\3@\5")
        buf.write("@\u0598\n@\3@\3@\5@\u059c\n@\3A\3A\3B\3B\5B\u05a2\nB\3")
        buf.write("B\3B\3B\5B\u05a7\nB\3B\3B\3B\3B\3B\5B\u05ae\nB\5B\u05b0")
        buf.write("\nB\3B\3B\5B\u05b4\nB\3B\3B\3B\3B\3B\5B\u05bb\nB\3B\3")
        buf.write("B\5B\u05bf\nB\3B\5B\u05c2\nB\3B\3B\3B\3B\3B\3B\3B\5B\u05cb")
        buf.write("\nB\3B\5B\u05ce\nB\5B\u05d0\nB\3C\3C\3C\3C\3C\3C\3C\5")
        buf.write("C\u05d9\nC\3C\3C\3C\3C\3C\3C\3C\3C\3C\5C\u05e4\nC\3C\3")
        buf.write("C\5C\u05e8\nC\5C\u05ea\nC\5C\u05ec\nC\3D\3D\3D\3D\5D\u05f2")
        buf.write("\nD\3D\3D\3D\5D\u05f7\nD\3D\3D\3D\3D\3D\5D\u05fe\nD\3")
        buf.write("D\3D\3D\3D\3D\3D\3D\3D\3D\3D\3D\5D\u060b\nD\5D\u060d\n")
        buf.write("D\5D\u060f\nD\3D\5D\u0612\nD\3D\5D\u0615\nD\3E\3E\3E\3")
        buf.write("E\3E\5E\u061c\nE\3E\5E\u061f\nE\3E\3E\3E\3E\5E\u0625\n")
        buf.write("E\3E\3E\3E\5E\u062a\nE\5E\u062c\nE\3E\5E\u062f\nE\3E\3")
        buf.write("E\3E\3E\5E\u0635\nE\3E\3E\3E\3E\3E\3E\5E\u063d\nE\5E\u063f")
        buf.write("\nE\3E\5E\u0642\nE\3E\3E\5E\u0646\nE\3E\5E\u0649\nE\3")
        buf.write("E\3E\3E\3E\5E\u064f\nE\3E\5E\u0652\nE\3E\3E\5E\u0656\n")
        buf.write("E\3E\5E\u0659\nE\3E\3E\3E\3E\5E\u065f\nE\3E\5E\u0662\n")
        buf.write("E\5E\u0664\nE\3F\3F\5F\u0668\nF\3G\3G\3G\5G\u066d\nG\3")
        buf.write("H\3H\3H\3H\3I\3I\5I\u0675\nI\3I\3I\3I\5I\u067a\nI\3J\3")
        buf.write("J\3J\3J\3J\3K\3K\5K\u0683\nK\3K\7K\u0686\nK\fK\16K\u0689")
        buf.write("\13K\3L\3L\5L\u068d\nL\3M\3M\3M\3M\5M\u0693\nM\3M\3M\5")
        buf.write("M\u0697\nM\3M\5M\u069a\nM\3M\3M\5M\u069e\nM\3M\3M\3M\3")
        buf.write("M\5M\u06a4\nM\3M\3M\3M\3M\3M\3M\5M\u06ac\nM\3M\3M\3M\5")
        buf.write("M\u06b1\nM\5M\u06b3\nM\3M\5M\u06b6\nM\3M\7M\u06b9\nM\f")
        buf.write("M\16M\u06bc\13M\3N\3N\5N\u06c0\nN\3N\5N\u06c3\nN\3N\3")
        buf.write("N\3N\5N\u06c8\nN\3N\5N\u06cb\nN\3N\5N\u06ce\nN\3N\3N\3")
        buf.write("N\3N\5N\u06d4\nN\3N\3N\3N\3N\5N\u06da\nN\3O\3O\5O\u06de")
        buf.write("\nO\3O\3O\3O\5O\u06e3\nO\3O\5O\u06e6\nO\3O\3O\3O\5O\u06eb")
        buf.write("\nO\3O\3O\5O\u06ef\nO\3O\3O\5O\u06f3\nO\3O\3O\3O\3O\5")
        buf.write("O\u06f9\nO\3O\3O\3O\3O\5O\u06ff\nO\3P\3P\3P\3P\3P\7P\u0706")
        buf.write("\nP\fP\16P\u0709\13P\3P\3P\3Q\3Q\3Q\3Q\3Q\5Q\u0712\nQ")
        buf.write("\3R\3R\3R\3R\3R\3R\3R\3R\5R\u071c\nR\5R\u071e\nR\5R\u0720")
        buf.write("\nR\3R\5R\u0723\nR\3R\5R\u0726\nR\3R\3R\3R\3R\3R\3R\3")
        buf.write("R\3R\3R\5R\u0731\nR\5R\u0733\nR\5R\u0735\nR\3R\5R\u0738")
        buf.write("\nR\3S\5S\u073b\nS\3S\5S\u073e\nS\3S\5S\u0741\nS\3S\5")
        buf.write("S\u0744\nS\3S\5S\u0747\nS\3S\3S\3S\3T\3T\3T\3T\3T\3T\3")
        buf.write("T\5T\u0753\nT\3T\5T\u0756\nT\3T\5T\u0759\nT\3T\3T\3T\3")
        buf.write("T\3T\7T\u0760\nT\fT\16T\u0763\13T\5T\u0765\nT\3T\5T\u0768")
        buf.write("\nT\3U\3U\3U\3U\3U\5U\u076f\nU\3U\5U\u0772\nU\3U\3U\3")
        buf.write("U\3U\3U\3U\3U\3U\3U\3U\3U\3U\5U\u0780\nU\3U\5U\u0783\n")
        buf.write("U\3U\3U\3U\3U\3U\5U\u078a\nU\3U\3U\3U\3U\3U\3U\3U\3U\3")
        buf.write("U\5U\u0795\nU\3V\3V\5V\u0799\nV\3W\3W\3W\3W\3W\3W\3W\3")
        buf.write("W\3W\6W\u07a4\nW\rW\16W\u07a5\3W\3W\5W\u07aa\nW\3W\3W")
        buf.write("\3W\3W\6W\u07b0\nW\rW\16W\u07b1\3W\3W\5W\u07b6\nW\3W\3")
        buf.write("W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\5W\u07c8\n")
        buf.write("W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\3W\7W\u07d7\nW\f")
        buf.write("W\16W\u07da\13W\3X\3X\3X\3X\3X\3X\3X\3X\5X\u07e4\nX\3")
        buf.write("Y\3Y\3Z\3Z\3Z\5Z\u07eb\nZ\3Z\3Z\3Z\7Z\u07f0\nZ\fZ\16Z")
        buf.write("\u07f3\13Z\3[\3[\3[\3[\3[\5[\u07fa\n[\3[\3[\3[\3[\3[\3")
        buf.write("\\\3\\\5\\\u0803\n\\\3\\\3\\\5\\\u0807\n\\\3\\\3\\\3\\")
        buf.write("\3\\\3\\\3\\\3\\\3\\\5\\\u0811\n\\\3]\3]\3]\7]\u0816\n")
        buf.write("]\f]\16]\u0819\13]\3^\3^\3^\3^\3^\3^\3^\3^\3^\7^\u0824")
        buf.write("\n^\f^\16^\u0827\13^\3_\3_\3_\3_\3_\3_\3_\3_\3_\3_\3_")
        buf.write("\3_\3_\3_\3_\3_\3_\3_\3_\3_\5_\u083d\n_\3_\3_\3_\3_\3")
        buf.write("_\3_\3_\5_\u0846\n_\3_\3_\3_\3_\5_\u084c\n_\3_\3_\3_\3")
        buf.write("_\5_\u0852\n_\3_\3_\3_\3_\5_\u0858\n_\3_\3_\3_\3_\3_\3")
        buf.write("_\3_\3_\3_\5_\u0863\n_\3`\3`\3`\3`\3`\5`\u086a\n`\3`\7")
        buf.write("`\u086d\n`\f`\16`\u0870\13`\3a\3a\5a\u0874\na\3a\3a\5")
        buf.write("a\u0878\na\3a\3a\3a\3a\3a\6a\u087f\na\ra\16a\u0880\5a")
        buf.write("\u0883\na\3b\3b\5b\u0887\nb\3b\5b\u088a\nb\3b\3b\3b\5")
        buf.write("b\u088f\nb\3b\3b\5b\u0893\nb\3b\3b\5b\u0897\nb\3b\3b\3")
        buf.write("b\3b\3b\7b\u089e\nb\fb\16b\u08a1\13b\5b\u08a3\nb\3b\3")
        buf.write("b\5b\u08a7\nb\3c\3c\3c\5c\u08ac\nc\3c\3c\5c\u08b0\nc\3")
        buf.write("d\3d\3d\3d\3d\7d\u08b7\nd\fd\16d\u08ba\13d\3d\3d\3d\3")
        buf.write("d\3d\3d\3d\3d\3d\5d\u08c5\nd\5d\u08c7\nd\3e\3e\3e\3e\3")
        buf.write("e\3e\5e\u08cf\ne\3e\3e\3e\3e\3e\3e\5e\u08d7\ne\3e\5e\u08da")
        buf.write("\ne\5e\u08dc\ne\3f\3f\3f\3f\3f\5f\u08e3\nf\3g\3g\5g\u08e7")
        buf.write("\ng\3h\3h\3i\3i\3i\3i\3i\7i\u08f0\ni\fi\16i\u08f3\13i")
        buf.write("\3i\3i\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3")
        buf.write("j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\7j\u0912\nj\fj\16j")
        buf.write("\u0915\13j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\3j\5j\u0924")
        buf.write("\nj\3k\3k\3k\3k\5k\u092a\nk\3l\3l\3l\7l\u092f\nl\fl\16")
        buf.write("l\u0932\13l\3m\3m\3m\5m\u0937\nm\3m\3m\3m\5m\u093c\nm")
        buf.write("\3m\3m\3m\3m\3m\3m\5m\u0944\nm\3m\5m\u0947\nm\5m\u0949")
        buf.write("\nm\3n\3n\3n\7n\u094e\nn\fn\16n\u0951\13n\3o\3o\3o\3o")
        buf.write("\3o\5o\u0958\no\3p\3p\7p\u095c\np\fp\16p\u095f\13p\3q")
        buf.write("\3q\5q\u0963\nq\3q\3q\5q\u0967\nq\3q\3q\3q\5q\u096c\n")
        buf.write("q\5q\u096e\nq\3q\3q\3q\3q\3q\5q\u0975\nq\3q\3q\5q\u0979")
        buf.write("\nq\3q\3q\3q\3q\3q\5q\u0980\nq\5q\u0982\nq\5q\u0984\n")
        buf.write("q\3r\3r\3r\3r\3r\3r\3r\3r\3s\5s\u098f\ns\3s\3s\5s\u0993")
        buf.write("\ns\5s\u0995\ns\3s\5s\u0998\ns\3s\3s\3s\3s\3s\3s\3s\3")
        buf.write("s\3s\3s\3s\3s\3s\3s\5s\u09a8\ns\3t\3t\5t\u09ac\nt\3u\3")
        buf.write("u\3u\3u\3u\3u\3u\3u\3u\3u\3u\3u\3u\3u\3u\3u\7u\u09be\n")
        buf.write("u\fu\16u\u09c1\13u\3u\5u\u09c4\nu\3u\3u\5u\u09c8\nu\3")
        buf.write("v\3v\3v\3v\3w\3w\3w\3w\3w\5w\u09d3\nw\3x\3x\3x\3x\3x\5")
        buf.write("x\u09da\nx\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3")
        buf.write("x\3x\3x\3x\3x\3x\5x\u09f0\nx\3x\3x\3x\3x\3x\3x\3x\3x\3")
        buf.write("x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3")
        buf.write("x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3x\3")
        buf.write("x\3x\3x\3x\3x\3x\5x\u0a24\nx\3x\3x\5x\u0a28\nx\3x\3x\3")
        buf.write("x\3x\3x\3x\3x\3x\3x\3x\3x\3x\5x\u0a36\nx\3y\3y\3y\3y\3")
        buf.write("y\3z\3z\3z\3z\3z\3{\5{\u0a43\n{\3{\3{\3|\3|\5|\u0a49\n")
        buf.write("|\3}\5}\u0a4c\n}\3}\3}\3}\3}\7}\u0a52\n}\f}\16}\u0a55")
        buf.write("\13}\3}\3}\3~\3~\3~\3~\3~\7~\u0a5e\n~\f~\16~\u0a61\13")
        buf.write("~\3~\3~\3\177\5\177\u0a66\n\177\3\177\3\177\3\177\3\177")
        buf.write("\3\177\7\177\u0a6d\n\177\f\177\16\177\u0a70\13\177\3\177")
        buf.write("\3\177\3\177\3\177\3\177\3\177\3\177\3\177\3\177\3\177")
        buf.write("\3\177\3\177\7\177\u0a7e\n\177\f\177\16\177\u0a81\13\177")
        buf.write("\3\177\3\177\3\177\5\177\u0a86\n\177\3\177\3\177\3\177")
        buf.write("\3\177\3\177\3\177\5\177\u0a8e\n\177\3\u0080\3\u0080\5")
        buf.write("\u0080\u0a92\n\u0080\3\u0081\3\u0081\3\u0081\3\u0081\7")
        buf.write("\u0081\u0a98\n\u0081\f\u0081\16\u0081\u0a9b\13\u0081\3")
        buf.write("\u0081\3\u0081\3\u0082\3\u0082\5\u0082\u0aa1\n\u0082\3")
        buf.write("\u0083\3\u0083\3\u0084\3\u0084\3\u0084\3\u0084\3\u0084")
        buf.write("\3\u0084\3\u0084\3\u0084\3\u0084\7\u0084\u0aae\n\u0084")
        buf.write("\f\u0084\16\u0084\u0ab1\13\u0084\3\u0085\3\u0085\3\u0085")
        buf.write("\7\u0085\u0ab6\n\u0085\f\u0085\16\u0085\u0ab9\13\u0085")
        buf.write("\3\u0086\3\u0086\3\u0086\3\u0086\3\u0086\3\u0086\3\u0086")
        buf.write("\3\u0086\3\u0086\3\u0086\5\u0086\u0ac5\n\u0086\3\u0087")
        buf.write("\3\u0087\3\u0087\5\u0087\u0aca\n\u0087\3\u0087\3\u0087")
        buf.write("\3\u0087\5\u0087\u0acf\n\u0087\3\u0087\3\u0087\3\u0087")
        buf.write("\3\u0087\5\u0087\u0ad5\n\u0087\3\u0087\5\u0087\u0ad8\n")
        buf.write("\u0087\3\u0087\3\u0087\5\u0087\u0adc\n\u0087\3\u0087\3")
        buf.write("\u0087\3\u0087\5\u0087\u0ae1\n\u0087\3\u0087\3\u0087\3")
        buf.write("\u0087\3\u0087\3\u0087\3\u0087\3\u0087\3\u0087\3\u0087")
        buf.write("\3\u0087\3\u0087\3\u0087\3\u0087\5\u0087\u0af0\n\u0087")
        buf.write("\3\u0088\3\u0088\3\u0089\3\u0089\3\u0089\3\u0089\3\u0089")
        buf.write("\5\u0089\u0af9\n\u0089\3\u0089\5\u0089\u0afc\n\u0089\3")
        buf.write("\u0089\5\u0089\u0aff\n\u0089\3\u0089\3\u0089\3\u008a\3")
        buf.write("\u008a\3\u008a\3\u008b\3\u008b\3\u008b\3\u008b\3\u008b")
        buf.write("\3\u008b\5\u008b\u0b0c\n\u008b\3\u008c\3\u008c\5\u008c")
        buf.write("\u0b10\n\u008c\3\u008d\3\u008d\3\u008d\3\u008d\3\u008d")
        buf.write("\3\u008d\5\u008d\u0b18\n\u008d\3\u008e\3\u008e\3\u008e")
        buf.write("\3\u008e\5\u008e\u0b1e\n\u008e\3\u008f\3\u008f\3\u008f")
        buf.write("\3\u008f\7\u008f\u0b24\n\u008f\f\u008f\16\u008f\u0b27")
        buf.write("\13\u008f\3\u008f\3\u008f\3\u008f\3\u008f\5\u008f\u0b2d")
        buf.write("\n\u008f\3\u008f\3\u008f\3\u008f\3\u008f\5\u008f\u0b33")
        buf.write("\n\u008f\3\u008f\3\u008f\3\u008f\3\u008f\3\u008f\3\u008f")
        buf.write("\3\u008f\3\u008f\3\u008f\3\u008f\3\u008f\3\u008f\3\u008f")
        buf.write("\5\u008f\u0b42\n\u008f\3\u0090\3\u0090\3\u0090\3\u0090")
        buf.write("\3\u0090\3\u0090\3\u0090\5\u0090\u0b4b\n\u0090\3\u0090")
        buf.write("\3\u0090\3\u0091\3\u0091\5\u0091\u0b51\n\u0091\3\u0092")
        buf.write("\3\u0092\3\u0092\3\u0092\5\u0092\u0b57\n\u0092\3\u0092")
        buf.write("\5\u0092\u0b5a\n\u0092\3\u0092\3\u0092\5\u0092\u0b5e\n")
        buf.write("\u0092\3\u0092\3\u0092\3\u0092\7\u0092\u0b63\n\u0092\f")
        buf.write("\u0092\16\u0092\u0b66\13\u0092\3\u0093\3\u0093\3\u0093")
        buf.write("\3\u0093\3\u0093\5\u0093\u0b6d\n\u0093\3\u0093\5\u0093")
        buf.write("\u0b70\n\u0093\3\u0093\3\u0093\3\u0093\3\u0093\5\u0093")
        buf.write("\u0b76\n\u0093\3\u0093\3\u0093\3\u0093\3\u0093\5\u0093")
        buf.write("\u0b7c\n\u0093\5\u0093\u0b7e\n\u0093\3\u0093\3\u0093\3")
        buf.write("\u0093\3\u0093\5\u0093\u0b84\n\u0093\3\u0093\5\u0093\u0b87")
        buf.write("\n\u0093\5\u0093\u0b89\n\u0093\3\u0093\3\u0093\3\u0093")
        buf.write("\3\u0093\5\u0093\u0b8f\n\u0093\5\u0093\u0b91\n\u0093\3")
        buf.write("\u0093\3\u0093\3\u0094\3\u0094\3\u0094\3\u0094\3\u0094")
        buf.write("\3\u0094\3\u0094\3\u0094\3\u0094\3\u0094\5\u0094\u0b9f")
        buf.write("\n\u0094\3\u0094\3\u0094\3\u0094\3\u0094\3\u0094\5\u0094")
        buf.write("\u0ba6\n\u0094\3\u0094\3\u0094\3\u0095\3\u0095\3\u0095")
        buf.write("\5\u0095\u0bad\n\u0095\3\u0095\3\u0095\3\u0095\3\u0095")
        buf.write("\3\u0095\5\u0095\u0bb4\n\u0095\3\u0095\3\u0095\3\u0096")
        buf.write("\3\u0096\3\u0096\5\u0096\u0bbb\n\u0096\3\u0096\3\u0096")
        buf.write("\3\u0097\3\u0097\3\u0097\5\u0097\u0bc2\n\u0097\3\u0097")
        buf.write("\3\u0097\3\u0097\3\u0097\3\u0097\5\u0097\u0bc9\n\u0097")
        buf.write("\3\u0097\3\u0097\3\u0098\3\u0098\5\u0098\u0bcf\n\u0098")
        buf.write("\3\u0099\3\u0099\3\u0099\5\u0099\u0bd4\n\u0099\3\u0099")
        buf.write("\3\u0099\3\u009a\3\u009a\3\u009a\7\u009a\u0bdb\n\u009a")
        buf.write("\f\u009a\16\u009a\u0bde\13\u009a\3\u009b\3\u009b\5\u009b")
        buf.write("\u0be2\n\u009b\3\u009c\3\u009c\3\u009d\3\u009d\3\u009e")
        buf.write("\5\u009e\u0be9\n\u009e\3\u009e\3\u009e\3\u009f\3\u009f")
        buf.write("\3\u009f\3\u009f\3\u009f\5\u009f\u0bf2\n\u009f\3\u00a0")
        buf.write("\3\u00a0\5\u00a0\u0bf6\n\u00a0\3\u00a0\3\u00a0\3\u00a0")
        buf.write("\3\u00a0\5\u00a0\u0bfc\n\u00a0\3\u00a0\5\u00a0\u0bff\n")
        buf.write("\u00a0\3\u00a1\3\u00a1\5\u00a1\u0c03\n\u00a1\3\u00a2\3")
        buf.write("\u00a2\3\u00a2\5\u00a2\u0c08\n\u00a2\3\u00a2\3\u00a2\5")
        buf.write("\u00a2\u0c0c\n\u00a2\3\u00a2\3\u00a2\5\u00a2\u0c10\n\u00a2")
        buf.write("\3\u00a2\3\u00a2\5\u00a2\u0c14\n\u00a2\3\u00a3\3\u00a3")
        buf.write("\3\u00a4\3\u00a4\3\u00a4\5\u00a4\u0c1b\n\u00a4\3\u00a5")
        buf.write("\3\u00a5\3\u00a6\3\u00a6\3\u00a6\3\u00a6\3\u00a6\3\u00a6")
        buf.write("\3\u00a6\3\u00a6\3\u00a6\3\u00a6\3\u00a6\3\u00a6\3\u00a6")
        buf.write("\3\u00a6\3\u00a6\5\u00a6\u0c2e\n\u00a6\3\u00a7\3\u00a7")
        buf.write("\3\u00a8\3\u00a8\5\u00a8\u0c34\n\u00a8\3\u00a8\2\4\u00ac")
        buf.write("\u00ba\u00a9\2\4\6\b\n\f\16\20\22\24\26\30\32\34\36 \"")
        buf.write("$&(*,.\60\62\64\668:<>@BDFHJLNPRTVXZ\\^`bdfhjlnprtvxz")
        buf.write("|~\u0080\u0082\u0084\u0086\u0088\u008a\u008c\u008e\u0090")
        buf.write("\u0092\u0094\u0096\u0098\u009a\u009c\u009e\u00a0\u00a2")
        buf.write("\u00a4\u00a6\u00a8\u00aa\u00ac\u00ae\u00b0\u00b2\u00b4")
        buf.write("\u00b6\u00b8\u00ba\u00bc\u00be\u00c0\u00c2\u00c4\u00c6")
        buf.write("\u00c8\u00ca\u00cc\u00ce\u00d0\u00d2\u00d4\u00d6\u00d8")
        buf.write("\u00da\u00dc\u00de\u00e0\u00e2\u00e4\u00e6\u00e8\u00ea")
        buf.write("\u00ec\u00ee\u00f0\u00f2\u00f4\u00f6\u00f8\u00fa\u00fc")
        buf.write("\u00fe\u0100\u0102\u0104\u0106\u0108\u010a\u010c\u010e")
        buf.write("\u0110\u0112\u0114\u0116\u0118\u011a\u011c\u011e\u0120")
        buf.write("\u0122\u0124\u0126\u0128\u012a\u012c\u012e\u0130\u0132")
        buf.write("\u0134\u0136\u0138\u013a\u013c\u013e\u0140\u0142\u0144")
        buf.write("\u0146\u0148\u014a\u014c\u014e\2<\3\2\u0194\u0195\4\2")
        buf.write("\u0194\u0194\u0197\u0197\4\2\u00f2\u00f2\u017a\u017a\4")
        buf.write("\2\u0194\u0195\u0197\u0197\4\2ll~~\4\2\n\n\65\65\3\2\u0085")
        buf.write("\u0086\4\2\u0144\u0145\u0151\u0151\4\2\177\177\u0160\u0160")
        buf.write("\5\2\u00fd\u00fd\u0163\u0163\u018a\u018a\5\2\u00a6\u00a6")
        buf.write("\u00cd\u00cd\u00f7\u00f7\4\2qqss\5\2\u00ee\u00ee\u0113")
        buf.write("\u0113\u012d\u012d\4\2\u010c\u010c\u0121\u0121\5\2\u00fb")
        buf.write("\u00fb\u013e\u013e\u0140\u0140\3\2\u0153\u0154\5\2\u0131")
        buf.write("\u0131\u015b\u015b\u016b\u016b\5\2\u00c5\u00c5\u00f8\u00f8")
        buf.write("\u0108\u0108\4\2\u0108\u0108\u016a\u016a\5\2OO\u00d7\u00d7")
        buf.write("\u016a\u016a\5\2ll\u00dd\u00dd\u017b\u017b\4\2\u012d\u012d")
        buf.write("\u0166\u0166\4\2\u00b8\u00b8\u0123\u0123\3\2\u0144\u0145")
        buf.write("\4\2\u00a6\u00a6\u00bb\u00bb\3\2\u00ac\u00ad\6\2\u00d8")
        buf.write("\u00d8\u0146\u0146\u0167\u0167\u0197\u0197\4\2\u0109\u0109")
        buf.write("\u0164\u0164\6\2\u00fa\u00fa\u0101\u0101\u011e\u011e\u016f")
        buf.write("\u016f\5\2\u0142\u0142\u0153\u0153\u0165\u0165\4\2\u00c3")
        buf.write("\u00c3\u0158\u0158\3\2\u01b4\u01b5\3\2\u01b1\u01b3\4\2")
        buf.write("\u01b4\u01b5\u01b7\u01b9\5\2\5\5\b\b\u00a3\u00a3\4\2\5")
        buf.write("\5\67\67\4\2\u015e\u015e\u0160\u0160\4\2\u0105\u0105\u0135")
        buf.write("\u0135\4\2{{\u0111\u0111\5\2hh\u00e1\u00e1\u0111\u0111")
        buf.write("\5\2hh\u0111\u0111\u0124\u0124\4\2UU\u015f\u015f\4\2n")
        buf.write("n\u0194\u0195\5\2OOcc\u0093\u0093\6\2hh\u0111\u0111\u0124")
        buf.write("\u0124\u0159\u0159\4\2\u0195\u0195\u0197\u0197\5\2\u00f5")
        buf.write("\u00f5\u0150\u0150\u0161\u0161\7\2\u00d4\u00d4\u0126\u0126")
        buf.write("\u012c\u012c\u0171\u0173\u0187\u0188\3\2\u00e5\u00e6\4")
        buf.write("\2\u014f\u014f\u0160\u0160\5\2OOqq\u0153\u0153\4\2\32")
        buf.write("\32kk\4\2\u0126\u0126\u0195\u0195\3\2\u0199\u019a\4\2")
        buf.write("\u0195\u0195\u0199\u0199-\2JJ\u00c3\u00c3\u00cb\u00cb")
        buf.write("\u00cd\u00cd\u00d4\u00d5\u00d8\u00da\u00de\u00df\u00e1")
        buf.write("\u00e1\u00e3\u00e6\u00f2\u00f2\u00f4\u00f5\u00f7\u00f7")
        buf.write("\u00fa\u00fa\u00fd\u00fd\u00ff\u0101\u0105\u010a\u010c")
        buf.write("\u010f\u0111\u0111\u0114\u0114\u0116\u0116\u0118\u011a")
        buf.write("\u011c\u0128\u012c\u012c\u0130\u0130\u0132\u0132\u0135")
        buf.write("\u0137\u0139\u0139\u013b\u013c\u013f\u0146\u0148\u014d")
        buf.write("\u014f\u0151\u0153\u0153\u0155\u0155\u0158\u015a\u015c")
        buf.write("\u0165\u0167\u0168\u016a\u016a\u016c\u0173\u0177\u017a")
        buf.write("\u017e\u017e\u0180\u0184\u0186\u018d\u0196\u0196\3\2\u019f")
        buf.write("\u01a6\7\2\u010b\u010b\u011b\u011b\u012a\u012a\u0176\u0176")
        buf.write("\u01b3\u01b3\u0e3f\2\u0153\3\2\2\2\4\u0158\3\2\2\2\6\u0160")
        buf.write("\3\2\2\2\b\u0168\3\2\2\2\n\u016e\3\2\2\2\f\u017f\3\2\2")
        buf.write("\2\16\u01fe\3\2\2\2\20\u0207\3\2\2\2\22\u020a\3\2\2\2")
        buf.write("\24\u0240\3\2\2\2\26\u0243\3\2\2\2\30\u0271\3\2\2\2\32")
        buf.write("\u0274\3\2\2\2\34\u0284\3\2\2\2\36\u02bf\3\2\2\2 \u02d7")
        buf.write("\3\2\2\2\"\u02ea\3\2\2\2$\u02ec\3\2\2\2&\u031d\3\2\2\2")
        buf.write("(\u0338\3\2\2\2*\u0361\3\2\2\2,\u0378\3\2\2\2.\u037a\3")
        buf.write("\2\2\2\60\u0399\3\2\2\2\62\u03af\3\2\2\2\64\u03cd\3\2")
        buf.write("\2\2\66\u03cf\3\2\2\28\u03f5\3\2\2\2:\u0422\3\2\2\2<\u0435")
        buf.write("\3\2\2\2>\u0437\3\2\2\2@\u0450\3\2\2\2B\u0452\3\2\2\2")
        buf.write("D\u045a\3\2\2\2F\u045c\3\2\2\2H\u045f\3\2\2\2J\u0462\3")
        buf.write("\2\2\2L\u0464\3\2\2\2N\u0466\3\2\2\2P\u0468\3\2\2\2R\u0485")
        buf.write("\3\2\2\2T\u0487\3\2\2\2V\u048a\3\2\2\2X\u0493\3\2\2\2")
        buf.write("Z\u049b\3\2\2\2\\\u04a2\3\2\2\2^\u04b9\3\2\2\2`\u04bb")
        buf.write("\3\2\2\2b\u04c6\3\2\2\2d\u04c8\3\2\2\2f\u04d6\3\2\2\2")
        buf.write("h\u04e0\3\2\2\2j\u04ea\3\2\2\2l\u04f4\3\2\2\2n\u0505\3")
        buf.write("\2\2\2p\u050c\3\2\2\2r\u0516\3\2\2\2t\u0518\3\2\2\2v\u051f")
        buf.write("\3\2\2\2x\u0545\3\2\2\2z\u0561\3\2\2\2|\u058c\3\2\2\2")
        buf.write("~\u0590\3\2\2\2\u0080\u059d\3\2\2\2\u0082\u05cf\3\2\2")
        buf.write("\2\u0084\u05eb\3\2\2\2\u0086\u0614\3\2\2\2\u0088\u0663")
        buf.write("\3\2\2\2\u008a\u0665\3\2\2\2\u008c\u0669\3\2\2\2\u008e")
        buf.write("\u066e\3\2\2\2\u0090\u0672\3\2\2\2\u0092\u067b\3\2\2\2")
        buf.write("\u0094\u0680\3\2\2\2\u0096\u068c\3\2\2\2\u0098\u068e\3")
        buf.write("\2\2\2\u009a\u06bf\3\2\2\2\u009c\u06dd\3\2\2\2\u009e\u0700")
        buf.write("\3\2\2\2\u00a0\u070c\3\2\2\2\u00a2\u0713\3\2\2\2\u00a4")
        buf.write("\u073a\3\2\2\2\u00a6\u074b\3\2\2\2\u00a8\u0794\3\2\2\2")
        buf.write("\u00aa\u0798\3\2\2\2\u00ac\u07c7\3\2\2\2\u00ae\u07e3\3")
        buf.write("\2\2\2\u00b0\u07e5\3\2\2\2\u00b2\u07e7\3\2\2\2\u00b4\u07f4")
        buf.write("\3\2\2\2\u00b6\u0810\3\2\2\2\u00b8\u0812\3\2\2\2\u00ba")
        buf.write("\u081a\3\2\2\2\u00bc\u0862\3\2\2\2\u00be\u0869\3\2\2\2")
        buf.write("\u00c0\u0877\3\2\2\2\u00c2\u0884\3\2\2\2\u00c4\u08a8\3")
        buf.write("\2\2\2\u00c6\u08b1\3\2\2\2\u00c8\u08db\3\2\2\2\u00ca\u08dd")
        buf.write("\3\2\2\2\u00cc\u08e4\3\2\2\2\u00ce\u08e8\3\2\2\2\u00d0")
        buf.write("\u08ea\3\2\2\2\u00d2\u0923\3\2\2\2\u00d4\u0925\3\2\2\2")
        buf.write("\u00d6\u092b\3\2\2\2\u00d8\u0948\3\2\2\2\u00da\u094a\3")
        buf.write("\2\2\2\u00dc\u0957\3\2\2\2\u00de\u0959\3\2\2\2\u00e0\u0983")
        buf.write("\3\2\2\2\u00e2\u0985\3\2\2\2\u00e4\u09a7\3\2\2\2\u00e6")
        buf.write("\u09a9\3\2\2\2\u00e8\u09c7\3\2\2\2\u00ea\u09c9\3\2\2\2")
        buf.write("\u00ec\u09d2\3\2\2\2\u00ee\u0a35\3\2\2\2\u00f0\u0a37\3")
        buf.write("\2\2\2\u00f2\u0a3c\3\2\2\2\u00f4\u0a42\3\2\2\2\u00f6\u0a46")
        buf.write("\3\2\2\2\u00f8\u0a4b\3\2\2\2\u00fa\u0a58\3\2\2\2\u00fc")
        buf.write("\u0a65\3\2\2\2\u00fe\u0a91\3\2\2\2\u0100\u0a93\3\2\2\2")
        buf.write("\u0102\u0aa0\3\2\2\2\u0104\u0aa2\3\2\2\2\u0106\u0aa4\3")
        buf.write("\2\2\2\u0108\u0ab2\3\2\2\2\u010a\u0ac4\3\2\2\2\u010c\u0aef")
        buf.write("\3\2\2\2\u010e\u0af1\3\2\2\2\u0110\u0af3\3\2\2\2\u0112")
        buf.write("\u0b02\3\2\2\2\u0114\u0b0b\3\2\2\2\u0116\u0b0f\3\2\2\2")
        buf.write("\u0118\u0b17\3\2\2\2\u011a\u0b1d\3\2\2\2\u011c\u0b41\3")
        buf.write("\2\2\2\u011e\u0b43\3\2\2\2\u0120\u0b50\3\2\2\2\u0122\u0b52")
        buf.write("\3\2\2\2\u0124\u0b67\3\2\2\2\u0126\u0ba5\3\2\2\2\u0128")
        buf.write("\u0bb3\3\2\2\2\u012a\u0bba\3\2\2\2\u012c\u0bc8\3\2\2\2")
        buf.write("\u012e\u0bce\3\2\2\2\u0130\u0bd3\3\2\2\2\u0132\u0bd7\3")
        buf.write("\2\2\2\u0134\u0be1\3\2\2\2\u0136\u0be3\3\2\2\2\u0138\u0be5")
        buf.write("\3\2\2\2\u013a\u0be8\3\2\2\2\u013c\u0bf1\3\2\2\2\u013e")
        buf.write("\u0bf3\3\2\2\2\u0140\u0c02\3\2\2\2\u0142\u0c13\3\2\2\2")
        buf.write("\u0144\u0c15\3\2\2\2\u0146\u0c1a\3\2\2\2\u0148\u0c1c\3")
        buf.write("\2\2\2\u014a\u0c2d\3\2\2\2\u014c\u0c2f\3\2\2\2\u014e\u0c31")
        buf.write("\3\2\2\2\u0150\u0152\5\4\3\2\u0151\u0150\3\2\2\2\u0152")
        buf.write("\u0155\3\2\2\2\u0153\u0151\3\2\2\2\u0153\u0154\3\2\2\2")
        buf.write("\u0154\u0156\3\2\2\2\u0155\u0153\3\2\2\2\u0156\u0157\7")
        buf.write("\2\2\3\u0157\3\3\2\2\2\u0158\u015a\5\6\4\2\u0159\u015b")
        buf.write("\5\u008aF\2\u015a\u0159\3\2\2\2\u015a\u015b\3\2\2\2\u015b")
        buf.write("\5\3\2\2\2\u015c\u015e\5\b\5\2\u015d\u015f\7\u01af\2\2")
        buf.write("\u015e\u015d\3\2\2\2\u015e\u015f\3\2\2\2\u015f\u0161\3")
        buf.write("\2\2\2\u0160\u015c\3\2\2\2\u0161\u0162\3\2\2\2\u0162\u0160")
        buf.write("\3\2\2\2\u0162\u0163\3\2\2\2\u0163\7\3\2\2\2\u0164\u0169")
        buf.write("\5\n\6\2\u0165\u0169\5\f\7\2\u0166\u0169\5\16\b\2\u0167")
        buf.write("\u0169\5\20\t\2\u0168\u0164\3\2\2\2\u0168\u0165\3\2\2")
        buf.write("\2\u0168\u0166\3\2\2\2\u0168\u0167\3\2\2\2\u0169\t\3\2")
        buf.write("\2\2\u016a\u016f\5\22\n\2\u016b\u016f\5\26\f\2\u016c\u016f")
        buf.write("\5\32\16\2\u016d\u016f\5\34\17\2\u016e\u016a\3\2\2\2\u016e")
        buf.write("\u016b\3\2\2\2\u016e\u016c\3\2\2\2\u016e\u016d\3\2\2\2")
        buf.write("\u016f\13\3\2\2\2\u0170\u0180\5$\23\2\u0171\u0180\5&\24")
        buf.write("\2\u0172\u0180\5(\25\2\u0173\u0180\5.\30\2\u0174\u0180")
        buf.write("\5\60\31\2\u0175\u0180\5n8\2\u0176\u0180\5\62\32\2\u0177")
        buf.write("\u0180\5\66\34\2\u0178\u0180\58\35\2\u0179\u0180\5d\63")
        buf.write("\2\u017a\u0180\5f\64\2\u017b\u0180\5h\65\2\u017c\u0180")
        buf.write("\5j\66\2\u017d\u0180\5p9\2\u017e\u0180\5l\67\2\u017f\u0170")
        buf.write("\3\2\2\2\u017f\u0171\3\2\2\2\u017f\u0172\3\2\2\2\u017f")
        buf.write("\u0173\3\2\2\2\u017f\u0174\3\2\2\2\u017f\u0175\3\2\2\2")
        buf.write("\u017f\u0176\3\2\2\2\u017f\u0177\3\2\2\2\u017f\u0178\3")
        buf.write("\2\2\2\u017f\u0179\3\2\2\2\u017f\u017a\3\2\2\2\u017f\u017b")
        buf.write("\3\2\2\2\u017f\u017c\3\2\2\2\u017f\u017d\3\2\2\2\u017f")
        buf.write("\u017e\3\2\2\2\u0180\r\3\2\2\2\u0181\u0183\7\r\2\2\u0182")
        buf.write("\u0184\7\u01af\2\2\u0183\u0182\3\2\2\2\u0183\u0184\3\2")
        buf.write("\2\2\u0184\u0186\3\2\2\2\u0185\u0187\5\6\4\2\u0186\u0185")
        buf.write("\3\2\2\2\u0186\u0187\3\2\2\2\u0187\u0188\3\2\2\2\u0188")
        buf.write("\u018a\7=\2\2\u0189\u018b\7\u01af\2\2\u018a\u0189\3\2")
        buf.write("\2\2\u018a\u018b\3\2\2\2\u018b\u01ff\3\2\2\2\u018c\u018e")
        buf.write("\7\17\2\2\u018d\u018f\7\u01af\2\2\u018e\u018d\3\2\2\2")
        buf.write("\u018e\u018f\3\2\2\2\u018f\u01ff\3\2\2\2\u0190\u0192\7")
        buf.write("$\2\2\u0191\u0193\7\u01af\2\2\u0192\u0191\3\2\2\2\u0192")
        buf.write("\u0193\3\2\2\2\u0193\u01ff\3\2\2\2\u0194\u0195\7Q\2\2")
        buf.write("\u0195\u0197\5\u0146\u00a4\2\u0196\u0198\7\u01af\2\2\u0197")
        buf.write("\u0196\3\2\2\2\u0197\u0198\3\2\2\2\u0198\u01ff\3\2\2\2")
        buf.write("\u0199\u019a\5\u0146\u00a4\2\u019a\u019c\7\u01b0\2\2\u019b")
        buf.write("\u019d\7\u01af\2\2\u019c\u019b\3\2\2\2\u019c\u019d\3\2")
        buf.write("\2\2\u019d\u01ff\3\2\2\2\u019e\u019f\7X\2\2\u019f\u01a0")
        buf.write("\5\u00ba^\2\u01a0\u01a3\5\b\5\2\u01a1\u01a2\7<\2\2\u01a2")
        buf.write("\u01a4\5\b\5\2\u01a3\u01a1\3\2\2\2\u01a3\u01a4\3\2\2\2")
        buf.write("\u01a4\u01a6\3\2\2\2\u01a5\u01a7\7\u01af\2\2\u01a6\u01a5")
        buf.write("\3\2\2\2\u01a6\u01a7\3\2\2\2\u01a7\u01ff\3\2\2\2\u01a8")
        buf.write("\u01aa\7\u0090\2\2\u01a9\u01ab\5\u00acW\2\u01aa\u01a9")
        buf.write("\3\2\2\2\u01aa\u01ab\3\2\2\2\u01ab\u01ad\3\2\2\2\u01ac")
        buf.write("\u01ae\7\u01af\2\2\u01ad\u01ac\3\2\2\2\u01ad\u01ae\3\2")
        buf.write("\2\2\u01ae\u01ff\3\2\2\2\u01af\u01b5\7\u0178\2\2\u01b0")
        buf.write("\u01b1\t\2\2\2\u01b1\u01b2\7\u01ae\2\2\u01b2\u01b3\t\3")
        buf.write("\2\2\u01b3\u01b4\7\u01ae\2\2\u01b4\u01b6\t\2\2\2\u01b5")
        buf.write("\u01b0\3\2\2\2\u01b5\u01b6\3\2\2\2\u01b6\u01b8\3\2\2\2")
        buf.write("\u01b7\u01b9\7\u01af\2\2\u01b8\u01b7\3\2\2\2\u01b8\u01b9")
        buf.write("\3\2\2\2\u01b9\u01ff\3\2\2\2\u01ba\u01bb\7\r\2\2\u01bb")
        buf.write("\u01bd\7\u017e\2\2\u01bc\u01be\7\u01af\2\2\u01bd\u01bc")
        buf.write("\3\2\2\2\u01bd\u01be\3\2\2\2\u01be\u01c0\3\2\2\2\u01bf")
        buf.write("\u01c1\5\6\4\2\u01c0\u01bf\3\2\2\2\u01c0\u01c1\3\2\2\2")
        buf.write("\u01c1\u01c2\3\2\2\2\u01c2\u01c3\7=\2\2\u01c3\u01c5\7")
        buf.write("\u017e\2\2\u01c4\u01c6\7\u01af\2\2\u01c5\u01c4\3\2\2\2")
        buf.write("\u01c5\u01c6\3\2\2\2\u01c6\u01c7\3\2\2\2\u01c7\u01c8\7")
        buf.write("\r\2\2\u01c8\u01ca\7\u00da\2\2\u01c9\u01cb\7\u01af\2\2")
        buf.write("\u01ca\u01c9\3\2\2\2\u01ca\u01cb\3\2\2\2\u01cb\u01cd\3")
        buf.write("\2\2\2\u01cc\u01ce\5\6\4\2\u01cd\u01cc\3\2\2\2\u01cd\u01ce")
        buf.write("\3\2\2\2\u01ce\u01cf\3\2\2\2\u01cf\u01d0\7=\2\2\u01d0")
        buf.write("\u01d2\7\u00da\2\2\u01d1\u01d3\7\u01af\2\2\u01d2\u01d1")
        buf.write("\3\2\2\2\u01d2\u01d3\3\2\2\2\u01d3\u01ff\3\2\2\2\u01d4")
        buf.write("\u01d5\7\u00bc\2\2\u01d5\u01d6\t\4\2\2\u01d6\u01d8\5\u00ac")
        buf.write("W\2\u01d7\u01d9\7\u01af\2\2\u01d8\u01d7\3\2\2\2\u01d8")
        buf.write("\u01d9\3\2\2\2\u01d9\u01ff\3\2\2\2\u01da\u01db\7\u00bf")
        buf.write("\2\2\u01db\u01e5\5\u00ba^\2\u01dc\u01e6\5\b\5\2\u01dd")
        buf.write("\u01df\7\17\2\2\u01de\u01e0\7\u01af\2\2\u01df\u01de\3")
        buf.write("\2\2\2\u01df\u01e0\3\2\2\2\u01e0\u01e6\3\2\2\2\u01e1\u01e3")
        buf.write("\7$\2\2\u01e2\u01e4\7\u01af\2\2\u01e3\u01e2\3\2\2\2\u01e3")
        buf.write("\u01e4\3\2\2\2\u01e4\u01e6\3\2\2\2\u01e5\u01dc\3\2\2\2")
        buf.write("\u01e5\u01dd\3\2\2\2\u01e5\u01e1\3\2\2\2\u01e6\u01ff\3")
        buf.write("\2\2\2\u01e7\u01e8\7\u0084\2\2\u01e8\u01ea\5\u00acW\2")
        buf.write("\u01e9\u01eb\7\u01af\2\2\u01ea\u01e9\3\2\2\2\u01ea\u01eb")
        buf.write("\3\2\2\2\u01eb\u01ff\3\2\2\2\u01ec\u01ed\7\u0088\2\2\u01ed")
        buf.write("\u01ee\7\u01ac\2\2\u01ee\u01ef\t\5\2\2\u01ef\u01f0\7\u01ae")
        buf.write("\2\2\u01f0\u01f1\5\u00aaV\2\u01f1\u01f2\7\u01ae\2\2\u01f2")
        buf.write("\u01f7\5\u00aaV\2\u01f3\u01f4\7\u01ae\2\2\u01f4\u01f6")
        buf.write("\5\u00aaV\2\u01f5\u01f3\3\2\2\2\u01f6\u01f9\3\2\2\2\u01f7")
        buf.write("\u01f5\3\2\2\2\u01f7\u01f8\3\2\2\2\u01f8\u01fa\3\2\2\2")
        buf.write("\u01f9\u01f7\3\2\2\2\u01fa\u01fc\7\u01ad\2\2\u01fb\u01fd")
        buf.write("\7\u01af\2\2\u01fc\u01fb\3\2\2\2\u01fc\u01fd\3\2\2\2\u01fd")
        buf.write("\u01ff\3\2\2\2\u01fe\u0181\3\2\2\2\u01fe\u018c\3\2\2\2")
        buf.write("\u01fe\u0190\3\2\2\2\u01fe\u0194\3\2\2\2\u01fe\u0199\3")
        buf.write("\2\2\2\u01fe\u019e\3\2\2\2\u01fe\u01a8\3\2\2\2\u01fe\u01af")
        buf.write("\3\2\2\2\u01fe\u01ba\3\2\2\2\u01fe\u01d4\3\2\2\2\u01fe")
        buf.write("\u01da\3\2\2\2\u01fe\u01e7\3\2\2\2\u01fe\u01ec\3\2\2\2")
        buf.write("\u01ff\17\3\2\2\2\u0200\u0208\5x=\2\u0201\u0208\5z>\2")
        buf.write("\u0202\u0208\5|?\2\u0203\u0208\5\u0082B\2\u0204\u0208")
        buf.write("\5\u0086D\2\u0205\u0208\5\u0088E\2\u0206\u0208\5\u008c")
        buf.write("G\2\u0207\u0200\3\2\2\2\u0207\u0201\3\2\2\2\u0207\u0202")
        buf.write("\3\2\2\2\u0207\u0203\3\2\2\2\u0207\u0204\3\2\2\2\u0207")
        buf.write("\u0205\3\2\2\2\u0207\u0206\3\2\2\2\u0208\21\3\2\2\2\u0209")
        buf.write("\u020b\5\u00b2Z\2\u020a\u0209\3\2\2\2\u020a\u020b\3\2")
        buf.write("\2\2\u020b\u020c\3\2\2\2\u020c\u0214\7\63\2\2\u020d\u020e")
        buf.write("\7\u00ab\2\2\u020e\u020f\7\u01ac\2\2\u020f\u0210\5\u00ac")
        buf.write("W\2\u0210\u0212\7\u01ad\2\2\u0211\u0213\7\177\2\2\u0212")
        buf.write("\u0211\3\2\2\2\u0212\u0213\3\2\2\2\u0213\u0215\3\2\2\2")
        buf.write("\u0214\u020d\3\2\2\2\u0214\u0215\3\2\2\2\u0215\u0217\3")
        buf.write("\2\2\2\u0216\u0218\7N\2\2\u0217\u0216\3\2\2\2\u0217\u0218")
        buf.write("\3\2\2\2\u0218\u0219\3\2\2\2\u0219\u021b\5\24\13\2\u021a")
        buf.write("\u021c\5\u00fa~\2\u021b\u021a\3\2\2\2\u021b\u021c\3\2")
        buf.write("\2\2\u021c\u021e\3\2\2\2\u021d\u021f\5\36\20\2\u021e\u021d")
        buf.write("\3\2\2\2\u021e\u021f\3\2\2\2\u021f\u0222\3\2\2\2\u0220")
        buf.write("\u0221\7N\2\2\u0221\u0223\5\u00dan\2\u0222\u0220\3\2\2")
        buf.write("\2\u0222\u0223\3\2\2\2\u0223\u0231\3\2\2\2\u0224\u022f")
        buf.write("\7\u00be\2\2\u0225\u0230\5\u00ba^\2\u0226\u0227\7(\2\2")
        buf.write("\u0227\u022d\7p\2\2\u0228\u022a\7\u010c\2\2\u0229\u0228")
        buf.write("\3\2\2\2\u0229\u022a\3\2\2\2\u022a\u022b\3\2\2\2\u022b")
        buf.write("\u022e\5\u0134\u009b\2\u022c\u022e\7\u0194\2\2\u022d\u0229")
        buf.write("\3\2\2\2\u022d\u022c\3\2\2\2\u022e\u0230\3\2\2\2\u022f")
        buf.write("\u0225\3\2\2\2\u022f\u0226\3\2\2\2\u0230\u0232\3\2\2\2")
        buf.write("\u0231\u0224\3\2\2\2\u0231\u0232\3\2\2\2\u0232\u0234\3")
        buf.write("\2\2\2\u0233\u0235\5\u00c8e\2\u0234\u0233\3\2\2\2\u0234")
        buf.write("\u0235\3\2\2\2\u0235\u0237\3\2\2\2\u0236\u0238\5\u00d0")
        buf.write("i\2\u0237\u0236\3\2\2\2\u0237\u0238\3\2\2\2\u0238\u023a")
        buf.write("\3\2\2\2\u0239\u023b\7\u01af\2\2\u023a\u0239\3\2\2\2\u023a")
        buf.write("\u023b\3\2\2\2\u023b\23\3\2\2\2\u023c\u0241\5\u00f6|\2")
        buf.write("\u023d\u0241\5\u012e\u0098\2\u023e\u0241\5r:\2\u023f\u0241")
        buf.write("\7\u0194\2\2\u0240\u023c\3\2\2\2\u0240\u023d\3\2\2\2\u0240")
        buf.write("\u023e\3\2\2\2\u0240\u023f\3\2\2\2\u0241\25\3\2\2\2\u0242")
        buf.write("\u0244\5\u00b2Z\2\u0243\u0242\3\2\2\2\u0243\u0244\3\2")
        buf.write("\2\2\u0244\u0245\3\2\2\2\u0245\u024d\7\\\2\2\u0246\u0247")
        buf.write("\7\u00ab\2\2\u0247\u0248\7\u01ac\2\2\u0248\u0249\5\u00ac")
        buf.write("W\2\u0249\u024b\7\u01ad\2\2\u024a\u024c\7\177\2\2\u024b")
        buf.write("\u024a\3\2\2\2\u024b\u024c\3\2\2\2\u024c\u024e\3\2\2\2")
        buf.write("\u024d\u0246\3\2\2\2\u024d\u024e\3\2\2\2\u024e\u0250\3")
        buf.write("\2\2\2\u024f\u0251\7^\2\2\u0250\u024f\3\2\2\2\u0250\u0251")
        buf.write("\3\2\2\2\u0251\u0254\3\2\2\2\u0252\u0255\5\u012e\u0098")
        buf.write("\2\u0253\u0255\5r:\2\u0254\u0252\3\2\2\2\u0254\u0253\3")
        buf.write("\2\2\2\u0255\u0257\3\2\2\2\u0256\u0258\5\u00fa~\2\u0257")
        buf.write("\u0256\3\2\2\2\u0257\u0258\3\2\2\2\u0258\u025d\3\2\2\2")
        buf.write("\u0259\u025a\7\u01ac\2\2\u025a\u025b\5\u0132\u009a\2\u025b")
        buf.write("\u025c\7\u01ad\2\2\u025c\u025e\3\2\2\2\u025d\u0259\3\2")
        buf.write("\2\2\u025d\u025e\3\2\2\2\u025e\u0260\3\2\2\2\u025f\u0261")
        buf.write("\5\36\20\2\u0260\u025f\3\2\2\2\u0260\u0261\3\2\2\2\u0261")
        buf.write("\u0262\3\2\2\2\u0262\u0264\5\30\r\2\u0263\u0265\5\u00c8")
        buf.write("e\2\u0264\u0263\3\2\2\2\u0264\u0265\3\2\2\2\u0265\u0267")
        buf.write("\3\2\2\2\u0266\u0268\5\u00d0i\2\u0267\u0266\3\2\2\2\u0267")
        buf.write("\u0268\3\2\2\2\u0268\u026a\3\2\2\2\u0269\u026b\7\u01af")
        buf.write("\2\2\u026a\u0269\3\2\2\2\u026a\u026b\3\2\2\2\u026b\27")
        buf.write("\3\2\2\2\u026c\u0272\5\u0106\u0084\2\u026d\u0272\5\u00ec")
        buf.write("w\2\u026e\u0272\5|?\2\u026f\u0270\7\62\2\2\u0270\u0272")
        buf.write("\7\u00b9\2\2\u0271\u026c\3\2\2\2\u0271\u026d\3\2\2\2\u0271")
        buf.write("\u026e\3\2\2\2\u0271\u026f\3\2\2\2\u0272\31\3\2\2\2\u0273")
        buf.write("\u0275\5\u00b2Z\2\u0274\u0273\3\2\2\2\u0274\u0275\3\2")
        buf.write("\2\2\u0275\u0276\3\2\2\2\u0276\u0278\5\u00be`\2\u0277")
        buf.write("\u0279\5\u00c6d\2\u0278\u0277\3\2\2\2\u0278\u0279\3\2")
        buf.write("\2\2\u0279\u027b\3\2\2\2\u027a\u027c\5\u00c8e\2\u027b")
        buf.write("\u027a\3\2\2\2\u027b\u027c\3\2\2\2\u027c\u027e\3\2\2\2")
        buf.write("\u027d\u027f\5\u00d0i\2\u027e\u027d\3\2\2\2\u027e\u027f")
        buf.write("\3\2\2\2\u027f\u0281\3\2\2\2\u0280\u0282\7\u01af\2\2\u0281")
        buf.write("\u0280\3\2\2\2\u0281\u0282\3\2\2\2\u0282\33\3\2\2\2\u0283")
        buf.write("\u0285\5\u00b2Z\2\u0284\u0283\3\2\2\2\u0284\u0285\3\2")
        buf.write("\2\2\u0285\u0286\3\2\2\2\u0286\u028e\7\u00b5\2\2\u0287")
        buf.write("\u0288\7\u00ab\2\2\u0288\u0289\7\u01ac\2\2\u0289\u028a")
        buf.write("\5\u00acW\2\u028a\u028c\7\u01ad\2\2\u028b\u028d\7\177")
        buf.write("\2\2\u028c\u028b\3\2\2\2\u028c\u028d\3\2\2\2\u028d\u028f")
        buf.write("\3\2\2\2\u028e\u0287\3\2\2\2\u028e\u028f\3\2\2\2\u028f")
        buf.write("\u0292\3\2\2\2\u0290\u0293\5\u012e\u0098\2\u0291\u0293")
        buf.write("\5r:\2\u0292\u0290\3\2\2\2\u0292\u0291\3\2\2\2\u0293\u0295")
        buf.write("\3\2\2\2\u0294\u0296\5\u00f8}\2\u0295\u0294\3\2\2\2\u0295")
        buf.write("\u0296\3\2\2\2\u0296\u0297\3\2\2\2\u0297\u0298\7\u00a0")
        buf.write("\2\2\u0298\u029d\5\u00b6\\\2\u0299\u029a\7\u01ae\2\2\u029a")
        buf.write("\u029c\5\u00b6\\\2\u029b\u0299\3\2\2\2\u029c\u029f\3\2")
        buf.write("\2\2\u029d\u029b\3\2\2\2\u029d\u029e\3\2\2\2\u029e\u02a1")
        buf.write("\3\2\2\2\u029f\u029d\3\2\2\2\u02a0\u02a2\5\36\20\2\u02a1")
        buf.write("\u02a0\3\2\2\2\u02a1\u02a2\3\2\2\2\u02a2\u02a5\3\2\2\2")
        buf.write("\u02a3\u02a4\7N\2\2\u02a4\u02a6\5\u00dan\2\u02a5\u02a3")
        buf.write("\3\2\2\2\u02a5\u02a6\3\2\2\2\u02a6\u02b4\3\2\2\2\u02a7")
        buf.write("\u02b2\7\u00be\2\2\u02a8\u02b3\5\u00b8]\2\u02a9\u02aa")
        buf.write("\7(\2\2\u02aa\u02b0\7p\2\2\u02ab\u02ad\7\u010c\2\2\u02ac")
        buf.write("\u02ab\3\2\2\2\u02ac\u02ad\3\2\2\2\u02ad\u02ae\3\2\2\2")
        buf.write("\u02ae\u02b1\5\u0134\u009b\2\u02af\u02b1\7\u0194\2\2\u02b0")
        buf.write("\u02ac\3\2\2\2\u02b0\u02af\3\2\2\2\u02b1\u02b3\3\2\2\2")
        buf.write("\u02b2\u02a8\3\2\2\2\u02b2\u02a9\3\2\2\2\u02b3\u02b5\3")
        buf.write("\2\2\2\u02b4\u02a7\3\2\2\2\u02b4\u02b5\3\2\2\2\u02b5\u02b7")
        buf.write("\3\2\2\2\u02b6\u02b8\5\u00c8e\2\u02b7\u02b6\3\2\2\2\u02b7")
        buf.write("\u02b8\3\2\2\2\u02b8\u02ba\3\2\2\2\u02b9\u02bb\5\u00d0")
        buf.write("i\2\u02ba\u02b9\3\2\2\2\u02ba\u02bb\3\2\2\2\u02bb\u02bd")
        buf.write("\3\2\2\2\u02bc\u02be\7\u01af\2\2\u02bd\u02bc\3\2\2\2\u02bd")
        buf.write("\u02be\3\2\2\2\u02be\35\3\2\2\2\u02bf\u02c0\7\u0145\2")
        buf.write("\2\u02c0\u02c5\5 \21\2\u02c1\u02c2\7\u01ae\2\2\u02c2\u02c4")
        buf.write("\5 \21\2\u02c3\u02c1\3\2\2\2\u02c4\u02c7\3\2\2\2\u02c5")
        buf.write("\u02c3\3\2\2\2\u02c5\u02c6\3\2\2\2\u02c6\u02d3\3\2\2\2")
        buf.write("\u02c7\u02c5\3\2\2\2\u02c8\u02cb\7^\2\2\u02c9\u02cc\7")
        buf.write("\u0194\2\2\u02ca\u02cc\5\u0128\u0095\2\u02cb\u02c9\3\2")
        buf.write("\2\2\u02cb\u02ca\3\2\2\2\u02cc\u02d1\3\2\2\2\u02cd\u02ce")
        buf.write("\7\u01ac\2\2\u02ce\u02cf\5\u0132\u009a\2\u02cf\u02d0\7")
        buf.write("\u01ad\2\2\u02d0\u02d2\3\2\2\2\u02d1\u02cd\3\2\2\2\u02d1")
        buf.write("\u02d2\3\2\2\2\u02d2\u02d4\3\2\2\2\u02d3\u02c8\3\2\2\2")
        buf.write("\u02d3\u02d4\3\2\2\2\u02d4\37\3\2\2\2\u02d5\u02d8\5\"")
        buf.write("\22\2\u02d6\u02d8\5\u00acW\2\u02d7\u02d5\3\2\2\2\u02d7")
        buf.write("\u02d6\3\2\2\2\u02d8\u02dd\3\2\2\2\u02d9\u02db\7\t\2\2")
        buf.write("\u02da\u02d9\3\2\2\2\u02da\u02db\3\2\2\2\u02db\u02dc\3")
        buf.write("\2\2\2\u02dc\u02de\5\u0102\u0082\2\u02dd\u02da\3\2\2\2")
        buf.write("\u02dd\u02de\3\2\2\2\u02de!\3\2\2\2\u02df\u02e3\7\u00f4")
        buf.write("\2\2\u02e0\u02e3\7\u0119\2\2\u02e1\u02e3\5\u0128\u0095")
        buf.write("\2\u02e2\u02df\3\2\2\2\u02e2\u02e0\3\2\2\2\u02e2\u02e1")
        buf.write("\3\2\2\2\u02e3\u02e4\3\2\2\2\u02e4\u02e7\7\u01a7\2\2\u02e5")
        buf.write("\u02e8\7\u01b1\2\2\u02e6\u02e8\5\u0146\u00a4\2\u02e7\u02e5")
        buf.write("\3\2\2\2\u02e7\u02e6\3\2\2\2\u02e8\u02eb\3\2\2\2\u02e9")
        buf.write("\u02eb\7\u018e\2\2\u02ea\u02e2\3\2\2\2\u02ea\u02e9\3\2")
        buf.write("\2\2\u02eb#\3\2\2\2\u02ec\u02ed\7&\2\2\u02ed\u02ee\7.")
        buf.write("\2\2\u02ee\u02f2\5\u0146\u00a4\2\u02ef\u02f0\7!\2\2\u02f0")
        buf.write("\u02f1\7\u019b\2\2\u02f1\u02f3\t\6\2\2\u02f2\u02ef\3\2")
        buf.write("\2\2\u02f2\u02f3\3\2\2\2\u02f3\u0300\3\2\2\2\u02f4\u02f6")
        buf.write("\7s\2\2\u02f5\u02f7\7\u0083\2\2\u02f6\u02f5\3\2\2\2\u02f6")
        buf.write("\u02f7\3\2\2\2\u02f7\u02f8\3\2\2\2\u02f8\u02fd\5\u0120")
        buf.write("\u0091\2\u02f9\u02fa\7\u01ae\2\2\u02fa\u02fc\5\u0120\u0091")
        buf.write("\2\u02fb\u02f9\3\2\2\2\u02fc\u02ff\3\2\2\2\u02fd\u02fb")
        buf.write("\3\2\2\2\u02fd\u02fe\3\2\2\2\u02fe\u0301\3\2\2\2\u02ff")
        buf.write("\u02fd\3\2\2\2\u0300\u02f4\3\2\2\2\u0300\u0301\3\2\2\2")
        buf.write("\u0301\u030c\3\2\2\2\u0302\u0303\7g\2\2\u0303\u0304\7")
        buf.write("s\2\2\u0304\u0309\5\u0120\u0091\2\u0305\u0306\7\u01ae")
        buf.write("\2\2\u0306\u0308\5\u0120\u0091\2\u0307\u0305\3\2\2\2\u0308")
        buf.write("\u030b\3\2\2\2\u0309\u0307\3\2\2\2\u0309\u030a\3\2\2\2")
        buf.write("\u030a\u030d\3\2\2\2\u030b\u0309\3\2\2\2\u030c\u0302\3")
        buf.write("\2\2\2\u030c\u030d\3\2\2\2\u030d\u0310\3\2\2\2\u030e\u030f")
        buf.write("\7\34\2\2\u030f\u0311\5\u0146\u00a4\2\u0310\u030e\3\2")
        buf.write("\2\2\u0310\u0311\3\2\2\2\u0311\u031b\3\2\2\2\u0312\u0313")
        buf.write("\7\u00c0\2\2\u0313\u0318\5\u011c\u008f\2\u0314\u0315\7")
        buf.write("\u01ae\2\2\u0315\u0317\5\u011c\u008f\2\u0316\u0314\3\2")
        buf.write("\2\2\u0317\u031a\3\2\2\2\u0318\u0316\3\2\2\2\u0318\u0319")
        buf.write("\3\2\2\2\u0319\u031c\3\2\2\2\u031a\u0318\3\2\2\2\u031b")
        buf.write("\u0312\3\2\2\2\u031b\u031c\3\2\2\2\u031c%\3\2\2\2\u031d")
        buf.write("\u031f\7&\2\2\u031e\u0320\7\u00b3\2\2\u031f\u031e\3\2")
        buf.write("\2\2\u031f\u0320\3\2\2\2\u0320\u0322\3\2\2\2\u0321\u0323")
        buf.write("\5\u0138\u009d\2\u0322\u0321\3\2\2\2\u0322\u0323\3\2\2")
        buf.write("\2\u0323\u0324\3\2\2\2\u0324\u0325\7Z\2\2\u0325\u0326")
        buf.write("\5\u0146\u00a4\2\u0326\u0327\7s\2\2\u0327\u0328\5\u00e6")
        buf.write("t\2\u0328\u0329\7\u01ac\2\2\u0329\u032b\5\u0132\u009a")
        buf.write("\2\u032a\u032c\t\7\2\2\u032b\u032a\3\2\2\2\u032b\u032c")
        buf.write("\3\2\2\2\u032c\u032d\3\2\2\2\u032d\u032f\7\u01ad\2\2\u032e")
        buf.write("\u0330\5\u009eP\2\u032f\u032e\3\2\2\2\u032f\u0330\3\2")
        buf.write("\2\2\u0330\u0333\3\2\2\2\u0331\u0332\7s\2\2\u0332\u0334")
        buf.write("\5\u0146\u00a4\2\u0333\u0331\3\2\2\2\u0333\u0334\3\2\2")
        buf.write("\2\u0334\u0336\3\2\2\2\u0335\u0337\7\u01af\2\2\u0336\u0335")
        buf.write("\3\2\2\2\u0336\u0337\3\2\2\2\u0337\'\3\2\2\2\u0338\u0339")
        buf.write("\7&\2\2\u0339\u033a\t\b\2\2\u033a\u033d\5\u012c\u0097")
        buf.write("\2\u033b\u033c\7\u01af\2\2\u033c\u033e\7\u0195\2\2\u033d")
        buf.write("\u033b\3\2\2\2\u033d\u033e\3\2\2\2\u033e\u034d\3\2\2\2")
        buf.write("\u033f\u0341\7\u01ac\2\2\u0340\u033f\3\2\2\2\u0340\u0341")
        buf.write("\3\2\2\2\u0341\u0342\3\2\2\2\u0342\u0347\5*\26\2\u0343")
        buf.write("\u0344\7\u01ae\2\2\u0344\u0346\5*\26\2\u0345\u0343\3\2")
        buf.write("\2\2\u0346\u0349\3\2\2\2\u0347\u0345\3\2\2\2\u0347\u0348")
        buf.write("\3\2\2\2\u0348\u034b\3\2\2\2\u0349\u0347\3\2\2\2\u034a")
        buf.write("\u034c\7\u01ad\2\2\u034b\u034a\3\2\2\2\u034b\u034c\3\2")
        buf.write("\2\2\u034c\u034e\3\2\2\2\u034d\u0340\3\2\2\2\u034d\u034e")
        buf.write("\3\2\2\2\u034e\u0358\3\2\2\2\u034f\u0350\7\u00c0\2\2\u0350")
        buf.write("\u0355\5,\27\2\u0351\u0352\7\u01ae\2\2\u0352\u0354\5,")
        buf.write("\27\2\u0353\u0351\3\2\2\2\u0354\u0357\3\2\2\2\u0355\u0353")
        buf.write("\3\2\2\2\u0355\u0356\3\2\2\2\u0356\u0359\3\2\2\2\u0357")
        buf.write("\u0355\3\2\2\2\u0358\u034f\3\2\2\2\u0358\u0359\3\2\2\2")
        buf.write("\u0359\u035c\3\2\2\2\u035a\u035b\7I\2\2\u035b\u035d\7")
        buf.write("\u008d\2\2\u035c\u035a\3\2\2\2\u035c\u035d\3\2\2\2\u035d")
        buf.write("\u035e\3\2\2\2\u035e\u035f\7\t\2\2\u035f\u0360\5\6\4\2")
        buf.write("\u0360)\3\2\2\2\u0361\u0365\7\u0194\2\2\u0362\u0363\5")
        buf.write("\u0146\u00a4\2\u0363\u0364\7\u01a7\2\2\u0364\u0366\3\2")
        buf.write("\2\2\u0365\u0362\3\2\2\2\u0365\u0366\3\2\2\2\u0366\u0368")
        buf.write("\3\2\2\2\u0367\u0369\7\t\2\2\u0368\u0367\3\2\2\2\u0368")
        buf.write("\u0369\3\2\2\2\u0369\u036a\3\2\2\2\u036a\u036c\5\u013e")
        buf.write("\u00a0\2\u036b\u036d\7\u00ba\2\2\u036c\u036b\3\2\2\2\u036c")
        buf.write("\u036d\3\2\2\2\u036d\u0370\3\2\2\2\u036e\u036f\7\u019b")
        buf.write("\2\2\u036f\u0371\5\u0140\u00a1\2\u0370\u036e\3\2\2\2\u0370")
        buf.write("\u0371\3\2\2\2\u0371\u0373\3\2\2\2\u0372\u0374\t\t\2\2")
        buf.write("\u0373\u0372\3\2\2\2\u0373\u0374\3\2\2\2\u0374+\3\2\2")
        buf.write("\2\u0375\u0379\7\u00fd\2\2\u0376\u0379\7\u0155\2\2\u0377")
        buf.write("\u0379\5\u008eH\2\u0378\u0375\3\2\2\2\u0378\u0376\3\2")
        buf.write("\2\2\u0378\u0377\3\2\2\2\u0379-\3\2\2\2\u037a\u037b\7")
        buf.write("&\2\2\u037b\u037c\7\u00a4\2\2\u037c\u037d\5\u0146\u00a4")
        buf.write("\2\u037d\u037e\7s\2\2\u037e\u037f\5\u00e6t\2\u037f\u0380")
        buf.write("\7\u01ac\2\2\u0380\u0381\5\u0132\u009a\2\u0381\u0394\7")
        buf.write("\u01ad\2\2\u0382\u0388\7\u00c0\2\2\u0383\u0389\7\u010a")
        buf.write("\2\2\u0384\u0385\7\u0162\2\2\u0385\u0386\7\u0195\2\2\u0386")
        buf.write("\u0389\t\n\2\2\u0387\u0389\7\u0170\2\2\u0388\u0383\3\2")
        buf.write("\2\2\u0388\u0384\3\2\2\2\u0388\u0387\3\2\2\2\u0389\u038c")
        buf.write("\3\2\2\2\u038a\u038b\7\u01ae\2\2\u038b\u038d\7\u0139\2")
        buf.write("\2\u038c\u038a\3\2\2\2\u038c\u038d\3\2\2\2\u038d\u0392")
        buf.write("\3\2\2\2\u038e\u038f\7\u01ae\2\2\u038f\u0390\7\u0117\2")
        buf.write("\2\u0390\u0391\7\u019b\2\2\u0391\u0393\5\u0136\u009c\2")
        buf.write("\u0392\u038e\3\2\2\2\u0392\u0393\3\2\2\2\u0393\u0395\3")
        buf.write("\2\2\2\u0394\u0382\3\2\2\2\u0394\u0395\3\2\2\2\u0395\u0397")
        buf.write("\3\2\2\2\u0396\u0398\7\u01af\2\2\u0397\u0396\3\2\2\2\u0397")
        buf.write("\u0398\3\2\2\2\u0398/\3\2\2\2\u0399\u039a\7&\2\2\u039a")
        buf.write("\u039b\7\u00a6\2\2\u039b\u039c\5\u0128\u0095\2\u039c\u039d")
        buf.write("\7\u01ac\2\2\u039d\u039f\5\u0094K\2\u039e\u03a0\7\u01ae")
        buf.write("\2\2\u039f\u039e\3\2\2\2\u039f\u03a0\3\2\2\2\u03a0\u03a1")
        buf.write("\3\2\2\2\u03a1\u03a5\7\u01ad\2\2\u03a2\u03a3\7s\2\2\u03a3")
        buf.write("\u03a6\5\u0146\u00a4\2\u03a4\u03a6\7\62\2\2\u03a5\u03a2")
        buf.write("\3\2\2\2\u03a5\u03a4\3\2\2\2\u03a5\u03a6\3\2\2\2\u03a6")
        buf.write("\u03aa\3\2\2\2\u03a7\u03a8\7\u0177\2\2\u03a8\u03ab\5\u0146")
        buf.write("\u00a4\2\u03a9\u03ab\7\62\2\2\u03aa\u03a7\3\2\2\2\u03aa")
        buf.write("\u03a9\3\2\2\2\u03aa\u03ab\3\2\2\2\u03ab\u03ad\3\2\2\2")
        buf.write("\u03ac\u03ae\7\u01af\2\2\u03ad\u03ac\3\2\2\2\u03ad\u03ae")
        buf.write("\3\2\2\2\u03ae\61\3\2\2\2\u03af\u03b0\7&\2\2\u03b0\u03b1")
        buf.write("\7\u00bb\2\2\u03b1\u03b6\5\u012a\u0096\2\u03b2\u03b3\7")
        buf.write("\u01ac\2\2\u03b3\u03b4\5\u0132\u009a\2\u03b4\u03b5\7\u01ad")
        buf.write("\2\2\u03b5\u03b7\3\2\2\2\u03b6\u03b2\3\2\2\2\u03b6\u03b7")
        buf.write("\3\2\2\2\u03b7\u03c1\3\2\2\2\u03b8\u03b9\7\u00c0\2\2\u03b9")
        buf.write("\u03be\5\64\33\2\u03ba\u03bb\7\u01ae\2\2\u03bb\u03bd\5")
        buf.write("\64\33\2\u03bc\u03ba\3\2\2\2\u03bd\u03c0\3\2\2\2\u03be")
        buf.write("\u03bc\3\2\2\2\u03be\u03bf\3\2\2\2\u03bf\u03c2\3\2\2\2")
        buf.write("\u03c0\u03be\3\2\2\2\u03c1\u03b8\3\2\2\2\u03c1\u03c2\3")
        buf.write("\2\2\2\u03c2\u03c3\3\2\2\2\u03c3\u03c4\7\t\2\2\u03c4\u03c8")
        buf.write("\5\32\16\2\u03c5\u03c6\7\u00c0\2\2\u03c6\u03c7\7\27\2")
        buf.write("\2\u03c7\u03c9\7y\2\2\u03c8\u03c5\3\2\2\2\u03c8\u03c9")
        buf.write("\3\2\2\2\u03c9\u03cb\3\2\2\2\u03ca\u03cc\7\u01af\2\2\u03cb")
        buf.write("\u03ca\3\2\2\2\u03cb\u03cc\3\2\2\2\u03cc\63\3\2\2\2\u03cd")
        buf.write("\u03ce\t\13\2\2\u03ce\65\3\2\2\2\u03cf\u03d0\7\6\2\2\u03d0")
        buf.write("\u03d1\7\u00a6\2\2\u03d1\u03f0\5\u0128\u0095\2\u03d2\u03d3")
        buf.write("\7\u00a0\2\2\u03d3\u03d4\7\u01ac\2\2\u03d4\u03d5\7\u0122")
        buf.write("\2\2\u03d5\u03d6\7\u019b\2\2\u03d6\u03d7\t\f\2\2\u03d7")
        buf.write("\u03f1\7\u01ad\2\2\u03d8\u03d9\7\4\2\2\u03d9\u03f1\5\u0096")
        buf.write("L\2\u03da\u03db\7:\2\2\u03db\u03dc\7 \2\2\u03dc\u03f1")
        buf.write("\5\u0146\u00a4\2\u03dd\u03de\7\u00c0\2\2\u03de\u03df\7")
        buf.write("\27\2\2\u03df\u03e0\7\4\2\2\u03e0\u03e1\7 \2\2\u03e1\u03e2")
        buf.write("\5\u0146\u00a4\2\u03e2\u03e3\7K\2\2\u03e3\u03e4\7a\2\2")
        buf.write("\u03e4\u03e5\7\u01ac\2\2\u03e5\u03e6\5\u0132\u009a\2\u03e6")
        buf.write("\u03e7\7\u01ad\2\2\u03e7\u03e8\7\u008c\2\2\u03e8\u03e9")
        buf.write("\5\u0128\u0095\2\u03e9\u03ea\7\u01ac\2\2\u03ea\u03eb\5")
        buf.write("\u0132\u009a\2\u03eb\u03ec\7\u01ad\2\2\u03ec\u03f1\3\2")
        buf.write("\2\2\u03ed\u03ee\7\27\2\2\u03ee\u03ef\7 \2\2\u03ef\u03f1")
        buf.write("\5\u0146\u00a4\2\u03f0\u03d2\3\2\2\2\u03f0\u03d8\3\2\2")
        buf.write("\2\u03f0\u03da\3\2\2\2\u03f0\u03dd\3\2\2\2\u03f0\u03ed")
        buf.write("\3\2\2\2\u03f1\u03f3\3\2\2\2\u03f2\u03f4\7\u01af\2\2\u03f3")
        buf.write("\u03f2\3\2\2\2\u03f3\u03f4\3\2\2\2\u03f4\67\3\2\2\2\u03f5")
        buf.write("\u03f6\7\6\2\2\u03f6\u03f9\7.\2\2\u03f7\u03fa\5\u0146")
        buf.write("\u00a4\2\u03f8\u03fa\7(\2\2\u03f9\u03f7\3\2\2\2\u03f9")
        buf.write("\u03f8\3\2\2\2\u03fa\u0407\3\2\2\2\u03fb\u03fc\7\u0130")
        buf.write("\2\2\u03fc\u03fd\7\u0132\2\2\u03fd\u03fe\7\u019b\2\2\u03fe")
        buf.write("\u0408\5\u0146\u00a4\2\u03ff\u0400\7\34\2\2\u0400\u0408")
        buf.write("\5\u0146\u00a4\2\u0401\u0402\7\u00a0\2\2\u0402\u0405\5")
        buf.write(":\36\2\u0403\u0404\7\u00c0\2\2\u0404\u0406\5b\62\2\u0405")
        buf.write("\u0403\3\2\2\2\u0405\u0406\3\2\2\2\u0406\u0408\3\2\2\2")
        buf.write("\u0407\u03fb\3\2\2\2\u0407\u03ff\3\2\2\2\u0407\u0401\3")
        buf.write("\2\2\2\u0408\u040a\3\2\2\2\u0409\u040b\7\u01af\2\2\u040a")
        buf.write("\u0409\3\2\2\2\u040a\u040b\3\2\2\2\u040b9\3\2\2\2\u040c")
        buf.write("\u0423\5<\37\2\u040d\u0423\5> \2\u040e\u0423\5B\"\2\u040f")
        buf.write("\u0423\5D#\2\u0410\u0423\5F$\2\u0411\u0423\5H%\2\u0412")
        buf.write("\u0423\5J&\2\u0413\u0423\5L\'\2\u0414\u0423\5N(\2\u0415")
        buf.write("\u0423\5P)\2\u0416\u0423\5R*\2\u0417\u0418\7\u0104\2\2")
        buf.write("\u0418\u0423\5\u011e\u0090\2\u0419\u0423\7\3\2\2\u041a")
        buf.write("\u0423\5T+\2\u041b\u0423\5V,\2\u041c\u0423\5X-\2\u041d")
        buf.write("\u0423\5Z.\2\u041e\u0423\5\\/\2\u041f\u0423\5^\60\2\u0420")
        buf.write("\u0423\5`\61\2\u0421\u0423\5b\62\2\u0422\u040c\3\2\2\2")
        buf.write("\u0422\u040d\3\2\2\2\u0422\u040e\3\2\2\2\u0422\u040f\3")
        buf.write("\2\2\2\u0422\u0410\3\2\2\2\u0422\u0411\3\2\2\2\u0422\u0412")
        buf.write("\3\2\2\2\u0422\u0413\3\2\2\2\u0422\u0414\3\2\2\2\u0422")
        buf.write("\u0415\3\2\2\2\u0422\u0416\3\2\2\2\u0422\u0417\3\2\2\2")
        buf.write("\u0422\u0419\3\2\2\2\u0422\u041a\3\2\2\2\u0422\u041b\3")
        buf.write("\2\2\2\u0422\u041c\3\2\2\2\u0422\u041d\3\2\2\2\u0422\u041e")
        buf.write("\3\2\2\2\u0422\u041f\3\2\2\2\u0422\u0420\3\2\2\2\u0422")
        buf.write("\u0421\3\2\2\2\u0423;\3\2\2\2\u0424\u0425\7\u00cf\2\2")
        buf.write("\u0425\u0436\5\u0136\u009c\2\u0426\u0427\7\u00d0\2\2\u0427")
        buf.write("\u0436\7q\2\2\u0428\u042d\7s\2\2\u0429\u042a\7\u0117\2")
        buf.write("\2\u042a\u042b\7\u019b\2\2\u042b\u042e\7s\2\2\u042c\u042e")
        buf.write("\7q\2\2\u042d\u0429\3\2\2\2\u042d\u042c\3\2\2\2\u042e")
        buf.write("\u0436\3\2\2\2\u042f\u0430\7\u00d1\2\2\u0430\u0436\5\u0136")
        buf.write("\u009c\2\u0431\u0432\7\u00d2\2\2\u0432\u0436\5\u0136\u009c")
        buf.write("\2\u0433\u0434\7\u00d3\2\2\u0434\u0436\t\r\2\2\u0435\u0424")
        buf.write("\3\2\2\2\u0435\u0426\3\2\2\2\u0435\u0428\3\2\2\2\u0435")
        buf.write("\u042f\3\2\2\2\u0435\u0431\3\2\2\2\u0435\u0433\3\2\2\2")
        buf.write("\u0436=\3\2\2\2\u0437\u0438\7\u00dc\2\2\u0438\u0448\7")
        buf.write("\u019b\2\2\u0439\u0449\7q\2\2\u043a\u0445\7s\2\2\u043b")
        buf.write("\u0440\5@!\2\u043c\u043d\7\u01ae\2\2\u043d\u043f\5@!\2")
        buf.write("\u043e\u043c\3\2\2\2\u043f\u0442\3\2\2\2\u0440\u043e\3")
        buf.write("\2\2\2\u0440\u0441\3\2\2\2\u0441\u0444\3\2\2\2\u0442\u0440")
        buf.write("\3\2\2\2\u0443\u043b\3\2\2\2\u0444\u0447\3\2\2\2\u0445")
        buf.write("\u0443\3\2\2\2\u0445\u0446\3\2\2\2\u0446\u0449\3\2\2\2")
        buf.write("\u0447\u0445\3\2\2\2\u0448\u0439\3\2\2\2\u0448\u043a\3")
        buf.write("\2\2\2\u0449?\3\2\2\2\u044a\u044b\7\u00ce\2\2\u044b\u044c")
        buf.write("\7\u019b\2\2\u044c\u0451\5\u0136\u009c\2\u044d\u044e\7")
        buf.write("\u00db\2\2\u044e\u044f\7\u019b\2\2\u044f\u0451\t\16\2")
        buf.write("\2\u0450\u044a\3\2\2\2\u0450\u044d\3\2\2\2\u0451A\3\2")
        buf.write("\2\2\u0452\u0453\7!\2\2\u0453\u0454\7\u019b\2\2\u0454")
        buf.write("\u0455\t\6\2\2\u0455C\3\2\2\2\u0456\u0457\7\u00e7\2\2")
        buf.write("\u0457\u045b\5\u0136\u009c\2\u0458\u0459\7\u00e8\2\2\u0459")
        buf.write("\u045b\t\17\2\2\u045a\u0456\3\2\2\2\u045a\u0458\3\2\2")
        buf.write("\2\u045bE\3\2\2\2\u045c\u045d\7\u00ed\2\2\u045d\u045e")
        buf.write("\5\u0136\u009c\2\u045eG\3\2\2\2\u045f\u0460\7\u00fd\2")
        buf.write("\2\u0460\u0461\5\u0136\u009c\2\u0461I\3\2\2\2\u0462\u0463")
        buf.write("\t\20\2\2\u0463K\3\2\2\2\u0464\u0465\t\21\2\2\u0465M\3")
        buf.write("\2\2\2\u0466\u0467\t\22\2\2\u0467O\3\2\2\2\u0468\u0469")
        buf.write("\7\u00f3\2\2\u0469\u046a\7\u019b\2\2\u046a\u046b\t\23")
        buf.write("\2\2\u046bQ\3\2\2\2\u046c\u046d\7\u00ef\2\2\u046d\u0486")
        buf.write("\5\u0136\u009c\2\u046e\u046f\7\u017d\2\2\u046f\u0486\5")
        buf.write("\u0136\u009c\2\u0470\u0471\7\u00f1\2\2\u0471\u0474\7\u019b")
        buf.write("\2\2\u0472\u0475\5\u0146\u00a4\2\u0473\u0475\7\u0197\2")
        buf.write("\2\u0474\u0472\3\2\2\2\u0474\u0473\3\2\2\2\u0475\u0486")
        buf.write("\3\2\2\2\u0476\u0477\7\u00f0\2\2\u0477\u047a\7\u019b\2")
        buf.write("\2\u0478\u047b\5\u0146\u00a4\2\u0479\u047b\7\u0197\2\2")
        buf.write("\u047a\u0478\3\2\2\2\u047a\u0479\3\2\2\2\u047b\u0486\3")
        buf.write("\2\2\2\u047c\u047d\7\u0133\2\2\u047d\u047e\7\u019b\2\2")
        buf.write("\u047e\u0486\t\r\2\2\u047f\u0480\7\u017c\2\2\u0480\u0481")
        buf.write("\7\u019b\2\2\u0481\u0486\t\r\2\2\u0482\u0483\7\u017f\2")
        buf.write("\2\u0483\u0484\7\u019b\2\2\u0484\u0486\7\u0195\2\2\u0485")
        buf.write("\u046c\3\2\2\2\u0485\u046e\3\2\2\2\u0485\u0470\3\2\2\2")
        buf.write("\u0485\u0476\3\2\2\2\u0485\u047c\3\2\2\2\u0485\u047f\3")
        buf.write("\2\2\2\u0485\u0482\3\2\2\2\u0486S\3\2\2\2\u0487\u0488")
        buf.write("\7\u012f\2\2\u0488\u0489\t\r\2\2\u0489U\3\2\2\2\u048a")
        buf.write("\u048b\7\u0148\2\2\u048b\u048c\t\24\2\2\u048cW\3\2\2\2")
        buf.write("\u048d\u048e\7\u0156\2\2\u048e\u0494\t\25\2\2\u048f\u0490")
        buf.write("\7\u017b\2\2\u0490\u0494\5\u0136\u009c\2\u0491\u0492\7")
        buf.write("\u0147\2\2\u0492\u0494\t\26\2\2\u0493\u048d\3\2\2\2\u0493")
        buf.write("\u048f\3\2\2\2\u0493\u0491\3\2\2\2\u0494Y\3\2\2\2\u0495")
        buf.write("\u049c\7\u00fc\2\2\u0496\u049c\7\u00f9\2\2\u0497\u049c")
        buf.write("\7\u0134\2\2\u0498\u049c\7\u00fe\2\2\u0499\u049a\7\u0112")
        buf.write("\2\2\u049a\u049c\5\u0136\u009c\2\u049b\u0495\3\2\2\2\u049b")
        buf.write("\u0496\3\2\2\2\u049b\u0497\3\2\2\2\u049b\u0498\3\2\2\2")
        buf.write("\u049b\u0499\3\2\2\2\u049c[\3\2\2\2\u049d\u049e\7\u00c6")
        buf.write("\2\2\u049e\u04a3\5\u0136\u009c\2\u049f\u04a0\7\u0152\2")
        buf.write("\2\u04a0\u04a3\t\r\2\2\u04a1\u04a3\t\r\2\2\u04a2\u049d")
        buf.write("\3\2\2\2\u04a2\u049f\3\2\2\2\u04a2\u04a1\3\2\2\2\u04a3")
        buf.write("]\3\2\2\2\u04a4\u04a5\7\u00c8\2\2\u04a5\u04ba\5\u0136")
        buf.write("\u009c\2\u04a6\u04a7\7\u00c7\2\2\u04a7\u04ba\5\u0136\u009c")
        buf.write("\2\u04a8\u04a9\7\u00c9\2\2\u04a9\u04ba\5\u0136\u009c\2")
        buf.write("\u04aa\u04ab\7\u00ca\2\2\u04ab\u04ba\5\u0136\u009c\2\u04ac")
        buf.write("\u04ad\7\u00cc\2\2\u04ad\u04ba\5\u0136\u009c\2\u04ae\u04af")
        buf.write("\7\u00e0\2\2\u04af\u04b0\7\u019b\2\2\u04b0\u04ba\7\u0195")
        buf.write("\2\2\u04b1\u04b2\7\u00e2\2\2\u04b2\u04ba\5\u0136\u009c")
        buf.write("\2\u04b3\u04b4\7\u013d\2\2\u04b4\u04ba\5\u0136\u009c\2")
        buf.write("\u04b5\u04b6\7\u014e\2\2\u04b6\u04ba\5\u0136\u009c\2\u04b7")
        buf.write("\u04b8\7\u0157\2\2\u04b8\u04ba\5\u0136\u009c\2\u04b9\u04a4")
        buf.write("\3\2\2\2\u04b9\u04a6\3\2\2\2\u04b9\u04a8\3\2\2\2\u04b9")
        buf.write("\u04aa\3\2\2\2\u04b9\u04ac\3\2\2\2\u04b9\u04ae\3\2\2\2")
        buf.write("\u04b9\u04b1\3\2\2\2\u04b9\u04b3\3\2\2\2\u04b9\u04b5\3")
        buf.write("\2\2\2\u04b9\u04b7\3\2\2\2\u04ba_\3\2\2\2\u04bb\u04bc")
        buf.write("\7\u0175\2\2\u04bc\u04bd\7\u019b\2\2\u04bd\u04be\7\u0195")
        buf.write("\2\2\u04be\u04bf\t\27\2\2\u04bfa\3\2\2\2\u04c0\u04c1\7")
        buf.write("\u0094\2\2\u04c1\u04c2\7\u00c4\2\2\u04c2\u04c7\7\u0195")
        buf.write("\2\2\u04c3\u04c4\7\u0094\2\2\u04c4\u04c7\7\u0115\2\2\u04c5")
        buf.write("\u04c7\7\u013a\2\2\u04c6\u04c0\3\2\2\2\u04c6\u04c3\3\2")
        buf.write("\2\2\u04c6\u04c5\3\2\2\2\u04c7c\3\2\2\2\u04c8\u04c9\7")
        buf.write(":\2\2\u04c9\u04cc\7Z\2\2\u04ca\u04cb\7X\2\2\u04cb\u04cd")
        buf.write("\7B\2\2\u04cc\u04ca\3\2\2\2\u04cc\u04cd\3\2\2\2\u04cd")
        buf.write("\u04ce\3\2\2\2\u04ce\u04d1\5\u0146\u00a4\2\u04cf\u04d0")
        buf.write("\7s\2\2\u04d0\u04d2\5\u0128\u0095\2\u04d1\u04cf\3\2\2")
        buf.write("\2\u04d1\u04d2\3\2\2\2\u04d2\u04d4\3\2\2\2\u04d3\u04d5")
        buf.write("\7\u01af\2\2\u04d4\u04d3\3\2\2\2\u04d4\u04d5\3\2\2\2\u04d5")
        buf.write("e\3\2\2\2\u04d6\u04d7\7:\2\2\u04d7\u04da\7\u0086\2\2\u04d8")
        buf.write("\u04d9\7X\2\2\u04d9\u04db\7B\2\2\u04da\u04d8\3\2\2\2\u04da")
        buf.write("\u04db\3\2\2\2\u04db\u04dc\3\2\2\2\u04dc\u04de\5\u012c")
        buf.write("\u0097\2\u04dd\u04df\7\u01af\2\2\u04de\u04dd\3\2\2\2\u04de")
        buf.write("\u04df\3\2\2\2\u04dfg\3\2\2\2\u04e0\u04e1\7:\2\2\u04e1")
        buf.write("\u04e5\7\u00a4\2\2\u04e2\u04e3\5\u0128\u0095\2\u04e3\u04e4")
        buf.write("\7\u01a7\2\2\u04e4\u04e6\3\2\2\2\u04e5\u04e2\3\2\2\2\u04e5")
        buf.write("\u04e6\3\2\2\2\u04e6\u04e7\3\2\2\2\u04e7\u04e8\5\u0146")
        buf.write("\u00a4\2\u04e8\u04e9\7\u01af\2\2\u04e9i\3\2\2\2\u04ea")
        buf.write("\u04eb\7:\2\2\u04eb\u04ee\7\u00a6\2\2\u04ec\u04ed\7X\2")
        buf.write("\2\u04ed\u04ef\7B\2\2\u04ee\u04ec\3\2\2\2\u04ee\u04ef")
        buf.write("\3\2\2\2\u04ef\u04f0\3\2\2\2\u04f0\u04f2\5\u0128\u0095")
        buf.write("\2\u04f1\u04f3\7\u01af\2\2\u04f2\u04f1\3\2\2\2\u04f2\u04f3")
        buf.write("\3\2\2\2\u04f3k\3\2\2\2\u04f4\u04f5\7:\2\2\u04f5\u04f8")
        buf.write("\7\u00bb\2\2\u04f6\u04f7\7X\2\2\u04f7\u04f9\7B\2\2\u04f8")
        buf.write("\u04f6\3\2\2\2\u04f8\u04f9\3\2\2\2\u04f9\u04fa\3\2\2\2")
        buf.write("\u04fa\u04ff\5\u012a\u0096\2\u04fb\u04fc\7\u01ae\2\2\u04fc")
        buf.write("\u04fe\5\u012a\u0096\2\u04fd\u04fb\3\2\2\2\u04fe\u0501")
        buf.write("\3\2\2\2\u04ff\u04fd\3\2\2\2\u04ff\u0500\3\2\2\2\u0500")
        buf.write("\u0503\3\2\2\2\u0501\u04ff\3\2\2\2\u0502\u0504\7\u01af")
        buf.write("\2\2\u0503\u0502\3\2\2\2\u0503\u0504\3\2\2\2\u0504m\3")
        buf.write("\2\2\2\u0505\u0506\7&\2\2\u0506\u0507\7\u0180\2\2\u0507")
        buf.write("\u0508\5\u012a\u0096\2\u0508\u0509\7N\2\2\u0509\u050a")
        buf.write("\5\u013e\u00a0\2\u050a\u050b\5\u0140\u00a1\2\u050bo\3")
        buf.write("\2\2\2\u050c\u050d\7:\2\2\u050d\u0510\7\u0180\2\2\u050e")
        buf.write("\u050f\7X\2\2\u050f\u0511\7B\2\2\u0510\u050e\3\2\2\2\u0510")
        buf.write("\u0511\3\2\2\2\u0511\u0512\3\2\2\2\u0512\u0513\5\u012a")
        buf.write("\u0096\2\u0513q\3\2\2\2\u0514\u0517\5t;\2\u0515\u0517")
        buf.write("\5v<\2\u0516\u0514\3\2\2\2\u0516\u0515\3\2\2\2\u0517s")
        buf.write("\3\2\2\2\u0518\u0519\7v\2\2\u0519\u051a\7\u01ac\2\2\u051a")
        buf.write("\u051b\5\u0146\u00a4\2\u051b\u051c\7\u01ae\2\2\u051c\u051d")
        buf.write("\7\u0197\2\2\u051d\u051e\7\u01ad\2\2\u051eu\3\2\2\2\u051f")
        buf.write("\u0520\7u\2\2\u0520\u0521\7\u01ac\2\2\u0521\u0522\7\u0197")
        buf.write("\2\2\u0522\u0523\7\u01ae\2\2\u0523\u0524\7\u0197\2\2\u0524")
        buf.write("\u0525\7\u01ad\2\2\u0525\u0527\7\u01a7\2\2\u0526\u0528")
        buf.write("\5\u0146\u00a4\2\u0527\u0526\3\2\2\2\u0527\u0528\3\2\2")
        buf.write("\2\u0528\u0529\3\2\2\2\u0529\u052b\7\u01a7\2\2\u052a\u052c")
        buf.write("\5\u0146\u00a4\2\u052b\u052a\3\2\2\2\u052b\u052c\3\2\2")
        buf.write("\2\u052c\u052d\3\2\2\2\u052d\u052e\7\u01a7\2\2\u052e\u052f")
        buf.write("\5\u0146\u00a4\2\u052fw\3\2\2\2\u0530\u0531\7\61\2\2\u0531")
        buf.write("\u0533\7\u0194\2\2\u0532\u0534\7\t\2\2\u0533\u0532\3\2")
        buf.write("\2\2\u0533\u0534\3\2\2\2\u0534\u0535\3\2\2\2\u0535\u0537")
        buf.write("\5\u0092J\2\u0536\u0538\7\u01af\2\2\u0537\u0536\3\2\2")
        buf.write("\2\u0537\u0538\3\2\2\2\u0538\u0546\3\2\2\2\u0539\u053a")
        buf.write("\7\61\2\2\u053a\u053f\5\u0090I\2\u053b\u053c\7\u01ae\2")
        buf.write("\2\u053c\u053e\5\u0090I\2\u053d\u053b\3\2\2\2\u053e\u0541")
        buf.write("\3\2\2\2\u053f\u053d\3\2\2\2\u053f\u0540\3\2\2\2\u0540")
        buf.write("\u0543\3\2\2\2\u0541\u053f\3\2\2\2\u0542\u0544\7\u01af")
        buf.write("\2\2\u0543\u0542\3\2\2\2\u0543\u0544\3\2\2\2\u0544\u0546")
        buf.write("\3\2\2\2\u0545\u0530\3\2\2\2\u0545\u0539\3\2\2\2\u0546")
        buf.write("y\3\2\2\2\u0547\u0549\7\31\2\2\u0548\u054a\7\u010c\2\2")
        buf.write("\u0549\u0548\3\2\2\2\u0549\u054a\3\2\2\2\u054a\u054b\3")
        buf.write("\2\2\2\u054b\u054d\5\u0134\u009b\2\u054c\u054e\7\u01af")
        buf.write("\2\2\u054d\u054c\3\2\2\2\u054d\u054e\3\2\2\2\u054e\u0562")
        buf.write("\3\2\2\2\u054f\u0551\7\60\2\2\u0550\u0552\7\u010c\2\2")
        buf.write("\u0551\u0550\3\2\2\2\u0551\u0552\3\2\2\2\u0552\u0553\3")
        buf.write("\2\2\2\u0553\u0555\5\u0134\u009b\2\u0554\u0556\7\u01af")
        buf.write("\2\2\u0555\u0554\3\2\2\2\u0555\u0556\3\2\2\2\u0556\u0562")
        buf.write("\3\2\2\2\u0557\u0562\5\u00a2R\2\u0558\u0562\5\u00a6T\2")
        buf.write("\u0559\u055b\7t\2\2\u055a\u055c\7\u010c\2\2\u055b\u055a")
        buf.write("\3\2\2\2\u055b\u055c\3\2\2\2\u055c\u055d\3\2\2\2\u055d")
        buf.write("\u055f\5\u0134\u009b\2\u055e\u0560\7\u01af\2\2\u055f\u055e")
        buf.write("\3\2\2\2\u055f\u0560\3\2\2\2\u0560\u0562\3\2\2\2\u0561")
        buf.write("\u0547\3\2\2\2\u0561\u054f\3\2\2\2\u0561\u0557\3\2\2\2")
        buf.write("\u0561\u0558\3\2\2\2\u0561\u0559\3\2\2\2\u0562{\3\2\2")
        buf.write("\2\u0563\u0566\7A\2\2\u0564\u0565\7\u0194\2\2\u0565\u0567")
        buf.write("\7\u019b\2\2\u0566\u0564\3\2\2\2\u0566\u0567\3\2\2\2\u0567")
        buf.write("\u0568\3\2\2\2\u0568\u0571\5\u012c\u0097\2\u0569\u056e")
        buf.write("\5~@\2\u056a\u056b\7\u01ae\2\2\u056b\u056d\5~@\2\u056c")
        buf.write("\u056a\3\2\2\2\u056d\u0570\3\2\2\2\u056e\u056c\3\2\2\2")
        buf.write("\u056e\u056f\3\2\2\2\u056f\u0572\3\2\2\2\u0570\u056e\3")
        buf.write("\2\2\2\u0571\u0569\3\2\2\2\u0571\u0572\3\2\2\2\u0572\u0574")
        buf.write("\3\2\2\2\u0573\u0575\7\u01af\2\2\u0574\u0573\3\2\2\2\u0574")
        buf.write("\u0575\3\2\2\2\u0575\u058d\3\2\2\2\u0576\u0577\7A\2\2")
        buf.write("\u0577\u0578\7\u01ac\2\2\u0578\u057d\5\u0080A\2\u0579")
        buf.write("\u057a\7\u01b4\2\2\u057a\u057c\5\u0080A\2\u057b\u0579")
        buf.write("\3\2\2\2\u057c\u057f\3\2\2\2\u057d\u057b\3\2\2\2\u057d")
        buf.write("\u057e\3\2\2\2\u057e\u0580\3\2\2\2\u057f\u057d\3\2\2\2")
        buf.write("\u0580\u0587\7\u01ad\2\2\u0581\u0583\7\t\2\2\u0582\u0581")
        buf.write("\3\2\2\2\u0582\u0583\3\2\2\2\u0583\u0584\3\2\2\2\u0584")
        buf.write("\u0585\t\30\2\2\u0585\u0586\7\u019b\2\2\u0586\u0588\7")
        buf.write("\u0197\2\2\u0587\u0582\3\2\2\2\u0587\u0588\3\2\2\2\u0588")
        buf.write("\u058a\3\2\2\2\u0589\u058b\7\u01af\2\2\u058a\u0589\3\2")
        buf.write("\2\2\u058a\u058b\3\2\2\2\u058b\u058d\3\2\2\2\u058c\u0563")
        buf.write("\3\2\2\2\u058c\u0576\3\2\2\2\u058d}\3\2\2\2\u058e\u058f")
        buf.write("\7\u0194\2\2\u058f\u0591\7\u019b\2\2\u0590\u058e\3\2\2")
        buf.write("\2\u0590\u0591\3\2\2\2\u0591\u059b\3\2\2\2\u0592\u0595")
        buf.write("\5\u00aaV\2\u0593\u0595\5\u0146\u00a4\2\u0594\u0592\3")
        buf.write("\2\2\2\u0594\u0593\3\2\2\2\u0595\u0597\3\2\2\2\u0596\u0598")
        buf.write("\t\31\2\2\u0597\u0596\3\2\2\2\u0597\u0598\3\2\2\2\u0598")
        buf.write("\u059c\3\2\2\2\u0599\u059c\7\62\2\2\u059a\u059c\7n\2\2")
        buf.write("\u059b\u0594\3\2\2\2\u059b\u0599\3\2\2\2\u059b\u059a\3")
        buf.write("\2\2\2\u059c\177\3\2\2\2\u059d\u059e\t\3\2\2\u059e\u0081")
        buf.write("\3\2\2\2\u059f\u05a1\5\u008eH\2\u05a0\u05a2\7\u01af\2")
        buf.write("\2\u05a1\u05a0\3\2\2\2\u05a1\u05a2\3\2\2\2\u05a2\u05d0")
        buf.write("\3\2\2\2\u05a3\u05af\7R\2\2\u05a4\u05a6\7\5\2\2\u05a5")
        buf.write("\u05a7\7\u014d\2\2\u05a6\u05a5\3\2\2\2\u05a6\u05a7\3\2")
        buf.write("\2\2\u05a7\u05b0\3\2\2\2\u05a8\u05ad\5\u0084C\2\u05a9")
        buf.write("\u05aa\7\u01ac\2\2\u05aa\u05ab\5\u0132\u009a\2\u05ab\u05ac")
        buf.write("\7\u01ad\2\2\u05ac\u05ae\3\2\2\2\u05ad\u05a9\3\2\2\2\u05ad")
        buf.write("\u05ae\3\2\2\2\u05ae\u05b0\3\2\2\2\u05af\u05a4\3\2\2\2")
        buf.write("\u05af\u05a8\3\2\2\2\u05b0\u05b3\3\2\2\2\u05b1\u05b2\7")
        buf.write("s\2\2\u05b2\u05b4\5\u0128\u0095\2\u05b3\u05b1\3\2\2\2")
        buf.write("\u05b3\u05b4\3\2\2\2\u05b4\u05b5\3\2\2\2\u05b5\u05b6\7")
        buf.write("\u00aa\2\2\u05b6\u05ba\5\u0146\u00a4\2\u05b7\u05b8\7\u00c0")
        buf.write("\2\2\u05b8\u05b9\7R\2\2\u05b9\u05bb\7y\2\2\u05ba\u05b7")
        buf.write("\3\2\2\2\u05ba\u05bb\3\2\2\2\u05bb\u05be\3\2\2\2\u05bc")
        buf.write("\u05bd\7\t\2\2\u05bd\u05bf\5\u0146\u00a4\2\u05be\u05bc")
        buf.write("\3\2\2\2\u05be\u05bf\3\2\2\2\u05bf\u05c1\3\2\2\2\u05c0")
        buf.write("\u05c2\7\u01af\2\2\u05c1\u05c0\3\2\2\2\u05c1\u05c2\3\2")
        buf.write("\2\2\u05c2\u05d0\3\2\2\2\u05c3\u05ca\7\u0091\2\2\u05c4")
        buf.write("\u05c5\7\u01ac\2\2\u05c5\u05c6\7\u00c0\2\2\u05c6\u05c7")
        buf.write("\7\u00e4\2\2\u05c7\u05c8\7\u019b\2\2\u05c8\u05c9\7\u0194")
        buf.write("\2\2\u05c9\u05cb\7\u01ad\2\2\u05ca\u05c4\3\2\2\2\u05ca")
        buf.write("\u05cb\3\2\2\2\u05cb\u05cd\3\2\2\2\u05cc\u05ce\7\u01af")
        buf.write("\2\2\u05cd\u05cc\3\2\2\2\u05cd\u05ce\3\2\2\2\u05ce\u05d0")
        buf.write("\3\2\2\2\u05cf\u059f\3\2\2\2\u05cf\u05a3\3\2\2\2\u05cf")
        buf.write("\u05c3\3\2\2\2\u05d0\u0083\3\2\2\2\u05d1\u05ec\7A\2\2")
        buf.write("\u05d2\u05d3\7\u00bb\2\2\u05d3\u05ec\5\u0146\u00a4\2\u05d4")
        buf.write("\u05d5\7\u0174\2\2\u05d5\u05ec\5\u0146\u00a4\2\u05d6\u05d8")
        buf.write("\7\u00e3\2\2\u05d7\u05d9\5\u0146\u00a4\2\u05d8\u05d7\3")
        buf.write("\2\2\2\u05d8\u05d9\3\2\2\2\u05d9\u05ec\3\2\2\2\u05da\u05db")
        buf.write("\7&\2\2\u05db\u05ec\t\32\2\2\u05dc\u05ec\7\u0169\2\2\u05dd")
        buf.write("\u05ec\7\u0116\2\2\u05de\u05ec\7\u009b\2\2\u05df\u05ec")
        buf.write("\7\u008c\2\2\u05e0\u05ec\7\\\2\2\u05e1\u05e9\7\6\2\2\u05e2")
        buf.write("\u05e4\7\b\2\2\u05e3\u05e2\3\2\2\2\u05e3\u05e4\3\2\2\2")
        buf.write("\u05e4\u05e7\3\2\2\2\u05e5\u05e8\5\u0146\u00a4\2\u05e6")
        buf.write("\u05e8\7.\2\2\u05e7\u05e5\3\2\2\2\u05e7\u05e6\3\2\2\2")
        buf.write("\u05e8\u05ea\3\2\2\2\u05e9\u05e3\3\2\2\2\u05e9\u05ea\3")
        buf.write("\2\2\2\u05ea\u05ec\3\2\2\2\u05eb\u05d1\3\2\2\2\u05eb\u05d2")
        buf.write("\3\2\2\2\u05eb\u05d4\3\2\2\2\u05eb\u05d6\3\2\2\2\u05eb")
        buf.write("\u05da\3\2\2\2\u05eb\u05dc\3\2\2\2\u05eb\u05dd\3\2\2\2")
        buf.write("\u05eb\u05de\3\2\2\2\u05eb\u05df\3\2\2\2\u05eb\u05e0\3")
        buf.write("\2\2\2\u05eb\u05e1\3\2\2\2\u05ec\u0085\3\2\2\2\u05ed\u05ee")
        buf.write("\7\u00a0\2\2\u05ee\u05f1\7\u0194\2\2\u05ef\u05f0\7\u01a7")
        buf.write("\2\2\u05f0\u05f2\5\u0146\u00a4\2\u05f1\u05ef\3\2\2\2\u05f1")
        buf.write("\u05f2\3\2\2\2\u05f2\u05f3\3\2\2\2\u05f3\u05f4\7\u019b")
        buf.write("\2\2\u05f4\u05f6\5\u00acW\2\u05f5\u05f7\7\u01af\2\2\u05f6")
        buf.write("\u05f5\3\2\2\2\u05f6\u05f7\3\2\2\2\u05f7\u0615\3\2\2\2")
        buf.write("\u05f8\u05f9\7\u00a0\2\2\u05f9\u05fa\7\u0194\2\2\u05fa")
        buf.write("\u05fb\5\u014c\u00a7\2\u05fb\u05fd\5\u00acW\2\u05fc\u05fe")
        buf.write("\7\u01af\2\2\u05fd\u05fc\3\2\2\2\u05fd\u05fe\3\2\2\2\u05fe")
        buf.write("\u0615\3\2\2\2\u05ff\u0600\7\u00a0\2\2\u0600\u0601\7\u0194")
        buf.write("\2\2\u0601\u0602\7\u019b\2\2\u0602\u0603\7-\2\2\u0603")
        buf.write("\u060e\5\u00a4S\2\u0604\u060c\7I\2\2\u0605\u0606\7\u0089")
        buf.write("\2\2\u0606\u060d\7\u0141\2\2\u0607\u060a\7\u00b5\2\2\u0608")
        buf.write("\u0609\7p\2\2\u0609\u060b\5\u0132\u009a\2\u060a\u0608")
        buf.write("\3\2\2\2\u060a\u060b\3\2\2\2\u060b\u060d\3\2\2\2\u060c")
        buf.write("\u0605\3\2\2\2\u060c\u0607\3\2\2\2\u060d\u060f\3\2\2\2")
        buf.write("\u060e\u0604\3\2\2\2\u060e\u060f\3\2\2\2\u060f\u0611\3")
        buf.write("\2\2\2\u0610\u0612\7\u01af\2\2\u0611\u0610\3\2\2\2\u0611")
        buf.write("\u0612\3\2\2\2\u0612\u0615\3\2\2\2\u0613\u0615\5\u00a8")
        buf.write("U\2\u0614\u05ed\3\2\2\2\u0614\u05f8\3\2\2\2\u0614\u05ff")
        buf.write("\3\2\2\2\u0614\u0613\3\2\2\2\u0615\u0087\3\2\2\2\u0616")
        buf.write("\u0617\7\r\2\2\u0617\u0618\78\2\2\u0618\u061b\t\33\2\2")
        buf.write("\u0619\u061c\5\u0146\u00a4\2\u061a\u061c\7\u0194\2\2\u061b")
        buf.write("\u0619\3\2\2\2\u061b\u061a\3\2\2\2\u061b\u061c\3\2\2\2")
        buf.write("\u061c\u061e\3\2\2\2\u061d\u061f\7\u01af\2\2\u061e\u061d")
        buf.write("\3\2\2\2\u061e\u061f\3\2\2\2\u061f\u0664\3\2\2\2\u0620")
        buf.write("\u0621\7\r\2\2\u0621\u062b\t\33\2\2\u0622\u0625\5\u0146")
        buf.write("\u00a4\2\u0623\u0625\7\u0194\2\2\u0624\u0622\3\2\2\2\u0624")
        buf.write("\u0623\3\2\2\2\u0625\u0629\3\2\2\2\u0626\u0627\7\u00c0")
        buf.write("\2\2\u0627\u0628\7\u0125\2\2\u0628\u062a\7\u0197\2\2\u0629")
        buf.write("\u0626\3\2\2\2\u0629\u062a\3\2\2\2\u062a\u062c\3\2\2\2")
        buf.write("\u062b\u0624\3\2\2\2\u062b\u062c\3\2\2\2\u062c\u062e\3")
        buf.write("\2\2\2\u062d\u062f\7\u01af\2\2\u062e\u062d\3\2\2\2\u062e")
        buf.write("\u062f\3\2\2\2\u062f\u0664\3\2\2\2\u0630\u0631\7\36\2")
        buf.write("\2\u0631\u063e\t\33\2\2\u0632\u0635\5\u0146\u00a4\2\u0633")
        buf.write("\u0635\7\u0194\2\2\u0634\u0632\3\2\2\2\u0634\u0633\3\2")
        buf.write("\2\2\u0635\u063c\3\2\2\2\u0636\u0637\7\u00c0\2\2\u0637")
        buf.write("\u0638\7\u01ac\2\2\u0638\u0639\7\u00f3\2\2\u0639\u063a")
        buf.write("\7\u019b\2\2\u063a\u063b\t\r\2\2\u063b\u063d\7\u01ad\2")
        buf.write("\2\u063c\u0636\3\2\2\2\u063c\u063d\3\2\2\2\u063d\u063f")
        buf.write("\3\2\2\2\u063e\u0634\3\2\2\2\u063e\u063f\3\2\2\2\u063f")
        buf.write("\u0641\3\2\2\2\u0640\u0642\7\u01af\2\2\u0641\u0640\3\2")
        buf.write("\2\2\u0641\u0642\3\2\2\2\u0642\u0664\3\2\2\2\u0643\u0645")
        buf.write("\7\36\2\2\u0644\u0646\7\u018b\2\2\u0645\u0644\3\2\2\2")
        buf.write("\u0645\u0646\3\2\2\2\u0646\u0648\3\2\2\2\u0647\u0649\7")
        buf.write("\u01af\2\2\u0648\u0647\3\2\2\2\u0648\u0649\3\2\2\2\u0649")
        buf.write("\u0664\3\2\2\2\u064a\u064b\7\u0094\2\2\u064b\u064e\t\33")
        buf.write("\2\2\u064c\u064f\5\u0146\u00a4\2\u064d\u064f\7\u0194\2")
        buf.write("\2\u064e\u064c\3\2\2\2\u064e\u064d\3\2\2\2\u064e\u064f")
        buf.write("\3\2\2\2\u064f\u0651\3\2\2\2\u0650\u0652\7\u01af\2\2\u0651")
        buf.write("\u0650\3\2\2\2\u0651\u0652\3\2\2\2\u0652\u0664\3\2\2\2")
        buf.write("\u0653\u0655\7\u0094\2\2\u0654\u0656\7\u018b\2\2\u0655")
        buf.write("\u0654\3\2\2\2\u0655\u0656\3\2\2\2\u0656\u0658\3\2\2\2")
        buf.write("\u0657\u0659\7\u01af\2\2\u0658\u0657\3\2\2\2\u0658\u0659")
        buf.write("\3\2\2\2\u0659\u0664\3\2\2\2\u065a\u065b\7\u0098\2\2\u065b")
        buf.write("\u065e\t\33\2\2\u065c\u065f\5\u0146\u00a4\2\u065d\u065f")
        buf.write("\7\u0194\2\2\u065e\u065c\3\2\2\2\u065e\u065d\3\2\2\2\u065e")
        buf.write("\u065f\3\2\2\2\u065f\u0661\3\2\2\2\u0660\u0662\7\u01af")
        buf.write("\2\2\u0661\u0660\3\2\2\2\u0661\u0662\3\2\2\2\u0662\u0664")
        buf.write("\3\2\2\2\u0663\u0616\3\2\2\2\u0663\u0620\3\2\2\2\u0663")
        buf.write("\u0630\3\2\2\2\u0663\u0643\3\2\2\2\u0663\u064a\3\2\2\2")
        buf.write("\u0663\u0653\3\2\2\2\u0663\u065a\3\2\2\2\u0664\u0089\3")
        buf.write("\2\2\2\u0665\u0667\7\u010d\2\2\u0666\u0668\7\u0195\2\2")
        buf.write("\u0667\u0666\3\2\2\2\u0667\u0668\3\2\2\2\u0668\u008b\3")
        buf.write("\2\2\2\u0669\u066a\7\u00b7\2\2\u066a\u066c\5\u0146\u00a4")
        buf.write("\2\u066b\u066d\7\u01af\2\2\u066c\u066b\3\2\2\2\u066c\u066d")
        buf.write("\3\2\2\2\u066d\u008d\3\2\2\2\u066e\u066f\7A\2\2\u066f")
        buf.write("\u0670\7\t\2\2\u0670\u0671\t\34\2\2\u0671\u008f\3\2\2")
        buf.write("\2\u0672\u0674\7\u0194\2\2\u0673\u0675\7\t\2\2\u0674\u0673")
        buf.write("\3\2\2\2\u0674\u0675\3\2\2\2\u0675\u0676\3\2\2\2\u0676")
        buf.write("\u0679\5\u013e\u00a0\2\u0677\u0678\7\u019b\2\2\u0678\u067a")
        buf.write("\5\u00acW\2\u0679\u0677\3\2\2\2\u0679\u067a\3\2\2\2\u067a")
        buf.write("\u0091\3\2\2\2\u067b\u067c\7\u00a6\2\2\u067c\u067d\7\u01ac")
        buf.write("\2\2\u067d\u067e\5\u0094K\2\u067e\u067f\7\u01ad\2\2\u067f")
        buf.write("\u0093\3\2\2\2\u0680\u0687\5\u0096L\2\u0681\u0683\7\u01ae")
        buf.write("\2\2\u0682\u0681\3\2\2\2\u0682\u0683\3\2\2\2\u0683\u0684")
        buf.write("\3\2\2\2\u0684\u0686\5\u0096L\2\u0685\u0682\3\2\2\2\u0686")
        buf.write("\u0689\3\2\2\2\u0687\u0685\3\2\2\2\u0687\u0688\3\2\2\2")
        buf.write("\u0688\u0095\3\2\2\2\u0689\u0687\3\2\2\2\u068a\u068d\5")
        buf.write("\u0098M\2\u068b\u068d\5\u009cO\2\u068c\u068a\3\2\2\2\u068c")
        buf.write("\u068b\3\2\2\2\u068d\u0097\3\2\2\2\u068e\u0692\5\u0146")
        buf.write("\u00a4\2\u068f\u0693\5\u013e\u00a0\2\u0690\u0691\7\t\2")
        buf.write("\2\u0691\u0693\5\u00acW\2\u0692\u068f\3\2\2\2\u0692\u0690")
        buf.write("\3\2\2\2\u0693\u0696\3\2\2\2\u0694\u0695\7\34\2\2\u0695")
        buf.write("\u0697\5\u0146\u00a4\2\u0696\u0694\3\2\2\2\u0696\u0697")
        buf.write("\3\2\2\2\u0697\u0699\3\2\2\2\u0698\u069a\5\u013a\u009e")
        buf.write("\2\u0699\u0698\3\2\2\2\u0699\u069a\3\2\2\2\u069a\u06b2")
        buf.write("\3\2\2\2\u069b\u069c\7 \2\2\u069c\u069e\5\u0146\u00a4")
        buf.write("\2\u069d\u069b\3\2\2\2\u069d\u069e\3\2\2\2\u069e\u069f")
        buf.write("\3\2\2\2\u069f\u06a0\7\62\2\2\u06a0\u06a3\5\u00aeX\2\u06a1")
        buf.write("\u06a2\7\u00c0\2\2\u06a2\u06a4\7\u00b9\2\2\u06a3\u06a1")
        buf.write("\3\2\2\2\u06a3\u06a4\3\2\2\2\u06a4\u06b3\3\2\2\2\u06a5")
        buf.write("\u06ab\7U\2\2\u06a6\u06a7\7\u01ac\2\2\u06a7\u06a8\7\u0195")
        buf.write("\2\2\u06a8\u06a9\7\u01ae\2\2\u06a9\u06aa\7\u0195\2\2\u06aa")
        buf.write("\u06ac\7\u01ad\2\2\u06ab\u06a6\3\2\2\2\u06ab\u06ac\3\2")
        buf.write("\2\2\u06ac\u06b0\3\2\2\2\u06ad\u06ae\7m\2\2\u06ae\u06af")
        buf.write("\7I\2\2\u06af\u06b1\7\u008d\2\2\u06b0\u06ad\3\2\2\2\u06b0")
        buf.write("\u06b1\3\2\2\2\u06b1\u06b3\3\2\2\2\u06b2\u069d\3\2\2\2")
        buf.write("\u06b2\u06a5\3\2\2\2\u06b2\u06b3\3\2\2\2\u06b3\u06b5\3")
        buf.write("\2\2\2\u06b4\u06b6\7\u0096\2\2\u06b5\u06b4\3\2\2\2\u06b5")
        buf.write("\u06b6\3\2\2\2\u06b6\u06ba\3\2\2\2\u06b7\u06b9\5\u009a")
        buf.write("N\2\u06b8\u06b7\3\2\2\2\u06b9\u06bc\3\2\2\2\u06ba\u06b8")
        buf.write("\3\2\2\2\u06ba\u06bb\3\2\2\2\u06bb\u0099\3\2\2\2\u06bc")
        buf.write("\u06ba\3\2\2\2\u06bd\u06be\7 \2\2\u06be\u06c0\5\u0146")
        buf.write("\u00a4\2\u06bf\u06bd\3\2\2\2\u06bf\u06c0\3\2\2\2\u06c0")
        buf.write("\u06c2\3\2\2\2\u06c1\u06c3\5\u013a\u009e\2\u06c2\u06c1")
        buf.write("\3\2\2\2\u06c2\u06c3\3\2\2\2\u06c3\u06d9\3\2\2\2\u06c4")
        buf.write("\u06c5\7\u0083\2\2\u06c5\u06c8\7a\2\2\u06c6\u06c8\7\u00b3")
        buf.write("\2\2\u06c7\u06c4\3\2\2\2\u06c7\u06c6\3\2\2\2\u06c8\u06ca")
        buf.write("\3\2\2\2\u06c9\u06cb\5\u0138\u009d\2\u06ca\u06c9\3\2\2")
        buf.write("\2\u06ca\u06cb\3\2\2\2\u06cb\u06cd\3\2\2\2\u06cc\u06ce")
        buf.write("\5\u009eP\2\u06cd\u06cc\3\2\2\2\u06cd\u06ce\3\2\2\2\u06ce")
        buf.write("\u06da\3\2\2\2\u06cf\u06d3\7\27\2\2\u06d0\u06d1\7m\2\2")
        buf.write("\u06d1\u06d2\7I\2\2\u06d2\u06d4\7\u008d\2\2\u06d3\u06d0")
        buf.write("\3\2\2\2\u06d3\u06d4\3\2\2\2\u06d4\u06d5\3\2\2\2\u06d5")
        buf.write("\u06d6\7\u01ac\2\2\u06d6\u06d7\5\u00ba^\2\u06d7\u06d8")
        buf.write("\7\u01ad\2\2\u06d8\u06da\3\2\2\2\u06d9\u06c7\3\2\2\2\u06d9")
        buf.write("\u06cf\3\2\2\2\u06da\u009b\3\2\2\2\u06db\u06dc\7 \2\2")
        buf.write("\u06dc\u06de\5\u0146\u00a4\2\u06dd\u06db\3\2\2\2\u06dd")
        buf.write("\u06de\3\2\2\2\u06de\u06fe\3\2\2\2\u06df\u06e0\7\u0083")
        buf.write("\2\2\u06e0\u06e3\7a\2\2\u06e1\u06e3\7\u00b3\2\2\u06e2")
        buf.write("\u06df\3\2\2\2\u06e2\u06e1\3\2\2\2\u06e3\u06e5\3\2\2\2")
        buf.write("\u06e4\u06e6\5\u0138\u009d\2\u06e5\u06e4\3\2\2\2\u06e5")
        buf.write("\u06e6\3\2\2\2\u06e6\u06e7\3\2\2\2\u06e7\u06e8\7\u01ac")
        buf.write("\2\2\u06e8\u06ea\5\u0132\u009a\2\u06e9\u06eb\t\7\2\2\u06ea")
        buf.write("\u06e9\3\2\2\2\u06ea\u06eb\3\2\2\2\u06eb\u06ec\3\2\2\2")
        buf.write("\u06ec\u06ee\7\u01ad\2\2\u06ed\u06ef\5\u009eP\2\u06ee")
        buf.write("\u06ed\3\2\2\2\u06ee\u06ef\3\2\2\2\u06ef\u06f2\3\2\2\2")
        buf.write("\u06f0\u06f1\7s\2\2\u06f1\u06f3\5\u0146\u00a4\2\u06f2")
        buf.write("\u06f0\3\2\2\2\u06f2\u06f3\3\2\2\2\u06f3\u06ff\3\2\2\2")
        buf.write("\u06f4\u06f8\7\27\2\2\u06f5\u06f6\7m\2\2\u06f6\u06f7\7")
        buf.write("I\2\2\u06f7\u06f9\7\u008d\2\2\u06f8\u06f5\3\2\2\2\u06f8")
        buf.write("\u06f9\3\2\2\2\u06f9\u06fa\3\2\2\2\u06fa\u06fb\7\u01ac")
        buf.write("\2\2\u06fb\u06fc\5\u00ba^\2\u06fc\u06fd\7\u01ad\2\2\u06fd")
        buf.write("\u06ff\3\2\2\2\u06fe\u06e2\3\2\2\2\u06fe\u06f4\3\2\2\2")
        buf.write("\u06ff\u009d\3\2\2\2\u0700\u0701\7\u00c0\2\2\u0701\u0702")
        buf.write("\7\u01ac\2\2\u0702\u0707\5\u00a0Q\2\u0703\u0704\7\u01ae")
        buf.write("\2\2\u0704\u0706\5\u00a0Q\2\u0705\u0703\3\2\2\2\u0706")
        buf.write("\u0709\3\2\2\2\u0707\u0705\3\2\2\2\u0707\u0708\3\2\2\2")
        buf.write("\u0708\u070a\3\2\2\2\u0709\u0707\3\2\2\2\u070a\u070b\7")
        buf.write("\u01ad\2\2\u070b\u009f\3\2\2\2\u070c\u070d\5\u0148\u00a5")
        buf.write("\2\u070d\u0711\7\u019b\2\2\u070e\u0712\5\u0148\u00a5\2")
        buf.write("\u070f\u0712\5\u0136\u009c\2\u0710\u0712\7\u0195\2\2\u0711")
        buf.write("\u070e\3\2\2\2\u0711\u070f\3\2\2\2\u0711\u0710\3\2\2\2")
        buf.write("\u0712\u00a1\3\2\2\2\u0713\u0714\7\61\2\2\u0714\u0734")
        buf.write("\5\u0134\u009b\2\u0715\u071f\7-\2\2\u0716\u071d\5\u00a4")
        buf.write("S\2\u0717\u0718\7I\2\2\u0718\u071b\7\u00b5\2\2\u0719\u071a")
        buf.write("\7p\2\2\u071a\u071c\5\u0132\u009a\2\u071b\u0719\3\2\2")
        buf.write("\2\u071b\u071c\3\2\2\2\u071c\u071e\3\2\2\2\u071d\u0717")
        buf.write("\3\2\2\2\u071d\u071e\3\2\2\2\u071e\u0720\3\2\2\2\u071f")
        buf.write("\u0716\3\2\2\2\u071f\u0720\3\2\2\2\u0720\u0735\3\2\2\2")
        buf.write("\u0721\u0723\7\u0118\2\2\u0722\u0721\3\2\2\2\u0722\u0723")
        buf.write("\3\2\2\2\u0723\u0725\3\2\2\2\u0724\u0726\7\u0164\2\2\u0725")
        buf.write("\u0724\3\2\2\2\u0725\u0726\3\2\2\2\u0726\u0727\3\2\2\2")
        buf.write("\u0727\u0728\7-\2\2\u0728\u0729\7I\2\2\u0729\u0732\5\32")
        buf.write("\16\2\u072a\u0730\7I\2\2\u072b\u072c\7\u0089\2\2\u072c")
        buf.write("\u0731\7\u0141\2\2\u072d\u0731\7\u00b5\2\2\u072e\u072f")
        buf.write("\7p\2\2\u072f\u0731\5\u0132\u009a\2\u0730\u072b\3\2\2")
        buf.write("\2\u0730\u072d\3\2\2\2\u0730\u072e\3\2\2\2\u0731\u0733")
        buf.write("\3\2\2\2\u0732\u072a\3\2\2\2\u0732\u0733\3\2\2\2\u0733")
        buf.write("\u0735\3\2\2\2\u0734\u0715\3\2\2\2\u0734\u0722\3\2\2\2")
        buf.write("\u0735\u0737\3\2\2\2\u0736\u0738\7\u01af\2\2\u0737\u0736")
        buf.write("\3\2\2\2\u0737\u0738\3\2\2\2\u0738\u00a3\3\2\2\2\u0739")
        buf.write("\u073b\t\17\2\2\u073a\u0739\3\2\2\2\u073a\u073b\3\2\2")
        buf.write("\2\u073b\u073d\3\2\2\2\u073c\u073e\t\35\2\2\u073d\u073c")
        buf.write("\3\2\2\2\u073d\u073e\3\2\2\2\u073e\u0740\3\2\2\2\u073f")
        buf.write("\u0741\t\36\2\2\u0740\u073f\3\2\2\2\u0740\u0741\3\2\2")
        buf.write("\2\u0741\u0743\3\2\2\2\u0742\u0744\t\37\2\2\u0743\u0742")
        buf.write("\3\2\2\2\u0743\u0744\3\2\2\2\u0744\u0746\3\2\2\2\u0745")
        buf.write("\u0747\7\u0181\2\2\u0746\u0745\3\2\2\2\u0746\u0747\3\2")
        buf.write("\2\2\u0747\u0748\3\2\2\2\u0748\u0749\7I\2\2\u0749\u074a")
        buf.write("\5\32\16\2\u074a\u00a5\3\2\2\2\u074b\u0755\7E\2\2\u074c")
        buf.write("\u0753\7\u0135\2\2\u074d\u0753\7\u014c\2\2\u074e\u0753")
        buf.write("\7\u0105\2\2\u074f\u0753\7\u011f\2\2\u0750\u0751\t \2")
        buf.write("\2\u0751\u0753\5\u00acW\2\u0752\u074c\3\2\2\2\u0752\u074d")
        buf.write("\3\2\2\2\u0752\u074e\3\2\2\2\u0752\u074f\3\2\2\2\u0752")
        buf.write("\u0750\3\2\2\2\u0752\u0753\3\2\2\2\u0753\u0754\3\2\2\2")
        buf.write("\u0754\u0756\7N\2\2\u0755\u0752\3\2\2\2\u0755\u0756\3")
        buf.write("\2\2\2\u0756\u0758\3\2\2\2\u0757\u0759\7\u010c\2\2\u0758")
        buf.write("\u0757\3\2\2\2\u0758\u0759\3\2\2\2\u0759\u075a\3\2\2\2")
        buf.write("\u075a\u0764\5\u0134\u009b\2\u075b\u075c\7^\2\2\u075c")
        buf.write("\u0761\7\u0194\2\2\u075d\u075e\7\u01ae\2\2\u075e\u0760")
        buf.write("\7\u0194\2\2\u075f\u075d\3\2\2\2\u0760\u0763\3\2\2\2\u0761")
        buf.write("\u075f\3\2\2\2\u0761\u0762\3\2\2\2\u0762\u0765\3\2\2\2")
        buf.write("\u0763\u0761\3\2\2\2\u0764\u075b\3\2\2\2\u0764\u0765\3")
        buf.write("\2\2\2\u0765\u0767\3\2\2\2\u0766\u0768\7\u01af\2\2\u0767")
        buf.write("\u0766\3\2\2\2\u0767\u0768\3\2\2\2\u0768\u00a7\3\2\2\2")
        buf.write("\u0769\u076a\7\u00a0\2\2\u076a\u076e\5\u0146\u00a4\2\u076b")
        buf.write("\u076f\5\u0146\u00a4\2\u076c\u076f\5\u00aaV\2\u076d\u076f")
        buf.write("\5\u0136\u009c\2\u076e\u076b\3\2\2\2\u076e\u076c\3\2\2")
        buf.write("\2\u076e\u076d\3\2\2\2\u076f\u0771\3\2\2\2\u0770\u0772")
        buf.write("\7\u01af\2\2\u0771\u0770\3\2\2\2\u0771\u0772\3\2\2\2\u0772")
        buf.write("\u0795\3\2\2\2\u0773\u0774\7\u00a0\2\2\u0774\u0775\7\u00ad")
        buf.write("\2\2\u0775\u0776\7\u011a\2\2\u0776\u077f\7\u0120\2\2\u0777")
        buf.write("\u0778\7\u0089\2\2\u0778\u0780\7\u0183\2\2\u0779\u077a")
        buf.write("\7\u0089\2\2\u077a\u0780\7\u00df\2\2\u077b\u077c\7\u015a")
        buf.write("\2\2\u077c\u0780\7\u0089\2\2\u077d\u0780\7\u016d\2\2\u077e")
        buf.write("\u0780\7\u0168\2\2\u077f\u0777\3\2\2\2\u077f\u0779\3\2")
        buf.write("\2\2\u077f\u077b\3\2\2\2\u077f\u077d\3\2\2\2\u077f\u077e")
        buf.write("\3\2\2\2\u0780\u0782\3\2\2\2\u0781\u0783\7\u01af\2\2\u0782")
        buf.write("\u0781\3\2\2\2\u0782\u0783\3\2\2\2\u0783\u0795\3\2\2\2")
        buf.write("\u0784\u0785\7\u00a0\2\2\u0785\u0786\7W\2\2\u0786\u0787")
        buf.write("\5\u0128\u0095\2\u0787\u0789\5\u0136\u009c\2\u0788\u078a")
        buf.write("\7\u01af\2\2\u0789\u0788\3\2\2\2\u0789\u078a\3\2\2\2\u078a")
        buf.write("\u0795\3\2\2\2\u078b\u078c\7\u00a0\2\2\u078c\u078d\7\u00c7")
        buf.write("\2\2\u078d\u0795\5\u0136\u009c\2\u078e\u078f\7\u00a0\2")
        buf.write("\2\u078f\u0790\7\u014e\2\2\u0790\u0795\5\u0136\u009c\2")
        buf.write("\u0791\u0792\7\u00a0\2\2\u0792\u0793\7\u00c9\2\2\u0793")
        buf.write("\u0795\5\u0136\u009c\2\u0794\u0769\3\2\2\2\u0794\u0773")
        buf.write("\3\2\2\2\u0794\u0784\3\2\2\2\u0794\u078b\3\2\2\2\u0794")
        buf.write("\u078e\3\2\2\2\u0794\u0791\3\2\2\2\u0795\u00a9\3\2\2\2")
        buf.write("\u0796\u0799\5\u0142\u00a2\2\u0797\u0799\7\u0194\2\2\u0798")
        buf.write("\u0796\3\2\2\2\u0798\u0797\3\2\2\2\u0799\u00ab\3\2\2\2")
        buf.write("\u079a\u079b\bW\1\2\u079b\u07c8\7\62\2\2\u079c\u07c8\7")
        buf.write("n\2\2\u079d\u07c8\7\u0194\2\2\u079e\u07c8\5\u0142\u00a2")
        buf.write("\2\u079f\u07c8\5\u00eex\2\u07a0\u07a1\7\24\2\2\u07a1\u07a3")
        buf.write("\5\u00acW\2\u07a2\u07a4\5\u00f0y\2\u07a3\u07a2\3\2\2\2")
        buf.write("\u07a4\u07a5\3\2\2\2\u07a5\u07a3\3\2\2\2\u07a5\u07a6\3")
        buf.write("\2\2\2\u07a6\u07a9\3\2\2\2\u07a7\u07a8\7<\2\2\u07a8\u07aa")
        buf.write("\5\u00acW\2\u07a9\u07a7\3\2\2\2\u07a9\u07aa\3\2\2\2\u07aa")
        buf.write("\u07ab\3\2\2\2\u07ab\u07ac\7=\2\2\u07ac\u07c8\3\2\2\2")
        buf.write("\u07ad\u07af\7\24\2\2\u07ae\u07b0\5\u00f2z\2\u07af\u07ae")
        buf.write("\3\2\2\2\u07b0\u07b1\3\2\2\2\u07b1\u07af\3\2\2\2\u07b1")
        buf.write("\u07b2\3\2\2\2\u07b2\u07b5\3\2\2\2\u07b3\u07b4\7<\2\2")
        buf.write("\u07b4\u07b6\5\u00acW\2\u07b5\u07b3\3\2\2\2\u07b5\u07b6")
        buf.write("\3\2\2\2\u07b6\u07b7\3\2\2\2\u07b7\u07b8\7=\2\2\u07b8")
        buf.write("\u07c8\3\2\2\2\u07b9\u07c8\5\u0130\u0099\2\u07ba\u07bb")
        buf.write("\7\u01ac\2\2\u07bb\u07bc\5\u00acW\2\u07bc\u07bd\7\u01ad")
        buf.write("\2\2\u07bd\u07c8\3\2\2\2\u07be\u07bf\7\u01ac\2\2\u07bf")
        buf.write("\u07c0\5\u00b0Y\2\u07c0\u07c1\7\u01ad\2\2\u07c1\u07c8")
        buf.write("\3\2\2\2\u07c2\u07c3\7\u01b6\2\2\u07c3\u07c8\5\u00acW")
        buf.write("\b\u07c4\u07c5\t!\2\2\u07c5\u07c8\5\u00acW\6\u07c6\u07c8")
        buf.write("\5\u0110\u0089\2\u07c7\u079a\3\2\2\2\u07c7\u079c\3\2\2")
        buf.write("\2\u07c7\u079d\3\2\2\2\u07c7\u079e\3\2\2\2\u07c7\u079f")
        buf.write("\3\2\2\2\u07c7\u07a0\3\2\2\2\u07c7\u07ad\3\2\2\2\u07c7")
        buf.write("\u07b9\3\2\2\2\u07c7\u07ba\3\2\2\2\u07c7\u07be\3\2\2\2")
        buf.write("\u07c7\u07c2\3\2\2\2\u07c7\u07c4\3\2\2\2\u07c7\u07c6\3")
        buf.write("\2\2\2\u07c8\u07d8\3\2\2\2\u07c9\u07ca\f\7\2\2\u07ca\u07cb")
        buf.write("\t\"\2\2\u07cb\u07d7\5\u00acW\b\u07cc\u07cd\f\5\2\2\u07cd")
        buf.write("\u07ce\t#\2\2\u07ce\u07d7\5\u00acW\6\u07cf\u07d0\f\4\2")
        buf.write("\2\u07d0\u07d1\5\u014a\u00a6\2\u07d1\u07d2\5\u00acW\5")
        buf.write("\u07d2\u07d7\3\2\2\2\u07d3\u07d4\f\16\2\2\u07d4\u07d5")
        buf.write("\7\34\2\2\u07d5\u07d7\5\u0146\u00a4\2\u07d6\u07c9\3\2")
        buf.write("\2\2\u07d6\u07cc\3\2\2\2\u07d6\u07cf\3\2\2\2\u07d6\u07d3")
        buf.write("\3\2\2\2\u07d7\u07da\3\2\2\2\u07d8\u07d6\3\2\2\2\u07d8")
        buf.write("\u07d9\3\2\2\2\u07d9\u00ad\3\2\2\2\u07da\u07d8\3\2\2\2")
        buf.write("\u07db\u07e4\7n\2\2\u07dc\u07e4\5\u0142\u00a2\2\u07dd")
        buf.write("\u07e4\5\u00eex\2\u07de\u07e4\7\u0194\2\2\u07df\u07e0")
        buf.write("\7\u01ac\2\2\u07e0\u07e1\5\u00aeX\2\u07e1\u07e2\7\u01ad")
        buf.write("\2\2\u07e2\u07e4\3\2\2\2\u07e3\u07db\3\2\2\2\u07e3\u07dc")
        buf.write("\3\2\2\2\u07e3\u07dd\3\2\2\2\u07e3\u07de\3\2\2\2\u07e3")
        buf.write("\u07df\3\2\2\2\u07e4\u00af\3\2\2\2\u07e5\u07e6\5\32\16")
        buf.write("\2\u07e6\u00b1\3\2\2\2\u07e7\u07ea\7\u00c0\2\2\u07e8\u07e9")
        buf.write("\7\u018d\2\2\u07e9\u07eb\7\u01ae\2\2\u07ea\u07e8\3\2\2")
        buf.write("\2\u07ea\u07eb\3\2\2\2\u07eb\u07ec\3\2\2\2\u07ec\u07f1")
        buf.write("\5\u00b4[\2\u07ed\u07ee\7\u01ae\2\2\u07ee\u07f0\5\u00b4")
        buf.write("[\2\u07ef\u07ed\3\2\2\2\u07f0\u07f3\3\2\2\2\u07f1\u07ef")
        buf.write("\3\2\2\2\u07f1\u07f2\3\2\2\2\u07f2\u00b3\3\2\2\2\u07f3")
        buf.write("\u07f1\3\2\2\2\u07f4\u07f9\5\u0146\u00a4\2\u07f5\u07f6")
        buf.write("\7\u01ac\2\2\u07f6\u07f7\5\u0132\u009a\2\u07f7\u07f8\7")
        buf.write("\u01ad\2\2\u07f8\u07fa\3\2\2\2\u07f9\u07f5\3\2\2\2\u07f9")
        buf.write("\u07fa\3\2\2\2\u07fa\u07fb\3\2\2\2\u07fb\u07fc\7\t\2\2")
        buf.write("\u07fc\u07fd\7\u01ac\2\2\u07fd\u07fe\5\32\16\2\u07fe\u07ff")
        buf.write("\7\u01ad\2\2\u07ff\u00b5\3\2\2\2\u0800\u0803\5\u0130\u0099")
        buf.write("\2\u0801\u0803\7\u0194\2\2\u0802\u0800\3\2\2\2\u0802\u0801")
        buf.write("\3\2\2\2\u0803\u0806\3\2\2\2\u0804\u0807\7\u019b\2\2\u0805")
        buf.write("\u0807\5\u014c\u00a7\2\u0806\u0804\3\2\2\2\u0806\u0805")
        buf.write("\3\2\2\2\u0807\u0808\3\2\2\2\u0808\u0811\5\u00acW\2\u0809")
        buf.write("\u080a\5\u0146\u00a4\2\u080a\u080b\7\u01a7\2\2\u080b\u080c")
        buf.write("\5\u0146\u00a4\2\u080c\u080d\7\u01ac\2\2\u080d\u080e\5")
        buf.write("\u0108\u0085\2\u080e\u080f\7\u01ad\2\2\u080f\u0811\3\2")
        buf.write("\2\2\u0810\u0802\3\2\2\2\u0810\u0809\3\2\2\2\u0811\u00b7")
        buf.write("\3\2\2\2\u0812\u0817\5\u00ba^\2\u0813\u0814\7\u01ae\2")
        buf.write("\2\u0814\u0816\5\u00ba^\2\u0815\u0813\3\2\2\2\u0816\u0819")
        buf.write("\3\2\2\2\u0817\u0815\3\2\2\2\u0817\u0818\3\2\2\2\u0818")
        buf.write("\u00b9\3\2\2\2\u0819\u0817\3\2\2\2\u081a\u081b\b^\1\2")
        buf.write("\u081b\u081c\5\u00bc_\2\u081c\u0825\3\2\2\2\u081d\u081e")
        buf.write("\f\5\2\2\u081e\u081f\7\7\2\2\u081f\u0824\5\u00ba^\6\u0820")
        buf.write("\u0821\f\4\2\2\u0821\u0822\7z\2\2\u0822\u0824\5\u00ba")
        buf.write("^\5\u0823\u081d\3\2\2\2\u0823\u0820\3\2\2\2\u0824\u0827")
        buf.write("\3\2\2\2\u0825\u0823\3\2\2\2\u0825\u0826\3\2\2\2\u0826")
        buf.write("\u00bb\3\2\2\2\u0827\u0825\3\2\2\2\u0828\u0829\7m\2\2")
        buf.write("\u0829\u0863\5\u00bc_\2\u082a\u082b\7B\2\2\u082b\u082c")
        buf.write("\7\u01ac\2\2\u082c\u082d\5\u00b0Y\2\u082d\u082e\7\u01ad")
        buf.write("\2\2\u082e\u0863\3\2\2\2\u082f\u0830\5\u00acW\2\u0830")
        buf.write("\u0831\5\u014a\u00a6\2\u0831\u0832\5\u00acW\2\u0832\u0863")
        buf.write("\3\2\2\2\u0833\u0834\5\u00acW\2\u0834\u0835\5\u014a\u00a6")
        buf.write("\2\u0835\u0836\t$\2\2\u0836\u0837\7\u01ac\2\2\u0837\u0838")
        buf.write("\5\u00b0Y\2\u0838\u0839\7\u01ad\2\2\u0839\u0863\3\2\2")
        buf.write("\2\u083a\u083c\5\u00acW\2\u083b\u083d\7m\2\2\u083c\u083b")
        buf.write("\3\2\2\2\u083c\u083d\3\2\2\2\u083d\u083e\3\2\2\2\u083e")
        buf.write("\u083f\7\16\2\2\u083f\u0840\5\u00acW\2\u0840\u0841\7\7")
        buf.write("\2\2\u0841\u0842\5\u00acW\2\u0842\u0863\3\2\2\2\u0843")
        buf.write("\u0845\5\u00acW\2\u0844\u0846\7m\2\2\u0845\u0844\3\2\2")
        buf.write("\2\u0845\u0846\3\2\2\2\u0846\u0847\3\2\2\2\u0847\u0848")
        buf.write("\7Y\2\2\u0848\u084b\7\u01ac\2\2\u0849\u084c\5\u00b0Y\2")
        buf.write("\u084a\u084c\5\u0108\u0085\2\u084b\u0849\3\2\2\2\u084b")
        buf.write("\u084a\3\2\2\2\u084c\u084d\3\2\2\2\u084d\u084e\7\u01ad")
        buf.write("\2\2\u084e\u0863\3\2\2\2\u084f\u0851\5\u00acW\2\u0850")
        buf.write("\u0852\7m\2\2\u0851\u0850\3\2\2\2\u0851\u0852\3\2\2\2")
        buf.write("\u0852\u0853\3\2\2\2\u0853\u0854\7d\2\2\u0854\u0857\5")
        buf.write("\u00acW\2\u0855\u0856\7?\2\2\u0856\u0858\5\u00acW\2\u0857")
        buf.write("\u0855\3\2\2\2\u0857\u0858\3\2\2\2\u0858\u0863\3\2\2\2")
        buf.write("\u0859\u085a\5\u00acW\2\u085a\u085b\7_\2\2\u085b\u085c")
        buf.write("\5\u013a\u009e\2\u085c\u0863\3\2\2\2\u085d\u085e\7\u01ac")
        buf.write("\2\2\u085e\u085f\5\u00ba^\2\u085f\u0860\7\u01ad\2\2\u0860")
        buf.write("\u0863\3\2\2\2\u0861\u0863\7\u0195\2\2\u0862\u0828\3\2")
        buf.write("\2\2\u0862\u082a\3\2\2\2\u0862\u082f\3\2\2\2\u0862\u0833")
        buf.write("\3\2\2\2\u0862\u083a\3\2\2\2\u0862\u0843\3\2\2\2\u0862")
        buf.write("\u084f\3\2\2\2\u0862\u0859\3\2\2\2\u0862\u085d\3\2\2\2")
        buf.write("\u0862\u0861\3\2\2\2\u0863\u00bd\3\2\2\2\u0864\u086a\5")
        buf.write("\u00c2b\2\u0865\u0866\7\u01ac\2\2\u0866\u0867\5\u00be")
        buf.write("`\2\u0867\u0868\7\u01ad\2\2\u0868\u086a\3\2\2\2\u0869")
        buf.write("\u0864\3\2\2\2\u0869\u0865\3\2\2\2\u086a\u086e\3\2\2\2")
        buf.write("\u086b\u086d\5\u00c0a\2\u086c\u086b\3\2\2\2\u086d\u0870")
        buf.write("\3\2\2\2\u086e\u086c\3\2\2\2\u086e\u086f\3\2\2\2\u086f")
        buf.write("\u00bf\3\2\2\2\u0870\u086e\3\2\2\2\u0871\u0873\7\u00b2")
        buf.write("\2\2\u0872\u0874\7\5\2\2\u0873\u0872\3\2\2\2\u0873\u0874")
        buf.write("\3\2\2\2\u0874\u0878\3\2\2\2\u0875\u0878\7@\2\2\u0876")
        buf.write("\u0878\7]\2\2\u0877\u0871\3\2\2\2\u0877\u0875\3\2\2\2")
        buf.write("\u0877\u0876\3\2\2\2\u0878\u0882\3\2\2\2\u0879\u0883\5")
        buf.write("\u00c2b\2\u087a\u087b\7\u01ac\2\2\u087b\u087c\5\u00be")
        buf.write("`\2\u087c\u087d\7\u01ad\2\2\u087d\u087f\3\2\2\2\u087e")
        buf.write("\u087a\3\2\2\2\u087f\u0880\3\2\2\2\u0880\u087e\3\2\2\2")
        buf.write("\u0880\u0881\3\2\2\2\u0881\u0883\3\2\2\2\u0882\u0879\3")
        buf.write("\2\2\2\u0882\u087e\3\2\2\2\u0883\u00c1\3\2\2\2\u0884\u0886")
        buf.write("\7\u009b\2\2\u0885\u0887\t%\2\2\u0886\u0885\3\2\2\2\u0886")
        buf.write("\u0887\3\2\2\2\u0887\u0889\3\2\2\2\u0888\u088a\5\u00c4")
        buf.write("c\2\u0889\u0888\3\2\2\2\u0889\u088a\3\2\2\2\u088a\u088b")
        buf.write("\3\2\2\2\u088b\u088e\5\u00d6l\2\u088c\u088d\7^\2\2\u088d")
        buf.write("\u088f\5\u0128\u0095\2\u088e\u088c\3\2\2\2\u088e\u088f")
        buf.write("\3\2\2\2\u088f\u0892\3\2\2\2\u0890\u0891\7N\2\2\u0891")
        buf.write("\u0893\5\u00dan\2\u0892\u0890\3\2\2\2\u0892\u0893\3\2")
        buf.write("\2\2\u0893\u0896\3\2\2\2\u0894\u0895\7\u00be\2\2\u0895")
        buf.write("\u0897\5\u00ba^\2\u0896\u0894\3\2\2\2\u0896\u0897\3\2")
        buf.write("\2\2\u0897\u08a2\3\2\2\2\u0898\u0899\7S\2\2\u0899\u089a")
        buf.write("\7\22\2\2\u089a\u089f\5\u00ceh\2\u089b\u089c\7\u01ae\2")
        buf.write("\2\u089c\u089e\5\u00ceh\2\u089d\u089b\3\2\2\2\u089e\u08a1")
        buf.write("\3\2\2\2\u089f\u089d\3\2\2\2\u089f\u08a0\3\2\2\2\u08a0")
        buf.write("\u08a3\3\2\2\2\u08a1\u089f\3\2\2\2\u08a2\u0898\3\2\2\2")
        buf.write("\u08a2\u08a3\3\2\2\2\u08a3\u08a6\3\2\2\2\u08a4\u08a5\7")
        buf.write("T\2\2\u08a5\u08a7\5\u00ba^\2\u08a6\u08a4\3\2\2\2\u08a6")
        buf.write("\u08a7\3\2\2\2\u08a7\u00c3\3\2\2\2\u08a8\u08a9\7\u00ab")
        buf.write("\2\2\u08a9\u08ab\5\u00acW\2\u08aa\u08ac\7\177\2\2\u08ab")
        buf.write("\u08aa\3\2\2\2\u08ab\u08ac\3\2\2\2\u08ac\u08af\3\2\2\2")
        buf.write("\u08ad\u08ae\7\u00c0\2\2\u08ae\u08b0\7\u0179\2\2\u08af")
        buf.write("\u08ad\3\2\2\2\u08af\u08b0\3\2\2\2\u08b0\u00c5\3\2\2\2")
        buf.write("\u08b1\u08b2\7{\2\2\u08b2\u08b3\7\22\2\2\u08b3\u08b8\5")
        buf.write("\u00ccg\2\u08b4\u08b5\7\u01ae\2\2\u08b5\u08b7\5\u00cc")
        buf.write("g\2\u08b6\u08b4\3\2\2\2\u08b7\u08ba\3\2\2\2\u08b8\u08b6")
        buf.write("\3\2\2\2\u08b8\u08b9\3\2\2\2\u08b9\u08c6\3\2\2\2\u08ba")
        buf.write("\u08b8\3\2\2\2\u08bb\u08bc\7\u013f\2\2\u08bc\u08bd\5\u00ac")
        buf.write("W\2\u08bd\u08c4\t&\2\2\u08be\u08bf\7E\2\2\u08bf\u08c0")
        buf.write("\t\'\2\2\u08c0\u08c1\5\u00acW\2\u08c1\u08c2\t&\2\2\u08c2")
        buf.write("\u08c3\7\u0141\2\2\u08c3\u08c5\3\2\2\2\u08c4\u08be\3\2")
        buf.write("\2\2\u08c4\u08c5\3\2\2\2\u08c5\u08c7\3\2\2\2\u08c6\u08bb")
        buf.write("\3\2\2\2\u08c6\u08c7\3\2\2\2\u08c7\u00c7\3\2\2\2\u08c8")
        buf.write("\u08c9\7I\2\2\u08c9\u08dc\7\20\2\2\u08ca\u08cb\7I\2\2")
        buf.write("\u08cb\u08cc\7\u018c\2\2\u08cc\u08ce\7\u00cd\2\2\u08cd")
        buf.write("\u08cf\5\u00caf\2\u08ce\u08cd\3\2\2\2\u08ce\u08cf\3\2")
        buf.write("\2\2\u08cf\u08dc\3\2\2\2\u08d0\u08d1\7I\2\2\u08d1\u08d2")
        buf.write("\7\u018c\2\2\u08d2\u08d6\7\u014a\2\2\u08d3\u08d4\7\u01ac")
        buf.write("\2\2\u08d4\u08d5\7\u0197\2\2\u08d5\u08d7\7\u01ad\2\2\u08d6")
        buf.write("\u08d3\3\2\2\2\u08d6\u08d7\3\2\2\2\u08d7\u08d9\3\2\2\2")
        buf.write("\u08d8\u08da\5\u00caf\2\u08d9\u08d8\3\2\2\2\u08d9\u08da")
        buf.write("\3\2\2\2\u08da\u08dc\3\2\2\2\u08db\u08c8\3\2\2\2\u08db")
        buf.write("\u08ca\3\2\2\2\u08db\u08d0\3\2\2\2\u08dc\u00c9\3\2\2\2")
        buf.write("\u08dd\u08e2\7\u01ae\2\2\u08de\u08df\7\u0198\2\2\u08df")
        buf.write("\u08e3\7\u00d5\2\2\u08e0\u08e3\7\u0180\2\2\u08e1\u08e3")
        buf.write("\7\u015d\2\2\u08e2\u08de\3\2\2\2\u08e2\u08e0\3\2\2\2\u08e2")
        buf.write("\u08e1\3\2\2\2\u08e3\u00cb\3\2\2\2\u08e4\u08e6\5\u00ac")
        buf.write("W\2\u08e5\u08e7\t\7\2\2\u08e6\u08e5\3\2\2\2\u08e6\u08e7")
        buf.write("\3\2\2\2\u08e7\u00cd\3\2\2\2\u08e8\u08e9\5\u00acW\2\u08e9")
        buf.write("\u00cf\3\2\2\2\u08ea\u08eb\7y\2\2\u08eb\u08ec\7\u01ac")
        buf.write("\2\2\u08ec\u08f1\5\u00d2j\2\u08ed\u08ee\7\u01ae\2\2\u08ee")
        buf.write("\u08f0\5\u00d2j\2\u08ef\u08ed\3\2\2\2\u08f0\u08f3\3\2")
        buf.write("\2\2\u08f1\u08ef\3\2\2\2\u08f1\u08f2\3\2\2\2\u08f2\u08f4")
        buf.write("\3\2\2\2\u08f3\u08f1\3\2\2\2\u08f4\u08f5\7\u01ad\2\2\u08f5")
        buf.write("\u00d1\3\2\2\2\u08f6\u08f7\7\u0100\2\2\u08f7\u0924\7\u0195")
        buf.write("\2\2\u08f8\u08f9\t(\2\2\u08f9\u0924\7S\2\2\u08fa\u08fb")
        buf.write("\t)\2\2\u08fb\u0924\7\u00b2\2\2\u08fc\u08fd\t*\2\2\u08fd")
        buf.write("\u0924\7`\2\2\u08fe\u08ff\7\u00ff\2\2\u08ff\u0924\7\u0189")
        buf.write("\2\2\u0900\u0901\7\u0107\2\2\u0901\u0924\7{\2\2\u0902")
        buf.write("\u0924\7\u0114\2\2\u0903\u0904\7\u011c\2\2\u0904\u0924")
        buf.write("\7\u0081\2\2\u0905\u0906\7\u011d\2\2\u0906\u0924\7\u0081")
        buf.write("\2\2\u0907\u0908\7\u0127\2\2\u0908\u0924\7\u0195\2\2\u0909")
        buf.write("\u090a\7\u0128\2\2\u090a\u0924\7\u0195\2\2\u090b\u090c")
        buf.write("\7\u0143\2\2\u090c\u090d\7I\2\2\u090d\u090e\7\u01ac\2")
        buf.write("\2\u090e\u0913\5\u00d4k\2\u090f\u0910\7\u01ae\2\2\u0910")
        buf.write("\u0912\5\u00d4k\2\u0911\u090f\3\2\2\2\u0912\u0915\3\2")
        buf.write("\2\2\u0913\u0911\3\2\2\2\u0913\u0914\3\2\2\2\u0914\u0916")
        buf.write("\3\2\2\2\u0915\u0913\3\2\2\2\u0916\u0917\7\u01ad\2\2\u0917")
        buf.write("\u0924\3\2\2\2\u0918\u0919\7\u0143\2\2\u0919\u091a\7I")
        buf.write("\2\2\u091a\u0924\7\u0184\2\2\u091b\u091c\7\u0148\2\2\u091c")
        buf.write("\u0924\t\24\2\2\u091d\u0924\7\u0155\2\2\u091e\u091f\7")
        buf.write("\u015c\2\2\u091f\u0924\7\u0081\2\2\u0920\u0921\7\u00b7")
        buf.write("\2\2\u0921\u0922\7\u0081\2\2\u0922\u0924\7\u0197\2\2\u0923")
        buf.write("\u08f6\3\2\2\2\u0923\u08f8\3\2\2\2\u0923\u08fa\3\2\2\2")
        buf.write("\u0923\u08fc\3\2\2\2\u0923\u08fe\3\2\2\2\u0923\u0900\3")
        buf.write("\2\2\2\u0923\u0902\3\2\2\2\u0923\u0903\3\2\2\2\u0923\u0905")
        buf.write("\3\2\2\2\u0923\u0907\3\2\2\2\u0923\u0909\3\2\2\2\u0923")
        buf.write("\u090b\3\2\2\2\u0923\u0918\3\2\2\2\u0923\u091b\3\2\2\2")
        buf.write("\u0923\u091d\3\2\2\2\u0923\u091e\3\2\2\2\u0923\u0920\3")
        buf.write("\2\2\2\u0924\u00d3\3\2\2\2\u0925\u0929\7\u0194\2\2\u0926")
        buf.write("\u092a\7\u0184\2\2\u0927\u0928\7\u019b\2\2\u0928\u092a")
        buf.write("\5\u0142\u00a2\2\u0929\u0926\3\2\2\2\u0929\u0927\3\2\2")
        buf.write("\2\u092a\u00d5\3\2\2\2\u092b\u0930\5\u00d8m\2\u092c\u092d")
        buf.write("\7\u01ae\2\2\u092d\u092f\5\u00d8m\2\u092e\u092c\3\2\2")
        buf.write("\2\u092f\u0932\3\2\2\2\u0930\u092e\3\2\2\2\u0930\u0931")
        buf.write("\3\2\2\2\u0931\u00d7\3\2\2\2\u0932\u0930\3\2\2\2\u0933")
        buf.write("\u0934\5\u0128\u0095\2\u0934\u0935\7\u01a7\2\2\u0935\u0937")
        buf.write("\3\2\2\2\u0936\u0933\3\2\2\2\u0936\u0937\3\2\2\2\u0937")
        buf.write("\u093b\3\2\2\2\u0938\u093c\5\u0104\u0083\2\u0939\u093a")
        buf.write("\7\u01ab\2\2\u093a\u093c\t+\2\2\u093b\u0938\3\2\2\2\u093b")
        buf.write("\u0939\3\2\2\2\u093c\u0949\3\2\2\2\u093d\u093e\5\u0102")
        buf.write("\u0082\2\u093e\u093f\7\u019b\2\2\u093f\u0940\5\u00acW")
        buf.write("\2\u0940\u0949\3\2\2\2\u0941\u0946\5\u00acW\2\u0942\u0944")
        buf.write("\7\t\2\2\u0943\u0942\3\2\2\2\u0943\u0944\3\2\2\2\u0944")
        buf.write("\u0945\3\2\2\2\u0945\u0947\5\u0102\u0082\2\u0946\u0943")
        buf.write("\3\2\2\2\u0946\u0947\3\2\2\2\u0947\u0949\3\2\2\2\u0948")
        buf.write("\u0936\3\2\2\2\u0948\u093d\3\2\2\2\u0948\u0941\3\2\2\2")
        buf.write("\u0949\u00d9\3\2\2\2\u094a\u094f\5\u00dco\2\u094b\u094c")
        buf.write("\7\u01ae\2\2\u094c\u094e\5\u00dco\2\u094d\u094b\3\2\2")
        buf.write("\2\u094e\u0951\3\2\2\2\u094f\u094d\3\2\2\2\u094f\u0950")
        buf.write("\3\2\2\2\u0950\u00db\3\2\2\2\u0951\u094f\3\2\2\2\u0952")
        buf.write("\u0958\5\u00dep\2\u0953\u0954\7\u01ac\2\2\u0954\u0955")
        buf.write("\5\u00dep\2\u0955\u0956\7\u01ad\2\2\u0956\u0958\3\2\2")
        buf.write("\2\u0957\u0952\3\2\2\2\u0957\u0953\3\2\2\2\u0958\u00dd")
        buf.write("\3\2\2\2\u0959\u095d\5\u00e0q\2\u095a\u095c\5\u00e4s\2")
        buf.write("\u095b\u095a\3\2\2\2\u095c\u095f\3\2\2\2\u095d\u095b\3")
        buf.write("\2\2\2\u095d\u095e\3\2\2\2\u095e\u00df\3\2\2\2\u095f\u095d")
        buf.write("\3\2\2\2\u0960\u0962\5\u00e6t\2\u0961\u0963\5\u00f4{\2")
        buf.write("\u0962\u0961\3\2\2\2\u0962\u0963\3\2\2\2\u0963\u0984\3")
        buf.write("\2\2\2\u0964\u0966\5\u00e8u\2\u0965\u0967\5\u00f4{\2\u0966")
        buf.write("\u0965\3\2\2\2\u0966\u0967\3\2\2\2\u0967\u0984\3\2\2\2")
        buf.write("\u0968\u096d\5\u00ecw\2\u0969\u096b\5\u00f4{\2\u096a\u096c")
        buf.write("\5\u0100\u0081\2\u096b\u096a\3\2\2\2\u096b\u096c\3\2\2")
        buf.write("\2\u096c\u096e\3\2\2\2\u096d\u0969\3\2\2\2\u096d\u096e")
        buf.write("\3\2\2\2\u096e\u0984\3\2\2\2\u096f\u0970\5\u00e2r\2\u0970")
        buf.write("\u0971\5\u00f4{\2\u0971\u0984\3\2\2\2\u0972\u0974\5\u00ee")
        buf.write("x\2\u0973\u0975\5\u00f4{\2\u0974\u0973\3\2\2\2\u0974\u0975")
        buf.write("\3\2\2\2\u0975\u0984\3\2\2\2\u0976\u0978\7\u0194\2\2\u0977")
        buf.write("\u0979\5\u00f4{\2\u0978\u0977\3\2\2\2\u0978\u0979\3\2")
        buf.write("\2\2\u0979\u0984\3\2\2\2\u097a\u097b\7\u0194\2\2\u097b")
        buf.write("\u097c\7\u01a7\2\2\u097c\u0981\5\u00eex\2\u097d\u097f")
        buf.write("\5\u00f4{\2\u097e\u0980\5\u0100\u0081\2\u097f\u097e\3")
        buf.write("\2\2\2\u097f\u0980\3\2\2\2\u0980\u0982\3\2\2\2\u0981\u097d")
        buf.write("\3\2\2\2\u0981\u0982\3\2\2\2\u0982\u0984\3\2\2\2\u0983")
        buf.write("\u0960\3\2\2\2\u0983\u0964\3\2\2\2\u0983\u0968\3\2\2\2")
        buf.write("\u0983\u096f\3\2\2\2\u0983\u0972\3\2\2\2\u0983\u0976\3")
        buf.write("\2\2\2\u0983\u097a\3\2\2\2\u0984\u00e1\3\2\2\2\u0985\u0986")
        buf.write("\7\25\2\2\u0986\u0987\7\u01ac\2\2\u0987\u0988\7\26\2\2")
        buf.write("\u0988\u0989\5\u0128\u0095\2\u0989\u098a\7\u01ae\2\2\u098a")
        buf.write("\u098b\t,\2\2\u098b\u098c\7\u01ad\2\2\u098c\u00e3\3\2")
        buf.write("\2\2\u098d\u098f\7[\2\2\u098e\u098d\3\2\2\2\u098e\u098f")
        buf.write("\3\2\2\2\u098f\u0995\3\2\2\2\u0990\u0992\t-\2\2\u0991")
        buf.write("\u0993\7|\2\2\u0992\u0991\3\2\2\2\u0992\u0993\3\2\2\2")
        buf.write("\u0993\u0995\3\2\2\2\u0994\u098e\3\2\2\2\u0994\u0990\3")
        buf.write("\2\2\2\u0995\u0997\3\2\2\2\u0996\u0998\t.\2\2\u0997\u0996")
        buf.write("\3\2\2\2\u0997\u0998\3\2\2\2\u0998\u0999\3\2\2\2\u0999")
        buf.write("\u099a\7`\2\2\u099a\u099b\5\u00dco\2\u099b\u099c\7s\2")
        buf.write("\2\u099c\u099d\5\u00ba^\2\u099d\u09a8\3\2\2\2\u099e\u099f")
        buf.write("\7\'\2\2\u099f\u09a0\7`\2\2\u09a0\u09a8\5\u00dco\2\u09a1")
        buf.write("\u09a2\7\'\2\2\u09a2\u09a3\7\u00cb\2\2\u09a3\u09a8\5\u00dc")
        buf.write("o\2\u09a4\u09a5\7|\2\2\u09a5\u09a6\7\u00cb\2\2\u09a6\u09a8")
        buf.write("\5\u00dco\2\u09a7\u0994\3\2\2\2\u09a7\u099e\3\2\2\2\u09a7")
        buf.write("\u09a1\3\2\2\2\u09a7\u09a4\3\2\2\2\u09a8\u00e5\3\2\2\2")
        buf.write("\u09a9\u09ab\5\u0128\u0095\2\u09aa\u09ac\5\u00f8}\2\u09ab")
        buf.write("\u09aa\3\2\2\2\u09ab\u09ac\3\2\2\2\u09ac\u00e7\3\2\2\2")
        buf.write("\u09ad\u09ae\7w\2\2\u09ae\u09af\7\u01ac\2\2\u09af\u09b0")
        buf.write("\7\u0197\2\2\u09b0\u09b1\7\u01ae\2\2\u09b1\u09b2\7\u0197")
        buf.write("\2\2\u09b2\u09b3\7\u01ae\2\2\u09b3\u09b4\7\u0197\2\2\u09b4")
        buf.write("\u09c8\7\u01ad\2\2\u09b5\u09b6\7w\2\2\u09b6\u09b7\7\u01ac")
        buf.write("\2\2\u09b7\u09b8\7\21\2\2\u09b8\u09b9\7\u0197\2\2\u09b9")
        buf.write("\u09c3\7\u01ae\2\2\u09ba\u09bf\5\u00eav\2\u09bb\u09bc")
        buf.write("\7\u01ae\2\2\u09bc\u09be\5\u00eav\2\u09bd\u09bb\3\2\2")
        buf.write("\2\u09be\u09c1\3\2\2\2\u09bf\u09bd\3\2\2\2\u09bf\u09c0")
        buf.write("\3\2\2\2\u09c0\u09c4\3\2\2\2\u09c1\u09bf\3\2\2\2\u09c2")
        buf.write("\u09c4\5\u0146\u00a4\2\u09c3\u09ba\3\2\2\2\u09c3\u09c2")
        buf.write("\3\2\2\2\u09c4\u09c5\3\2\2\2\u09c5\u09c6\7\u01ad\2\2\u09c6")
        buf.write("\u09c8\3\2\2\2\u09c7\u09ad\3\2\2\2\u09c7\u09b5\3\2\2\2")
        buf.write("\u09c8\u00e9\3\2\2\2\u09c9\u09ca\5\u0146\u00a4\2\u09ca")
        buf.write("\u09cb\7\u019b\2\2\u09cb\u09cc\t/\2\2\u09cc\u00eb\3\2")
        buf.write("\2\2\u09cd\u09d3\5\u00b0Y\2\u09ce\u09cf\7\u01ac\2\2\u09cf")
        buf.write("\u09d0\5\u00b0Y\2\u09d0\u09d1\7\u01ad\2\2\u09d1\u09d3")
        buf.write("\3\2\2\2\u09d2\u09cd\3\2\2\2\u09d2\u09ce\3\2\2\2\u09d3")
        buf.write("\u00ed\3\2\2\2\u09d4\u0a36\5\u010a\u0086\2\u09d5\u0a36")
        buf.write("\5\u010c\u0087\2\u09d6\u09d7\5\u013c\u009f\2\u09d7\u09d9")
        buf.write("\7\u01ac\2\2\u09d8\u09da\5\u0108\u0085\2\u09d9\u09d8\3")
        buf.write("\2\2\2\u09d9\u09da\3\2\2\2\u09da\u09db\3\2\2\2\u09db\u09dc")
        buf.write("\7\u01ad\2\2\u09dc\u0a36\3\2\2\2\u09dd\u09de\7\u00d6\2")
        buf.write("\2\u09de\u09df\7\u01ac\2\2\u09df\u09e0\7\u01b1\2\2\u09e0")
        buf.write("\u0a36\7\u01ad\2\2\u09e1\u09e2\7\u00d9\2\2\u09e2\u09e3")
        buf.write("\7\u01ac\2\2\u09e3\u09e4\5\u00acW\2\u09e4\u09e5\7\t\2")
        buf.write("\2\u09e5\u09e6\5\u013e\u00a0\2\u09e6\u09e7\7\u01ad\2\2")
        buf.write("\u09e7\u0a36\3\2\2\2\u09e8\u09e9\7%\2\2\u09e9\u09ea\7")
        buf.write("\u01ac\2\2\u09ea\u09eb\5\u013e\u00a0\2\u09eb\u09ec\7\u01ae")
        buf.write("\2\2\u09ec\u09ef\5\u00acW\2\u09ed\u09ee\7\u01ae\2\2\u09ee")
        buf.write("\u09f0\5\u00acW\2\u09ef\u09ed\3\2\2\2\u09ef\u09f0\3\2")
        buf.write("\2\2\u09f0\u09f1\3\2\2\2\u09f1\u09f2\7\u01ad\2\2\u09f2")
        buf.write("\u0a36\3\2\2\2\u09f3\u09f4\7\u00dd\2\2\u09f4\u09f5\7\u01ac")
        buf.write("\2\2\u09f5\u09f6\7\u01b1\2\2\u09f6\u0a36\7\u01ad\2\2\u09f7")
        buf.write("\u09f8\7\33\2\2\u09f8\u09f9\7\u01ac\2\2\u09f9\u09fa\5")
        buf.write("\u0108\u0085\2\u09fa\u09fb\7\u01ad\2\2\u09fb\u0a36\3\2")
        buf.write("\2\2\u09fc\u0a36\7+\2\2\u09fd\u0a36\7,\2\2\u09fe\u09ff")
        buf.write("\7\u00e9\2\2\u09ff\u0a00\7\u01ac\2\2\u0a00\u0a01\7\u0196")
        buf.write("\2\2\u0a01\u0a02\7\u01ae\2\2\u0a02\u0a03\5\u00acW\2\u0a03")
        buf.write("\u0a04\7\u01ae\2\2\u0a04\u0a05\5\u00acW\2\u0a05\u0a06")
        buf.write("\7\u01ad\2\2\u0a06\u0a36\3\2\2\2\u0a07\u0a08\7\u00ea\2")
        buf.write("\2\u0a08\u0a09\7\u01ac\2\2\u0a09\u0a0a\7\u0196\2\2\u0a0a")
        buf.write("\u0a0b\7\u01ae\2\2\u0a0b\u0a0c\5\u00acW\2\u0a0c\u0a0d")
        buf.write("\7\u01ae\2\2\u0a0d\u0a0e\5\u00acW\2\u0a0e\u0a0f\7\u01ad")
        buf.write("\2\2\u0a0f\u0a36\3\2\2\2\u0a10\u0a11\7\u00eb\2\2\u0a11")
        buf.write("\u0a12\7\u01ac\2\2\u0a12\u0a13\7\u0196\2\2\u0a13\u0a14")
        buf.write("\7\u01ae\2\2\u0a14\u0a15\5\u00acW\2\u0a15\u0a16\7\u01ad")
        buf.write("\2\2\u0a16\u0a36\3\2\2\2\u0a17\u0a18\7\u00ec\2\2\u0a18")
        buf.write("\u0a19\7\u01ac\2\2\u0a19\u0a1a\7\u0196\2\2\u0a1a\u0a1b")
        buf.write("\7\u01ae\2\2\u0a1b\u0a1c\5\u00acW\2\u0a1c\u0a1d\7\u01ad")
        buf.write("\2\2\u0a1d\u0a36\3\2\2\2\u0a1e\u0a1f\7U\2\2\u0a1f\u0a20")
        buf.write("\7\u01ac\2\2\u0a20\u0a23\5\u013e\u00a0\2\u0a21\u0a22\7")
        buf.write("\u01ae\2\2\u0a22\u0a24\7\u0195\2\2\u0a23\u0a21\3\2\2\2")
        buf.write("\u0a23\u0a24\3\2\2\2\u0a24\u0a27\3\2\2\2\u0a25\u0a26\7")
        buf.write("\u01ae\2\2\u0a26\u0a28\7\u0195\2\2\u0a27\u0a25\3\2\2\2")
        buf.write("\u0a27\u0a28\3\2\2\2\u0a28\u0a29\3\2\2\2\u0a29\u0a2a\7")
        buf.write("\u01ad\2\2\u0a2a\u0a36\3\2\2\2\u0a2b\u0a36\7\u012e\2\2")
        buf.write("\u0a2c\u0a2d\7o\2\2\u0a2d\u0a2e\7\u01ac\2\2\u0a2e\u0a2f")
        buf.write("\5\u00acW\2\u0a2f\u0a30\7\u01ae\2\2\u0a30\u0a31\5\u00ac")
        buf.write("W\2\u0a31\u0a32\7\u01ad\2\2\u0a32\u0a36\3\2\2\2\u0a33")
        buf.write("\u0a36\7\u009f\2\2\u0a34\u0a36\7\u00a5\2\2\u0a35\u09d4")
        buf.write("\3\2\2\2\u0a35\u09d5\3\2\2\2\u0a35\u09d6\3\2\2\2\u0a35")
        buf.write("\u09dd\3\2\2\2\u0a35\u09e1\3\2\2\2\u0a35\u09e8\3\2\2\2")
        buf.write("\u0a35\u09f3\3\2\2\2\u0a35\u09f7\3\2\2\2\u0a35\u09fc\3")
        buf.write("\2\2\2\u0a35\u09fd\3\2\2\2\u0a35\u09fe\3\2\2\2\u0a35\u0a07")
        buf.write("\3\2\2\2\u0a35\u0a10\3\2\2\2\u0a35\u0a17\3\2\2\2\u0a35")
        buf.write("\u0a1e\3\2\2\2\u0a35\u0a2b\3\2\2\2\u0a35\u0a2c\3\2\2\2")
        buf.write("\u0a35\u0a33\3\2\2\2\u0a35\u0a34\3\2\2\2\u0a36\u00ef\3")
        buf.write("\2\2\2\u0a37\u0a38\7\u00bd\2\2\u0a38\u0a39\5\u00acW\2")
        buf.write("\u0a39\u0a3a\7\u00a9\2\2\u0a3a\u0a3b\5\u00acW\2\u0a3b")
        buf.write("\u00f1\3\2\2\2\u0a3c\u0a3d\7\u00bd\2\2\u0a3d\u0a3e\5\u00ba")
        buf.write("^\2\u0a3e\u0a3f\7\u00a9\2\2\u0a3f\u0a40\5\u00acW\2\u0a40")
        buf.write("\u00f3\3\2\2\2\u0a41\u0a43\7\t\2\2\u0a42\u0a41\3\2\2\2")
        buf.write("\u0a42\u0a43\3\2\2\2\u0a43\u0a44\3\2\2\2\u0a44\u0a45\5")
        buf.write("\u00f6|\2\u0a45\u00f5\3\2\2\2\u0a46\u0a48\5\u0146\u00a4")
        buf.write("\2\u0a47\u0a49\5\u00f8}\2\u0a48\u0a47\3\2\2\2\u0a48\u0a49")
        buf.write("\3\2\2\2\u0a49\u00f7\3\2\2\2\u0a4a\u0a4c\7\u00c0\2\2\u0a4b")
        buf.write("\u0a4a\3\2\2\2\u0a4b\u0a4c\3\2\2\2\u0a4c\u0a4d\3\2\2\2")
        buf.write("\u0a4d\u0a4e\7\u01ac\2\2\u0a4e\u0a53\5\u00fc\177\2\u0a4f")
        buf.write("\u0a50\7\u01ae\2\2\u0a50\u0a52\5\u00fc\177\2\u0a51\u0a4f")
        buf.write("\3\2\2\2\u0a52\u0a55\3\2\2\2\u0a53\u0a51\3\2\2\2\u0a53")
        buf.write("\u0a54\3\2\2\2\u0a54\u0a56\3\2\2\2\u0a55\u0a53\3\2\2\2")
        buf.write("\u0a56\u0a57\7\u01ad\2\2\u0a57\u00f9\3\2\2\2\u0a58\u0a59")
        buf.write("\7\u00c0\2\2\u0a59\u0a5a\7\u01ac\2\2\u0a5a\u0a5f\5\u00fc")
        buf.write("\177\2\u0a5b\u0a5c\7\u01ae\2\2\u0a5c\u0a5e\5\u00fc\177")
        buf.write("\2\u0a5d\u0a5b\3\2\2\2\u0a5e\u0a61\3\2\2\2\u0a5f\u0a5d")
        buf.write("\3\2\2\2\u0a5f\u0a60\3\2\2\2\u0a60\u0a62\3\2\2\2\u0a61")
        buf.write("\u0a5f\3\2\2\2\u0a62\u0a63\7\u01ad\2\2\u0a63\u00fb\3\2")
        buf.write("\2\2\u0a64\u0a66\7\u0137\2\2\u0a65\u0a64\3\2\2\2\u0a65")
        buf.write("\u0a66\3\2\2\2\u0a66\u0a8d\3\2\2\2\u0a67\u0a68\7Z\2\2")
        buf.write("\u0a68\u0a69\7\u01ac\2\2\u0a69\u0a6e\5\u00fe\u0080\2\u0a6a")
        buf.write("\u0a6b\7\u01ae\2\2\u0a6b\u0a6d\5\u00fe\u0080\2\u0a6c\u0a6a")
        buf.write("\3\2\2\2\u0a6d\u0a70\3\2\2\2\u0a6e\u0a6c\3\2\2\2\u0a6e")
        buf.write("\u0a6f\3\2\2\2\u0a6f\u0a71\3\2\2\2\u0a70\u0a6e\3\2\2\2")
        buf.write("\u0a71\u0a72\7\u01ad\2\2\u0a72\u0a8e\3\2\2\2\u0a73\u0a74")
        buf.write("\7Z\2\2\u0a74\u0a75\7\u019b\2\2\u0a75\u0a8e\5\u00fe\u0080")
        buf.write("\2\u0a76\u0a85\7J\2\2\u0a77\u0a78\7\u01ac\2\2\u0a78\u0a79")
        buf.write("\5\u00fe\u0080\2\u0a79\u0a7a\7\u01ac\2\2\u0a7a\u0a7f\7")
        buf.write("\u0196\2\2\u0a7b\u0a7c\7\u01ae\2\2\u0a7c\u0a7e\7\u0196")
        buf.write("\2\2\u0a7d\u0a7b\3\2\2\2\u0a7e\u0a81\3\2\2\2\u0a7f\u0a7d")
        buf.write("\3\2\2\2\u0a7f\u0a80\3\2\2\2\u0a80\u0a82\3\2\2\2\u0a81")
        buf.write("\u0a7f\3\2\2\2\u0a82\u0a83\7\u01ad\2\2\u0a83\u0a84\7\u01ad")
        buf.write("\2\2\u0a84\u0a86\3\2\2\2\u0a85\u0a77\3\2\2\2\u0a85\u0a86")
        buf.write("\3\2\2\2\u0a86\u0a8e\3\2\2\2\u0a87\u0a8e\7\u0168\2\2\u0a88")
        buf.write("\u0a8e\7\u016d\2\2\u0a89\u0a8a\7\u016e\2\2\u0a8a\u0a8b")
        buf.write("\7\u019b\2\2\u0a8b\u0a8e\7\u0195\2\2\u0a8c\u0a8e\7\u0196")
        buf.write("\2\2\u0a8d\u0a67\3\2\2\2\u0a8d\u0a73\3\2\2\2\u0a8d\u0a76")
        buf.write("\3\2\2\2\u0a8d\u0a87\3\2\2\2\u0a8d\u0a88\3\2\2\2\u0a8d")
        buf.write("\u0a89\3\2\2\2\u0a8d\u0a8c\3\2\2\2\u0a8d\u0a8e\3\2\2\2")
        buf.write("\u0a8e\u00fd\3\2\2\2\u0a8f\u0a92\5\u0146\u00a4\2\u0a90")
        buf.write("\u0a92\7\u0195\2\2\u0a91\u0a8f\3\2\2\2\u0a91\u0a90\3\2")
        buf.write("\2\2\u0a92\u00ff\3\2\2\2\u0a93\u0a94\7\u01ac\2\2\u0a94")
        buf.write("\u0a99\5\u0102\u0082\2\u0a95\u0a96\7\u01ae\2\2\u0a96\u0a98")
        buf.write("\5\u0102\u0082\2\u0a97\u0a95\3\2\2\2\u0a98\u0a9b\3\2\2")
        buf.write("\2\u0a99\u0a97\3\2\2\2\u0a99\u0a9a\3\2\2\2\u0a9a\u0a9c")
        buf.write("\3\2\2\2\u0a9b\u0a99\3\2\2\2\u0a9c\u0a9d\7\u01ad\2\2\u0a9d")
        buf.write("\u0101\3\2\2\2\u0a9e\u0aa1\5\u0146\u00a4\2\u0a9f\u0aa1")
        buf.write("\7\u0197\2\2\u0aa0\u0a9e\3\2\2\2\u0aa0\u0a9f\3\2\2\2\u0aa1")
        buf.write("\u0103\3\2\2\2\u0aa2\u0aa3\7\u01b1\2\2\u0aa3\u0105\3\2")
        buf.write("\2\2\u0aa4\u0aa5\7\u00b9\2\2\u0aa5\u0aa6\7\u01ac\2\2\u0aa6")
        buf.write("\u0aa7\5\u0108\u0085\2\u0aa7\u0aaf\7\u01ad\2\2\u0aa8\u0aa9")
        buf.write("\7\u01ae\2\2\u0aa9\u0aaa\7\u01ac\2\2\u0aaa\u0aab\5\u0108")
        buf.write("\u0085\2\u0aab\u0aac\7\u01ad\2\2\u0aac\u0aae\3\2\2\2\u0aad")
        buf.write("\u0aa8\3\2\2\2\u0aae\u0ab1\3\2\2\2\u0aaf\u0aad\3\2\2\2")
        buf.write("\u0aaf\u0ab0\3\2\2\2\u0ab0\u0107\3\2\2\2\u0ab1\u0aaf\3")
        buf.write("\2\2\2\u0ab2\u0ab7\5\u00acW\2\u0ab3\u0ab4\7\u01ae\2\2")
        buf.write("\u0ab4\u0ab6\5\u00acW\2\u0ab5\u0ab3\3\2\2\2\u0ab6\u0ab9")
        buf.write("\3\2\2\2\u0ab7\u0ab5\3\2\2\2\u0ab7\u0ab8\3\2\2\2\u0ab8")
        buf.write("\u0109\3\2\2\2\u0ab9\u0ab7\3\2\2\2\u0aba\u0abb\t\60\2")
        buf.write("\2\u0abb\u0abc\7\u01ac\2\2\u0abc\u0abd\7\u01ad\2\2\u0abd")
        buf.write("\u0ac5\5\u0110\u0089\2\u0abe\u0abf\7\u013b\2\2\u0abf\u0ac0")
        buf.write("\7\u01ac\2\2\u0ac0\u0ac1\5\u00acW\2\u0ac1\u0ac2\7\u01ad")
        buf.write("\2\2\u0ac2\u0ac3\5\u0110\u0089\2\u0ac3\u0ac5\3\2\2\2\u0ac4")
        buf.write("\u0aba\3\2\2\2\u0ac4\u0abe\3\2\2\2\u0ac5\u010b\3\2\2\2")
        buf.write("\u0ac6\u0ac7\t\61\2\2\u0ac7\u0ac9\7\u01ac\2\2\u0ac8\u0aca")
        buf.write("\5\u010e\u0088\2\u0ac9\u0ac8\3\2\2\2\u0ac9\u0aca\3\2\2")
        buf.write("\2\u0aca\u0acb\3\2\2\2\u0acb\u0acc\5\u00acW\2\u0acc\u0ace")
        buf.write("\7\u01ad\2\2\u0acd\u0acf\5\u0110\u0089\2\u0ace\u0acd\3")
        buf.write("\2\2\2\u0ace\u0acf\3\2\2\2\u0acf\u0af0\3\2\2\2\u0ad0\u0ad1")
        buf.write("\t\62\2\2\u0ad1\u0ad7\7\u01ac\2\2\u0ad2\u0ad8\7\u01b1")
        buf.write("\2\2\u0ad3\u0ad5\5\u010e\u0088\2\u0ad4\u0ad3\3\2\2\2\u0ad4")
        buf.write("\u0ad5\3\2\2\2\u0ad5\u0ad6\3\2\2\2\u0ad6\u0ad8\5\u00ac")
        buf.write("W\2\u0ad7\u0ad2\3\2\2\2\u0ad7\u0ad4\3\2\2\2\u0ad8\u0ad9")
        buf.write("\3\2\2\2\u0ad9\u0adb\7\u01ad\2\2\u0ada\u0adc\5\u0110\u0089")
        buf.write("\2\u0adb\u0ada\3\2\2\2\u0adb\u0adc\3\2\2\2\u0adc\u0af0")
        buf.write("\3\2\2\2\u0add\u0ade\7\u00de\2\2\u0ade\u0ae0\7\u01ac\2")
        buf.write("\2\u0adf\u0ae1\5\u010e\u0088\2\u0ae0\u0adf\3\2\2\2\u0ae0")
        buf.write("\u0ae1\3\2\2\2\u0ae1\u0ae2\3\2\2\2\u0ae2\u0ae3\5\u00ac")
        buf.write("W\2\u0ae3\u0ae4\7\u01ad\2\2\u0ae4\u0af0\3\2\2\2\u0ae5")
        buf.write("\u0ae6\7\u010e\2\2\u0ae6\u0ae7\7\u01ac\2\2\u0ae7\u0ae8")
        buf.write("\5\u00acW\2\u0ae8\u0ae9\7\u01ad\2\2\u0ae9\u0af0\3\2\2")
        buf.write("\2\u0aea\u0aeb\7\u010f\2\2\u0aeb\u0aec\7\u01ac\2\2\u0aec")
        buf.write("\u0aed\5\u0108\u0085\2\u0aed\u0aee\7\u01ad\2\2\u0aee\u0af0")
        buf.write("\3\2\2\2\u0aef\u0ac6\3\2\2\2\u0aef\u0ad0\3\2\2\2\u0aef")
        buf.write("\u0add\3\2\2\2\u0aef\u0ae5\3\2\2\2\u0aef\u0aea\3\2\2\2")
        buf.write("\u0af0\u010d\3\2\2\2\u0af1\u0af2\t%\2\2\u0af2\u010f\3")
        buf.write("\2\2\2\u0af3\u0af4\7}\2\2\u0af4\u0af8\7\u01ac\2\2\u0af5")
        buf.write("\u0af6\7\u0149\2\2\u0af6\u0af7\7\22\2\2\u0af7\u0af9\5")
        buf.write("\u0108\u0085\2\u0af8\u0af5\3\2\2\2\u0af8\u0af9\3\2\2\2")
        buf.write("\u0af9\u0afb\3\2\2\2\u0afa\u0afc\5\u00c6d\2\u0afb\u0afa")
        buf.write("\3\2\2\2\u0afb\u0afc\3\2\2\2\u0afc\u0afe\3\2\2\2\u0afd")
        buf.write("\u0aff\5\u0112\u008a\2\u0afe\u0afd\3\2\2\2\u0afe\u0aff")
        buf.write("\3\2\2\2\u0aff\u0b00\3\2\2\2\u0b00\u0b01\7\u01ad\2\2\u0b01")
        buf.write("\u0111\3\2\2\2\u0b02\u0b03\t\63\2\2\u0b03\u0b04\5\u0114")
        buf.write("\u008b\2\u0b04\u0113\3\2\2\2\u0b05\u0b0c\5\u0118\u008d")
        buf.write("\2\u0b06\u0b07\7\16\2\2\u0b07\u0b08\5\u0116\u008c\2\u0b08")
        buf.write("\u0b09\7\7\2\2\u0b09\u0b0a\5\u0116\u008c\2\u0b0a\u0b0c")
        buf.write("\3\2\2\2\u0b0b\u0b05\3\2\2\2\u0b0b\u0b06\3\2\2\2\u0b0c")
        buf.write("\u0115\3\2\2\2\u0b0d\u0b10\5\u0118\u008d\2\u0b0e\u0b10")
        buf.write("\5\u011a\u008e\2\u0b0f\u0b0d\3\2\2\2\u0b0f\u0b0e\3\2\2")
        buf.write("\2\u0b10\u0117\3\2\2\2\u0b11\u0b12\7\u0182\2\2\u0b12\u0b18")
        buf.write("\7\u014b\2\2\u0b13\u0b14\7\u0195\2\2\u0b14\u0b18\7\u014b")
        buf.write("\2\2\u0b15\u0b16\7(\2\2\u0b16\u0b18\7\u015e\2\2\u0b17")
        buf.write("\u0b11\3\2\2\2\u0b17\u0b13\3\2\2\2\u0b17\u0b15\3\2\2\2")
        buf.write("\u0b18\u0119\3\2\2\2\u0b19\u0b1a\7\u0182\2\2\u0b1a\u0b1e")
        buf.write("\7\u0106\2\2\u0b1b\u0b1c\7\u0195\2\2\u0b1c\u0b1e\7\u0106")
        buf.write("\2\2\u0b1d\u0b19\3\2\2\2\u0b1d\u0b1b\3\2\2\2\u0b1e\u011b")
        buf.write("\3\2\2\2\u0b1f\u0b20\7\u0104\2\2\u0b20\u0b25\5\u011e\u0090")
        buf.write("\2\u0b21\u0b22\7\u01ae\2\2\u0b22\u0b24\5\u011e\u0090\2")
        buf.write("\u0b23\u0b21\3\2\2\2\u0b24\u0b27\3\2\2\2\u0b25\u0b23\3")
        buf.write("\2\2\2\u0b25\u0b26\3\2\2\2\u0b26\u0b42\3\2\2\2\u0b27\u0b25")
        buf.write("\3\2\2\2\u0b28\u0b29\7\u00f1\2\2\u0b29\u0b2c\7\u019b\2")
        buf.write("\2\u0b2a\u0b2d\5\u0146\u00a4\2\u0b2b\u0b2d\7\u0197\2\2")
        buf.write("\u0b2c\u0b2a\3\2\2\2\u0b2c\u0b2b\3\2\2\2\u0b2d\u0b42\3")
        buf.write("\2\2\2\u0b2e\u0b2f\7\u00f0\2\2\u0b2f\u0b32\7\u019b\2\2")
        buf.write("\u0b30\u0b33\5\u0146\u00a4\2\u0b31\u0b33\7\u0197\2\2\u0b32")
        buf.write("\u0b30\3\2\2\2\u0b32\u0b31\3\2\2\2\u0b33\u0b42\3\2\2\2")
        buf.write("\u0b34\u0b35\7\u0133\2\2\u0b35\u0b36\7\u019b\2\2\u0b36")
        buf.write("\u0b42\t\r\2\2\u0b37\u0b38\7\u017c\2\2\u0b38\u0b39\7\u019b")
        buf.write("\2\2\u0b39\u0b42\t\r\2\2\u0b3a\u0b3b\7\u017f\2\2\u0b3b")
        buf.write("\u0b3c\7\u019b\2\2\u0b3c\u0b42\7\u0195\2\2\u0b3d\u0b3e")
        buf.write("\7\u00ef\2\2\u0b3e\u0b42\t\r\2\2\u0b3f\u0b40\7\u017d\2")
        buf.write("\2\u0b40\u0b42\t\r\2\2\u0b41\u0b1f\3\2\2\2\u0b41\u0b28")
        buf.write("\3\2\2\2\u0b41\u0b2e\3\2\2\2\u0b41\u0b34\3\2\2\2\u0b41")
        buf.write("\u0b37\3\2\2\2\u0b41\u0b3a\3\2\2\2\u0b41\u0b3d\3\2\2\2")
        buf.write("\u0b41\u0b3f\3\2\2\2\u0b42\u011d\3\2\2\2\u0b43\u0b4a\7")
        buf.write("\u01ac\2\2\u0b44\u0b45\7\u0138\2\2\u0b45\u0b46\7\u019b")
        buf.write("\2\2\u0b46\u0b4b\t\64\2\2\u0b47\u0b48\7\u00f6\2\2\u0b48")
        buf.write("\u0b49\7\u019b\2\2\u0b49\u0b4b\7\u0197\2\2\u0b4a\u0b44")
        buf.write("\3\2\2\2\u0b4a\u0b47\3\2\2\2\u0b4b\u0b4c\3\2\2\2\u0b4c")
        buf.write("\u0b4d\7\u01ad\2\2\u0b4d\u011f\3\2\2\2\u0b4e\u0b51\5\u0122")
        buf.write("\u0092\2\u0b4f\u0b51\5\u0124\u0093\2\u0b50\u0b4e\3\2\2")
        buf.write("\2\u0b50\u0b4f\3\2\2\2\u0b51\u0121\3\2\2\2\u0b52\u0b53")
        buf.write("\7\u0102\2\2\u0b53\u0b56\5\u0146\u00a4\2\u0b54\u0b55\7")
        buf.write("\"\2\2\u0b55\u0b57\7\u0104\2\2\u0b56\u0b54\3\2\2\2\u0b56")
        buf.write("\u0b57\3\2\2\2\u0b57\u0b59\3\2\2\2\u0b58\u0b5a\7\62\2")
        buf.write("\2\u0b59\u0b58\3\2\2\2\u0b59\u0b5a\3\2\2\2\u0b5a\u0b5d")
        buf.write("\3\2\2\2\u0b5b\u0b5c\7\"\2\2\u0b5c\u0b5e\7\u012b\2\2\u0b5d")
        buf.write("\u0b5b\3\2\2\2\u0b5d\u0b5e\3\2\2\2\u0b5e\u0b5f\3\2\2\2")
        buf.write("\u0b5f\u0b64\5\u0124\u0093\2\u0b60\u0b61\7\u01ae\2\2\u0b61")
        buf.write("\u0b63\5\u0124\u0093\2\u0b62\u0b60\3\2\2\2\u0b63\u0b66")
        buf.write("\3\2\2\2\u0b64\u0b62\3\2\2\2\u0b64\u0b65\3\2\2\2\u0b65")
        buf.write("\u0123\3\2\2\2\u0b66\u0b64\3\2\2\2\u0b67\u0b68\7\u01ac")
        buf.write("\2\2\u0b68\u0b69\7\u0132\2\2\u0b69\u0b6c\7\u019b\2\2\u0b6a")
        buf.write("\u0b6d\5\u0146\u00a4\2\u0b6b\u0b6d\7\u0197\2\2\u0b6c\u0b6a")
        buf.write("\3\2\2\2\u0b6c\u0b6b\3\2\2\2\u0b6d\u0b6f\3\2\2\2\u0b6e")
        buf.write("\u0b70\7\u01ae\2\2\u0b6f\u0b6e\3\2\2\2\u0b6f\u0b70\3\2")
        buf.write("\2\2\u0b70\u0b71\3\2\2\2\u0b71\u0b72\7G\2\2\u0b72\u0b73")
        buf.write("\7\u019b\2\2\u0b73\u0b75\7\u0197\2\2\u0b74\u0b76\7\u01ae")
        buf.write("\2\2\u0b75\u0b74\3\2\2\2\u0b75\u0b76\3\2\2\2\u0b76\u0b7d")
        buf.write("\3\2\2\2\u0b77\u0b78\7\u016c\2\2\u0b78\u0b79\7\u019b\2")
        buf.write("\2\u0b79\u0b7b\5\u014e\u00a8\2\u0b7a\u0b7c\7\u01ae\2\2")
        buf.write("\u0b7b\u0b7a\3\2\2\2\u0b7b\u0b7c\3\2\2\2\u0b7c\u0b7e\3")
        buf.write("\2\2\2\u0b7d\u0b77\3\2\2\2\u0b7d\u0b7e\3\2\2\2\u0b7e\u0b88")
        buf.write("\3\2\2\2\u0b7f\u0b80\7\u0129\2\2\u0b80\u0b83\7\u019b\2")
        buf.write("\2\u0b81\u0b84\5\u014e\u00a8\2\u0b82\u0b84\7\u0185\2\2")
        buf.write("\u0b83\u0b81\3\2\2\2\u0b83\u0b82\3\2\2\2\u0b84\u0b86\3")
        buf.write("\2\2\2\u0b85\u0b87\7\u01ae\2\2\u0b86\u0b85\3\2\2\2\u0b86")
        buf.write("\u0b87\3\2\2\2\u0b87\u0b89\3\2\2\2\u0b88\u0b7f\3\2\2\2")
        buf.write("\u0b88\u0b89\3\2\2\2\u0b89\u0b90\3\2\2\2\u0b8a\u0b8b\7")
        buf.write("\u0103\2\2\u0b8b\u0b8c\7\u019b\2\2\u0b8c\u0b8e\5\u014e")
        buf.write("\u00a8\2\u0b8d\u0b8f\7\u01ae\2\2\u0b8e\u0b8d\3\2\2\2\u0b8e")
        buf.write("\u0b8f\3\2\2\2\u0b8f\u0b91\3\2\2\2\u0b90\u0b8a\3\2\2\2")
        buf.write("\u0b90\u0b91\3\2\2\2\u0b91\u0b92\3\2\2\2\u0b92\u0b93\7")
        buf.write("\u01ad\2\2\u0b93\u0125\3\2\2\2\u0b94\u0b95\5\u0146\u00a4")
        buf.write("\2\u0b95\u0b96\7\u01a7\2\2\u0b96\u0b97\5\u0146\u00a4\2")
        buf.write("\u0b97\u0b98\7\u01a7\2\2\u0b98\u0b99\5\u0146\u00a4\2\u0b99")
        buf.write("\u0b9a\7\u01a7\2\2\u0b9a\u0ba6\3\2\2\2\u0b9b\u0b9c\5\u0146")
        buf.write("\u00a4\2\u0b9c\u0b9e\7\u01a7\2\2\u0b9d\u0b9f\5\u0146\u00a4")
        buf.write("\2\u0b9e\u0b9d\3\2\2\2\u0b9e\u0b9f\3\2\2\2\u0b9f\u0ba0")
        buf.write("\3\2\2\2\u0ba0\u0ba1\7\u01a7\2\2\u0ba1\u0ba6\3\2\2\2\u0ba2")
        buf.write("\u0ba3\5\u0146\u00a4\2\u0ba3\u0ba4\7\u01a7\2\2\u0ba4\u0ba6")
        buf.write("\3\2\2\2\u0ba5\u0b94\3\2\2\2\u0ba5\u0b9b\3\2\2\2\u0ba5")
        buf.write("\u0ba2\3\2\2\2\u0ba5\u0ba6\3\2\2\2\u0ba6\u0ba7\3\2\2\2")
        buf.write("\u0ba7\u0ba8\5\u0146\u00a4\2\u0ba8\u0127\3\2\2\2\u0ba9")
        buf.write("\u0baa\5\u0146\u00a4\2\u0baa\u0bac\7\u01a7\2\2\u0bab\u0bad")
        buf.write("\5\u0146\u00a4\2\u0bac\u0bab\3\2\2\2\u0bac\u0bad\3\2\2")
        buf.write("\2\u0bad\u0bae\3\2\2\2\u0bae\u0baf\7\u01a7\2\2\u0baf\u0bb4")
        buf.write("\3\2\2\2\u0bb0\u0bb1\5\u0146\u00a4\2\u0bb1\u0bb2\7\u01a7")
        buf.write("\2\2\u0bb2\u0bb4\3\2\2\2\u0bb3\u0ba9\3\2\2\2\u0bb3\u0bb0")
        buf.write("\3\2\2\2\u0bb3\u0bb4\3\2\2\2\u0bb4\u0bb5\3\2\2\2\u0bb5")
        buf.write("\u0bb6\5\u0146\u00a4\2\u0bb6\u0129\3\2\2\2\u0bb7\u0bb8")
        buf.write("\5\u0146\u00a4\2\u0bb8\u0bb9\7\u01a7\2\2\u0bb9\u0bbb\3")
        buf.write("\2\2\2\u0bba\u0bb7\3\2\2\2\u0bba\u0bbb\3\2\2\2\u0bbb\u0bbc")
        buf.write("\3\2\2\2\u0bbc\u0bbd\5\u0146\u00a4\2\u0bbd\u012b\3\2\2")
        buf.write("\2\u0bbe\u0bbf\5\u0146\u00a4\2\u0bbf\u0bc1\7\u01a7\2\2")
        buf.write("\u0bc0\u0bc2\5\u0146\u00a4\2\u0bc1\u0bc0\3\2\2\2\u0bc1")
        buf.write("\u0bc2\3\2\2\2\u0bc2\u0bc3\3\2\2\2\u0bc3\u0bc4\7\u01a7")
        buf.write("\2\2\u0bc4\u0bc9\3\2\2\2\u0bc5\u0bc6\5\u0146\u00a4\2\u0bc6")
        buf.write("\u0bc7\7\u01a7\2\2\u0bc7\u0bc9\3\2\2\2\u0bc8\u0bbe\3\2")
        buf.write("\2\2\u0bc8\u0bc5\3\2\2\2\u0bc8\u0bc9\3\2\2\2\u0bc9\u0bca")
        buf.write("\3\2\2\2\u0bca\u0bcb\5\u0146\u00a4\2\u0bcb\u012d\3\2\2")
        buf.write("\2\u0bcc\u0bcf\5\u0126\u0094\2\u0bcd\u0bcf\7\u0194\2\2")
        buf.write("\u0bce\u0bcc\3\2\2\2\u0bce\u0bcd\3\2\2\2\u0bcf\u012f\3")
        buf.write("\2\2\2\u0bd0\u0bd1\5\u0128\u0095\2\u0bd1\u0bd2\7\u01a7")
        buf.write("\2\2\u0bd2\u0bd4\3\2\2\2\u0bd3\u0bd0\3\2\2\2\u0bd3\u0bd4")
        buf.write("\3\2\2\2\u0bd4\u0bd5\3\2\2\2\u0bd5\u0bd6\5\u0146\u00a4")
        buf.write("\2\u0bd6\u0131\3\2\2\2\u0bd7\u0bdc\5\u0146\u00a4\2\u0bd8")
        buf.write("\u0bd9\7\u01ae\2\2\u0bd9\u0bdb\5\u0146\u00a4\2\u0bda\u0bd8")
        buf.write("\3\2\2\2\u0bdb\u0bde\3\2\2\2\u0bdc\u0bda\3\2\2\2\u0bdc")
        buf.write("\u0bdd\3\2\2\2\u0bdd\u0133\3\2\2\2\u0bde\u0bdc\3\2\2\2")
        buf.write("\u0bdf\u0be2\5\u0146\u00a4\2\u0be0\u0be2\7\u0194\2\2\u0be1")
        buf.write("\u0bdf\3\2\2\2\u0be1\u0be0\3\2\2\2\u0be2\u0135\3\2\2\2")
        buf.write("\u0be3\u0be4\t\r\2\2\u0be4\u0137\3\2\2\2\u0be5\u0be6\t")
        buf.write("\65\2\2\u0be6\u0139\3\2\2\2\u0be7\u0be9\7m\2\2\u0be8\u0be7")
        buf.write("\3\2\2\2\u0be8\u0be9\3\2\2\2\u0be9\u0bea\3\2\2\2\u0bea")
        buf.write("\u0beb\7n\2\2\u0beb\u013b\3\2\2\2\u0bec\u0bf2\5\u012c")
        buf.write("\u0097\2\u0bed\u0bf2\7\u0093\2\2\u0bee\u0bf2\7c\2\2\u0bef")
        buf.write("\u0bf2\7\u00d6\2\2\u0bf0\u0bf2\7\u00dd\2\2\u0bf1\u0bec")
        buf.write("\3\2\2\2\u0bf1\u0bed\3\2\2\2\u0bf1\u0bee\3\2\2\2\u0bf1")
        buf.write("\u0bef\3\2\2\2\u0bf1\u0bf0\3\2\2\2\u0bf2\u013d\3\2\2\2")
        buf.write("\u0bf3\u0bf5\5\u0146\u00a4\2\u0bf4\u0bf6\7U\2\2\u0bf5")
        buf.write("\u0bf4\3\2\2\2\u0bf5\u0bf6\3\2\2\2\u0bf6\u0bfe\3\2\2\2")
        buf.write("\u0bf7\u0bf8\7\u01ac\2\2\u0bf8\u0bfb\t\66\2\2\u0bf9\u0bfa")
        buf.write("\7\u01ae\2\2\u0bfa\u0bfc\7\u0195\2\2\u0bfb\u0bf9\3\2\2")
        buf.write("\2\u0bfb\u0bfc\3\2\2\2\u0bfc\u0bfd\3\2\2\2\u0bfd\u0bff")
        buf.write("\7\u01ad\2\2\u0bfe\u0bf7\3\2\2\2\u0bfe\u0bff\3\2\2\2\u0bff")
        buf.write("\u013f\3\2\2\2\u0c00\u0c03\7n\2\2\u0c01\u0c03\5\u0142")
        buf.write("\u00a2\2\u0c02\u0c00\3\2\2\2\u0c02\u0c01\3\2\2\2\u0c03")
        buf.write("\u0141\3\2\2\2\u0c04\u0c14\7\u0197\2\2\u0c05\u0c14\7\u0198")
        buf.write("\2\2\u0c06\u0c08\5\u0144\u00a3\2\u0c07\u0c06\3\2\2\2\u0c07")
        buf.write("\u0c08\3\2\2\2\u0c08\u0c09\3\2\2\2\u0c09\u0c14\7\u0195")
        buf.write("\2\2\u0c0a\u0c0c\5\u0144\u00a3\2\u0c0b\u0c0a\3\2\2\2\u0c0b")
        buf.write("\u0c0c\3\2\2\2\u0c0c\u0c0d\3\2\2\2\u0c0d\u0c14\t\67\2")
        buf.write("\2\u0c0e\u0c10\5\u0144\u00a3\2\u0c0f\u0c0e\3\2\2\2\u0c0f")
        buf.write("\u0c10\3\2\2\2\u0c10\u0c11\3\2\2\2\u0c11\u0c12\7\u01ab")
        buf.write("\2\2\u0c12\u0c14\t8\2\2\u0c13\u0c04\3\2\2\2\u0c13\u0c05")
        buf.write("\3\2\2\2\u0c13\u0c07\3\2\2\2\u0c13\u0c0b\3\2\2\2\u0c13")
        buf.write("\u0c0f\3\2\2\2\u0c14\u0143\3\2\2\2\u0c15\u0c16\t!\2\2")
        buf.write("\u0c16\u0145\3\2\2\2\u0c17\u0c1b\5\u0148\u00a5\2\u0c18")
        buf.write("\u0c1b\7\u0192\2\2\u0c19\u0c1b\7\u0193\2\2\u0c1a\u0c17")
        buf.write("\3\2\2\2\u0c1a\u0c18\3\2\2\2\u0c1a\u0c19\3\2\2\2\u0c1b")
        buf.write("\u0147\3\2\2\2\u0c1c\u0c1d\t9\2\2\u0c1d\u0149\3\2\2\2")
        buf.write("\u0c1e\u0c2e\7\u019b\2\2\u0c1f\u0c2e\7\u019c\2\2\u0c20")
        buf.write("\u0c2e\7\u019d\2\2\u0c21\u0c22\7\u019d\2\2\u0c22\u0c2e")
        buf.write("\7\u019b\2\2\u0c23\u0c24\7\u019c\2\2\u0c24\u0c2e\7\u019b")
        buf.write("\2\2\u0c25\u0c26\7\u019d\2\2\u0c26\u0c2e\7\u019c\2\2\u0c27")
        buf.write("\u0c28\7\u019e\2\2\u0c28\u0c2e\7\u019b\2\2\u0c29\u0c2a")
        buf.write("\7\u019e\2\2\u0c2a\u0c2e\7\u019c\2\2\u0c2b\u0c2c\7\u019e")
        buf.write("\2\2\u0c2c\u0c2e\7\u019d\2\2\u0c2d\u0c1e\3\2\2\2\u0c2d")
        buf.write("\u0c1f\3\2\2\2\u0c2d\u0c20\3\2\2\2\u0c2d\u0c21\3\2\2\2")
        buf.write("\u0c2d\u0c23\3\2\2\2\u0c2d\u0c25\3\2\2\2\u0c2d\u0c27\3")
        buf.write("\2\2\2\u0c2d\u0c29\3\2\2\2\u0c2d\u0c2b\3\2\2\2\u0c2e\u014b")
        buf.write("\3\2\2\2\u0c2f\u0c30\t:\2\2\u0c30\u014d\3\2\2\2\u0c31")
        buf.write("\u0c33\7\u0195\2\2\u0c32\u0c34\t;\2\2\u0c33\u0c32\3\2")
        buf.write("\2\2\u0c33\u0c34\3\2\2\2\u0c34\u014f\3\2\2\2\u01ce\u0153")
        buf.write("\u015a\u015e\u0162\u0168\u016e\u017f\u0183\u0186\u018a")
        buf.write("\u018e\u0192\u0197\u019c\u01a3\u01a6\u01aa\u01ad\u01b5")
        buf.write("\u01b8\u01bd\u01c0\u01c5\u01ca\u01cd\u01d2\u01d8\u01df")
        buf.write("\u01e3\u01e5\u01ea\u01f7\u01fc\u01fe\u0207\u020a\u0212")
        buf.write("\u0214\u0217\u021b\u021e\u0222\u0229\u022d\u022f\u0231")
        buf.write("\u0234\u0237\u023a\u0240\u0243\u024b\u024d\u0250\u0254")
        buf.write("\u0257\u025d\u0260\u0264\u0267\u026a\u0271\u0274\u0278")
        buf.write("\u027b\u027e\u0281\u0284\u028c\u028e\u0292\u0295\u029d")
        buf.write("\u02a1\u02a5\u02ac\u02b0\u02b2\u02b4\u02b7\u02ba\u02bd")
        buf.write("\u02c5\u02cb\u02d1\u02d3\u02d7\u02da\u02dd\u02e2\u02e7")
        buf.write("\u02ea\u02f2\u02f6\u02fd\u0300\u0309\u030c\u0310\u0318")
        buf.write("\u031b\u031f\u0322\u032b\u032f\u0333\u0336\u033d\u0340")
        buf.write("\u0347\u034b\u034d\u0355\u0358\u035c\u0365\u0368\u036c")
        buf.write("\u0370\u0373\u0378\u0388\u038c\u0392\u0394\u0397\u039f")
        buf.write("\u03a5\u03aa\u03ad\u03b6\u03be\u03c1\u03c8\u03cb\u03f0")
        buf.write("\u03f3\u03f9\u0405\u0407\u040a\u0422\u042d\u0435\u0440")
        buf.write("\u0445\u0448\u0450\u045a\u0474\u047a\u0485\u0493\u049b")
        buf.write("\u04a2\u04b9\u04c6\u04cc\u04d1\u04d4\u04da\u04de\u04e5")
        buf.write("\u04ee\u04f2\u04f8\u04ff\u0503\u0510\u0516\u0527\u052b")
        buf.write("\u0533\u0537\u053f\u0543\u0545\u0549\u054d\u0551\u0555")
        buf.write("\u055b\u055f\u0561\u0566\u056e\u0571\u0574\u057d\u0582")
        buf.write("\u0587\u058a\u058c\u0590\u0594\u0597\u059b\u05a1\u05a6")
        buf.write("\u05ad\u05af\u05b3\u05ba\u05be\u05c1\u05ca\u05cd\u05cf")
        buf.write("\u05d8\u05e3\u05e7\u05e9\u05eb\u05f1\u05f6\u05fd\u060a")
        buf.write("\u060c\u060e\u0611\u0614\u061b\u061e\u0624\u0629\u062b")
        buf.write("\u062e\u0634\u063c\u063e\u0641\u0645\u0648\u064e\u0651")
        buf.write("\u0655\u0658\u065e\u0661\u0663\u0667\u066c\u0674\u0679")
        buf.write("\u0682\u0687\u068c\u0692\u0696\u0699\u069d\u06a3\u06ab")
        buf.write("\u06b0\u06b2\u06b5\u06ba\u06bf\u06c2\u06c7\u06ca\u06cd")
        buf.write("\u06d3\u06d9\u06dd\u06e2\u06e5\u06ea\u06ee\u06f2\u06f8")
        buf.write("\u06fe\u0707\u0711\u071b\u071d\u071f\u0722\u0725\u0730")
        buf.write("\u0732\u0734\u0737\u073a\u073d\u0740\u0743\u0746\u0752")
        buf.write("\u0755\u0758\u0761\u0764\u0767\u076e\u0771\u077f\u0782")
        buf.write("\u0789\u0794\u0798\u07a5\u07a9\u07b1\u07b5\u07c7\u07d6")
        buf.write("\u07d8\u07e3\u07ea\u07f1\u07f9\u0802\u0806\u0810\u0817")
        buf.write("\u0823\u0825\u083c\u0845\u084b\u0851\u0857\u0862\u0869")
        buf.write("\u086e\u0873\u0877\u0880\u0882\u0886\u0889\u088e\u0892")
        buf.write("\u0896\u089f\u08a2\u08a6\u08ab\u08af\u08b8\u08c4\u08c6")
        buf.write("\u08ce\u08d6\u08d9\u08db\u08e2\u08e6\u08f1\u0913\u0923")
        buf.write("\u0929\u0930\u0936\u093b\u0943\u0946\u0948\u094f\u0957")
        buf.write("\u095d\u0962\u0966\u096b\u096d\u0974\u0978\u097f\u0981")
        buf.write("\u0983\u098e\u0992\u0994\u0997\u09a7\u09ab\u09bf\u09c3")
        buf.write("\u09c7\u09d2\u09d9\u09ef\u0a23\u0a27\u0a35\u0a42\u0a48")
        buf.write("\u0a4b\u0a53\u0a5f\u0a65\u0a6e\u0a7f\u0a85\u0a8d\u0a91")
        buf.write("\u0a99\u0aa0\u0aaf\u0ab7\u0ac4\u0ac9\u0ace\u0ad4\u0ad7")
        buf.write("\u0adb\u0ae0\u0aef\u0af8\u0afb\u0afe\u0b0b\u0b0f\u0b17")
        buf.write("\u0b1d\u0b25\u0b2c\u0b32\u0b41\u0b4a\u0b50\u0b56\u0b59")
        buf.write("\u0b5d\u0b64\u0b6c\u0b6f\u0b75\u0b7b\u0b7d\u0b83\u0b86")
        buf.write("\u0b88\u0b8e\u0b90\u0b9e\u0ba5\u0bac\u0bb3\u0bba\u0bc1")
        buf.write("\u0bc8\u0bce\u0bd3\u0bdc\u0be1\u0be8\u0bf1\u0bf5\u0bfb")
        buf.write("\u0bfe\u0c02\u0c07\u0c0b\u0c0f\u0c13\u0c1a\u0c2d\u0c33")
        return buf.getvalue()


class tsqlParser ( Parser ):

    grammarFileName = "tsql.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "'='", "'>'", "'<'", "'!'", "'+='", "'-='", 
                     "'*='", "'/='", "'%='", "'&='", "'^='", "'|='", "'.'", 
                     "'_'", "'@'", "'#'", "'$'", "'('", "')'", "','", "';'", 
                     "':'", "'*'", "'/'", "'%'", "'+'", "'-'", "'~'", "'|'", 
                     "'&'", "'^'" ]

    symbolicNames = [ "<INVALID>", "HADR_options", "ADD", "ALL", "ALTER", 
                      "AND", "ANY", "AS", "ASC", "AUTHORIZATION", "BACKUP", 
                      "BEGIN", "BETWEEN", "BREAK", "BROWSE", "BULK", "BY", 
                      "CASCADE", "CASE", "CHANGETABLE", "CHANGES", "CHECK", 
                      "CHECKPOINT", "CLOSE", "CLUSTERED", "COALESCE", "COLLATE", 
                      "COLUMN", "COMMIT", "COMPUTE", "CONSTRAINT", "CONTAINMENT", 
                      "CONTAINS", "CONTAINSTABLE", "CONTINUE", "CONVERT", 
                      "CREATE", "CROSS", "CURRENT", "CURRENT_DATE", "CURRENT_TIME", 
                      "CURRENT_TIMESTAMP", "CURRENT_USER", "CURSOR", "DATABASE", 
                      "DBCC", "DEALLOCATE", "DECLARE", "DEFAULT", "DELETE", 
                      "DENY", "DESC", "DISK", "DISTINCT", "DISTRIBUTED", 
                      "DOUBLE", "DROP", "DUMP", "ELSE", "END", "ERRLVL", 
                      "ESCAPE", "EXCEPT", "EXECUTE", "EXISTS", "EXIT", "EXTERNAL", 
                      "FETCH", "FILE", "FILENAME", "FILLFACTOR", "FOR", 
                      "FORCESEEK", "FOREIGN", "FREETEXT", "FREETEXTTABLE", 
                      "FROM", "FULL", "FUNCTION", "GOTO", "GRANT", "GROUP", 
                      "HAVING", "IDENTITY", "IDENTITYCOL", "IDENTITY_INSERT", 
                      "IF", "IN", "INDEX", "INNER", "INSERT", "INTERSECT", 
                      "INTO", "IS", "JOIN", "KEY", "KILL", "LEFT", "LIKE", 
                      "LINENO", "LOAD", "LOG", "MERGE", "NATIONAL", "NOCHECK", 
                      "NONCLUSTERED", "NONE", "NOT", "NULL", "NULLIF", "OF", 
                      "OFF", "OFFSETS", "ON", "OPEN", "OPENDATASOURCE", 
                      "OPENQUERY", "OPENROWSET", "OPENXML", "OPTION", "OR", 
                      "ORDER", "OUTER", "OVER", "PARTIAL", "PERCENT", "PIVOT", 
                      "PLAN", "PRECISION", "PRIMARY", "PRINT", "PROC", "PROCEDURE", 
                      "PUBLIC", "RAISERROR", "READ", "READTEXT", "RECONFIGURE", 
                      "REFERENCES", "REPLICATION", "RESTORE", "RESTRICT", 
                      "RETURN", "REVERT", "REVOKE", "RIGHT", "ROLLBACK", 
                      "ROWCOUNT", "ROWGUIDCOL", "RULE", "SAVE", "SCHEMA", 
                      "SECURITYAUDIT", "SELECT", "SEMANTICKEYPHRASETABLE", 
                      "SEMANTICSIMILARITYDETAILSTABLE", "SEMANTICSIMILARITYTABLE", 
                      "SESSION_USER", "SET", "SETUSER", "SHUTDOWN", "SOME", 
                      "STATISTICS", "SYSTEM_USER", "TABLE", "TABLESAMPLE", 
                      "TEXTSIZE", "THEN", "TO", "TOP", "TRAN", "TRANSACTION", 
                      "TRIGGER", "TRUNCATE", "TRY_CONVERT", "TSEQUAL", "UNION", 
                      "UNIQUE", "UNPIVOT", "UPDATE", "UPDATETEXT", "USE", 
                      "USER", "VALUES", "VARYING", "VIEW", "WAITFOR", "WHEN", 
                      "WHERE", "WHILE", "WITH", "WITHIN", "WRITETEXT", "ABSOLUTE", 
                      "AFTER", "ALLOWED", "ALLOW_SNAPSHOT_ISOLATION", "ANSI_NULLS", 
                      "ANSI_NULL_DEFAULT", "ANSI_PADDING", "ANSI_WARNINGS", 
                      "APPLY", "ARITHABORT", "AUTO", "AUTO_CLEANUP", "AUTO_CLOSE", 
                      "AUTO_CREATE_STATISTICS", "AUTO_SHRINK", "AUTO_UPDATE_STATISTICS", 
                      "AUTO_UPDATE_STATISTICS_ASYNC", "AVG", "BASE64", "BINARY_CHECKSUM", 
                      "BULK_LOGGED", "CALLER", "CAST", "CATCH", "CHANGE_RETENTION", 
                      "CHANGE_TRACKING", "CHECKSUM", "CHECKSUM_AGG", "COMMITTED", 
                      "COMPATIBILITY_LEVEL", "CONCAT", "CONCAT_NULL_YIELDS_NULL", 
                      "CONTROL", "COOKIE", "COUNT", "COUNT_BIG", "CURSOR_CLOSE_ON_COMMIT", 
                      "CURSOR_DEFAULT", "DATEADD", "DATEDIFF", "DATENAME", 
                      "DATEPART", "DATE_CORRELATION_OPTIMIZATION", "DAYS", 
                      "DB_CHAINING", "DEFAULT_FULLTEXT_LANGUAGE", "DEFAULT_LANGUAGE", 
                      "DELAY", "DELAYED_DURABILITY", "DELETED", "DENSE_RANK", 
                      "DIRECTORY_NAME", "DISABLE", "DISABLED", "DISABLE_BROKER", 
                      "DYNAMIC", "EMERGENCY", "ENABLE_BROKER", "ENCRYPTION", 
                      "ERROR_BROKER_CONVERSATIONS", "EXPAND", "FAST", "FAST_FORWARD", 
                      "FILEGROUP", "FILEGROWTH", "FILESTREAM", "FIRST", 
                      "FOLLOWING", "FORCE", "FORCED", "FORWARD_ONLY", "FULLSCAN", 
                      "GB", "GLOBAL", "GO", "GROUPING", "GROUPING_ID", "HADR", 
                      "HASH", "HONOR_BROKER_PRIORITY", "HOURS", "IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX", 
                      "IMMEDIATE", "IMPERSONATE", "INCREMENTAL", "INSENSITIVE", 
                      "INSERTED", "ISOLATION", "KB", "KEEP", "KEEPFIXED", 
                      "KEYSET", "LAST", "LEVEL", "LOCAL", "LOCK_ESCALATION", 
                      "LOGIN", "LOOP", "MARK", "MAX", "MAXDOP", "MAXRECURSION", 
                      "MAXSIZE", "MB", "MEMORY_OPTIMIZED_DATA", "MIN", "MINUTES", 
                      "MIN_ACTIVE_ROWVERSION", "MIXED_PAGE_ALLOCATION", 
                      "MODIFY", "MULTI_USER", "NAME", "NESTED_TRIGGERS", 
                      "NEW_BROKER", "NEXT", "NOCOUNT", "NOEXPAND", "NON_TRANSACTED_ACCESS", 
                      "NORECOMPUTE", "NO_WAIT", "NTILE", "NUMBER", "NUMERIC_ROUNDABORT", 
                      "OFFLINE", "OFFSET", "ONLINE", "ONLY", "OPTIMISTIC", 
                      "OPTIMIZE", "OUT", "OUTPUT", "OWNER", "PAGE_VERIFY", 
                      "PARAMETERIZATION", "PARTITION", "PATH", "PRECEDING", 
                      "PRIOR", "PRIVILEGES", "QUOTED_IDENTIFIER", "RANGE", 
                      "RANK", "READONLY", "READ_COMMITTED_SNAPSHOT", "READ_ONLY", 
                      "READ_WRITE", "RECOMPILE", "RECOVERY", "RECURSIVE_TRIGGERS", 
                      "RELATIVE", "REMOTE", "REPEATABLE", "RESTRICTED_USER", 
                      "ROBUST", "ROOT", "ROW", "ROWGUID", "ROWS", "ROW_NUMBER", 
                      "SAMPLE", "SCHEMABINDING", "SCROLL", "SCROLL_LOCKS", 
                      "SECONDS", "SELF", "SERIALIZABLE", "SHOWPLAN", "SIMPLE", 
                      "SINGLE_USER", "SIZE", "SNAPSHOT", "SPATIAL_WINDOW_MAX_CELLS", 
                      "STATIC", "STATS_STREAM", "STDEV", "STDEVP", "SUM", 
                      "TAKE", "TARGET_RECOVERY_TIME", "TB", "TEXTIMAGE_ON", 
                      "THROW", "TIES", "TIME", "TORN_PAGE_DETECTION", "TRANSFORM_NOISE_WORDS", 
                      "TRUSTWORTHY", "TRY", "TWO_DIGIT_YEAR_CUTOFF", "TYPE", 
                      "TYPE_WARNING", "UNBOUNDED", "UNCOMMITTED", "UNKNOWN", 
                      "UNLIMITED", "USING", "VAR", "VARP", "VIEWS", "VIEW_METADATA", 
                      "WORK", "XML", "XMLNAMESPACES", "DOLLAR_ACTION", "SPACE", 
                      "COMMENT", "LINE_COMMENT", "DOUBLE_QUOTE_ID", "SQUARE_BRACKET_ID", 
                      "LOCAL_ID", "DECIMAL", "ID", "STRING", "BINARY", "FLOAT", 
                      "REAL", "EQUAL", "GREATER", "LESS", "EXCLAMATION", 
                      "PLUS_ASSIGN", "MINUS_ASSIGN", "MULT_ASSIGN", "DIV_ASSIGN", 
                      "MOD_ASSIGN", "AND_ASSIGN", "XOR_ASSIGN", "OR_ASSIGN", 
                      "DOT", "UNDERLINE", "AT", "SHARP", "DOLLAR", "LR_BRACKET", 
                      "RR_BRACKET", "COMMA", "SEMI", "COLON", "STAR", "DIVIDE", 
                      "MODULE", "PLUS", "MINUS", "BIT_NOT", "BIT_OR", "BIT_AND", 
                      "BIT_XOR" ]

    RULE_tsql_file = 0
    RULE_batch = 1
    RULE_sql_clauses = 2
    RULE_sql_clause = 3
    RULE_dml_clause = 4
    RULE_ddl_clause = 5
    RULE_cfl_statement = 6
    RULE_another_statement = 7
    RULE_delete_statement = 8
    RULE_delete_statement_from = 9
    RULE_insert_statement = 10
    RULE_insert_statement_value = 11
    RULE_select_statement = 12
    RULE_update_statement = 13
    RULE_output_clause = 14
    RULE_output_dml_list_elem = 15
    RULE_output_column_name = 16
    RULE_create_database = 17
    RULE_create_index = 18
    RULE_create_procedure = 19
    RULE_procedure_param = 20
    RULE_procedure_option = 21
    RULE_create_statistics = 22
    RULE_create_table = 23
    RULE_create_view = 24
    RULE_view_attribute = 25
    RULE_alter_table = 26
    RULE_alter_database = 27
    RULE_database_optionspec = 28
    RULE_auto_option = 29
    RULE_change_tracking_option = 30
    RULE_change_tracking_option_list = 31
    RULE_containment_option = 32
    RULE_cursor_option = 33
    RULE_date_correlation_optimization_option = 34
    RULE_db_encryption_option = 35
    RULE_db_state_option = 36
    RULE_db_update_option = 37
    RULE_db_user_access_option = 38
    RULE_delayed_durability_option = 39
    RULE_external_access_option = 40
    RULE_mixed_page_allocation_option = 41
    RULE_parameterization_option = 42
    RULE_recovery_option = 43
    RULE_service_broker_option = 44
    RULE_snapshot_option = 45
    RULE_sql_option = 46
    RULE_target_recovery_time_option = 47
    RULE_termination = 48
    RULE_drop_index = 49
    RULE_drop_procedure = 50
    RULE_drop_statistics = 51
    RULE_drop_table = 52
    RULE_drop_view = 53
    RULE_create_type = 54
    RULE_drop_type = 55
    RULE_rowset_function_limited = 56
    RULE_openquery = 57
    RULE_opendatasource = 58
    RULE_declare_statement = 59
    RULE_cursor_statement = 60
    RULE_execute_statement = 61
    RULE_execute_statement_arg = 62
    RULE_execute_var_string = 63
    RULE_security_statement = 64
    RULE_grant_permission = 65
    RULE_set_statement = 66
    RULE_transaction_statement = 67
    RULE_go_statement = 68
    RULE_use_statement = 69
    RULE_execute_clause = 70
    RULE_declare_local = 71
    RULE_table_type_definition = 72
    RULE_column_def_table_constraints = 73
    RULE_column_def_table_constraint = 74
    RULE_column_definition = 75
    RULE_column_constraint = 76
    RULE_table_constraint = 77
    RULE_index_options = 78
    RULE_index_option = 79
    RULE_declare_cursor = 80
    RULE_declare_set_cursor_common = 81
    RULE_fetch_cursor = 82
    RULE_set_special = 83
    RULE_constant_LOCAL_ID = 84
    RULE_expression = 85
    RULE_constant_expression = 86
    RULE_subquery = 87
    RULE_with_expression = 88
    RULE_common_table_expression = 89
    RULE_update_elem = 90
    RULE_search_condition_list = 91
    RULE_search_condition = 92
    RULE_predicate = 93
    RULE_query_expression = 94
    RULE_union = 95
    RULE_query_specification = 96
    RULE_top_clause = 97
    RULE_order_by_clause = 98
    RULE_for_clause = 99
    RULE_xml_common_directives = 100
    RULE_order_by_expression = 101
    RULE_group_by_item = 102
    RULE_option_clause = 103
    RULE_option = 104
    RULE_optimize_for_arg = 105
    RULE_select_list = 106
    RULE_select_list_elem = 107
    RULE_table_sources = 108
    RULE_table_source = 109
    RULE_table_source_item_joined = 110
    RULE_table_source_item = 111
    RULE_change_table = 112
    RULE_join_part = 113
    RULE_table_name_with_hint = 114
    RULE_rowset_function = 115
    RULE_bulk_option = 116
    RULE_derived_table = 117
    RULE_function_call = 118
    RULE_switch_section = 119
    RULE_switch_search_condition_section = 120
    RULE_as_table_alias = 121
    RULE_table_alias = 122
    RULE_with_table_hints = 123
    RULE_insert_with_table_hints = 124
    RULE_table_hint = 125
    RULE_index_value = 126
    RULE_column_alias_list = 127
    RULE_column_alias = 128
    RULE_a_star = 129
    RULE_table_value_constructor = 130
    RULE_expression_list = 131
    RULE_ranking_windowed_function = 132
    RULE_aggregate_windowed_function = 133
    RULE_all_distinct = 134
    RULE_over_clause = 135
    RULE_row_or_range_clause = 136
    RULE_window_frame_extent = 137
    RULE_window_frame_bound = 138
    RULE_window_frame_preceding = 139
    RULE_window_frame_following = 140
    RULE_create_database_option = 141
    RULE_database_filestream_option = 142
    RULE_database_file_spec = 143
    RULE_file_group = 144
    RULE_file_spec = 145
    RULE_full_table_name = 146
    RULE_table_name = 147
    RULE_simple_name = 148
    RULE_func_proc_name = 149
    RULE_ddl_object = 150
    RULE_full_column_name = 151
    RULE_column_name_list = 152
    RULE_cursor_name = 153
    RULE_on_off = 154
    RULE_clustered = 155
    RULE_null_notnull = 156
    RULE_scalar_function_name = 157
    RULE_data_type = 158
    RULE_default_value = 159
    RULE_constant = 160
    RULE_sign = 161
    RULE_r_id = 162
    RULE_simple_id = 163
    RULE_comparison_operator = 164
    RULE_assignment_operator = 165
    RULE_file_size = 166

    ruleNames =  [ "tsql_file", "batch", "sql_clauses", "sql_clause", "dml_clause", 
                   "ddl_clause", "cfl_statement", "another_statement", "delete_statement", 
                   "delete_statement_from", "insert_statement", "insert_statement_value", 
                   "select_statement", "update_statement", "output_clause", 
                   "output_dml_list_elem", "output_column_name", "create_database", 
                   "create_index", "create_procedure", "procedure_param", 
                   "procedure_option", "create_statistics", "create_table", 
                   "create_view", "view_attribute", "alter_table", "alter_database", 
                   "database_optionspec", "auto_option", "change_tracking_option", 
                   "change_tracking_option_list", "containment_option", 
                   "cursor_option", "date_correlation_optimization_option", 
                   "db_encryption_option", "db_state_option", "db_update_option", 
                   "db_user_access_option", "delayed_durability_option", 
                   "external_access_option", "mixed_page_allocation_option", 
                   "parameterization_option", "recovery_option", "service_broker_option", 
                   "snapshot_option", "sql_option", "target_recovery_time_option", 
                   "termination", "drop_index", "drop_procedure", "drop_statistics", 
                   "drop_table", "drop_view", "create_type", "drop_type", 
                   "rowset_function_limited", "openquery", "opendatasource", 
                   "declare_statement", "cursor_statement", "execute_statement", 
                   "execute_statement_arg", "execute_var_string", "security_statement", 
                   "grant_permission", "set_statement", "transaction_statement", 
                   "go_statement", "use_statement", "execute_clause", "declare_local", 
                   "table_type_definition", "column_def_table_constraints", 
                   "column_def_table_constraint", "column_definition", "column_constraint", 
                   "table_constraint", "index_options", "index_option", 
                   "declare_cursor", "declare_set_cursor_common", "fetch_cursor", 
                   "set_special", "constant_LOCAL_ID", "expression", "constant_expression", 
                   "subquery", "with_expression", "common_table_expression", 
                   "update_elem", "search_condition_list", "search_condition", 
                   "predicate", "query_expression", "union", "query_specification", 
                   "top_clause", "order_by_clause", "for_clause", "xml_common_directives", 
                   "order_by_expression", "group_by_item", "option_clause", 
                   "option", "optimize_for_arg", "select_list", "select_list_elem", 
                   "table_sources", "table_source", "table_source_item_joined", 
                   "table_source_item", "change_table", "join_part", "table_name_with_hint", 
                   "rowset_function", "bulk_option", "derived_table", "function_call", 
                   "switch_section", "switch_search_condition_section", 
                   "as_table_alias", "table_alias", "with_table_hints", 
                   "insert_with_table_hints", "table_hint", "index_value", 
                   "column_alias_list", "column_alias", "a_star", "table_value_constructor", 
                   "expression_list", "ranking_windowed_function", "aggregate_windowed_function", 
                   "all_distinct", "over_clause", "row_or_range_clause", 
                   "window_frame_extent", "window_frame_bound", "window_frame_preceding", 
                   "window_frame_following", "create_database_option", "database_filestream_option", 
                   "database_file_spec", "file_group", "file_spec", "full_table_name", 
                   "table_name", "simple_name", "func_proc_name", "ddl_object", 
                   "full_column_name", "column_name_list", "cursor_name", 
                   "on_off", "clustered", "null_notnull", "scalar_function_name", 
                   "data_type", "default_value", "constant", "sign", "r_id", 
                   "simple_id", "comparison_operator", "assignment_operator", 
                   "file_size" ]

    EOF = Token.EOF
    HADR_options=1
    ADD=2
    ALL=3
    ALTER=4
    AND=5
    ANY=6
    AS=7
    ASC=8
    AUTHORIZATION=9
    BACKUP=10
    BEGIN=11
    BETWEEN=12
    BREAK=13
    BROWSE=14
    BULK=15
    BY=16
    CASCADE=17
    CASE=18
    CHANGETABLE=19
    CHANGES=20
    CHECK=21
    CHECKPOINT=22
    CLOSE=23
    CLUSTERED=24
    COALESCE=25
    COLLATE=26
    COLUMN=27
    COMMIT=28
    COMPUTE=29
    CONSTRAINT=30
    CONTAINMENT=31
    CONTAINS=32
    CONTAINSTABLE=33
    CONTINUE=34
    CONVERT=35
    CREATE=36
    CROSS=37
    CURRENT=38
    CURRENT_DATE=39
    CURRENT_TIME=40
    CURRENT_TIMESTAMP=41
    CURRENT_USER=42
    CURSOR=43
    DATABASE=44
    DBCC=45
    DEALLOCATE=46
    DECLARE=47
    DEFAULT=48
    DELETE=49
    DENY=50
    DESC=51
    DISK=52
    DISTINCT=53
    DISTRIBUTED=54
    DOUBLE=55
    DROP=56
    DUMP=57
    ELSE=58
    END=59
    ERRLVL=60
    ESCAPE=61
    EXCEPT=62
    EXECUTE=63
    EXISTS=64
    EXIT=65
    EXTERNAL=66
    FETCH=67
    FILE=68
    FILENAME=69
    FILLFACTOR=70
    FOR=71
    FORCESEEK=72
    FOREIGN=73
    FREETEXT=74
    FREETEXTTABLE=75
    FROM=76
    FULL=77
    FUNCTION=78
    GOTO=79
    GRANT=80
    GROUP=81
    HAVING=82
    IDENTITY=83
    IDENTITYCOL=84
    IDENTITY_INSERT=85
    IF=86
    IN=87
    INDEX=88
    INNER=89
    INSERT=90
    INTERSECT=91
    INTO=92
    IS=93
    JOIN=94
    KEY=95
    KILL=96
    LEFT=97
    LIKE=98
    LINENO=99
    LOAD=100
    LOG=101
    MERGE=102
    NATIONAL=103
    NOCHECK=104
    NONCLUSTERED=105
    NONE=106
    NOT=107
    NULL=108
    NULLIF=109
    OF=110
    OFF=111
    OFFSETS=112
    ON=113
    OPEN=114
    OPENDATASOURCE=115
    OPENQUERY=116
    OPENROWSET=117
    OPENXML=118
    OPTION=119
    OR=120
    ORDER=121
    OUTER=122
    OVER=123
    PARTIAL=124
    PERCENT=125
    PIVOT=126
    PLAN=127
    PRECISION=128
    PRIMARY=129
    PRINT=130
    PROC=131
    PROCEDURE=132
    PUBLIC=133
    RAISERROR=134
    READ=135
    READTEXT=136
    RECONFIGURE=137
    REFERENCES=138
    REPLICATION=139
    RESTORE=140
    RESTRICT=141
    RETURN=142
    REVERT=143
    REVOKE=144
    RIGHT=145
    ROLLBACK=146
    ROWCOUNT=147
    ROWGUIDCOL=148
    RULE=149
    SAVE=150
    SCHEMA=151
    SECURITYAUDIT=152
    SELECT=153
    SEMANTICKEYPHRASETABLE=154
    SEMANTICSIMILARITYDETAILSTABLE=155
    SEMANTICSIMILARITYTABLE=156
    SESSION_USER=157
    SET=158
    SETUSER=159
    SHUTDOWN=160
    SOME=161
    STATISTICS=162
    SYSTEM_USER=163
    TABLE=164
    TABLESAMPLE=165
    TEXTSIZE=166
    THEN=167
    TO=168
    TOP=169
    TRAN=170
    TRANSACTION=171
    TRIGGER=172
    TRUNCATE=173
    TRY_CONVERT=174
    TSEQUAL=175
    UNION=176
    UNIQUE=177
    UNPIVOT=178
    UPDATE=179
    UPDATETEXT=180
    USE=181
    USER=182
    VALUES=183
    VARYING=184
    VIEW=185
    WAITFOR=186
    WHEN=187
    WHERE=188
    WHILE=189
    WITH=190
    WITHIN=191
    WRITETEXT=192
    ABSOLUTE=193
    AFTER=194
    ALLOWED=195
    ALLOW_SNAPSHOT_ISOLATION=196
    ANSI_NULLS=197
    ANSI_NULL_DEFAULT=198
    ANSI_PADDING=199
    ANSI_WARNINGS=200
    APPLY=201
    ARITHABORT=202
    AUTO=203
    AUTO_CLEANUP=204
    AUTO_CLOSE=205
    AUTO_CREATE_STATISTICS=206
    AUTO_SHRINK=207
    AUTO_UPDATE_STATISTICS=208
    AUTO_UPDATE_STATISTICS_ASYNC=209
    AVG=210
    BASE64=211
    BINARY_CHECKSUM=212
    BULK_LOGGED=213
    CALLER=214
    CAST=215
    CATCH=216
    CHANGE_RETENTION=217
    CHANGE_TRACKING=218
    CHECKSUM=219
    CHECKSUM_AGG=220
    COMMITTED=221
    COMPATIBILITY_LEVEL=222
    CONCAT=223
    CONCAT_NULL_YIELDS_NULL=224
    CONTROL=225
    COOKIE=226
    COUNT=227
    COUNT_BIG=228
    CURSOR_CLOSE_ON_COMMIT=229
    CURSOR_DEFAULT=230
    DATEADD=231
    DATEDIFF=232
    DATENAME=233
    DATEPART=234
    DATE_CORRELATION_OPTIMIZATION=235
    DAYS=236
    DB_CHAINING=237
    DEFAULT_FULLTEXT_LANGUAGE=238
    DEFAULT_LANGUAGE=239
    DELAY=240
    DELAYED_DURABILITY=241
    DELETED=242
    DENSE_RANK=243
    DIRECTORY_NAME=244
    DISABLE=245
    DISABLED=246
    DISABLE_BROKER=247
    DYNAMIC=248
    EMERGENCY=249
    ENABLE_BROKER=250
    ENCRYPTION=251
    ERROR_BROKER_CONVERSATIONS=252
    EXPAND=253
    FAST=254
    FAST_FORWARD=255
    FILEGROUP=256
    FILEGROWTH=257
    FILESTREAM=258
    FIRST=259
    FOLLOWING=260
    FORCE=261
    FORCED=262
    FORWARD_ONLY=263
    FULLSCAN=264
    GB=265
    GLOBAL=266
    GO=267
    GROUPING=268
    GROUPING_ID=269
    HADR=270
    HASH=271
    HONOR_BROKER_PRIORITY=272
    HOURS=273
    IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX=274
    IMMEDIATE=275
    IMPERSONATE=276
    INCREMENTAL=277
    INSENSITIVE=278
    INSERTED=279
    ISOLATION=280
    KB=281
    KEEP=282
    KEEPFIXED=283
    KEYSET=284
    LAST=285
    LEVEL=286
    LOCAL=287
    LOCK_ESCALATION=288
    LOGIN=289
    LOOP=290
    MARK=291
    MAX=292
    MAXDOP=293
    MAXRECURSION=294
    MAXSIZE=295
    MB=296
    MEMORY_OPTIMIZED_DATA=297
    MIN=298
    MINUTES=299
    MIN_ACTIVE_ROWVERSION=300
    MIXED_PAGE_ALLOCATION=301
    MODIFY=302
    MULTI_USER=303
    NAME=304
    NESTED_TRIGGERS=305
    NEW_BROKER=306
    NEXT=307
    NOCOUNT=308
    NOEXPAND=309
    NON_TRANSACTED_ACCESS=310
    NORECOMPUTE=311
    NO_WAIT=312
    NTILE=313
    NUMBER=314
    NUMERIC_ROUNDABORT=315
    OFFLINE=316
    OFFSET=317
    ONLINE=318
    ONLY=319
    OPTIMISTIC=320
    OPTIMIZE=321
    OUT=322
    OUTPUT=323
    OWNER=324
    PAGE_VERIFY=325
    PARAMETERIZATION=326
    PARTITION=327
    PATH=328
    PRECEDING=329
    PRIOR=330
    PRIVILEGES=331
    QUOTED_IDENTIFIER=332
    RANGE=333
    RANK=334
    READONLY=335
    READ_COMMITTED_SNAPSHOT=336
    READ_ONLY=337
    READ_WRITE=338
    RECOMPILE=339
    RECOVERY=340
    RECURSIVE_TRIGGERS=341
    RELATIVE=342
    REMOTE=343
    REPEATABLE=344
    RESTRICTED_USER=345
    ROBUST=346
    ROOT=347
    ROW=348
    ROWGUID=349
    ROWS=350
    ROW_NUMBER=351
    SAMPLE=352
    SCHEMABINDING=353
    SCROLL=354
    SCROLL_LOCKS=355
    SECONDS=356
    SELF=357
    SERIALIZABLE=358
    SHOWPLAN=359
    SIMPLE=360
    SINGLE_USER=361
    SIZE=362
    SNAPSHOT=363
    SPATIAL_WINDOW_MAX_CELLS=364
    STATIC=365
    STATS_STREAM=366
    STDEV=367
    STDEVP=368
    SUM=369
    TAKE=370
    TARGET_RECOVERY_TIME=371
    TB=372
    TEXTIMAGE_ON=373
    THROW=374
    TIES=375
    TIME=376
    TORN_PAGE_DETECTION=377
    TRANSFORM_NOISE_WORDS=378
    TRUSTWORTHY=379
    TRY=380
    TWO_DIGIT_YEAR_CUTOFF=381
    TYPE=382
    TYPE_WARNING=383
    UNBOUNDED=384
    UNCOMMITTED=385
    UNKNOWN=386
    UNLIMITED=387
    USING=388
    VAR=389
    VARP=390
    VIEWS=391
    VIEW_METADATA=392
    WORK=393
    XML=394
    XMLNAMESPACES=395
    DOLLAR_ACTION=396
    SPACE=397
    COMMENT=398
    LINE_COMMENT=399
    DOUBLE_QUOTE_ID=400
    SQUARE_BRACKET_ID=401
    LOCAL_ID=402
    DECIMAL=403
    ID=404
    STRING=405
    BINARY=406
    FLOAT=407
    REAL=408
    EQUAL=409
    GREATER=410
    LESS=411
    EXCLAMATION=412
    PLUS_ASSIGN=413
    MINUS_ASSIGN=414
    MULT_ASSIGN=415
    DIV_ASSIGN=416
    MOD_ASSIGN=417
    AND_ASSIGN=418
    XOR_ASSIGN=419
    OR_ASSIGN=420
    DOT=421
    UNDERLINE=422
    AT=423
    SHARP=424
    DOLLAR=425
    LR_BRACKET=426
    RR_BRACKET=427
    COMMA=428
    SEMI=429
    COLON=430
    STAR=431
    DIVIDE=432
    MODULE=433
    PLUS=434
    MINUS=435
    BIT_NOT=436
    BIT_OR=437
    BIT_AND=438
    BIT_XOR=439

    def __init__(self, input:TokenStream):
        super().__init__(input)
        self.checkVersion("4.6.1")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None



    class Tsql_fileContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(tsqlParser.EOF, 0)

        def batch(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.BatchContext)
            else:
                return self.getTypedRuleContext(tsqlParser.BatchContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_tsql_file

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTsql_file" ):
                listener.enterTsql_file(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTsql_file" ):
                listener.exitTsql_file(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTsql_file" ):
                return visitor.visitTsql_file(self)
            else:
                return visitor.visitChildren(self)




    def tsql_file(self):

        localctx = tsqlParser.Tsql_fileContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_tsql_file)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 337
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << tsqlParser.ALTER) | (1 << tsqlParser.BEGIN) | (1 << tsqlParser.BREAK) | (1 << tsqlParser.CLOSE) | (1 << tsqlParser.COMMIT) | (1 << tsqlParser.CONTINUE) | (1 << tsqlParser.CREATE) | (1 << tsqlParser.DEALLOCATE) | (1 << tsqlParser.DECLARE) | (1 << tsqlParser.DELETE) | (1 << tsqlParser.DROP) | (1 << tsqlParser.EXECUTE))) != 0) or ((((_la - 67)) & ~0x3f) == 0 and ((1 << (_la - 67)) & ((1 << (tsqlParser.FETCH - 67)) | (1 << (tsqlParser.FORCESEEK - 67)) | (1 << (tsqlParser.GOTO - 67)) | (1 << (tsqlParser.GRANT - 67)) | (1 << (tsqlParser.IF - 67)) | (1 << (tsqlParser.INSERT - 67)) | (1 << (tsqlParser.OPEN - 67)) | (1 << (tsqlParser.PRINT - 67)))) != 0) or ((((_la - 134)) & ~0x3f) == 0 and ((1 << (_la - 134)) & ((1 << (tsqlParser.RAISERROR - 134)) | (1 << (tsqlParser.RETURN - 134)) | (1 << (tsqlParser.REVERT - 134)) | (1 << (tsqlParser.ROLLBACK - 134)) | (1 << (tsqlParser.SAVE - 134)) | (1 << (tsqlParser.SELECT - 134)) | (1 << (tsqlParser.SET - 134)) | (1 << (tsqlParser.UPDATE - 134)) | (1 << (tsqlParser.USE - 134)) | (1 << (tsqlParser.WAITFOR - 134)) | (1 << (tsqlParser.WHILE - 134)) | (1 << (tsqlParser.WITH - 134)) | (1 << (tsqlParser.ABSOLUTE - 134)))) != 0) or ((((_la - 201)) & ~0x3f) == 0 and ((1 << (_la - 201)) & ((1 << (tsqlParser.APPLY - 201)) | (1 << (tsqlParser.AUTO - 201)) | (1 << (tsqlParser.AVG - 201)) | (1 << (tsqlParser.BASE64 - 201)) | (1 << (tsqlParser.CALLER - 201)) | (1 << (tsqlParser.CAST - 201)) | (1 << (tsqlParser.CATCH - 201)) | (1 << (tsqlParser.CHECKSUM_AGG - 201)) | (1 << (tsqlParser.COMMITTED - 201)) | (1 << (tsqlParser.CONCAT - 201)) | (1 << (tsqlParser.CONTROL - 201)) | (1 << (tsqlParser.COOKIE - 201)) | (1 << (tsqlParser.COUNT - 201)) | (1 << (tsqlParser.COUNT_BIG - 201)) | (1 << (tsqlParser.DELAY - 201)) | (1 << (tsqlParser.DELETED - 201)) | (1 << (tsqlParser.DENSE_RANK - 201)) | (1 << (tsqlParser.DISABLE - 201)) | (1 << (tsqlParser.DYNAMIC - 201)) | (1 << (tsqlParser.ENCRYPTION - 201)) | (1 << (tsqlParser.EXPAND - 201)) | (1 << (tsqlParser.FAST - 201)) | (1 << (tsqlParser.FAST_FORWARD - 201)) | (1 << (tsqlParser.FIRST - 201)) | (1 << (tsqlParser.FOLLOWING - 201)) | (1 << (tsqlParser.FORCE - 201)) | (1 << (tsqlParser.FORCED - 201)) | (1 << (tsqlParser.FORWARD_ONLY - 201)) | (1 << (tsqlParser.FULLSCAN - 201)))) != 0) or ((((_la - 266)) & ~0x3f) == 0 and ((1 << (_la - 266)) & ((1 << (tsqlParser.GLOBAL - 266)) | (1 << (tsqlParser.GO - 266)) | (1 << (tsqlParser.GROUPING - 266)) | (1 << (tsqlParser.GROUPING_ID - 266)) | (1 << (tsqlParser.HASH - 266)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 266)) | (1 << (tsqlParser.IMPERSONATE - 266)) | (1 << (tsqlParser.INSENSITIVE - 266)) | (1 << (tsqlParser.INSERTED - 266)) | (1 << (tsqlParser.ISOLATION - 266)) | (1 << (tsqlParser.KEEP - 266)) | (1 << (tsqlParser.KEEPFIXED - 266)) | (1 << (tsqlParser.KEYSET - 266)) | (1 << (tsqlParser.LAST - 266)) | (1 << (tsqlParser.LEVEL - 266)) | (1 << (tsqlParser.LOCAL - 266)) | (1 << (tsqlParser.LOCK_ESCALATION - 266)) | (1 << (tsqlParser.LOGIN - 266)) | (1 << (tsqlParser.LOOP - 266)) | (1 << (tsqlParser.MARK - 266)) | (1 << (tsqlParser.MAX - 266)) | (1 << (tsqlParser.MAXDOP - 266)) | (1 << (tsqlParser.MAXRECURSION - 266)) | (1 << (tsqlParser.MIN - 266)) | (1 << (tsqlParser.MODIFY - 266)) | (1 << (tsqlParser.NAME - 266)) | (1 << (tsqlParser.NEXT - 266)) | (1 << (tsqlParser.NOCOUNT - 266)) | (1 << (tsqlParser.NOEXPAND - 266)) | (1 << (tsqlParser.NORECOMPUTE - 266)) | (1 << (tsqlParser.NTILE - 266)) | (1 << (tsqlParser.NUMBER - 266)) | (1 << (tsqlParser.OFFSET - 266)) | (1 << (tsqlParser.ONLINE - 266)) | (1 << (tsqlParser.ONLY - 266)) | (1 << (tsqlParser.OPTIMISTIC - 266)) | (1 << (tsqlParser.OPTIMIZE - 266)) | (1 << (tsqlParser.OUT - 266)) | (1 << (tsqlParser.OUTPUT - 266)) | (1 << (tsqlParser.OWNER - 266)) | (1 << (tsqlParser.PARAMETERIZATION - 266)) | (1 << (tsqlParser.PARTITION - 266)) | (1 << (tsqlParser.PATH - 266)) | (1 << (tsqlParser.PRECEDING - 266)))) != 0) or ((((_la - 330)) & ~0x3f) == 0 and ((1 << (_la - 330)) & ((1 << (tsqlParser.PRIOR - 330)) | (1 << (tsqlParser.PRIVILEGES - 330)) | (1 << (tsqlParser.RANGE - 330)) | (1 << (tsqlParser.RANK - 330)) | (1 << (tsqlParser.READONLY - 330)) | (1 << (tsqlParser.READ_ONLY - 330)) | (1 << (tsqlParser.RECOMPILE - 330)) | (1 << (tsqlParser.RELATIVE - 330)) | (1 << (tsqlParser.REMOTE - 330)) | (1 << (tsqlParser.REPEATABLE - 330)) | (1 << (tsqlParser.ROBUST - 330)) | (1 << (tsqlParser.ROOT - 330)) | (1 << (tsqlParser.ROW - 330)) | (1 << (tsqlParser.ROWGUID - 330)) | (1 << (tsqlParser.ROWS - 330)) | (1 << (tsqlParser.ROW_NUMBER - 330)) | (1 << (tsqlParser.SAMPLE - 330)) | (1 << (tsqlParser.SCHEMABINDING - 330)) | (1 << (tsqlParser.SCROLL - 330)) | (1 << (tsqlParser.SCROLL_LOCKS - 330)) | (1 << (tsqlParser.SELF - 330)) | (1 << (tsqlParser.SERIALIZABLE - 330)) | (1 << (tsqlParser.SIMPLE - 330)) | (1 << (tsqlParser.SIZE - 330)) | (1 << (tsqlParser.SNAPSHOT - 330)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 330)) | (1 << (tsqlParser.STATIC - 330)) | (1 << (tsqlParser.STATS_STREAM - 330)) | (1 << (tsqlParser.STDEV - 330)) | (1 << (tsqlParser.STDEVP - 330)) | (1 << (tsqlParser.SUM - 330)) | (1 << (tsqlParser.TEXTIMAGE_ON - 330)) | (1 << (tsqlParser.THROW - 330)) | (1 << (tsqlParser.TIES - 330)) | (1 << (tsqlParser.TIME - 330)) | (1 << (tsqlParser.TRY - 330)) | (1 << (tsqlParser.TYPE - 330)) | (1 << (tsqlParser.TYPE_WARNING - 330)) | (1 << (tsqlParser.UNBOUNDED - 330)) | (1 << (tsqlParser.UNCOMMITTED - 330)) | (1 << (tsqlParser.UNKNOWN - 330)) | (1 << (tsqlParser.USING - 330)) | (1 << (tsqlParser.VAR - 330)) | (1 << (tsqlParser.VARP - 330)) | (1 << (tsqlParser.VIEWS - 330)) | (1 << (tsqlParser.VIEW_METADATA - 330)) | (1 << (tsqlParser.WORK - 330)))) != 0) or ((((_la - 394)) & ~0x3f) == 0 and ((1 << (_la - 394)) & ((1 << (tsqlParser.XML - 394)) | (1 << (tsqlParser.XMLNAMESPACES - 394)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 394)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 394)) | (1 << (tsqlParser.ID - 394)) | (1 << (tsqlParser.LR_BRACKET - 394)))) != 0):
                self.state = 334
                self.batch()
                self.state = 339
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 340
            self.match(tsqlParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class BatchContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def sql_clauses(self):
            return self.getTypedRuleContext(tsqlParser.Sql_clausesContext,0)


        def go_statement(self):
            return self.getTypedRuleContext(tsqlParser.Go_statementContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_batch

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBatch" ):
                listener.enterBatch(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBatch" ):
                listener.exitBatch(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBatch" ):
                return visitor.visitBatch(self)
            else:
                return visitor.visitChildren(self)




    def batch(self):

        localctx = tsqlParser.BatchContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_batch)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 342
            self.sql_clauses()
            self.state = 344
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,1,self._ctx)
            if la_ == 1:
                self.state = 343
                self.go_statement()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Sql_clausesContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def sql_clause(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Sql_clauseContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Sql_clauseContext,i)


        def SEMI(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.SEMI)
            else:
                return self.getToken(tsqlParser.SEMI, i)

        def getRuleIndex(self):
            return tsqlParser.RULE_sql_clauses

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSql_clauses" ):
                listener.enterSql_clauses(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSql_clauses" ):
                listener.exitSql_clauses(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSql_clauses" ):
                return visitor.visitSql_clauses(self)
            else:
                return visitor.visitChildren(self)




    def sql_clauses(self):

        localctx = tsqlParser.Sql_clausesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_sql_clauses)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 350 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 346
                    self.sql_clause()
                    self.state = 348
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,2,self._ctx)
                    if la_ == 1:
                        self.state = 347
                        self.match(tsqlParser.SEMI)



                else:
                    raise NoViableAltException(self)
                self.state = 352 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,3,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Sql_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def dml_clause(self):
            return self.getTypedRuleContext(tsqlParser.Dml_clauseContext,0)


        def ddl_clause(self):
            return self.getTypedRuleContext(tsqlParser.Ddl_clauseContext,0)


        def cfl_statement(self):
            return self.getTypedRuleContext(tsqlParser.Cfl_statementContext,0)


        def another_statement(self):
            return self.getTypedRuleContext(tsqlParser.Another_statementContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_sql_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSql_clause" ):
                listener.enterSql_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSql_clause" ):
                listener.exitSql_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSql_clause" ):
                return visitor.visitSql_clause(self)
            else:
                return visitor.visitChildren(self)




    def sql_clause(self):

        localctx = tsqlParser.Sql_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_sql_clause)
        try:
            self.state = 358
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,4,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 354
                self.dml_clause()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 355
                self.ddl_clause()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 356
                self.cfl_statement()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 357
                self.another_statement()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Dml_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def delete_statement(self):
            return self.getTypedRuleContext(tsqlParser.Delete_statementContext,0)


        def insert_statement(self):
            return self.getTypedRuleContext(tsqlParser.Insert_statementContext,0)


        def select_statement(self):
            return self.getTypedRuleContext(tsqlParser.Select_statementContext,0)


        def update_statement(self):
            return self.getTypedRuleContext(tsqlParser.Update_statementContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_dml_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDml_clause" ):
                listener.enterDml_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDml_clause" ):
                listener.exitDml_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDml_clause" ):
                return visitor.visitDml_clause(self)
            else:
                return visitor.visitChildren(self)




    def dml_clause(self):

        localctx = tsqlParser.Dml_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_dml_clause)
        try:
            self.state = 364
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,5,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 360
                self.delete_statement()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 361
                self.insert_statement()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 362
                self.select_statement()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 363
                self.update_statement()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Ddl_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def create_database(self):
            return self.getTypedRuleContext(tsqlParser.Create_databaseContext,0)


        def create_index(self):
            return self.getTypedRuleContext(tsqlParser.Create_indexContext,0)


        def create_procedure(self):
            return self.getTypedRuleContext(tsqlParser.Create_procedureContext,0)


        def create_statistics(self):
            return self.getTypedRuleContext(tsqlParser.Create_statisticsContext,0)


        def create_table(self):
            return self.getTypedRuleContext(tsqlParser.Create_tableContext,0)


        def create_type(self):
            return self.getTypedRuleContext(tsqlParser.Create_typeContext,0)


        def create_view(self):
            return self.getTypedRuleContext(tsqlParser.Create_viewContext,0)


        def alter_table(self):
            return self.getTypedRuleContext(tsqlParser.Alter_tableContext,0)


        def alter_database(self):
            return self.getTypedRuleContext(tsqlParser.Alter_databaseContext,0)


        def drop_index(self):
            return self.getTypedRuleContext(tsqlParser.Drop_indexContext,0)


        def drop_procedure(self):
            return self.getTypedRuleContext(tsqlParser.Drop_procedureContext,0)


        def drop_statistics(self):
            return self.getTypedRuleContext(tsqlParser.Drop_statisticsContext,0)


        def drop_table(self):
            return self.getTypedRuleContext(tsqlParser.Drop_tableContext,0)


        def drop_type(self):
            return self.getTypedRuleContext(tsqlParser.Drop_typeContext,0)


        def drop_view(self):
            return self.getTypedRuleContext(tsqlParser.Drop_viewContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_ddl_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDdl_clause" ):
                listener.enterDdl_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDdl_clause" ):
                listener.exitDdl_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDdl_clause" ):
                return visitor.visitDdl_clause(self)
            else:
                return visitor.visitChildren(self)




    def ddl_clause(self):

        localctx = tsqlParser.Ddl_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_ddl_clause)
        try:
            self.state = 381
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,6,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 366
                self.create_database()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 367
                self.create_index()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 368
                self.create_procedure()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 369
                self.create_statistics()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 370
                self.create_table()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 371
                self.create_type()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 372
                self.create_view()
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 373
                self.alter_table()
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 374
                self.alter_database()
                pass

            elif la_ == 10:
                self.enterOuterAlt(localctx, 10)
                self.state = 375
                self.drop_index()
                pass

            elif la_ == 11:
                self.enterOuterAlt(localctx, 11)
                self.state = 376
                self.drop_procedure()
                pass

            elif la_ == 12:
                self.enterOuterAlt(localctx, 12)
                self.state = 377
                self.drop_statistics()
                pass

            elif la_ == 13:
                self.enterOuterAlt(localctx, 13)
                self.state = 378
                self.drop_table()
                pass

            elif la_ == 14:
                self.enterOuterAlt(localctx, 14)
                self.state = 379
                self.drop_type()
                pass

            elif la_ == 15:
                self.enterOuterAlt(localctx, 15)
                self.state = 380
                self.drop_view()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Cfl_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_cfl_statement

     
        def copyFrom(self, ctx:ParserRuleContext):
            super().copyFrom(ctx)



    class Return_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def RETURN(self):
            return self.getToken(tsqlParser.RETURN, 0)
        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterReturn_statement" ):
                listener.enterReturn_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitReturn_statement" ):
                listener.exitReturn_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitReturn_statement" ):
                return visitor.visitReturn_statement(self)
            else:
                return visitor.visitChildren(self)


    class Break_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def BREAK(self):
            return self.getToken(tsqlParser.BREAK, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBreak_statement" ):
                listener.enterBreak_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBreak_statement" ):
                listener.exitBreak_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBreak_statement" ):
                return visitor.visitBreak_statement(self)
            else:
                return visitor.visitChildren(self)


    class Try_catch_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.try_clauses = None # Sql_clausesContext
            self.catch_clauses = None # Sql_clausesContext
            self.copyFrom(ctx)

        def BEGIN(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.BEGIN)
            else:
                return self.getToken(tsqlParser.BEGIN, i)
        def TRY(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.TRY)
            else:
                return self.getToken(tsqlParser.TRY, i)
        def END(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.END)
            else:
                return self.getToken(tsqlParser.END, i)
        def CATCH(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.CATCH)
            else:
                return self.getToken(tsqlParser.CATCH, i)
        def sql_clauses(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Sql_clausesContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Sql_clausesContext,i)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTry_catch_statement" ):
                listener.enterTry_catch_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTry_catch_statement" ):
                listener.exitTry_catch_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTry_catch_statement" ):
                return visitor.visitTry_catch_statement(self)
            else:
                return visitor.visitChildren(self)


    class Raiseerror_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.msg = None # Token
            self.severity = None # Constant_LOCAL_IDContext
            self.state = None # Constant_LOCAL_IDContext
            self.copyFrom(ctx)

        def RAISERROR(self):
            return self.getToken(tsqlParser.RAISERROR, 0)
        def constant_LOCAL_ID(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Constant_LOCAL_IDContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Constant_LOCAL_IDContext,i)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)
        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)
        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaiseerror_statement" ):
                listener.enterRaiseerror_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaiseerror_statement" ):
                listener.exitRaiseerror_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRaiseerror_statement" ):
                return visitor.visitRaiseerror_statement(self)
            else:
                return visitor.visitChildren(self)


    class Print_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def PRINT(self):
            return self.getToken(tsqlParser.PRINT, 0)
        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrint_statement" ):
                listener.enterPrint_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrint_statement" ):
                listener.exitPrint_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPrint_statement" ):
                return visitor.visitPrint_statement(self)
            else:
                return visitor.visitChildren(self)


    class If_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def IF(self):
            return self.getToken(tsqlParser.IF, 0)
        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)

        def sql_clause(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Sql_clauseContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Sql_clauseContext,i)

        def ELSE(self):
            return self.getToken(tsqlParser.ELSE, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIf_statement" ):
                listener.enterIf_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIf_statement" ):
                listener.exitIf_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitIf_statement" ):
                return visitor.visitIf_statement(self)
            else:
                return visitor.visitChildren(self)


    class Waitfor_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def WAITFOR(self):
            return self.getToken(tsqlParser.WAITFOR, 0)
        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)

        def DELAY(self):
            return self.getToken(tsqlParser.DELAY, 0)
        def TIME(self):
            return self.getToken(tsqlParser.TIME, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWaitfor_statement" ):
                listener.enterWaitfor_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWaitfor_statement" ):
                listener.exitWaitfor_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWaitfor_statement" ):
                return visitor.visitWaitfor_statement(self)
            else:
                return visitor.visitChildren(self)


    class Block_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def BEGIN(self):
            return self.getToken(tsqlParser.BEGIN, 0)
        def END(self):
            return self.getToken(tsqlParser.END, 0)
        def sql_clauses(self):
            return self.getTypedRuleContext(tsqlParser.Sql_clausesContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBlock_statement" ):
                listener.enterBlock_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBlock_statement" ):
                listener.exitBlock_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBlock_statement" ):
                return visitor.visitBlock_statement(self)
            else:
                return visitor.visitChildren(self)


    class While_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def WHILE(self):
            return self.getToken(tsqlParser.WHILE, 0)
        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)

        def sql_clause(self):
            return self.getTypedRuleContext(tsqlParser.Sql_clauseContext,0)

        def BREAK(self):
            return self.getToken(tsqlParser.BREAK, 0)
        def CONTINUE(self):
            return self.getToken(tsqlParser.CONTINUE, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWhile_statement" ):
                listener.enterWhile_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWhile_statement" ):
                listener.exitWhile_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWhile_statement" ):
                return visitor.visitWhile_statement(self)
            else:
                return visitor.visitChildren(self)


    class Throw_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.error_number = None # Token
            self.message = None # Token
            self.state = None # Token
            self.copyFrom(ctx)

        def THROW(self):
            return self.getToken(tsqlParser.THROW, 0)
        def DECIMAL(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.DECIMAL)
            else:
                return self.getToken(tsqlParser.DECIMAL, i)
        def LOCAL_ID(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.LOCAL_ID)
            else:
                return self.getToken(tsqlParser.LOCAL_ID, i)
        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterThrow_statement" ):
                listener.enterThrow_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitThrow_statement" ):
                listener.exitThrow_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitThrow_statement" ):
                return visitor.visitThrow_statement(self)
            else:
                return visitor.visitChildren(self)


    class Goto_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def GOTO(self):
            return self.getToken(tsqlParser.GOTO, 0)
        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGoto_statement" ):
                listener.enterGoto_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGoto_statement" ):
                listener.exitGoto_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGoto_statement" ):
                return visitor.visitGoto_statement(self)
            else:
                return visitor.visitChildren(self)


    class Continue_statementContext(Cfl_statementContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Cfl_statementContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def CONTINUE(self):
            return self.getToken(tsqlParser.CONTINUE, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterContinue_statement" ):
                listener.enterContinue_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitContinue_statement" ):
                listener.exitContinue_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitContinue_statement" ):
                return visitor.visitContinue_statement(self)
            else:
                return visitor.visitChildren(self)



    def cfl_statement(self):

        localctx = tsqlParser.Cfl_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_cfl_statement)
        self._la = 0 # Token type
        try:
            self.state = 508
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,33,self._ctx)
            if la_ == 1:
                localctx = tsqlParser.Block_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 1)
                self.state = 383
                self.match(tsqlParser.BEGIN)
                self.state = 385
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.SEMI:
                    self.state = 384
                    self.match(tsqlParser.SEMI)


                self.state = 388
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << tsqlParser.ALTER) | (1 << tsqlParser.BEGIN) | (1 << tsqlParser.BREAK) | (1 << tsqlParser.CLOSE) | (1 << tsqlParser.COMMIT) | (1 << tsqlParser.CONTINUE) | (1 << tsqlParser.CREATE) | (1 << tsqlParser.DEALLOCATE) | (1 << tsqlParser.DECLARE) | (1 << tsqlParser.DELETE) | (1 << tsqlParser.DROP) | (1 << tsqlParser.EXECUTE))) != 0) or ((((_la - 67)) & ~0x3f) == 0 and ((1 << (_la - 67)) & ((1 << (tsqlParser.FETCH - 67)) | (1 << (tsqlParser.FORCESEEK - 67)) | (1 << (tsqlParser.GOTO - 67)) | (1 << (tsqlParser.GRANT - 67)) | (1 << (tsqlParser.IF - 67)) | (1 << (tsqlParser.INSERT - 67)) | (1 << (tsqlParser.OPEN - 67)) | (1 << (tsqlParser.PRINT - 67)))) != 0) or ((((_la - 134)) & ~0x3f) == 0 and ((1 << (_la - 134)) & ((1 << (tsqlParser.RAISERROR - 134)) | (1 << (tsqlParser.RETURN - 134)) | (1 << (tsqlParser.REVERT - 134)) | (1 << (tsqlParser.ROLLBACK - 134)) | (1 << (tsqlParser.SAVE - 134)) | (1 << (tsqlParser.SELECT - 134)) | (1 << (tsqlParser.SET - 134)) | (1 << (tsqlParser.UPDATE - 134)) | (1 << (tsqlParser.USE - 134)) | (1 << (tsqlParser.WAITFOR - 134)) | (1 << (tsqlParser.WHILE - 134)) | (1 << (tsqlParser.WITH - 134)) | (1 << (tsqlParser.ABSOLUTE - 134)))) != 0) or ((((_la - 201)) & ~0x3f) == 0 and ((1 << (_la - 201)) & ((1 << (tsqlParser.APPLY - 201)) | (1 << (tsqlParser.AUTO - 201)) | (1 << (tsqlParser.AVG - 201)) | (1 << (tsqlParser.BASE64 - 201)) | (1 << (tsqlParser.CALLER - 201)) | (1 << (tsqlParser.CAST - 201)) | (1 << (tsqlParser.CATCH - 201)) | (1 << (tsqlParser.CHECKSUM_AGG - 201)) | (1 << (tsqlParser.COMMITTED - 201)) | (1 << (tsqlParser.CONCAT - 201)) | (1 << (tsqlParser.CONTROL - 201)) | (1 << (tsqlParser.COOKIE - 201)) | (1 << (tsqlParser.COUNT - 201)) | (1 << (tsqlParser.COUNT_BIG - 201)) | (1 << (tsqlParser.DELAY - 201)) | (1 << (tsqlParser.DELETED - 201)) | (1 << (tsqlParser.DENSE_RANK - 201)) | (1 << (tsqlParser.DISABLE - 201)) | (1 << (tsqlParser.DYNAMIC - 201)) | (1 << (tsqlParser.ENCRYPTION - 201)) | (1 << (tsqlParser.EXPAND - 201)) | (1 << (tsqlParser.FAST - 201)) | (1 << (tsqlParser.FAST_FORWARD - 201)) | (1 << (tsqlParser.FIRST - 201)) | (1 << (tsqlParser.FOLLOWING - 201)) | (1 << (tsqlParser.FORCE - 201)) | (1 << (tsqlParser.FORCED - 201)) | (1 << (tsqlParser.FORWARD_ONLY - 201)) | (1 << (tsqlParser.FULLSCAN - 201)))) != 0) or ((((_la - 266)) & ~0x3f) == 0 and ((1 << (_la - 266)) & ((1 << (tsqlParser.GLOBAL - 266)) | (1 << (tsqlParser.GO - 266)) | (1 << (tsqlParser.GROUPING - 266)) | (1 << (tsqlParser.GROUPING_ID - 266)) | (1 << (tsqlParser.HASH - 266)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 266)) | (1 << (tsqlParser.IMPERSONATE - 266)) | (1 << (tsqlParser.INSENSITIVE - 266)) | (1 << (tsqlParser.INSERTED - 266)) | (1 << (tsqlParser.ISOLATION - 266)) | (1 << (tsqlParser.KEEP - 266)) | (1 << (tsqlParser.KEEPFIXED - 266)) | (1 << (tsqlParser.KEYSET - 266)) | (1 << (tsqlParser.LAST - 266)) | (1 << (tsqlParser.LEVEL - 266)) | (1 << (tsqlParser.LOCAL - 266)) | (1 << (tsqlParser.LOCK_ESCALATION - 266)) | (1 << (tsqlParser.LOGIN - 266)) | (1 << (tsqlParser.LOOP - 266)) | (1 << (tsqlParser.MARK - 266)) | (1 << (tsqlParser.MAX - 266)) | (1 << (tsqlParser.MAXDOP - 266)) | (1 << (tsqlParser.MAXRECURSION - 266)) | (1 << (tsqlParser.MIN - 266)) | (1 << (tsqlParser.MODIFY - 266)) | (1 << (tsqlParser.NAME - 266)) | (1 << (tsqlParser.NEXT - 266)) | (1 << (tsqlParser.NOCOUNT - 266)) | (1 << (tsqlParser.NOEXPAND - 266)) | (1 << (tsqlParser.NORECOMPUTE - 266)) | (1 << (tsqlParser.NTILE - 266)) | (1 << (tsqlParser.NUMBER - 266)) | (1 << (tsqlParser.OFFSET - 266)) | (1 << (tsqlParser.ONLINE - 266)) | (1 << (tsqlParser.ONLY - 266)) | (1 << (tsqlParser.OPTIMISTIC - 266)) | (1 << (tsqlParser.OPTIMIZE - 266)) | (1 << (tsqlParser.OUT - 266)) | (1 << (tsqlParser.OUTPUT - 266)) | (1 << (tsqlParser.OWNER - 266)) | (1 << (tsqlParser.PARAMETERIZATION - 266)) | (1 << (tsqlParser.PARTITION - 266)) | (1 << (tsqlParser.PATH - 266)) | (1 << (tsqlParser.PRECEDING - 266)))) != 0) or ((((_la - 330)) & ~0x3f) == 0 and ((1 << (_la - 330)) & ((1 << (tsqlParser.PRIOR - 330)) | (1 << (tsqlParser.PRIVILEGES - 330)) | (1 << (tsqlParser.RANGE - 330)) | (1 << (tsqlParser.RANK - 330)) | (1 << (tsqlParser.READONLY - 330)) | (1 << (tsqlParser.READ_ONLY - 330)) | (1 << (tsqlParser.RECOMPILE - 330)) | (1 << (tsqlParser.RELATIVE - 330)) | (1 << (tsqlParser.REMOTE - 330)) | (1 << (tsqlParser.REPEATABLE - 330)) | (1 << (tsqlParser.ROBUST - 330)) | (1 << (tsqlParser.ROOT - 330)) | (1 << (tsqlParser.ROW - 330)) | (1 << (tsqlParser.ROWGUID - 330)) | (1 << (tsqlParser.ROWS - 330)) | (1 << (tsqlParser.ROW_NUMBER - 330)) | (1 << (tsqlParser.SAMPLE - 330)) | (1 << (tsqlParser.SCHEMABINDING - 330)) | (1 << (tsqlParser.SCROLL - 330)) | (1 << (tsqlParser.SCROLL_LOCKS - 330)) | (1 << (tsqlParser.SELF - 330)) | (1 << (tsqlParser.SERIALIZABLE - 330)) | (1 << (tsqlParser.SIMPLE - 330)) | (1 << (tsqlParser.SIZE - 330)) | (1 << (tsqlParser.SNAPSHOT - 330)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 330)) | (1 << (tsqlParser.STATIC - 330)) | (1 << (tsqlParser.STATS_STREAM - 330)) | (1 << (tsqlParser.STDEV - 330)) | (1 << (tsqlParser.STDEVP - 330)) | (1 << (tsqlParser.SUM - 330)) | (1 << (tsqlParser.TEXTIMAGE_ON - 330)) | (1 << (tsqlParser.THROW - 330)) | (1 << (tsqlParser.TIES - 330)) | (1 << (tsqlParser.TIME - 330)) | (1 << (tsqlParser.TRY - 330)) | (1 << (tsqlParser.TYPE - 330)) | (1 << (tsqlParser.TYPE_WARNING - 330)) | (1 << (tsqlParser.UNBOUNDED - 330)) | (1 << (tsqlParser.UNCOMMITTED - 330)) | (1 << (tsqlParser.UNKNOWN - 330)) | (1 << (tsqlParser.USING - 330)) | (1 << (tsqlParser.VAR - 330)) | (1 << (tsqlParser.VARP - 330)) | (1 << (tsqlParser.VIEWS - 330)) | (1 << (tsqlParser.VIEW_METADATA - 330)) | (1 << (tsqlParser.WORK - 330)))) != 0) or ((((_la - 394)) & ~0x3f) == 0 and ((1 << (_la - 394)) & ((1 << (tsqlParser.XML - 394)) | (1 << (tsqlParser.XMLNAMESPACES - 394)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 394)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 394)) | (1 << (tsqlParser.ID - 394)) | (1 << (tsqlParser.LR_BRACKET - 394)))) != 0):
                    self.state = 387
                    self.sql_clauses()


                self.state = 390
                self.match(tsqlParser.END)
                self.state = 392
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,9,self._ctx)
                if la_ == 1:
                    self.state = 391
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 2:
                localctx = tsqlParser.Break_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 2)
                self.state = 394
                self.match(tsqlParser.BREAK)
                self.state = 396
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,10,self._ctx)
                if la_ == 1:
                    self.state = 395
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 3:
                localctx = tsqlParser.Continue_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 3)
                self.state = 398
                self.match(tsqlParser.CONTINUE)
                self.state = 400
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,11,self._ctx)
                if la_ == 1:
                    self.state = 399
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 4:
                localctx = tsqlParser.Goto_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 4)
                self.state = 402
                self.match(tsqlParser.GOTO)
                self.state = 403
                self.r_id()
                self.state = 405
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,12,self._ctx)
                if la_ == 1:
                    self.state = 404
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 5:
                localctx = tsqlParser.Goto_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 5)
                self.state = 407
                self.r_id()
                self.state = 408
                self.match(tsqlParser.COLON)
                self.state = 410
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,13,self._ctx)
                if la_ == 1:
                    self.state = 409
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 6:
                localctx = tsqlParser.If_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 6)
                self.state = 412
                self.match(tsqlParser.IF)
                self.state = 413
                self.search_condition(0)
                self.state = 414
                self.sql_clause()
                self.state = 417
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,14,self._ctx)
                if la_ == 1:
                    self.state = 415
                    self.match(tsqlParser.ELSE)
                    self.state = 416
                    self.sql_clause()


                self.state = 420
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,15,self._ctx)
                if la_ == 1:
                    self.state = 419
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 7:
                localctx = tsqlParser.Return_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 7)
                self.state = 422
                self.match(tsqlParser.RETURN)
                self.state = 424
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,16,self._ctx)
                if la_ == 1:
                    self.state = 423
                    self.expression(0)


                self.state = 427
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,17,self._ctx)
                if la_ == 1:
                    self.state = 426
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 8:
                localctx = tsqlParser.Throw_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 8)
                self.state = 429
                self.match(tsqlParser.THROW)
                self.state = 435
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.LOCAL_ID or _la==tsqlParser.DECIMAL:
                    self.state = 430
                    localctx.error_number = self._input.LT(1)
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.LOCAL_ID or _la==tsqlParser.DECIMAL):
                        localctx.error_number = self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 431
                    self.match(tsqlParser.COMMA)
                    self.state = 432
                    localctx.message = self._input.LT(1)
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.LOCAL_ID or _la==tsqlParser.STRING):
                        localctx.message = self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 433
                    self.match(tsqlParser.COMMA)
                    self.state = 434
                    localctx.state = self._input.LT(1)
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.LOCAL_ID or _la==tsqlParser.DECIMAL):
                        localctx.state = self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()


                self.state = 438
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,19,self._ctx)
                if la_ == 1:
                    self.state = 437
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 9:
                localctx = tsqlParser.Try_catch_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 9)
                self.state = 440
                self.match(tsqlParser.BEGIN)
                self.state = 441
                self.match(tsqlParser.TRY)
                self.state = 443
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.SEMI:
                    self.state = 442
                    self.match(tsqlParser.SEMI)


                self.state = 446
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << tsqlParser.ALTER) | (1 << tsqlParser.BEGIN) | (1 << tsqlParser.BREAK) | (1 << tsqlParser.CLOSE) | (1 << tsqlParser.COMMIT) | (1 << tsqlParser.CONTINUE) | (1 << tsqlParser.CREATE) | (1 << tsqlParser.DEALLOCATE) | (1 << tsqlParser.DECLARE) | (1 << tsqlParser.DELETE) | (1 << tsqlParser.DROP) | (1 << tsqlParser.EXECUTE))) != 0) or ((((_la - 67)) & ~0x3f) == 0 and ((1 << (_la - 67)) & ((1 << (tsqlParser.FETCH - 67)) | (1 << (tsqlParser.FORCESEEK - 67)) | (1 << (tsqlParser.GOTO - 67)) | (1 << (tsqlParser.GRANT - 67)) | (1 << (tsqlParser.IF - 67)) | (1 << (tsqlParser.INSERT - 67)) | (1 << (tsqlParser.OPEN - 67)) | (1 << (tsqlParser.PRINT - 67)))) != 0) or ((((_la - 134)) & ~0x3f) == 0 and ((1 << (_la - 134)) & ((1 << (tsqlParser.RAISERROR - 134)) | (1 << (tsqlParser.RETURN - 134)) | (1 << (tsqlParser.REVERT - 134)) | (1 << (tsqlParser.ROLLBACK - 134)) | (1 << (tsqlParser.SAVE - 134)) | (1 << (tsqlParser.SELECT - 134)) | (1 << (tsqlParser.SET - 134)) | (1 << (tsqlParser.UPDATE - 134)) | (1 << (tsqlParser.USE - 134)) | (1 << (tsqlParser.WAITFOR - 134)) | (1 << (tsqlParser.WHILE - 134)) | (1 << (tsqlParser.WITH - 134)) | (1 << (tsqlParser.ABSOLUTE - 134)))) != 0) or ((((_la - 201)) & ~0x3f) == 0 and ((1 << (_la - 201)) & ((1 << (tsqlParser.APPLY - 201)) | (1 << (tsqlParser.AUTO - 201)) | (1 << (tsqlParser.AVG - 201)) | (1 << (tsqlParser.BASE64 - 201)) | (1 << (tsqlParser.CALLER - 201)) | (1 << (tsqlParser.CAST - 201)) | (1 << (tsqlParser.CATCH - 201)) | (1 << (tsqlParser.CHECKSUM_AGG - 201)) | (1 << (tsqlParser.COMMITTED - 201)) | (1 << (tsqlParser.CONCAT - 201)) | (1 << (tsqlParser.CONTROL - 201)) | (1 << (tsqlParser.COOKIE - 201)) | (1 << (tsqlParser.COUNT - 201)) | (1 << (tsqlParser.COUNT_BIG - 201)) | (1 << (tsqlParser.DELAY - 201)) | (1 << (tsqlParser.DELETED - 201)) | (1 << (tsqlParser.DENSE_RANK - 201)) | (1 << (tsqlParser.DISABLE - 201)) | (1 << (tsqlParser.DYNAMIC - 201)) | (1 << (tsqlParser.ENCRYPTION - 201)) | (1 << (tsqlParser.EXPAND - 201)) | (1 << (tsqlParser.FAST - 201)) | (1 << (tsqlParser.FAST_FORWARD - 201)) | (1 << (tsqlParser.FIRST - 201)) | (1 << (tsqlParser.FOLLOWING - 201)) | (1 << (tsqlParser.FORCE - 201)) | (1 << (tsqlParser.FORCED - 201)) | (1 << (tsqlParser.FORWARD_ONLY - 201)) | (1 << (tsqlParser.FULLSCAN - 201)))) != 0) or ((((_la - 266)) & ~0x3f) == 0 and ((1 << (_la - 266)) & ((1 << (tsqlParser.GLOBAL - 266)) | (1 << (tsqlParser.GO - 266)) | (1 << (tsqlParser.GROUPING - 266)) | (1 << (tsqlParser.GROUPING_ID - 266)) | (1 << (tsqlParser.HASH - 266)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 266)) | (1 << (tsqlParser.IMPERSONATE - 266)) | (1 << (tsqlParser.INSENSITIVE - 266)) | (1 << (tsqlParser.INSERTED - 266)) | (1 << (tsqlParser.ISOLATION - 266)) | (1 << (tsqlParser.KEEP - 266)) | (1 << (tsqlParser.KEEPFIXED - 266)) | (1 << (tsqlParser.KEYSET - 266)) | (1 << (tsqlParser.LAST - 266)) | (1 << (tsqlParser.LEVEL - 266)) | (1 << (tsqlParser.LOCAL - 266)) | (1 << (tsqlParser.LOCK_ESCALATION - 266)) | (1 << (tsqlParser.LOGIN - 266)) | (1 << (tsqlParser.LOOP - 266)) | (1 << (tsqlParser.MARK - 266)) | (1 << (tsqlParser.MAX - 266)) | (1 << (tsqlParser.MAXDOP - 266)) | (1 << (tsqlParser.MAXRECURSION - 266)) | (1 << (tsqlParser.MIN - 266)) | (1 << (tsqlParser.MODIFY - 266)) | (1 << (tsqlParser.NAME - 266)) | (1 << (tsqlParser.NEXT - 266)) | (1 << (tsqlParser.NOCOUNT - 266)) | (1 << (tsqlParser.NOEXPAND - 266)) | (1 << (tsqlParser.NORECOMPUTE - 266)) | (1 << (tsqlParser.NTILE - 266)) | (1 << (tsqlParser.NUMBER - 266)) | (1 << (tsqlParser.OFFSET - 266)) | (1 << (tsqlParser.ONLINE - 266)) | (1 << (tsqlParser.ONLY - 266)) | (1 << (tsqlParser.OPTIMISTIC - 266)) | (1 << (tsqlParser.OPTIMIZE - 266)) | (1 << (tsqlParser.OUT - 266)) | (1 << (tsqlParser.OUTPUT - 266)) | (1 << (tsqlParser.OWNER - 266)) | (1 << (tsqlParser.PARAMETERIZATION - 266)) | (1 << (tsqlParser.PARTITION - 266)) | (1 << (tsqlParser.PATH - 266)) | (1 << (tsqlParser.PRECEDING - 266)))) != 0) or ((((_la - 330)) & ~0x3f) == 0 and ((1 << (_la - 330)) & ((1 << (tsqlParser.PRIOR - 330)) | (1 << (tsqlParser.PRIVILEGES - 330)) | (1 << (tsqlParser.RANGE - 330)) | (1 << (tsqlParser.RANK - 330)) | (1 << (tsqlParser.READONLY - 330)) | (1 << (tsqlParser.READ_ONLY - 330)) | (1 << (tsqlParser.RECOMPILE - 330)) | (1 << (tsqlParser.RELATIVE - 330)) | (1 << (tsqlParser.REMOTE - 330)) | (1 << (tsqlParser.REPEATABLE - 330)) | (1 << (tsqlParser.ROBUST - 330)) | (1 << (tsqlParser.ROOT - 330)) | (1 << (tsqlParser.ROW - 330)) | (1 << (tsqlParser.ROWGUID - 330)) | (1 << (tsqlParser.ROWS - 330)) | (1 << (tsqlParser.ROW_NUMBER - 330)) | (1 << (tsqlParser.SAMPLE - 330)) | (1 << (tsqlParser.SCHEMABINDING - 330)) | (1 << (tsqlParser.SCROLL - 330)) | (1 << (tsqlParser.SCROLL_LOCKS - 330)) | (1 << (tsqlParser.SELF - 330)) | (1 << (tsqlParser.SERIALIZABLE - 330)) | (1 << (tsqlParser.SIMPLE - 330)) | (1 << (tsqlParser.SIZE - 330)) | (1 << (tsqlParser.SNAPSHOT - 330)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 330)) | (1 << (tsqlParser.STATIC - 330)) | (1 << (tsqlParser.STATS_STREAM - 330)) | (1 << (tsqlParser.STDEV - 330)) | (1 << (tsqlParser.STDEVP - 330)) | (1 << (tsqlParser.SUM - 330)) | (1 << (tsqlParser.TEXTIMAGE_ON - 330)) | (1 << (tsqlParser.THROW - 330)) | (1 << (tsqlParser.TIES - 330)) | (1 << (tsqlParser.TIME - 330)) | (1 << (tsqlParser.TRY - 330)) | (1 << (tsqlParser.TYPE - 330)) | (1 << (tsqlParser.TYPE_WARNING - 330)) | (1 << (tsqlParser.UNBOUNDED - 330)) | (1 << (tsqlParser.UNCOMMITTED - 330)) | (1 << (tsqlParser.UNKNOWN - 330)) | (1 << (tsqlParser.USING - 330)) | (1 << (tsqlParser.VAR - 330)) | (1 << (tsqlParser.VARP - 330)) | (1 << (tsqlParser.VIEWS - 330)) | (1 << (tsqlParser.VIEW_METADATA - 330)) | (1 << (tsqlParser.WORK - 330)))) != 0) or ((((_la - 394)) & ~0x3f) == 0 and ((1 << (_la - 394)) & ((1 << (tsqlParser.XML - 394)) | (1 << (tsqlParser.XMLNAMESPACES - 394)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 394)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 394)) | (1 << (tsqlParser.ID - 394)) | (1 << (tsqlParser.LR_BRACKET - 394)))) != 0):
                    self.state = 445
                    localctx.try_clauses = self.sql_clauses()


                self.state = 448
                self.match(tsqlParser.END)
                self.state = 449
                self.match(tsqlParser.TRY)
                self.state = 451
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.SEMI:
                    self.state = 450
                    self.match(tsqlParser.SEMI)


                self.state = 453
                self.match(tsqlParser.BEGIN)
                self.state = 454
                self.match(tsqlParser.CATCH)
                self.state = 456
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.SEMI:
                    self.state = 455
                    self.match(tsqlParser.SEMI)


                self.state = 459
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << tsqlParser.ALTER) | (1 << tsqlParser.BEGIN) | (1 << tsqlParser.BREAK) | (1 << tsqlParser.CLOSE) | (1 << tsqlParser.COMMIT) | (1 << tsqlParser.CONTINUE) | (1 << tsqlParser.CREATE) | (1 << tsqlParser.DEALLOCATE) | (1 << tsqlParser.DECLARE) | (1 << tsqlParser.DELETE) | (1 << tsqlParser.DROP) | (1 << tsqlParser.EXECUTE))) != 0) or ((((_la - 67)) & ~0x3f) == 0 and ((1 << (_la - 67)) & ((1 << (tsqlParser.FETCH - 67)) | (1 << (tsqlParser.FORCESEEK - 67)) | (1 << (tsqlParser.GOTO - 67)) | (1 << (tsqlParser.GRANT - 67)) | (1 << (tsqlParser.IF - 67)) | (1 << (tsqlParser.INSERT - 67)) | (1 << (tsqlParser.OPEN - 67)) | (1 << (tsqlParser.PRINT - 67)))) != 0) or ((((_la - 134)) & ~0x3f) == 0 and ((1 << (_la - 134)) & ((1 << (tsqlParser.RAISERROR - 134)) | (1 << (tsqlParser.RETURN - 134)) | (1 << (tsqlParser.REVERT - 134)) | (1 << (tsqlParser.ROLLBACK - 134)) | (1 << (tsqlParser.SAVE - 134)) | (1 << (tsqlParser.SELECT - 134)) | (1 << (tsqlParser.SET - 134)) | (1 << (tsqlParser.UPDATE - 134)) | (1 << (tsqlParser.USE - 134)) | (1 << (tsqlParser.WAITFOR - 134)) | (1 << (tsqlParser.WHILE - 134)) | (1 << (tsqlParser.WITH - 134)) | (1 << (tsqlParser.ABSOLUTE - 134)))) != 0) or ((((_la - 201)) & ~0x3f) == 0 and ((1 << (_la - 201)) & ((1 << (tsqlParser.APPLY - 201)) | (1 << (tsqlParser.AUTO - 201)) | (1 << (tsqlParser.AVG - 201)) | (1 << (tsqlParser.BASE64 - 201)) | (1 << (tsqlParser.CALLER - 201)) | (1 << (tsqlParser.CAST - 201)) | (1 << (tsqlParser.CATCH - 201)) | (1 << (tsqlParser.CHECKSUM_AGG - 201)) | (1 << (tsqlParser.COMMITTED - 201)) | (1 << (tsqlParser.CONCAT - 201)) | (1 << (tsqlParser.CONTROL - 201)) | (1 << (tsqlParser.COOKIE - 201)) | (1 << (tsqlParser.COUNT - 201)) | (1 << (tsqlParser.COUNT_BIG - 201)) | (1 << (tsqlParser.DELAY - 201)) | (1 << (tsqlParser.DELETED - 201)) | (1 << (tsqlParser.DENSE_RANK - 201)) | (1 << (tsqlParser.DISABLE - 201)) | (1 << (tsqlParser.DYNAMIC - 201)) | (1 << (tsqlParser.ENCRYPTION - 201)) | (1 << (tsqlParser.EXPAND - 201)) | (1 << (tsqlParser.FAST - 201)) | (1 << (tsqlParser.FAST_FORWARD - 201)) | (1 << (tsqlParser.FIRST - 201)) | (1 << (tsqlParser.FOLLOWING - 201)) | (1 << (tsqlParser.FORCE - 201)) | (1 << (tsqlParser.FORCED - 201)) | (1 << (tsqlParser.FORWARD_ONLY - 201)) | (1 << (tsqlParser.FULLSCAN - 201)))) != 0) or ((((_la - 266)) & ~0x3f) == 0 and ((1 << (_la - 266)) & ((1 << (tsqlParser.GLOBAL - 266)) | (1 << (tsqlParser.GO - 266)) | (1 << (tsqlParser.GROUPING - 266)) | (1 << (tsqlParser.GROUPING_ID - 266)) | (1 << (tsqlParser.HASH - 266)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 266)) | (1 << (tsqlParser.IMPERSONATE - 266)) | (1 << (tsqlParser.INSENSITIVE - 266)) | (1 << (tsqlParser.INSERTED - 266)) | (1 << (tsqlParser.ISOLATION - 266)) | (1 << (tsqlParser.KEEP - 266)) | (1 << (tsqlParser.KEEPFIXED - 266)) | (1 << (tsqlParser.KEYSET - 266)) | (1 << (tsqlParser.LAST - 266)) | (1 << (tsqlParser.LEVEL - 266)) | (1 << (tsqlParser.LOCAL - 266)) | (1 << (tsqlParser.LOCK_ESCALATION - 266)) | (1 << (tsqlParser.LOGIN - 266)) | (1 << (tsqlParser.LOOP - 266)) | (1 << (tsqlParser.MARK - 266)) | (1 << (tsqlParser.MAX - 266)) | (1 << (tsqlParser.MAXDOP - 266)) | (1 << (tsqlParser.MAXRECURSION - 266)) | (1 << (tsqlParser.MIN - 266)) | (1 << (tsqlParser.MODIFY - 266)) | (1 << (tsqlParser.NAME - 266)) | (1 << (tsqlParser.NEXT - 266)) | (1 << (tsqlParser.NOCOUNT - 266)) | (1 << (tsqlParser.NOEXPAND - 266)) | (1 << (tsqlParser.NORECOMPUTE - 266)) | (1 << (tsqlParser.NTILE - 266)) | (1 << (tsqlParser.NUMBER - 266)) | (1 << (tsqlParser.OFFSET - 266)) | (1 << (tsqlParser.ONLINE - 266)) | (1 << (tsqlParser.ONLY - 266)) | (1 << (tsqlParser.OPTIMISTIC - 266)) | (1 << (tsqlParser.OPTIMIZE - 266)) | (1 << (tsqlParser.OUT - 266)) | (1 << (tsqlParser.OUTPUT - 266)) | (1 << (tsqlParser.OWNER - 266)) | (1 << (tsqlParser.PARAMETERIZATION - 266)) | (1 << (tsqlParser.PARTITION - 266)) | (1 << (tsqlParser.PATH - 266)) | (1 << (tsqlParser.PRECEDING - 266)))) != 0) or ((((_la - 330)) & ~0x3f) == 0 and ((1 << (_la - 330)) & ((1 << (tsqlParser.PRIOR - 330)) | (1 << (tsqlParser.PRIVILEGES - 330)) | (1 << (tsqlParser.RANGE - 330)) | (1 << (tsqlParser.RANK - 330)) | (1 << (tsqlParser.READONLY - 330)) | (1 << (tsqlParser.READ_ONLY - 330)) | (1 << (tsqlParser.RECOMPILE - 330)) | (1 << (tsqlParser.RELATIVE - 330)) | (1 << (tsqlParser.REMOTE - 330)) | (1 << (tsqlParser.REPEATABLE - 330)) | (1 << (tsqlParser.ROBUST - 330)) | (1 << (tsqlParser.ROOT - 330)) | (1 << (tsqlParser.ROW - 330)) | (1 << (tsqlParser.ROWGUID - 330)) | (1 << (tsqlParser.ROWS - 330)) | (1 << (tsqlParser.ROW_NUMBER - 330)) | (1 << (tsqlParser.SAMPLE - 330)) | (1 << (tsqlParser.SCHEMABINDING - 330)) | (1 << (tsqlParser.SCROLL - 330)) | (1 << (tsqlParser.SCROLL_LOCKS - 330)) | (1 << (tsqlParser.SELF - 330)) | (1 << (tsqlParser.SERIALIZABLE - 330)) | (1 << (tsqlParser.SIMPLE - 330)) | (1 << (tsqlParser.SIZE - 330)) | (1 << (tsqlParser.SNAPSHOT - 330)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 330)) | (1 << (tsqlParser.STATIC - 330)) | (1 << (tsqlParser.STATS_STREAM - 330)) | (1 << (tsqlParser.STDEV - 330)) | (1 << (tsqlParser.STDEVP - 330)) | (1 << (tsqlParser.SUM - 330)) | (1 << (tsqlParser.TEXTIMAGE_ON - 330)) | (1 << (tsqlParser.THROW - 330)) | (1 << (tsqlParser.TIES - 330)) | (1 << (tsqlParser.TIME - 330)) | (1 << (tsqlParser.TRY - 330)) | (1 << (tsqlParser.TYPE - 330)) | (1 << (tsqlParser.TYPE_WARNING - 330)) | (1 << (tsqlParser.UNBOUNDED - 330)) | (1 << (tsqlParser.UNCOMMITTED - 330)) | (1 << (tsqlParser.UNKNOWN - 330)) | (1 << (tsqlParser.USING - 330)) | (1 << (tsqlParser.VAR - 330)) | (1 << (tsqlParser.VARP - 330)) | (1 << (tsqlParser.VIEWS - 330)) | (1 << (tsqlParser.VIEW_METADATA - 330)) | (1 << (tsqlParser.WORK - 330)))) != 0) or ((((_la - 394)) & ~0x3f) == 0 and ((1 << (_la - 394)) & ((1 << (tsqlParser.XML - 394)) | (1 << (tsqlParser.XMLNAMESPACES - 394)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 394)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 394)) | (1 << (tsqlParser.ID - 394)) | (1 << (tsqlParser.LR_BRACKET - 394)))) != 0):
                    self.state = 458
                    localctx.catch_clauses = self.sql_clauses()


                self.state = 461
                self.match(tsqlParser.END)
                self.state = 462
                self.match(tsqlParser.CATCH)
                self.state = 464
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,25,self._ctx)
                if la_ == 1:
                    self.state = 463
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 10:
                localctx = tsqlParser.Waitfor_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 10)
                self.state = 466
                self.match(tsqlParser.WAITFOR)
                self.state = 467
                _la = self._input.LA(1)
                if not(_la==tsqlParser.DELAY or _la==tsqlParser.TIME):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 468
                self.expression(0)
                self.state = 470
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,26,self._ctx)
                if la_ == 1:
                    self.state = 469
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 11:
                localctx = tsqlParser.While_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 11)
                self.state = 472
                self.match(tsqlParser.WHILE)
                self.state = 473
                self.search_condition(0)
                self.state = 483
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,29,self._ctx)
                if la_ == 1:
                    self.state = 474
                    self.sql_clause()
                    pass

                elif la_ == 2:
                    self.state = 475
                    self.match(tsqlParser.BREAK)
                    self.state = 477
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,27,self._ctx)
                    if la_ == 1:
                        self.state = 476
                        self.match(tsqlParser.SEMI)


                    pass

                elif la_ == 3:
                    self.state = 479
                    self.match(tsqlParser.CONTINUE)
                    self.state = 481
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,28,self._ctx)
                    if la_ == 1:
                        self.state = 480
                        self.match(tsqlParser.SEMI)


                    pass


                pass

            elif la_ == 12:
                localctx = tsqlParser.Print_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 12)
                self.state = 485
                self.match(tsqlParser.PRINT)
                self.state = 486
                self.expression(0)
                self.state = 488
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,30,self._ctx)
                if la_ == 1:
                    self.state = 487
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 13:
                localctx = tsqlParser.Raiseerror_statementContext(self, localctx)
                self.enterOuterAlt(localctx, 13)
                self.state = 490
                self.match(tsqlParser.RAISERROR)
                self.state = 491
                self.match(tsqlParser.LR_BRACKET)
                self.state = 492
                localctx.msg = self._input.LT(1)
                _la = self._input.LA(1)
                if not(((((_la - 402)) & ~0x3f) == 0 and ((1 << (_la - 402)) & ((1 << (tsqlParser.LOCAL_ID - 402)) | (1 << (tsqlParser.DECIMAL - 402)) | (1 << (tsqlParser.STRING - 402)))) != 0)):
                    localctx.msg = self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 493
                self.match(tsqlParser.COMMA)
                self.state = 494
                localctx.severity = self.constant_LOCAL_ID()
                self.state = 495
                self.match(tsqlParser.COMMA)
                self.state = 496
                localctx.state = self.constant_LOCAL_ID()
                self.state = 501
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 497
                    self.match(tsqlParser.COMMA)
                    self.state = 498
                    self.constant_LOCAL_ID()
                    self.state = 503
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 504
                self.match(tsqlParser.RR_BRACKET)
                self.state = 506
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,32,self._ctx)
                if la_ == 1:
                    self.state = 505
                    self.match(tsqlParser.SEMI)


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Another_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def declare_statement(self):
            return self.getTypedRuleContext(tsqlParser.Declare_statementContext,0)


        def cursor_statement(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_statementContext,0)


        def execute_statement(self):
            return self.getTypedRuleContext(tsqlParser.Execute_statementContext,0)


        def security_statement(self):
            return self.getTypedRuleContext(tsqlParser.Security_statementContext,0)


        def set_statement(self):
            return self.getTypedRuleContext(tsqlParser.Set_statementContext,0)


        def transaction_statement(self):
            return self.getTypedRuleContext(tsqlParser.Transaction_statementContext,0)


        def use_statement(self):
            return self.getTypedRuleContext(tsqlParser.Use_statementContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_another_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAnother_statement" ):
                listener.enterAnother_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAnother_statement" ):
                listener.exitAnother_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAnother_statement" ):
                return visitor.visitAnother_statement(self)
            else:
                return visitor.visitChildren(self)




    def another_statement(self):

        localctx = tsqlParser.Another_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_another_statement)
        try:
            self.state = 517
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,34,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 510
                self.declare_statement()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 511
                self.cursor_statement()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 512
                self.execute_statement()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 513
                self.security_statement()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 514
                self.set_statement()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 515
                self.transaction_statement()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 516
                self.use_statement()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Delete_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.cursor_var = None # Token

        def DELETE(self):
            return self.getToken(tsqlParser.DELETE, 0)

        def delete_statement_from(self):
            return self.getTypedRuleContext(tsqlParser.Delete_statement_fromContext,0)


        def with_expression(self):
            return self.getTypedRuleContext(tsqlParser.With_expressionContext,0)


        def TOP(self):
            return self.getToken(tsqlParser.TOP, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def FROM(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.FROM)
            else:
                return self.getToken(tsqlParser.FROM, i)

        def insert_with_table_hints(self):
            return self.getTypedRuleContext(tsqlParser.Insert_with_table_hintsContext,0)


        def output_clause(self):
            return self.getTypedRuleContext(tsqlParser.Output_clauseContext,0)


        def table_sources(self):
            return self.getTypedRuleContext(tsqlParser.Table_sourcesContext,0)


        def WHERE(self):
            return self.getToken(tsqlParser.WHERE, 0)

        def for_clause(self):
            return self.getTypedRuleContext(tsqlParser.For_clauseContext,0)


        def option_clause(self):
            return self.getTypedRuleContext(tsqlParser.Option_clauseContext,0)


        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)


        def CURRENT(self):
            return self.getToken(tsqlParser.CURRENT, 0)

        def OF(self):
            return self.getToken(tsqlParser.OF, 0)

        def PERCENT(self):
            return self.getToken(tsqlParser.PERCENT, 0)

        def cursor_name(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_nameContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_delete_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDelete_statement" ):
                listener.enterDelete_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDelete_statement" ):
                listener.exitDelete_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDelete_statement" ):
                return visitor.visitDelete_statement(self)
            else:
                return visitor.visitChildren(self)




    def delete_statement(self):

        localctx = tsqlParser.Delete_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_delete_statement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 520
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 519
                self.with_expression()


            self.state = 522
            self.match(tsqlParser.DELETE)
            self.state = 530
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.TOP:
                self.state = 523
                self.match(tsqlParser.TOP)
                self.state = 524
                self.match(tsqlParser.LR_BRACKET)
                self.state = 525
                self.expression(0)
                self.state = 526
                self.match(tsqlParser.RR_BRACKET)
                self.state = 528
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PERCENT:
                    self.state = 527
                    self.match(tsqlParser.PERCENT)




            self.state = 533
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FROM:
                self.state = 532
                self.match(tsqlParser.FROM)


            self.state = 535
            self.delete_statement_from()
            self.state = 537
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,39,self._ctx)
            if la_ == 1:
                self.state = 536
                self.insert_with_table_hints()


            self.state = 540
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,40,self._ctx)
            if la_ == 1:
                self.state = 539
                self.output_clause()


            self.state = 544
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FROM:
                self.state = 542
                self.match(tsqlParser.FROM)
                self.state = 543
                self.table_sources()


            self.state = 559
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WHERE:
                self.state = 546
                self.match(tsqlParser.WHERE)
                self.state = 557
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.CASE, tsqlParser.COALESCE, tsqlParser.CONVERT, tsqlParser.CURRENT_TIMESTAMP, tsqlParser.CURRENT_USER, tsqlParser.DEFAULT, tsqlParser.EXISTS, tsqlParser.FORCESEEK, tsqlParser.IDENTITY, tsqlParser.LEFT, tsqlParser.NOT, tsqlParser.NULL, tsqlParser.NULLIF, tsqlParser.OVER, tsqlParser.RIGHT, tsqlParser.SESSION_USER, tsqlParser.SYSTEM_USER, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.BINARY_CHECKSUM, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DATEADD, tsqlParser.DATEDIFF, tsqlParser.DATENAME, tsqlParser.DATEPART, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MIN_ACTIVE_ROWVERSION, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.LOCAL_ID, tsqlParser.DECIMAL, tsqlParser.ID, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.LR_BRACKET, tsqlParser.PLUS, tsqlParser.MINUS, tsqlParser.BIT_NOT]:
                    self.state = 547
                    self.search_condition(0)
                    pass
                elif token in [tsqlParser.CURRENT]:
                    self.state = 548
                    self.match(tsqlParser.CURRENT)
                    self.state = 549
                    self.match(tsqlParser.OF)
                    self.state = 555
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,43,self._ctx)
                    if la_ == 1:
                        self.state = 551
                        self._errHandler.sync(self)
                        la_ = self._interp.adaptivePredict(self._input,42,self._ctx)
                        if la_ == 1:
                            self.state = 550
                            self.match(tsqlParser.GLOBAL)


                        self.state = 553
                        self.cursor_name()
                        pass

                    elif la_ == 2:
                        self.state = 554
                        localctx.cursor_var = self.match(tsqlParser.LOCAL_ID)
                        pass


                    pass
                else:
                    raise NoViableAltException(self)



            self.state = 562
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FOR:
                self.state = 561
                self.for_clause()


            self.state = 565
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.OPTION:
                self.state = 564
                self.option_clause()


            self.state = 568
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,48,self._ctx)
            if la_ == 1:
                self.state = 567
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Delete_statement_fromContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.table_var = None # Token

        def table_alias(self):
            return self.getTypedRuleContext(tsqlParser.Table_aliasContext,0)


        def ddl_object(self):
            return self.getTypedRuleContext(tsqlParser.Ddl_objectContext,0)


        def rowset_function_limited(self):
            return self.getTypedRuleContext(tsqlParser.Rowset_function_limitedContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_delete_statement_from

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDelete_statement_from" ):
                listener.enterDelete_statement_from(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDelete_statement_from" ):
                listener.exitDelete_statement_from(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDelete_statement_from" ):
                return visitor.visitDelete_statement_from(self)
            else:
                return visitor.visitChildren(self)




    def delete_statement_from(self):

        localctx = tsqlParser.Delete_statement_fromContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_delete_statement_from)
        try:
            self.state = 574
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,49,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 570
                self.table_alias()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 571
                self.ddl_object()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 572
                self.rowset_function_limited()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 573
                localctx.table_var = self.match(tsqlParser.LOCAL_ID)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Insert_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INSERT(self):
            return self.getToken(tsqlParser.INSERT, 0)

        def insert_statement_value(self):
            return self.getTypedRuleContext(tsqlParser.Insert_statement_valueContext,0)


        def ddl_object(self):
            return self.getTypedRuleContext(tsqlParser.Ddl_objectContext,0)


        def rowset_function_limited(self):
            return self.getTypedRuleContext(tsqlParser.Rowset_function_limitedContext,0)


        def with_expression(self):
            return self.getTypedRuleContext(tsqlParser.With_expressionContext,0)


        def TOP(self):
            return self.getToken(tsqlParser.TOP, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def INTO(self):
            return self.getToken(tsqlParser.INTO, 0)

        def insert_with_table_hints(self):
            return self.getTypedRuleContext(tsqlParser.Insert_with_table_hintsContext,0)


        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def output_clause(self):
            return self.getTypedRuleContext(tsqlParser.Output_clauseContext,0)


        def for_clause(self):
            return self.getTypedRuleContext(tsqlParser.For_clauseContext,0)


        def option_clause(self):
            return self.getTypedRuleContext(tsqlParser.Option_clauseContext,0)


        def PERCENT(self):
            return self.getToken(tsqlParser.PERCENT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_insert_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInsert_statement" ):
                listener.enterInsert_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInsert_statement" ):
                listener.exitInsert_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInsert_statement" ):
                return visitor.visitInsert_statement(self)
            else:
                return visitor.visitChildren(self)




    def insert_statement(self):

        localctx = tsqlParser.Insert_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_insert_statement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 577
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 576
                self.with_expression()


            self.state = 579
            self.match(tsqlParser.INSERT)
            self.state = 587
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.TOP:
                self.state = 580
                self.match(tsqlParser.TOP)
                self.state = 581
                self.match(tsqlParser.LR_BRACKET)
                self.state = 582
                self.expression(0)
                self.state = 583
                self.match(tsqlParser.RR_BRACKET)
                self.state = 585
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PERCENT:
                    self.state = 584
                    self.match(tsqlParser.PERCENT)




            self.state = 590
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.INTO:
                self.state = 589
                self.match(tsqlParser.INTO)


            self.state = 594
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.LOCAL_ID, tsqlParser.ID]:
                self.state = 592
                self.ddl_object()
                pass
            elif token in [tsqlParser.OPENDATASOURCE, tsqlParser.OPENQUERY]:
                self.state = 593
                self.rowset_function_limited()
                pass
            else:
                raise NoViableAltException(self)

            self.state = 597
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,55,self._ctx)
            if la_ == 1:
                self.state = 596
                self.insert_with_table_hints()


            self.state = 603
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,56,self._ctx)
            if la_ == 1:
                self.state = 599
                self.match(tsqlParser.LR_BRACKET)
                self.state = 600
                self.column_name_list()
                self.state = 601
                self.match(tsqlParser.RR_BRACKET)


            self.state = 606
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.OUTPUT:
                self.state = 605
                self.output_clause()


            self.state = 608
            self.insert_statement_value()
            self.state = 610
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FOR:
                self.state = 609
                self.for_clause()


            self.state = 613
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.OPTION:
                self.state = 612
                self.option_clause()


            self.state = 616
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,60,self._ctx)
            if la_ == 1:
                self.state = 615
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Insert_statement_valueContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_value_constructor(self):
            return self.getTypedRuleContext(tsqlParser.Table_value_constructorContext,0)


        def derived_table(self):
            return self.getTypedRuleContext(tsqlParser.Derived_tableContext,0)


        def execute_statement(self):
            return self.getTypedRuleContext(tsqlParser.Execute_statementContext,0)


        def DEFAULT(self):
            return self.getToken(tsqlParser.DEFAULT, 0)

        def VALUES(self):
            return self.getToken(tsqlParser.VALUES, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_insert_statement_value

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInsert_statement_value" ):
                listener.enterInsert_statement_value(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInsert_statement_value" ):
                listener.exitInsert_statement_value(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInsert_statement_value" ):
                return visitor.visitInsert_statement_value(self)
            else:
                return visitor.visitChildren(self)




    def insert_statement_value(self):

        localctx = tsqlParser.Insert_statement_valueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_insert_statement_value)
        try:
            self.state = 623
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.VALUES]:
                self.enterOuterAlt(localctx, 1)
                self.state = 618
                self.table_value_constructor()
                pass
            elif token in [tsqlParser.SELECT, tsqlParser.WITH, tsqlParser.LR_BRACKET]:
                self.enterOuterAlt(localctx, 2)
                self.state = 619
                self.derived_table()
                pass
            elif token in [tsqlParser.EXECUTE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 620
                self.execute_statement()
                pass
            elif token in [tsqlParser.DEFAULT]:
                self.enterOuterAlt(localctx, 4)
                self.state = 621
                self.match(tsqlParser.DEFAULT)
                self.state = 622
                self.match(tsqlParser.VALUES)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Select_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def query_expression(self):
            return self.getTypedRuleContext(tsqlParser.Query_expressionContext,0)


        def with_expression(self):
            return self.getTypedRuleContext(tsqlParser.With_expressionContext,0)


        def order_by_clause(self):
            return self.getTypedRuleContext(tsqlParser.Order_by_clauseContext,0)


        def for_clause(self):
            return self.getTypedRuleContext(tsqlParser.For_clauseContext,0)


        def option_clause(self):
            return self.getTypedRuleContext(tsqlParser.Option_clauseContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_select_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSelect_statement" ):
                listener.enterSelect_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSelect_statement" ):
                listener.exitSelect_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSelect_statement" ):
                return visitor.visitSelect_statement(self)
            else:
                return visitor.visitChildren(self)




    def select_statement(self):

        localctx = tsqlParser.Select_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_select_statement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 626
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 625
                self.with_expression()


            self.state = 628
            self.query_expression()
            self.state = 630
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,63,self._ctx)
            if la_ == 1:
                self.state = 629
                self.order_by_clause()


            self.state = 633
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,64,self._ctx)
            if la_ == 1:
                self.state = 632
                self.for_clause()


            self.state = 636
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,65,self._ctx)
            if la_ == 1:
                self.state = 635
                self.option_clause()


            self.state = 639
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,66,self._ctx)
            if la_ == 1:
                self.state = 638
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Update_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.cursor_var = None # Token

        def UPDATE(self):
            return self.getToken(tsqlParser.UPDATE, 0)

        def SET(self):
            return self.getToken(tsqlParser.SET, 0)

        def update_elem(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Update_elemContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Update_elemContext,i)


        def ddl_object(self):
            return self.getTypedRuleContext(tsqlParser.Ddl_objectContext,0)


        def rowset_function_limited(self):
            return self.getTypedRuleContext(tsqlParser.Rowset_function_limitedContext,0)


        def with_expression(self):
            return self.getTypedRuleContext(tsqlParser.With_expressionContext,0)


        def TOP(self):
            return self.getToken(tsqlParser.TOP, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def with_table_hints(self):
            return self.getTypedRuleContext(tsqlParser.With_table_hintsContext,0)


        def output_clause(self):
            return self.getTypedRuleContext(tsqlParser.Output_clauseContext,0)


        def FROM(self):
            return self.getToken(tsqlParser.FROM, 0)

        def table_sources(self):
            return self.getTypedRuleContext(tsqlParser.Table_sourcesContext,0)


        def WHERE(self):
            return self.getToken(tsqlParser.WHERE, 0)

        def for_clause(self):
            return self.getTypedRuleContext(tsqlParser.For_clauseContext,0)


        def option_clause(self):
            return self.getTypedRuleContext(tsqlParser.Option_clauseContext,0)


        def search_condition_list(self):
            return self.getTypedRuleContext(tsqlParser.Search_condition_listContext,0)


        def CURRENT(self):
            return self.getToken(tsqlParser.CURRENT, 0)

        def OF(self):
            return self.getToken(tsqlParser.OF, 0)

        def PERCENT(self):
            return self.getToken(tsqlParser.PERCENT, 0)

        def cursor_name(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_nameContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_update_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUpdate_statement" ):
                listener.enterUpdate_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUpdate_statement" ):
                listener.exitUpdate_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUpdate_statement" ):
                return visitor.visitUpdate_statement(self)
            else:
                return visitor.visitChildren(self)




    def update_statement(self):

        localctx = tsqlParser.Update_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_update_statement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 642
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 641
                self.with_expression()


            self.state = 644
            self.match(tsqlParser.UPDATE)
            self.state = 652
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.TOP:
                self.state = 645
                self.match(tsqlParser.TOP)
                self.state = 646
                self.match(tsqlParser.LR_BRACKET)
                self.state = 647
                self.expression(0)
                self.state = 648
                self.match(tsqlParser.RR_BRACKET)
                self.state = 650
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PERCENT:
                    self.state = 649
                    self.match(tsqlParser.PERCENT)




            self.state = 656
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.LOCAL_ID, tsqlParser.ID]:
                self.state = 654
                self.ddl_object()
                pass
            elif token in [tsqlParser.OPENDATASOURCE, tsqlParser.OPENQUERY]:
                self.state = 655
                self.rowset_function_limited()
                pass
            else:
                raise NoViableAltException(self)

            self.state = 659
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH or _la==tsqlParser.LR_BRACKET:
                self.state = 658
                self.with_table_hints()


            self.state = 661
            self.match(tsqlParser.SET)
            self.state = 662
            self.update_elem()
            self.state = 667
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 663
                self.match(tsqlParser.COMMA)
                self.state = 664
                self.update_elem()
                self.state = 669
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 671
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,73,self._ctx)
            if la_ == 1:
                self.state = 670
                self.output_clause()


            self.state = 675
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FROM:
                self.state = 673
                self.match(tsqlParser.FROM)
                self.state = 674
                self.table_sources()


            self.state = 690
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WHERE:
                self.state = 677
                self.match(tsqlParser.WHERE)
                self.state = 688
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.CASE, tsqlParser.COALESCE, tsqlParser.CONVERT, tsqlParser.CURRENT_TIMESTAMP, tsqlParser.CURRENT_USER, tsqlParser.DEFAULT, tsqlParser.EXISTS, tsqlParser.FORCESEEK, tsqlParser.IDENTITY, tsqlParser.LEFT, tsqlParser.NOT, tsqlParser.NULL, tsqlParser.NULLIF, tsqlParser.OVER, tsqlParser.RIGHT, tsqlParser.SESSION_USER, tsqlParser.SYSTEM_USER, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.BINARY_CHECKSUM, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DATEADD, tsqlParser.DATEDIFF, tsqlParser.DATENAME, tsqlParser.DATEPART, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MIN_ACTIVE_ROWVERSION, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.LOCAL_ID, tsqlParser.DECIMAL, tsqlParser.ID, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.LR_BRACKET, tsqlParser.PLUS, tsqlParser.MINUS, tsqlParser.BIT_NOT]:
                    self.state = 678
                    self.search_condition_list()
                    pass
                elif token in [tsqlParser.CURRENT]:
                    self.state = 679
                    self.match(tsqlParser.CURRENT)
                    self.state = 680
                    self.match(tsqlParser.OF)
                    self.state = 686
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,76,self._ctx)
                    if la_ == 1:
                        self.state = 682
                        self._errHandler.sync(self)
                        la_ = self._interp.adaptivePredict(self._input,75,self._ctx)
                        if la_ == 1:
                            self.state = 681
                            self.match(tsqlParser.GLOBAL)


                        self.state = 684
                        self.cursor_name()
                        pass

                    elif la_ == 2:
                        self.state = 685
                        localctx.cursor_var = self.match(tsqlParser.LOCAL_ID)
                        pass


                    pass
                else:
                    raise NoViableAltException(self)



            self.state = 693
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FOR:
                self.state = 692
                self.for_clause()


            self.state = 696
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.OPTION:
                self.state = 695
                self.option_clause()


            self.state = 699
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,81,self._ctx)
            if la_ == 1:
                self.state = 698
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Output_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OUTPUT(self):
            return self.getToken(tsqlParser.OUTPUT, 0)

        def output_dml_list_elem(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Output_dml_list_elemContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Output_dml_list_elemContext,i)


        def INTO(self):
            return self.getToken(tsqlParser.INTO, 0)

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_output_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOutput_clause" ):
                listener.enterOutput_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOutput_clause" ):
                listener.exitOutput_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOutput_clause" ):
                return visitor.visitOutput_clause(self)
            else:
                return visitor.visitChildren(self)




    def output_clause(self):

        localctx = tsqlParser.Output_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_output_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 701
            self.match(tsqlParser.OUTPUT)
            self.state = 702
            self.output_dml_list_elem()
            self.state = 707
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 703
                self.match(tsqlParser.COMMA)
                self.state = 704
                self.output_dml_list_elem()
                self.state = 709
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 721
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.INTO:
                self.state = 710
                self.match(tsqlParser.INTO)
                self.state = 713
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.LOCAL_ID]:
                    self.state = 711
                    self.match(tsqlParser.LOCAL_ID)
                    pass
                elif token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 712
                    self.table_name()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 719
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,84,self._ctx)
                if la_ == 1:
                    self.state = 715
                    self.match(tsqlParser.LR_BRACKET)
                    self.state = 716
                    self.column_name_list()
                    self.state = 717
                    self.match(tsqlParser.RR_BRACKET)




        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Output_dml_list_elemContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def output_column_name(self):
            return self.getTypedRuleContext(tsqlParser.Output_column_nameContext,0)


        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def column_alias(self):
            return self.getTypedRuleContext(tsqlParser.Column_aliasContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_output_dml_list_elem

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOutput_dml_list_elem" ):
                listener.enterOutput_dml_list_elem(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOutput_dml_list_elem" ):
                listener.exitOutput_dml_list_elem(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOutput_dml_list_elem" ):
                return visitor.visitOutput_dml_list_elem(self)
            else:
                return visitor.visitChildren(self)




    def output_dml_list_elem(self):

        localctx = tsqlParser.Output_dml_list_elemContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_output_dml_list_elem)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 725
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,86,self._ctx)
            if la_ == 1:
                self.state = 723
                self.output_column_name()
                pass

            elif la_ == 2:
                self.state = 724
                self.expression(0)
                pass


            self.state = 731
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,88,self._ctx)
            if la_ == 1:
                self.state = 728
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.AS:
                    self.state = 727
                    self.match(tsqlParser.AS)


                self.state = 730
                self.column_alias()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Output_column_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DELETED(self):
            return self.getToken(tsqlParser.DELETED, 0)

        def INSERTED(self):
            return self.getToken(tsqlParser.INSERTED, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def DOLLAR_ACTION(self):
            return self.getToken(tsqlParser.DOLLAR_ACTION, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_output_column_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOutput_column_name" ):
                listener.enterOutput_column_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOutput_column_name" ):
                listener.exitOutput_column_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOutput_column_name" ):
                return visitor.visitOutput_column_name(self)
            else:
                return visitor.visitChildren(self)




    def output_column_name(self):

        localctx = tsqlParser.Output_column_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_output_column_name)
        try:
            self.state = 744
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 736
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,89,self._ctx)
                if la_ == 1:
                    self.state = 733
                    self.match(tsqlParser.DELETED)
                    pass

                elif la_ == 2:
                    self.state = 734
                    self.match(tsqlParser.INSERTED)
                    pass

                elif la_ == 3:
                    self.state = 735
                    self.table_name()
                    pass


                self.state = 738
                self.match(tsqlParser.DOT)
                self.state = 741
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.STAR]:
                    self.state = 739
                    self.match(tsqlParser.STAR)
                    pass
                elif token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 740
                    self.r_id()
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            elif token in [tsqlParser.DOLLAR_ACTION]:
                self.enterOuterAlt(localctx, 2)
                self.state = 743
                self.match(tsqlParser.DOLLAR_ACTION)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_databaseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.database = None # R_idContext
            self.collation_name = None # R_idContext

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def DATABASE(self):
            return self.getToken(tsqlParser.DATABASE, 0)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def CONTAINMENT(self):
            return self.getToken(tsqlParser.CONTAINMENT, 0)

        def ON(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.ON)
            else:
                return self.getToken(tsqlParser.ON, i)

        def database_file_spec(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Database_file_specContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Database_file_specContext,i)


        def LOG(self):
            return self.getToken(tsqlParser.LOG, 0)

        def COLLATE(self):
            return self.getToken(tsqlParser.COLLATE, 0)

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def create_database_option(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Create_database_optionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Create_database_optionContext,i)


        def NONE(self):
            return self.getToken(tsqlParser.NONE, 0)

        def PARTIAL(self):
            return self.getToken(tsqlParser.PARTIAL, 0)

        def PRIMARY(self):
            return self.getToken(tsqlParser.PRIMARY, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_create_database

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_database" ):
                listener.enterCreate_database(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_database" ):
                listener.exitCreate_database(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_database" ):
                return visitor.visitCreate_database(self)
            else:
                return visitor.visitChildren(self)




    def create_database(self):

        localctx = tsqlParser.Create_databaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_create_database)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 746
            self.match(tsqlParser.CREATE)
            self.state = 747
            self.match(tsqlParser.DATABASE)

            self.state = 748
            localctx.database = self.r_id()
            self.state = 752
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.CONTAINMENT:
                self.state = 749
                self.match(tsqlParser.CONTAINMENT)
                self.state = 750
                self.match(tsqlParser.EQUAL)
                self.state = 751
                _la = self._input.LA(1)
                if not(_la==tsqlParser.NONE or _la==tsqlParser.PARTIAL):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 766
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ON:
                self.state = 754
                self.match(tsqlParser.ON)
                self.state = 756
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PRIMARY:
                    self.state = 755
                    self.match(tsqlParser.PRIMARY)


                self.state = 758
                self.database_file_spec()
                self.state = 763
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 759
                    self.match(tsqlParser.COMMA)
                    self.state = 760
                    self.database_file_spec()
                    self.state = 765
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 778
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.LOG:
                self.state = 768
                self.match(tsqlParser.LOG)
                self.state = 769
                self.match(tsqlParser.ON)
                self.state = 770
                self.database_file_spec()
                self.state = 775
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 771
                    self.match(tsqlParser.COMMA)
                    self.state = 772
                    self.database_file_spec()
                    self.state = 777
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 782
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.COLLATE:
                self.state = 780
                self.match(tsqlParser.COLLATE)
                self.state = 781
                localctx.collation_name = self.r_id()


            self.state = 793
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,100,self._ctx)
            if la_ == 1:
                self.state = 784
                self.match(tsqlParser.WITH)
                self.state = 785
                self.create_database_option()
                self.state = 790
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 786
                    self.match(tsqlParser.COMMA)
                    self.state = 787
                    self.create_database_option()
                    self.state = 792
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_indexContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def INDEX(self):
            return self.getToken(tsqlParser.INDEX, 0)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def ON(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.ON)
            else:
                return self.getToken(tsqlParser.ON, i)

        def table_name_with_hint(self):
            return self.getTypedRuleContext(tsqlParser.Table_name_with_hintContext,0)


        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def UNIQUE(self):
            return self.getToken(tsqlParser.UNIQUE, 0)

        def clustered(self):
            return self.getTypedRuleContext(tsqlParser.ClusteredContext,0)


        def index_options(self):
            return self.getTypedRuleContext(tsqlParser.Index_optionsContext,0)


        def ASC(self):
            return self.getToken(tsqlParser.ASC, 0)

        def DESC(self):
            return self.getToken(tsqlParser.DESC, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_create_index

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_index" ):
                listener.enterCreate_index(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_index" ):
                listener.exitCreate_index(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_index" ):
                return visitor.visitCreate_index(self)
            else:
                return visitor.visitChildren(self)




    def create_index(self):

        localctx = tsqlParser.Create_indexContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_create_index)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 795
            self.match(tsqlParser.CREATE)
            self.state = 797
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.UNIQUE:
                self.state = 796
                self.match(tsqlParser.UNIQUE)


            self.state = 800
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.CLUSTERED or _la==tsqlParser.NONCLUSTERED:
                self.state = 799
                self.clustered()


            self.state = 802
            self.match(tsqlParser.INDEX)
            self.state = 803
            self.r_id()
            self.state = 804
            self.match(tsqlParser.ON)
            self.state = 805
            self.table_name_with_hint()
            self.state = 806
            self.match(tsqlParser.LR_BRACKET)
            self.state = 807
            self.column_name_list()
            self.state = 809
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ASC or _la==tsqlParser.DESC:
                self.state = 808
                _la = self._input.LA(1)
                if not(_la==tsqlParser.ASC or _la==tsqlParser.DESC):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 811
            self.match(tsqlParser.RR_BRACKET)
            self.state = 813
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,104,self._ctx)
            if la_ == 1:
                self.state = 812
                self.index_options()


            self.state = 817
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ON:
                self.state = 815
                self.match(tsqlParser.ON)
                self.state = 816
                self.r_id()


            self.state = 820
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,106,self._ctx)
            if la_ == 1:
                self.state = 819
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_procedureContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.proc = None # Token

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def func_proc_name(self):
            return self.getTypedRuleContext(tsqlParser.Func_proc_nameContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def sql_clauses(self):
            return self.getTypedRuleContext(tsqlParser.Sql_clausesContext,0)


        def PROC(self):
            return self.getToken(tsqlParser.PROC, 0)

        def PROCEDURE(self):
            return self.getToken(tsqlParser.PROCEDURE, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def procedure_param(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Procedure_paramContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Procedure_paramContext,i)


        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def procedure_option(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Procedure_optionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Procedure_optionContext,i)


        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def REPLICATION(self):
            return self.getToken(tsqlParser.REPLICATION, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_create_procedure

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_procedure" ):
                listener.enterCreate_procedure(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_procedure" ):
                listener.exitCreate_procedure(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_procedure" ):
                return visitor.visitCreate_procedure(self)
            else:
                return visitor.visitChildren(self)




    def create_procedure(self):

        localctx = tsqlParser.Create_procedureContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_create_procedure)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 822
            self.match(tsqlParser.CREATE)
            self.state = 823
            localctx.proc = self._input.LT(1)
            _la = self._input.LA(1)
            if not(_la==tsqlParser.PROC or _la==tsqlParser.PROCEDURE):
                localctx.proc = self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 824
            self.func_proc_name()
            self.state = 827
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.SEMI:
                self.state = 825
                self.match(tsqlParser.SEMI)
                self.state = 826
                self.match(tsqlParser.DECIMAL)


            self.state = 843
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.LOCAL_ID or _la==tsqlParser.LR_BRACKET:
                self.state = 830
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.LR_BRACKET:
                    self.state = 829
                    self.match(tsqlParser.LR_BRACKET)


                self.state = 832
                self.procedure_param()
                self.state = 837
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 833
                    self.match(tsqlParser.COMMA)
                    self.state = 834
                    self.procedure_param()
                    self.state = 839
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 841
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.RR_BRACKET:
                    self.state = 840
                    self.match(tsqlParser.RR_BRACKET)




            self.state = 854
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 845
                self.match(tsqlParser.WITH)
                self.state = 846
                self.procedure_option()
                self.state = 851
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 847
                    self.match(tsqlParser.COMMA)
                    self.state = 848
                    self.procedure_option()
                    self.state = 853
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 858
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FOR:
                self.state = 856
                self.match(tsqlParser.FOR)
                self.state = 857
                self.match(tsqlParser.REPLICATION)


            self.state = 860
            self.match(tsqlParser.AS)
            self.state = 861
            self.sql_clauses()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Procedure_paramContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.default_val = None # Default_valueContext

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def data_type(self):
            return self.getTypedRuleContext(tsqlParser.Data_typeContext,0)


        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def VARYING(self):
            return self.getToken(tsqlParser.VARYING, 0)

        def default_value(self):
            return self.getTypedRuleContext(tsqlParser.Default_valueContext,0)


        def OUT(self):
            return self.getToken(tsqlParser.OUT, 0)

        def OUTPUT(self):
            return self.getToken(tsqlParser.OUTPUT, 0)

        def READONLY(self):
            return self.getToken(tsqlParser.READONLY, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_procedure_param

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProcedure_param" ):
                listener.enterProcedure_param(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProcedure_param" ):
                listener.exitProcedure_param(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitProcedure_param" ):
                return visitor.visitProcedure_param(self)
            else:
                return visitor.visitChildren(self)




    def procedure_param(self):

        localctx = tsqlParser.Procedure_paramContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_procedure_param)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 863
            self.match(tsqlParser.LOCAL_ID)
            self.state = 867
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,115,self._ctx)
            if la_ == 1:
                self.state = 864
                self.r_id()
                self.state = 865
                self.match(tsqlParser.DOT)


            self.state = 870
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.AS:
                self.state = 869
                self.match(tsqlParser.AS)


            self.state = 872
            self.data_type()
            self.state = 874
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.VARYING:
                self.state = 873
                self.match(tsqlParser.VARYING)


            self.state = 878
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.EQUAL:
                self.state = 876
                self.match(tsqlParser.EQUAL)
                self.state = 877
                localctx.default_val = self.default_value()


            self.state = 881
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if ((((_la - 322)) & ~0x3f) == 0 and ((1 << (_la - 322)) & ((1 << (tsqlParser.OUT - 322)) | (1 << (tsqlParser.OUTPUT - 322)) | (1 << (tsqlParser.READONLY - 322)))) != 0):
                self.state = 880
                _la = self._input.LA(1)
                if not(((((_la - 322)) & ~0x3f) == 0 and ((1 << (_la - 322)) & ((1 << (tsqlParser.OUT - 322)) | (1 << (tsqlParser.OUTPUT - 322)) | (1 << (tsqlParser.READONLY - 322)))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Procedure_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ENCRYPTION(self):
            return self.getToken(tsqlParser.ENCRYPTION, 0)

        def RECOMPILE(self):
            return self.getToken(tsqlParser.RECOMPILE, 0)

        def execute_clause(self):
            return self.getTypedRuleContext(tsqlParser.Execute_clauseContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_procedure_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProcedure_option" ):
                listener.enterProcedure_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProcedure_option" ):
                listener.exitProcedure_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitProcedure_option" ):
                return visitor.visitProcedure_option(self)
            else:
                return visitor.visitChildren(self)




    def procedure_option(self):

        localctx = tsqlParser.Procedure_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_procedure_option)
        try:
            self.state = 886
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.ENCRYPTION]:
                self.enterOuterAlt(localctx, 1)
                self.state = 883
                self.match(tsqlParser.ENCRYPTION)
                pass
            elif token in [tsqlParser.RECOMPILE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 884
                self.match(tsqlParser.RECOMPILE)
                pass
            elif token in [tsqlParser.EXECUTE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 885
                self.execute_clause()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_statisticsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def STATISTICS(self):
            return self.getToken(tsqlParser.STATISTICS, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def table_name_with_hint(self):
            return self.getTypedRuleContext(tsqlParser.Table_name_with_hintContext,0)


        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def FULLSCAN(self):
            return self.getToken(tsqlParser.FULLSCAN, 0)

        def SAMPLE(self):
            return self.getToken(tsqlParser.SAMPLE, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def STATS_STREAM(self):
            return self.getToken(tsqlParser.STATS_STREAM, 0)

        def PERCENT(self):
            return self.getToken(tsqlParser.PERCENT, 0)

        def ROWS(self):
            return self.getToken(tsqlParser.ROWS, 0)

        def NORECOMPUTE(self):
            return self.getToken(tsqlParser.NORECOMPUTE, 0)

        def INCREMENTAL(self):
            return self.getToken(tsqlParser.INCREMENTAL, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_create_statistics

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_statistics" ):
                listener.enterCreate_statistics(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_statistics" ):
                listener.exitCreate_statistics(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_statistics" ):
                return visitor.visitCreate_statistics(self)
            else:
                return visitor.visitChildren(self)




    def create_statistics(self):

        localctx = tsqlParser.Create_statisticsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_create_statistics)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 888
            self.match(tsqlParser.CREATE)
            self.state = 889
            self.match(tsqlParser.STATISTICS)
            self.state = 890
            self.r_id()
            self.state = 891
            self.match(tsqlParser.ON)
            self.state = 892
            self.table_name_with_hint()
            self.state = 893
            self.match(tsqlParser.LR_BRACKET)
            self.state = 894
            self.column_name_list()
            self.state = 895
            self.match(tsqlParser.RR_BRACKET)
            self.state = 914
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,124,self._ctx)
            if la_ == 1:
                self.state = 896
                self.match(tsqlParser.WITH)
                self.state = 902
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FULLSCAN]:
                    self.state = 897
                    self.match(tsqlParser.FULLSCAN)
                    pass
                elif token in [tsqlParser.SAMPLE]:
                    self.state = 898
                    self.match(tsqlParser.SAMPLE)
                    self.state = 899
                    self.match(tsqlParser.DECIMAL)
                    self.state = 900
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.PERCENT or _la==tsqlParser.ROWS):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    pass
                elif token in [tsqlParser.STATS_STREAM]:
                    self.state = 901
                    self.match(tsqlParser.STATS_STREAM)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 906
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,122,self._ctx)
                if la_ == 1:
                    self.state = 904
                    self.match(tsqlParser.COMMA)
                    self.state = 905
                    self.match(tsqlParser.NORECOMPUTE)


                self.state = 912
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 908
                    self.match(tsqlParser.COMMA)
                    self.state = 909
                    self.match(tsqlParser.INCREMENTAL)
                    self.state = 910
                    self.match(tsqlParser.EQUAL)
                    self.state = 911
                    self.on_off()




            self.state = 917
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,125,self._ctx)
            if la_ == 1:
                self.state = 916
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_tableContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def TABLE(self):
            return self.getToken(tsqlParser.TABLE, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def column_def_table_constraints(self):
            return self.getTypedRuleContext(tsqlParser.Column_def_table_constraintsContext,0)


        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def DEFAULT(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.DEFAULT)
            else:
                return self.getToken(tsqlParser.DEFAULT, i)

        def TEXTIMAGE_ON(self):
            return self.getToken(tsqlParser.TEXTIMAGE_ON, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_create_table

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_table" ):
                listener.enterCreate_table(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_table" ):
                listener.exitCreate_table(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_table" ):
                return visitor.visitCreate_table(self)
            else:
                return visitor.visitChildren(self)




    def create_table(self):

        localctx = tsqlParser.Create_tableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_create_table)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 919
            self.match(tsqlParser.CREATE)
            self.state = 920
            self.match(tsqlParser.TABLE)
            self.state = 921
            self.table_name()
            self.state = 922
            self.match(tsqlParser.LR_BRACKET)
            self.state = 923
            self.column_def_table_constraints()
            self.state = 925
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.COMMA:
                self.state = 924
                self.match(tsqlParser.COMMA)


            self.state = 927
            self.match(tsqlParser.RR_BRACKET)
            self.state = 931
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,127,self._ctx)
            if la_ == 1:
                self.state = 928
                self.match(tsqlParser.ON)
                self.state = 929
                self.r_id()

            elif la_ == 2:
                self.state = 930
                self.match(tsqlParser.DEFAULT)


            self.state = 936
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,128,self._ctx)
            if la_ == 1:
                self.state = 933
                self.match(tsqlParser.TEXTIMAGE_ON)
                self.state = 934
                self.r_id()

            elif la_ == 2:
                self.state = 935
                self.match(tsqlParser.DEFAULT)


            self.state = 939
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,129,self._ctx)
            if la_ == 1:
                self.state = 938
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_viewContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def VIEW(self):
            return self.getToken(tsqlParser.VIEW, 0)

        def simple_name(self):
            return self.getTypedRuleContext(tsqlParser.Simple_nameContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def select_statement(self):
            return self.getTypedRuleContext(tsqlParser.Select_statementContext,0)


        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def WITH(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.WITH)
            else:
                return self.getToken(tsqlParser.WITH, i)

        def view_attribute(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.View_attributeContext)
            else:
                return self.getTypedRuleContext(tsqlParser.View_attributeContext,i)


        def CHECK(self):
            return self.getToken(tsqlParser.CHECK, 0)

        def OPTION(self):
            return self.getToken(tsqlParser.OPTION, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_create_view

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_view" ):
                listener.enterCreate_view(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_view" ):
                listener.exitCreate_view(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_view" ):
                return visitor.visitCreate_view(self)
            else:
                return visitor.visitChildren(self)




    def create_view(self):

        localctx = tsqlParser.Create_viewContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_create_view)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 941
            self.match(tsqlParser.CREATE)
            self.state = 942
            self.match(tsqlParser.VIEW)
            self.state = 943
            self.simple_name()
            self.state = 948
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.LR_BRACKET:
                self.state = 944
                self.match(tsqlParser.LR_BRACKET)
                self.state = 945
                self.column_name_list()
                self.state = 946
                self.match(tsqlParser.RR_BRACKET)


            self.state = 959
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 950
                self.match(tsqlParser.WITH)
                self.state = 951
                self.view_attribute()
                self.state = 956
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 952
                    self.match(tsqlParser.COMMA)
                    self.state = 953
                    self.view_attribute()
                    self.state = 958
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 961
            self.match(tsqlParser.AS)
            self.state = 962
            self.select_statement()
            self.state = 966
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,133,self._ctx)
            if la_ == 1:
                self.state = 963
                self.match(tsqlParser.WITH)
                self.state = 964
                self.match(tsqlParser.CHECK)
                self.state = 965
                self.match(tsqlParser.OPTION)


            self.state = 969
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,134,self._ctx)
            if la_ == 1:
                self.state = 968
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class View_attributeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ENCRYPTION(self):
            return self.getToken(tsqlParser.ENCRYPTION, 0)

        def SCHEMABINDING(self):
            return self.getToken(tsqlParser.SCHEMABINDING, 0)

        def VIEW_METADATA(self):
            return self.getToken(tsqlParser.VIEW_METADATA, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_view_attribute

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterView_attribute" ):
                listener.enterView_attribute(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitView_attribute" ):
                listener.exitView_attribute(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitView_attribute" ):
                return visitor.visitView_attribute(self)
            else:
                return visitor.visitChildren(self)




    def view_attribute(self):

        localctx = tsqlParser.View_attributeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_view_attribute)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 971
            _la = self._input.LA(1)
            if not(_la==tsqlParser.ENCRYPTION or _la==tsqlParser.SCHEMABINDING or _la==tsqlParser.VIEW_METADATA):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Alter_tableContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.constraint = None # R_idContext
            self.fk = None # Column_name_listContext
            self.pk = None # Column_name_listContext

        def ALTER(self):
            return self.getToken(tsqlParser.ALTER, 0)

        def TABLE(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.TABLE)
            else:
                return self.getToken(tsqlParser.TABLE, i)

        def table_name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Table_nameContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Table_nameContext,i)


        def SET(self):
            return self.getToken(tsqlParser.SET, 0)

        def LOCK_ESCALATION(self):
            return self.getToken(tsqlParser.LOCK_ESCALATION, 0)

        def ADD(self):
            return self.getToken(tsqlParser.ADD, 0)

        def column_def_table_constraint(self):
            return self.getTypedRuleContext(tsqlParser.Column_def_table_constraintContext,0)


        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def CONSTRAINT(self):
            return self.getToken(tsqlParser.CONSTRAINT, 0)

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def CHECK(self):
            return self.getToken(tsqlParser.CHECK, 0)

        def FOREIGN(self):
            return self.getToken(tsqlParser.FOREIGN, 0)

        def KEY(self):
            return self.getToken(tsqlParser.KEY, 0)

        def REFERENCES(self):
            return self.getToken(tsqlParser.REFERENCES, 0)

        def AUTO(self):
            return self.getToken(tsqlParser.AUTO, 0)

        def DISABLE(self):
            return self.getToken(tsqlParser.DISABLE, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def column_name_list(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Column_name_listContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Column_name_listContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_alter_table

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAlter_table" ):
                listener.enterAlter_table(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAlter_table" ):
                listener.exitAlter_table(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAlter_table" ):
                return visitor.visitAlter_table(self)
            else:
                return visitor.visitChildren(self)




    def alter_table(self):

        localctx = tsqlParser.Alter_tableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_alter_table)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 973
            self.match(tsqlParser.ALTER)
            self.state = 974
            self.match(tsqlParser.TABLE)
            self.state = 975
            self.table_name()
            self.state = 1006
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.SET]:
                self.state = 976
                self.match(tsqlParser.SET)
                self.state = 977
                self.match(tsqlParser.LR_BRACKET)
                self.state = 978
                self.match(tsqlParser.LOCK_ESCALATION)
                self.state = 979
                self.match(tsqlParser.EQUAL)
                self.state = 980
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TABLE or _la==tsqlParser.AUTO or _la==tsqlParser.DISABLE):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 981
                self.match(tsqlParser.RR_BRACKET)
                pass
            elif token in [tsqlParser.ADD]:
                self.state = 982
                self.match(tsqlParser.ADD)
                self.state = 983
                self.column_def_table_constraint()
                pass
            elif token in [tsqlParser.DROP]:
                self.state = 984
                self.match(tsqlParser.DROP)
                self.state = 985
                self.match(tsqlParser.CONSTRAINT)
                self.state = 986
                localctx.constraint = self.r_id()
                pass
            elif token in [tsqlParser.WITH]:
                self.state = 987
                self.match(tsqlParser.WITH)
                self.state = 988
                self.match(tsqlParser.CHECK)
                self.state = 989
                self.match(tsqlParser.ADD)
                self.state = 990
                self.match(tsqlParser.CONSTRAINT)
                self.state = 991
                localctx.constraint = self.r_id()
                self.state = 992
                self.match(tsqlParser.FOREIGN)
                self.state = 993
                self.match(tsqlParser.KEY)
                self.state = 994
                self.match(tsqlParser.LR_BRACKET)
                self.state = 995
                localctx.fk = self.column_name_list()
                self.state = 996
                self.match(tsqlParser.RR_BRACKET)
                self.state = 997
                self.match(tsqlParser.REFERENCES)
                self.state = 998
                self.table_name()
                self.state = 999
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1000
                localctx.pk = self.column_name_list()
                self.state = 1001
                self.match(tsqlParser.RR_BRACKET)
                pass
            elif token in [tsqlParser.CHECK]:
                self.state = 1003
                self.match(tsqlParser.CHECK)
                self.state = 1004
                self.match(tsqlParser.CONSTRAINT)
                self.state = 1005
                localctx.constraint = self.r_id()
                pass
            else:
                raise NoViableAltException(self)

            self.state = 1009
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,136,self._ctx)
            if la_ == 1:
                self.state = 1008
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Alter_databaseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.database = None # R_idContext
            self.new_name = None # R_idContext
            self.collation = None # R_idContext

        def ALTER(self):
            return self.getToken(tsqlParser.ALTER, 0)

        def DATABASE(self):
            return self.getToken(tsqlParser.DATABASE, 0)

        def CURRENT(self):
            return self.getToken(tsqlParser.CURRENT, 0)

        def MODIFY(self):
            return self.getToken(tsqlParser.MODIFY, 0)

        def NAME(self):
            return self.getToken(tsqlParser.NAME, 0)

        def COLLATE(self):
            return self.getToken(tsqlParser.COLLATE, 0)

        def SET(self):
            return self.getToken(tsqlParser.SET, 0)

        def database_optionspec(self):
            return self.getTypedRuleContext(tsqlParser.Database_optionspecContext,0)


        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def termination(self):
            return self.getTypedRuleContext(tsqlParser.TerminationContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_alter_database

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAlter_database" ):
                listener.enterAlter_database(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAlter_database" ):
                listener.exitAlter_database(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAlter_database" ):
                return visitor.visitAlter_database(self)
            else:
                return visitor.visitChildren(self)




    def alter_database(self):

        localctx = tsqlParser.Alter_databaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_alter_database)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1011
            self.match(tsqlParser.ALTER)
            self.state = 1012
            self.match(tsqlParser.DATABASE)
            self.state = 1015
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.state = 1013
                localctx.database = self.r_id()
                pass
            elif token in [tsqlParser.CURRENT]:
                self.state = 1014
                self.match(tsqlParser.CURRENT)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 1029
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.MODIFY]:
                self.state = 1017
                self.match(tsqlParser.MODIFY)
                self.state = 1018
                self.match(tsqlParser.NAME)
                self.state = 1019
                self.match(tsqlParser.EQUAL)
                self.state = 1020
                localctx.new_name = self.r_id()
                pass
            elif token in [tsqlParser.COLLATE]:
                self.state = 1021
                self.match(tsqlParser.COLLATE)
                self.state = 1022
                localctx.collation = self.r_id()
                pass
            elif token in [tsqlParser.SET]:
                self.state = 1023
                self.match(tsqlParser.SET)
                self.state = 1024
                self.database_optionspec()
                self.state = 1027
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,138,self._ctx)
                if la_ == 1:
                    self.state = 1025
                    self.match(tsqlParser.WITH)
                    self.state = 1026
                    self.termination()


                pass
            else:
                raise NoViableAltException(self)

            self.state = 1032
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,140,self._ctx)
            if la_ == 1:
                self.state = 1031
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Database_optionspecContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def auto_option(self):
            return self.getTypedRuleContext(tsqlParser.Auto_optionContext,0)


        def change_tracking_option(self):
            return self.getTypedRuleContext(tsqlParser.Change_tracking_optionContext,0)


        def containment_option(self):
            return self.getTypedRuleContext(tsqlParser.Containment_optionContext,0)


        def cursor_option(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_optionContext,0)


        def date_correlation_optimization_option(self):
            return self.getTypedRuleContext(tsqlParser.Date_correlation_optimization_optionContext,0)


        def db_encryption_option(self):
            return self.getTypedRuleContext(tsqlParser.Db_encryption_optionContext,0)


        def db_state_option(self):
            return self.getTypedRuleContext(tsqlParser.Db_state_optionContext,0)


        def db_update_option(self):
            return self.getTypedRuleContext(tsqlParser.Db_update_optionContext,0)


        def db_user_access_option(self):
            return self.getTypedRuleContext(tsqlParser.Db_user_access_optionContext,0)


        def delayed_durability_option(self):
            return self.getTypedRuleContext(tsqlParser.Delayed_durability_optionContext,0)


        def external_access_option(self):
            return self.getTypedRuleContext(tsqlParser.External_access_optionContext,0)


        def FILESTREAM(self):
            return self.getToken(tsqlParser.FILESTREAM, 0)

        def database_filestream_option(self):
            return self.getTypedRuleContext(tsqlParser.Database_filestream_optionContext,0)


        def HADR_options(self):
            return self.getToken(tsqlParser.HADR_options, 0)

        def mixed_page_allocation_option(self):
            return self.getTypedRuleContext(tsqlParser.Mixed_page_allocation_optionContext,0)


        def parameterization_option(self):
            return self.getTypedRuleContext(tsqlParser.Parameterization_optionContext,0)


        def recovery_option(self):
            return self.getTypedRuleContext(tsqlParser.Recovery_optionContext,0)


        def service_broker_option(self):
            return self.getTypedRuleContext(tsqlParser.Service_broker_optionContext,0)


        def snapshot_option(self):
            return self.getTypedRuleContext(tsqlParser.Snapshot_optionContext,0)


        def sql_option(self):
            return self.getTypedRuleContext(tsqlParser.Sql_optionContext,0)


        def target_recovery_time_option(self):
            return self.getTypedRuleContext(tsqlParser.Target_recovery_time_optionContext,0)


        def termination(self):
            return self.getTypedRuleContext(tsqlParser.TerminationContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_database_optionspec

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDatabase_optionspec" ):
                listener.enterDatabase_optionspec(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDatabase_optionspec" ):
                listener.exitDatabase_optionspec(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDatabase_optionspec" ):
                return visitor.visitDatabase_optionspec(self)
            else:
                return visitor.visitChildren(self)




    def database_optionspec(self):

        localctx = tsqlParser.Database_optionspecContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_database_optionspec)
        try:
            self.state = 1056
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,141,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1034
                self.auto_option()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1035
                self.change_tracking_option()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1036
                self.containment_option()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1037
                self.cursor_option()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 1038
                self.date_correlation_optimization_option()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 1039
                self.db_encryption_option()
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 1040
                self.db_state_option()
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 1041
                self.db_update_option()
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 1042
                self.db_user_access_option()
                pass

            elif la_ == 10:
                self.enterOuterAlt(localctx, 10)
                self.state = 1043
                self.delayed_durability_option()
                pass

            elif la_ == 11:
                self.enterOuterAlt(localctx, 11)
                self.state = 1044
                self.external_access_option()
                pass

            elif la_ == 12:
                self.enterOuterAlt(localctx, 12)
                self.state = 1045
                self.match(tsqlParser.FILESTREAM)
                self.state = 1046
                self.database_filestream_option()
                pass

            elif la_ == 13:
                self.enterOuterAlt(localctx, 13)
                self.state = 1047
                self.match(tsqlParser.HADR_options)
                pass

            elif la_ == 14:
                self.enterOuterAlt(localctx, 14)
                self.state = 1048
                self.mixed_page_allocation_option()
                pass

            elif la_ == 15:
                self.enterOuterAlt(localctx, 15)
                self.state = 1049
                self.parameterization_option()
                pass

            elif la_ == 16:
                self.enterOuterAlt(localctx, 16)
                self.state = 1050
                self.recovery_option()
                pass

            elif la_ == 17:
                self.enterOuterAlt(localctx, 17)
                self.state = 1051
                self.service_broker_option()
                pass

            elif la_ == 18:
                self.enterOuterAlt(localctx, 18)
                self.state = 1052
                self.snapshot_option()
                pass

            elif la_ == 19:
                self.enterOuterAlt(localctx, 19)
                self.state = 1053
                self.sql_option()
                pass

            elif la_ == 20:
                self.enterOuterAlt(localctx, 20)
                self.state = 1054
                self.target_recovery_time_option()
                pass

            elif la_ == 21:
                self.enterOuterAlt(localctx, 21)
                self.state = 1055
                self.termination()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Auto_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def AUTO_CLOSE(self):
            return self.getToken(tsqlParser.AUTO_CLOSE, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def AUTO_CREATE_STATISTICS(self):
            return self.getToken(tsqlParser.AUTO_CREATE_STATISTICS, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def ON(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.ON)
            else:
                return self.getToken(tsqlParser.ON, i)

        def INCREMENTAL(self):
            return self.getToken(tsqlParser.INCREMENTAL, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def AUTO_SHRINK(self):
            return self.getToken(tsqlParser.AUTO_SHRINK, 0)

        def AUTO_UPDATE_STATISTICS(self):
            return self.getToken(tsqlParser.AUTO_UPDATE_STATISTICS, 0)

        def AUTO_UPDATE_STATISTICS_ASYNC(self):
            return self.getToken(tsqlParser.AUTO_UPDATE_STATISTICS_ASYNC, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_auto_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAuto_option" ):
                listener.enterAuto_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAuto_option" ):
                listener.exitAuto_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAuto_option" ):
                return visitor.visitAuto_option(self)
            else:
                return visitor.visitChildren(self)




    def auto_option(self):

        localctx = tsqlParser.Auto_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_auto_option)
        self._la = 0 # Token type
        try:
            self.state = 1075
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.AUTO_CLOSE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1058
                self.match(tsqlParser.AUTO_CLOSE)
                self.state = 1059
                self.on_off()
                pass
            elif token in [tsqlParser.AUTO_CREATE_STATISTICS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1060
                self.match(tsqlParser.AUTO_CREATE_STATISTICS)
                self.state = 1061
                self.match(tsqlParser.OFF)
                pass
            elif token in [tsqlParser.ON]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1062
                self.match(tsqlParser.ON)
                self.state = 1067
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.INCREMENTAL]:
                    self.state = 1063
                    self.match(tsqlParser.INCREMENTAL)
                    self.state = 1064
                    self.match(tsqlParser.EQUAL)
                    self.state = 1065
                    self.match(tsqlParser.ON)
                    pass
                elif token in [tsqlParser.OFF]:
                    self.state = 1066
                    self.match(tsqlParser.OFF)
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            elif token in [tsqlParser.AUTO_SHRINK]:
                self.enterOuterAlt(localctx, 4)
                self.state = 1069
                self.match(tsqlParser.AUTO_SHRINK)
                self.state = 1070
                self.on_off()
                pass
            elif token in [tsqlParser.AUTO_UPDATE_STATISTICS]:
                self.enterOuterAlt(localctx, 5)
                self.state = 1071
                self.match(tsqlParser.AUTO_UPDATE_STATISTICS)
                self.state = 1072
                self.on_off()
                pass
            elif token in [tsqlParser.AUTO_UPDATE_STATISTICS_ASYNC]:
                self.enterOuterAlt(localctx, 6)
                self.state = 1073
                self.match(tsqlParser.AUTO_UPDATE_STATISTICS_ASYNC)
                self.state = 1074
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Change_tracking_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CHANGE_TRACKING(self):
            return self.getToken(tsqlParser.CHANGE_TRACKING, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def change_tracking_option_list(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Change_tracking_option_listContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Change_tracking_option_listContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_change_tracking_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterChange_tracking_option" ):
                listener.enterChange_tracking_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitChange_tracking_option" ):
                listener.exitChange_tracking_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitChange_tracking_option" ):
                return visitor.visitChange_tracking_option(self)
            else:
                return visitor.visitChildren(self)




    def change_tracking_option(self):

        localctx = tsqlParser.Change_tracking_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_change_tracking_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1077
            self.match(tsqlParser.CHANGE_TRACKING)
            self.state = 1078
            self.match(tsqlParser.EQUAL)
            self.state = 1094
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.OFF]:
                self.state = 1079
                self.match(tsqlParser.OFF)
                pass
            elif token in [tsqlParser.ON]:
                self.state = 1080
                self.match(tsqlParser.ON)
                self.state = 1091
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.AUTO_CLEANUP or _la==tsqlParser.CHANGE_RETENTION:
                    self.state = 1081
                    self.change_tracking_option_list()
                    self.state = 1086
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    while _la==tsqlParser.COMMA:
                        self.state = 1082
                        self.match(tsqlParser.COMMA)
                        self.state = 1083
                        self.change_tracking_option_list()
                        self.state = 1088
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)

                    self.state = 1093
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Change_tracking_option_listContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def AUTO_CLEANUP(self):
            return self.getToken(tsqlParser.AUTO_CLEANUP, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def CHANGE_RETENTION(self):
            return self.getToken(tsqlParser.CHANGE_RETENTION, 0)

        def DAYS(self):
            return self.getToken(tsqlParser.DAYS, 0)

        def HOURS(self):
            return self.getToken(tsqlParser.HOURS, 0)

        def MINUTES(self):
            return self.getToken(tsqlParser.MINUTES, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_change_tracking_option_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterChange_tracking_option_list" ):
                listener.enterChange_tracking_option_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitChange_tracking_option_list" ):
                listener.exitChange_tracking_option_list(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitChange_tracking_option_list" ):
                return visitor.visitChange_tracking_option_list(self)
            else:
                return visitor.visitChildren(self)




    def change_tracking_option_list(self):

        localctx = tsqlParser.Change_tracking_option_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_change_tracking_option_list)
        self._la = 0 # Token type
        try:
            self.state = 1102
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.AUTO_CLEANUP]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1096
                self.match(tsqlParser.AUTO_CLEANUP)
                self.state = 1097
                self.match(tsqlParser.EQUAL)
                self.state = 1098
                self.on_off()
                pass
            elif token in [tsqlParser.CHANGE_RETENTION]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1099
                self.match(tsqlParser.CHANGE_RETENTION)
                self.state = 1100
                self.match(tsqlParser.EQUAL)
                self.state = 1101
                _la = self._input.LA(1)
                if not(((((_la - 236)) & ~0x3f) == 0 and ((1 << (_la - 236)) & ((1 << (tsqlParser.DAYS - 236)) | (1 << (tsqlParser.HOURS - 236)) | (1 << (tsqlParser.MINUTES - 236)))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Containment_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CONTAINMENT(self):
            return self.getToken(tsqlParser.CONTAINMENT, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def NONE(self):
            return self.getToken(tsqlParser.NONE, 0)

        def PARTIAL(self):
            return self.getToken(tsqlParser.PARTIAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_containment_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterContainment_option" ):
                listener.enterContainment_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitContainment_option" ):
                listener.exitContainment_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitContainment_option" ):
                return visitor.visitContainment_option(self)
            else:
                return visitor.visitChildren(self)




    def containment_option(self):

        localctx = tsqlParser.Containment_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_containment_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1104
            self.match(tsqlParser.CONTAINMENT)
            self.state = 1105
            self.match(tsqlParser.EQUAL)
            self.state = 1106
            _la = self._input.LA(1)
            if not(_la==tsqlParser.NONE or _la==tsqlParser.PARTIAL):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Cursor_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CURSOR_CLOSE_ON_COMMIT(self):
            return self.getToken(tsqlParser.CURSOR_CLOSE_ON_COMMIT, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def CURSOR_DEFAULT(self):
            return self.getToken(tsqlParser.CURSOR_DEFAULT, 0)

        def LOCAL(self):
            return self.getToken(tsqlParser.LOCAL, 0)

        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_cursor_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCursor_option" ):
                listener.enterCursor_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCursor_option" ):
                listener.exitCursor_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCursor_option" ):
                return visitor.visitCursor_option(self)
            else:
                return visitor.visitChildren(self)




    def cursor_option(self):

        localctx = tsqlParser.Cursor_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_cursor_option)
        self._la = 0 # Token type
        try:
            self.state = 1112
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.CURSOR_CLOSE_ON_COMMIT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1108
                self.match(tsqlParser.CURSOR_CLOSE_ON_COMMIT)
                self.state = 1109
                self.on_off()
                pass
            elif token in [tsqlParser.CURSOR_DEFAULT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1110
                self.match(tsqlParser.CURSOR_DEFAULT)
                self.state = 1111
                _la = self._input.LA(1)
                if not(_la==tsqlParser.GLOBAL or _la==tsqlParser.LOCAL):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Date_correlation_optimization_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DATE_CORRELATION_OPTIMIZATION(self):
            return self.getToken(tsqlParser.DATE_CORRELATION_OPTIMIZATION, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_date_correlation_optimization_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDate_correlation_optimization_option" ):
                listener.enterDate_correlation_optimization_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDate_correlation_optimization_option" ):
                listener.exitDate_correlation_optimization_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDate_correlation_optimization_option" ):
                return visitor.visitDate_correlation_optimization_option(self)
            else:
                return visitor.visitChildren(self)




    def date_correlation_optimization_option(self):

        localctx = tsqlParser.Date_correlation_optimization_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_date_correlation_optimization_option)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1114
            self.match(tsqlParser.DATE_CORRELATION_OPTIMIZATION)
            self.state = 1115
            self.on_off()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Db_encryption_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ENCRYPTION(self):
            return self.getToken(tsqlParser.ENCRYPTION, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_db_encryption_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDb_encryption_option" ):
                listener.enterDb_encryption_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDb_encryption_option" ):
                listener.exitDb_encryption_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDb_encryption_option" ):
                return visitor.visitDb_encryption_option(self)
            else:
                return visitor.visitChildren(self)




    def db_encryption_option(self):

        localctx = tsqlParser.Db_encryption_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_db_encryption_option)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1117
            self.match(tsqlParser.ENCRYPTION)
            self.state = 1118
            self.on_off()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Db_state_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ONLINE(self):
            return self.getToken(tsqlParser.ONLINE, 0)

        def OFFLINE(self):
            return self.getToken(tsqlParser.OFFLINE, 0)

        def EMERGENCY(self):
            return self.getToken(tsqlParser.EMERGENCY, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_db_state_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDb_state_option" ):
                listener.enterDb_state_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDb_state_option" ):
                listener.exitDb_state_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDb_state_option" ):
                return visitor.visitDb_state_option(self)
            else:
                return visitor.visitChildren(self)




    def db_state_option(self):

        localctx = tsqlParser.Db_state_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_db_state_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1120
            _la = self._input.LA(1)
            if not(_la==tsqlParser.EMERGENCY or _la==tsqlParser.OFFLINE or _la==tsqlParser.ONLINE):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Db_update_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def READ_ONLY(self):
            return self.getToken(tsqlParser.READ_ONLY, 0)

        def READ_WRITE(self):
            return self.getToken(tsqlParser.READ_WRITE, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_db_update_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDb_update_option" ):
                listener.enterDb_update_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDb_update_option" ):
                listener.exitDb_update_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDb_update_option" ):
                return visitor.visitDb_update_option(self)
            else:
                return visitor.visitChildren(self)




    def db_update_option(self):

        localctx = tsqlParser.Db_update_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_db_update_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1122
            _la = self._input.LA(1)
            if not(_la==tsqlParser.READ_ONLY or _la==tsqlParser.READ_WRITE):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Db_user_access_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SINGLE_USER(self):
            return self.getToken(tsqlParser.SINGLE_USER, 0)

        def RESTRICTED_USER(self):
            return self.getToken(tsqlParser.RESTRICTED_USER, 0)

        def MULTI_USER(self):
            return self.getToken(tsqlParser.MULTI_USER, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_db_user_access_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDb_user_access_option" ):
                listener.enterDb_user_access_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDb_user_access_option" ):
                listener.exitDb_user_access_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDb_user_access_option" ):
                return visitor.visitDb_user_access_option(self)
            else:
                return visitor.visitChildren(self)




    def db_user_access_option(self):

        localctx = tsqlParser.Db_user_access_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_db_user_access_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1124
            _la = self._input.LA(1)
            if not(((((_la - 303)) & ~0x3f) == 0 and ((1 << (_la - 303)) & ((1 << (tsqlParser.MULTI_USER - 303)) | (1 << (tsqlParser.RESTRICTED_USER - 303)) | (1 << (tsqlParser.SINGLE_USER - 303)))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Delayed_durability_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DELAYED_DURABILITY(self):
            return self.getToken(tsqlParser.DELAYED_DURABILITY, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def DISABLED(self):
            return self.getToken(tsqlParser.DISABLED, 0)

        def ALLOWED(self):
            return self.getToken(tsqlParser.ALLOWED, 0)

        def FORCED(self):
            return self.getToken(tsqlParser.FORCED, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_delayed_durability_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDelayed_durability_option" ):
                listener.enterDelayed_durability_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDelayed_durability_option" ):
                listener.exitDelayed_durability_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDelayed_durability_option" ):
                return visitor.visitDelayed_durability_option(self)
            else:
                return visitor.visitChildren(self)




    def delayed_durability_option(self):

        localctx = tsqlParser.Delayed_durability_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_delayed_durability_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1126
            self.match(tsqlParser.DELAYED_DURABILITY)
            self.state = 1127
            self.match(tsqlParser.EQUAL)
            self.state = 1128
            _la = self._input.LA(1)
            if not(_la==tsqlParser.ALLOWED or _la==tsqlParser.DISABLED or _la==tsqlParser.FORCED):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class External_access_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DB_CHAINING(self):
            return self.getToken(tsqlParser.DB_CHAINING, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def TRUSTWORTHY(self):
            return self.getToken(tsqlParser.TRUSTWORTHY, 0)

        def DEFAULT_LANGUAGE(self):
            return self.getToken(tsqlParser.DEFAULT_LANGUAGE, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def DEFAULT_FULLTEXT_LANGUAGE(self):
            return self.getToken(tsqlParser.DEFAULT_FULLTEXT_LANGUAGE, 0)

        def NESTED_TRIGGERS(self):
            return self.getToken(tsqlParser.NESTED_TRIGGERS, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def TRANSFORM_NOISE_WORDS(self):
            return self.getToken(tsqlParser.TRANSFORM_NOISE_WORDS, 0)

        def TWO_DIGIT_YEAR_CUTOFF(self):
            return self.getToken(tsqlParser.TWO_DIGIT_YEAR_CUTOFF, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_external_access_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExternal_access_option" ):
                listener.enterExternal_access_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExternal_access_option" ):
                listener.exitExternal_access_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExternal_access_option" ):
                return visitor.visitExternal_access_option(self)
            else:
                return visitor.visitChildren(self)




    def external_access_option(self):

        localctx = tsqlParser.External_access_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_external_access_option)
        self._la = 0 # Token type
        try:
            self.state = 1155
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.DB_CHAINING]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1130
                self.match(tsqlParser.DB_CHAINING)
                self.state = 1131
                self.on_off()
                pass
            elif token in [tsqlParser.TRUSTWORTHY]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1132
                self.match(tsqlParser.TRUSTWORTHY)
                self.state = 1133
                self.on_off()
                pass
            elif token in [tsqlParser.DEFAULT_LANGUAGE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1134
                self.match(tsqlParser.DEFAULT_LANGUAGE)
                self.state = 1135
                self.match(tsqlParser.EQUAL)
                self.state = 1138
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 1136
                    self.r_id()
                    pass
                elif token in [tsqlParser.STRING]:
                    self.state = 1137
                    self.match(tsqlParser.STRING)
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            elif token in [tsqlParser.DEFAULT_FULLTEXT_LANGUAGE]:
                self.enterOuterAlt(localctx, 4)
                self.state = 1140
                self.match(tsqlParser.DEFAULT_FULLTEXT_LANGUAGE)
                self.state = 1141
                self.match(tsqlParser.EQUAL)
                self.state = 1144
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 1142
                    self.r_id()
                    pass
                elif token in [tsqlParser.STRING]:
                    self.state = 1143
                    self.match(tsqlParser.STRING)
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            elif token in [tsqlParser.NESTED_TRIGGERS]:
                self.enterOuterAlt(localctx, 5)
                self.state = 1146
                self.match(tsqlParser.NESTED_TRIGGERS)
                self.state = 1147
                self.match(tsqlParser.EQUAL)
                self.state = 1148
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.TRANSFORM_NOISE_WORDS]:
                self.enterOuterAlt(localctx, 6)
                self.state = 1149
                self.match(tsqlParser.TRANSFORM_NOISE_WORDS)
                self.state = 1150
                self.match(tsqlParser.EQUAL)
                self.state = 1151
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.TWO_DIGIT_YEAR_CUTOFF]:
                self.enterOuterAlt(localctx, 7)
                self.state = 1152
                self.match(tsqlParser.TWO_DIGIT_YEAR_CUTOFF)
                self.state = 1153
                self.match(tsqlParser.EQUAL)
                self.state = 1154
                self.match(tsqlParser.DECIMAL)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Mixed_page_allocation_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def MIXED_PAGE_ALLOCATION(self):
            return self.getToken(tsqlParser.MIXED_PAGE_ALLOCATION, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_mixed_page_allocation_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMixed_page_allocation_option" ):
                listener.enterMixed_page_allocation_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMixed_page_allocation_option" ):
                listener.exitMixed_page_allocation_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitMixed_page_allocation_option" ):
                return visitor.visitMixed_page_allocation_option(self)
            else:
                return visitor.visitChildren(self)




    def mixed_page_allocation_option(self):

        localctx = tsqlParser.Mixed_page_allocation_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 82, self.RULE_mixed_page_allocation_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1157
            self.match(tsqlParser.MIXED_PAGE_ALLOCATION)
            self.state = 1158
            _la = self._input.LA(1)
            if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Parameterization_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PARAMETERIZATION(self):
            return self.getToken(tsqlParser.PARAMETERIZATION, 0)

        def SIMPLE(self):
            return self.getToken(tsqlParser.SIMPLE, 0)

        def FORCED(self):
            return self.getToken(tsqlParser.FORCED, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_parameterization_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterParameterization_option" ):
                listener.enterParameterization_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitParameterization_option" ):
                listener.exitParameterization_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitParameterization_option" ):
                return visitor.visitParameterization_option(self)
            else:
                return visitor.visitChildren(self)




    def parameterization_option(self):

        localctx = tsqlParser.Parameterization_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 84, self.RULE_parameterization_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1160
            self.match(tsqlParser.PARAMETERIZATION)
            self.state = 1161
            _la = self._input.LA(1)
            if not(_la==tsqlParser.FORCED or _la==tsqlParser.SIMPLE):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Recovery_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RECOVERY(self):
            return self.getToken(tsqlParser.RECOVERY, 0)

        def FULL(self):
            return self.getToken(tsqlParser.FULL, 0)

        def BULK_LOGGED(self):
            return self.getToken(tsqlParser.BULK_LOGGED, 0)

        def SIMPLE(self):
            return self.getToken(tsqlParser.SIMPLE, 0)

        def TORN_PAGE_DETECTION(self):
            return self.getToken(tsqlParser.TORN_PAGE_DETECTION, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def PAGE_VERIFY(self):
            return self.getToken(tsqlParser.PAGE_VERIFY, 0)

        def CHECKSUM(self):
            return self.getToken(tsqlParser.CHECKSUM, 0)

        def NONE(self):
            return self.getToken(tsqlParser.NONE, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_recovery_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRecovery_option" ):
                listener.enterRecovery_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRecovery_option" ):
                listener.exitRecovery_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRecovery_option" ):
                return visitor.visitRecovery_option(self)
            else:
                return visitor.visitChildren(self)




    def recovery_option(self):

        localctx = tsqlParser.Recovery_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 86, self.RULE_recovery_option)
        self._la = 0 # Token type
        try:
            self.state = 1169
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.RECOVERY]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1163
                self.match(tsqlParser.RECOVERY)
                self.state = 1164
                _la = self._input.LA(1)
                if not(_la==tsqlParser.FULL or _la==tsqlParser.BULK_LOGGED or _la==tsqlParser.SIMPLE):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.TORN_PAGE_DETECTION]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1165
                self.match(tsqlParser.TORN_PAGE_DETECTION)
                self.state = 1166
                self.on_off()
                pass
            elif token in [tsqlParser.PAGE_VERIFY]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1167
                self.match(tsqlParser.PAGE_VERIFY)
                self.state = 1168
                _la = self._input.LA(1)
                if not(_la==tsqlParser.NONE or _la==tsqlParser.CHECKSUM or _la==tsqlParser.TORN_PAGE_DETECTION):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Service_broker_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ENABLE_BROKER(self):
            return self.getToken(tsqlParser.ENABLE_BROKER, 0)

        def DISABLE_BROKER(self):
            return self.getToken(tsqlParser.DISABLE_BROKER, 0)

        def NEW_BROKER(self):
            return self.getToken(tsqlParser.NEW_BROKER, 0)

        def ERROR_BROKER_CONVERSATIONS(self):
            return self.getToken(tsqlParser.ERROR_BROKER_CONVERSATIONS, 0)

        def HONOR_BROKER_PRIORITY(self):
            return self.getToken(tsqlParser.HONOR_BROKER_PRIORITY, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_service_broker_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterService_broker_option" ):
                listener.enterService_broker_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitService_broker_option" ):
                listener.exitService_broker_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitService_broker_option" ):
                return visitor.visitService_broker_option(self)
            else:
                return visitor.visitChildren(self)




    def service_broker_option(self):

        localctx = tsqlParser.Service_broker_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 88, self.RULE_service_broker_option)
        try:
            self.state = 1177
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.ENABLE_BROKER]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1171
                self.match(tsqlParser.ENABLE_BROKER)
                pass
            elif token in [tsqlParser.DISABLE_BROKER]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1172
                self.match(tsqlParser.DISABLE_BROKER)
                pass
            elif token in [tsqlParser.NEW_BROKER]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1173
                self.match(tsqlParser.NEW_BROKER)
                pass
            elif token in [tsqlParser.ERROR_BROKER_CONVERSATIONS]:
                self.enterOuterAlt(localctx, 4)
                self.state = 1174
                self.match(tsqlParser.ERROR_BROKER_CONVERSATIONS)
                pass
            elif token in [tsqlParser.HONOR_BROKER_PRIORITY]:
                self.enterOuterAlt(localctx, 5)
                self.state = 1175
                self.match(tsqlParser.HONOR_BROKER_PRIORITY)
                self.state = 1176
                self.on_off()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Snapshot_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.MEMORY_OPTIMIZED_ELEVATE_TO_SNAPSHOT = None # Token

        def ALLOW_SNAPSHOT_ISOLATION(self):
            return self.getToken(tsqlParser.ALLOW_SNAPSHOT_ISOLATION, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def READ_COMMITTED_SNAPSHOT(self):
            return self.getToken(tsqlParser.READ_COMMITTED_SNAPSHOT, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_snapshot_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSnapshot_option" ):
                listener.enterSnapshot_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSnapshot_option" ):
                listener.exitSnapshot_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSnapshot_option" ):
                return visitor.visitSnapshot_option(self)
            else:
                return visitor.visitChildren(self)




    def snapshot_option(self):

        localctx = tsqlParser.Snapshot_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 90, self.RULE_snapshot_option)
        self._la = 0 # Token type
        try:
            self.state = 1184
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.ALLOW_SNAPSHOT_ISOLATION]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1179
                self.match(tsqlParser.ALLOW_SNAPSHOT_ISOLATION)
                self.state = 1180
                self.on_off()
                pass
            elif token in [tsqlParser.READ_COMMITTED_SNAPSHOT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1181
                self.match(tsqlParser.READ_COMMITTED_SNAPSHOT)
                self.state = 1182
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.OFF, tsqlParser.ON]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1183
                localctx.MEMORY_OPTIMIZED_ELEVATE_TO_SNAPSHOT = self._input.LT(1)
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    localctx.MEMORY_OPTIMIZED_ELEVATE_TO_SNAPSHOT = self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Sql_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ANSI_NULL_DEFAULT(self):
            return self.getToken(tsqlParser.ANSI_NULL_DEFAULT, 0)

        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def ANSI_NULLS(self):
            return self.getToken(tsqlParser.ANSI_NULLS, 0)

        def ANSI_PADDING(self):
            return self.getToken(tsqlParser.ANSI_PADDING, 0)

        def ANSI_WARNINGS(self):
            return self.getToken(tsqlParser.ANSI_WARNINGS, 0)

        def ARITHABORT(self):
            return self.getToken(tsqlParser.ARITHABORT, 0)

        def COMPATIBILITY_LEVEL(self):
            return self.getToken(tsqlParser.COMPATIBILITY_LEVEL, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def CONCAT_NULL_YIELDS_NULL(self):
            return self.getToken(tsqlParser.CONCAT_NULL_YIELDS_NULL, 0)

        def NUMERIC_ROUNDABORT(self):
            return self.getToken(tsqlParser.NUMERIC_ROUNDABORT, 0)

        def QUOTED_IDENTIFIER(self):
            return self.getToken(tsqlParser.QUOTED_IDENTIFIER, 0)

        def RECURSIVE_TRIGGERS(self):
            return self.getToken(tsqlParser.RECURSIVE_TRIGGERS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_sql_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSql_option" ):
                listener.enterSql_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSql_option" ):
                listener.exitSql_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSql_option" ):
                return visitor.visitSql_option(self)
            else:
                return visitor.visitChildren(self)




    def sql_option(self):

        localctx = tsqlParser.Sql_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 92, self.RULE_sql_option)
        try:
            self.state = 1207
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.ANSI_NULL_DEFAULT]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1186
                self.match(tsqlParser.ANSI_NULL_DEFAULT)
                self.state = 1187
                self.on_off()
                pass
            elif token in [tsqlParser.ANSI_NULLS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1188
                self.match(tsqlParser.ANSI_NULLS)
                self.state = 1189
                self.on_off()
                pass
            elif token in [tsqlParser.ANSI_PADDING]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1190
                self.match(tsqlParser.ANSI_PADDING)
                self.state = 1191
                self.on_off()
                pass
            elif token in [tsqlParser.ANSI_WARNINGS]:
                self.enterOuterAlt(localctx, 4)
                self.state = 1192
                self.match(tsqlParser.ANSI_WARNINGS)
                self.state = 1193
                self.on_off()
                pass
            elif token in [tsqlParser.ARITHABORT]:
                self.enterOuterAlt(localctx, 5)
                self.state = 1194
                self.match(tsqlParser.ARITHABORT)
                self.state = 1195
                self.on_off()
                pass
            elif token in [tsqlParser.COMPATIBILITY_LEVEL]:
                self.enterOuterAlt(localctx, 6)
                self.state = 1196
                self.match(tsqlParser.COMPATIBILITY_LEVEL)
                self.state = 1197
                self.match(tsqlParser.EQUAL)
                self.state = 1198
                self.match(tsqlParser.DECIMAL)
                pass
            elif token in [tsqlParser.CONCAT_NULL_YIELDS_NULL]:
                self.enterOuterAlt(localctx, 7)
                self.state = 1199
                self.match(tsqlParser.CONCAT_NULL_YIELDS_NULL)
                self.state = 1200
                self.on_off()
                pass
            elif token in [tsqlParser.NUMERIC_ROUNDABORT]:
                self.enterOuterAlt(localctx, 8)
                self.state = 1201
                self.match(tsqlParser.NUMERIC_ROUNDABORT)
                self.state = 1202
                self.on_off()
                pass
            elif token in [tsqlParser.QUOTED_IDENTIFIER]:
                self.enterOuterAlt(localctx, 9)
                self.state = 1203
                self.match(tsqlParser.QUOTED_IDENTIFIER)
                self.state = 1204
                self.on_off()
                pass
            elif token in [tsqlParser.RECURSIVE_TRIGGERS]:
                self.enterOuterAlt(localctx, 10)
                self.state = 1205
                self.match(tsqlParser.RECURSIVE_TRIGGERS)
                self.state = 1206
                self.on_off()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Target_recovery_time_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TARGET_RECOVERY_TIME(self):
            return self.getToken(tsqlParser.TARGET_RECOVERY_TIME, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def SECONDS(self):
            return self.getToken(tsqlParser.SECONDS, 0)

        def MINUTES(self):
            return self.getToken(tsqlParser.MINUTES, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_target_recovery_time_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTarget_recovery_time_option" ):
                listener.enterTarget_recovery_time_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTarget_recovery_time_option" ):
                listener.exitTarget_recovery_time_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTarget_recovery_time_option" ):
                return visitor.visitTarget_recovery_time_option(self)
            else:
                return visitor.visitChildren(self)




    def target_recovery_time_option(self):

        localctx = tsqlParser.Target_recovery_time_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 94, self.RULE_target_recovery_time_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1209
            self.match(tsqlParser.TARGET_RECOVERY_TIME)
            self.state = 1210
            self.match(tsqlParser.EQUAL)
            self.state = 1211
            self.match(tsqlParser.DECIMAL)
            self.state = 1212
            _la = self._input.LA(1)
            if not(_la==tsqlParser.MINUTES or _la==tsqlParser.SECONDS):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class TerminationContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.seconds = None # Token

        def ROLLBACK(self):
            return self.getToken(tsqlParser.ROLLBACK, 0)

        def AFTER(self):
            return self.getToken(tsqlParser.AFTER, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def IMMEDIATE(self):
            return self.getToken(tsqlParser.IMMEDIATE, 0)

        def NO_WAIT(self):
            return self.getToken(tsqlParser.NO_WAIT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_termination

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTermination" ):
                listener.enterTermination(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTermination" ):
                listener.exitTermination(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTermination" ):
                return visitor.visitTermination(self)
            else:
                return visitor.visitChildren(self)




    def termination(self):

        localctx = tsqlParser.TerminationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 96, self.RULE_termination)
        try:
            self.state = 1220
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,156,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1214
                self.match(tsqlParser.ROLLBACK)
                self.state = 1215
                self.match(tsqlParser.AFTER)
                self.state = 1216
                localctx.seconds = self.match(tsqlParser.DECIMAL)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1217
                self.match(tsqlParser.ROLLBACK)
                self.state = 1218
                self.match(tsqlParser.IMMEDIATE)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1219
                self.match(tsqlParser.NO_WAIT)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Drop_indexContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.name = None # R_idContext

        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def INDEX(self):
            return self.getToken(tsqlParser.INDEX, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def IF(self):
            return self.getToken(tsqlParser.IF, 0)

        def EXISTS(self):
            return self.getToken(tsqlParser.EXISTS, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_drop_index

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDrop_index" ):
                listener.enterDrop_index(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDrop_index" ):
                listener.exitDrop_index(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDrop_index" ):
                return visitor.visitDrop_index(self)
            else:
                return visitor.visitChildren(self)




    def drop_index(self):

        localctx = tsqlParser.Drop_indexContext(self, self._ctx, self.state)
        self.enterRule(localctx, 98, self.RULE_drop_index)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1222
            self.match(tsqlParser.DROP)
            self.state = 1223
            self.match(tsqlParser.INDEX)
            self.state = 1226
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.IF:
                self.state = 1224
                self.match(tsqlParser.IF)
                self.state = 1225
                self.match(tsqlParser.EXISTS)


            self.state = 1228
            localctx.name = self.r_id()
            self.state = 1231
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ON:
                self.state = 1229
                self.match(tsqlParser.ON)
                self.state = 1230
                self.table_name()


            self.state = 1234
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,159,self._ctx)
            if la_ == 1:
                self.state = 1233
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Drop_procedureContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def PROCEDURE(self):
            return self.getToken(tsqlParser.PROCEDURE, 0)

        def func_proc_name(self):
            return self.getTypedRuleContext(tsqlParser.Func_proc_nameContext,0)


        def IF(self):
            return self.getToken(tsqlParser.IF, 0)

        def EXISTS(self):
            return self.getToken(tsqlParser.EXISTS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_drop_procedure

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDrop_procedure" ):
                listener.enterDrop_procedure(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDrop_procedure" ):
                listener.exitDrop_procedure(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDrop_procedure" ):
                return visitor.visitDrop_procedure(self)
            else:
                return visitor.visitChildren(self)




    def drop_procedure(self):

        localctx = tsqlParser.Drop_procedureContext(self, self._ctx, self.state)
        self.enterRule(localctx, 100, self.RULE_drop_procedure)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1236
            self.match(tsqlParser.DROP)
            self.state = 1237
            self.match(tsqlParser.PROCEDURE)
            self.state = 1240
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.IF:
                self.state = 1238
                self.match(tsqlParser.IF)
                self.state = 1239
                self.match(tsqlParser.EXISTS)


            self.state = 1242
            self.func_proc_name()
            self.state = 1244
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,161,self._ctx)
            if la_ == 1:
                self.state = 1243
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Drop_statisticsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.name = None # R_idContext

        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def STATISTICS(self):
            return self.getToken(tsqlParser.STATISTICS, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_drop_statistics

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDrop_statistics" ):
                listener.enterDrop_statistics(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDrop_statistics" ):
                listener.exitDrop_statistics(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDrop_statistics" ):
                return visitor.visitDrop_statistics(self)
            else:
                return visitor.visitChildren(self)




    def drop_statistics(self):

        localctx = tsqlParser.Drop_statisticsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 102, self.RULE_drop_statistics)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1246
            self.match(tsqlParser.DROP)
            self.state = 1247
            self.match(tsqlParser.STATISTICS)
            self.state = 1251
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,162,self._ctx)
            if la_ == 1:
                self.state = 1248
                self.table_name()
                self.state = 1249
                self.match(tsqlParser.DOT)


            self.state = 1253
            localctx.name = self.r_id()
            self.state = 1254
            self.match(tsqlParser.SEMI)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Drop_tableContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def TABLE(self):
            return self.getToken(tsqlParser.TABLE, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def IF(self):
            return self.getToken(tsqlParser.IF, 0)

        def EXISTS(self):
            return self.getToken(tsqlParser.EXISTS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_drop_table

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDrop_table" ):
                listener.enterDrop_table(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDrop_table" ):
                listener.exitDrop_table(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDrop_table" ):
                return visitor.visitDrop_table(self)
            else:
                return visitor.visitChildren(self)




    def drop_table(self):

        localctx = tsqlParser.Drop_tableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 104, self.RULE_drop_table)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1256
            self.match(tsqlParser.DROP)
            self.state = 1257
            self.match(tsqlParser.TABLE)
            self.state = 1260
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.IF:
                self.state = 1258
                self.match(tsqlParser.IF)
                self.state = 1259
                self.match(tsqlParser.EXISTS)


            self.state = 1262
            self.table_name()
            self.state = 1264
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,164,self._ctx)
            if la_ == 1:
                self.state = 1263
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Drop_viewContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def VIEW(self):
            return self.getToken(tsqlParser.VIEW, 0)

        def simple_name(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Simple_nameContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Simple_nameContext,i)


        def IF(self):
            return self.getToken(tsqlParser.IF, 0)

        def EXISTS(self):
            return self.getToken(tsqlParser.EXISTS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_drop_view

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDrop_view" ):
                listener.enterDrop_view(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDrop_view" ):
                listener.exitDrop_view(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDrop_view" ):
                return visitor.visitDrop_view(self)
            else:
                return visitor.visitChildren(self)




    def drop_view(self):

        localctx = tsqlParser.Drop_viewContext(self, self._ctx, self.state)
        self.enterRule(localctx, 106, self.RULE_drop_view)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1266
            self.match(tsqlParser.DROP)
            self.state = 1267
            self.match(tsqlParser.VIEW)
            self.state = 1270
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.IF:
                self.state = 1268
                self.match(tsqlParser.IF)
                self.state = 1269
                self.match(tsqlParser.EXISTS)


            self.state = 1272
            self.simple_name()
            self.state = 1277
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 1273
                self.match(tsqlParser.COMMA)
                self.state = 1274
                self.simple_name()
                self.state = 1279
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1281
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,167,self._ctx)
            if la_ == 1:
                self.state = 1280
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_typeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.name = None # Simple_nameContext

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def TYPE(self):
            return self.getToken(tsqlParser.TYPE, 0)

        def FROM(self):
            return self.getToken(tsqlParser.FROM, 0)

        def data_type(self):
            return self.getTypedRuleContext(tsqlParser.Data_typeContext,0)


        def default_value(self):
            return self.getTypedRuleContext(tsqlParser.Default_valueContext,0)


        def simple_name(self):
            return self.getTypedRuleContext(tsqlParser.Simple_nameContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_create_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_type" ):
                listener.enterCreate_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_type" ):
                listener.exitCreate_type(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_type" ):
                return visitor.visitCreate_type(self)
            else:
                return visitor.visitChildren(self)




    def create_type(self):

        localctx = tsqlParser.Create_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 108, self.RULE_create_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1283
            self.match(tsqlParser.CREATE)
            self.state = 1284
            self.match(tsqlParser.TYPE)
            self.state = 1285
            localctx.name = self.simple_name()
            self.state = 1286
            self.match(tsqlParser.FROM)
            self.state = 1287
            self.data_type()
            self.state = 1288
            self.default_value()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Drop_typeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.name = None # Simple_nameContext

        def DROP(self):
            return self.getToken(tsqlParser.DROP, 0)

        def TYPE(self):
            return self.getToken(tsqlParser.TYPE, 0)

        def simple_name(self):
            return self.getTypedRuleContext(tsqlParser.Simple_nameContext,0)


        def IF(self):
            return self.getToken(tsqlParser.IF, 0)

        def EXISTS(self):
            return self.getToken(tsqlParser.EXISTS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_drop_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDrop_type" ):
                listener.enterDrop_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDrop_type" ):
                listener.exitDrop_type(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDrop_type" ):
                return visitor.visitDrop_type(self)
            else:
                return visitor.visitChildren(self)




    def drop_type(self):

        localctx = tsqlParser.Drop_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 110, self.RULE_drop_type)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1290
            self.match(tsqlParser.DROP)
            self.state = 1291
            self.match(tsqlParser.TYPE)
            self.state = 1294
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.IF:
                self.state = 1292
                self.match(tsqlParser.IF)
                self.state = 1293
                self.match(tsqlParser.EXISTS)


            self.state = 1296
            localctx.name = self.simple_name()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Rowset_function_limitedContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def openquery(self):
            return self.getTypedRuleContext(tsqlParser.OpenqueryContext,0)


        def opendatasource(self):
            return self.getTypedRuleContext(tsqlParser.OpendatasourceContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_rowset_function_limited

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRowset_function_limited" ):
                listener.enterRowset_function_limited(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRowset_function_limited" ):
                listener.exitRowset_function_limited(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRowset_function_limited" ):
                return visitor.visitRowset_function_limited(self)
            else:
                return visitor.visitChildren(self)




    def rowset_function_limited(self):

        localctx = tsqlParser.Rowset_function_limitedContext(self, self._ctx, self.state)
        self.enterRule(localctx, 112, self.RULE_rowset_function_limited)
        try:
            self.state = 1300
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.OPENQUERY]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1298
                self.openquery()
                pass
            elif token in [tsqlParser.OPENDATASOURCE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1299
                self.opendatasource()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class OpenqueryContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.linked_server = None # R_idContext
            self.query = None # Token

        def OPENQUERY(self):
            return self.getToken(tsqlParser.OPENQUERY, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_openquery

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOpenquery" ):
                listener.enterOpenquery(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOpenquery" ):
                listener.exitOpenquery(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOpenquery" ):
                return visitor.visitOpenquery(self)
            else:
                return visitor.visitChildren(self)




    def openquery(self):

        localctx = tsqlParser.OpenqueryContext(self, self._ctx, self.state)
        self.enterRule(localctx, 114, self.RULE_openquery)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1302
            self.match(tsqlParser.OPENQUERY)
            self.state = 1303
            self.match(tsqlParser.LR_BRACKET)
            self.state = 1304
            localctx.linked_server = self.r_id()
            self.state = 1305
            self.match(tsqlParser.COMMA)
            self.state = 1306
            localctx.query = self.match(tsqlParser.STRING)
            self.state = 1307
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class OpendatasourceContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.provider = None # Token
            self.init = None # Token
            self.database = None # R_idContext
            self.scheme = None # R_idContext
            self.table = None # R_idContext

        def OPENDATASOURCE(self):
            return self.getToken(tsqlParser.OPENDATASOURCE, 0)

        def STRING(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.STRING)
            else:
                return self.getToken(tsqlParser.STRING, i)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_opendatasource

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOpendatasource" ):
                listener.enterOpendatasource(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOpendatasource" ):
                listener.exitOpendatasource(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOpendatasource" ):
                return visitor.visitOpendatasource(self)
            else:
                return visitor.visitChildren(self)




    def opendatasource(self):

        localctx = tsqlParser.OpendatasourceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 116, self.RULE_opendatasource)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1309
            self.match(tsqlParser.OPENDATASOURCE)
            self.state = 1310
            self.match(tsqlParser.LR_BRACKET)
            self.state = 1311
            localctx.provider = self.match(tsqlParser.STRING)
            self.state = 1312
            self.match(tsqlParser.COMMA)
            self.state = 1313
            localctx.init = self.match(tsqlParser.STRING)
            self.state = 1314
            self.match(tsqlParser.RR_BRACKET)
            self.state = 1315
            self.match(tsqlParser.DOT)
            self.state = 1317
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                self.state = 1316
                localctx.database = self.r_id()


            self.state = 1319
            self.match(tsqlParser.DOT)
            self.state = 1321
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                self.state = 1320
                localctx.scheme = self.r_id()


            self.state = 1323
            self.match(tsqlParser.DOT)

            self.state = 1324
            localctx.table = self.r_id()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Declare_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DECLARE(self):
            return self.getToken(tsqlParser.DECLARE, 0)

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def table_type_definition(self):
            return self.getTypedRuleContext(tsqlParser.Table_type_definitionContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def declare_local(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Declare_localContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Declare_localContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_declare_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDeclare_statement" ):
                listener.enterDeclare_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDeclare_statement" ):
                listener.exitDeclare_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDeclare_statement" ):
                return visitor.visitDeclare_statement(self)
            else:
                return visitor.visitChildren(self)




    def declare_statement(self):

        localctx = tsqlParser.Declare_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 118, self.RULE_declare_statement)
        self._la = 0 # Token type
        try:
            self.state = 1347
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,176,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1326
                self.match(tsqlParser.DECLARE)
                self.state = 1327
                self.match(tsqlParser.LOCAL_ID)
                self.state = 1329
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.AS:
                    self.state = 1328
                    self.match(tsqlParser.AS)


                self.state = 1331
                self.table_type_definition()
                self.state = 1333
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,173,self._ctx)
                if la_ == 1:
                    self.state = 1332
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1335
                self.match(tsqlParser.DECLARE)
                self.state = 1336
                self.declare_local()
                self.state = 1341
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 1337
                    self.match(tsqlParser.COMMA)
                    self.state = 1338
                    self.declare_local()
                    self.state = 1343
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 1345
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,175,self._ctx)
                if la_ == 1:
                    self.state = 1344
                    self.match(tsqlParser.SEMI)


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Cursor_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CLOSE(self):
            return self.getToken(tsqlParser.CLOSE, 0)

        def cursor_name(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_nameContext,0)


        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def DEALLOCATE(self):
            return self.getToken(tsqlParser.DEALLOCATE, 0)

        def declare_cursor(self):
            return self.getTypedRuleContext(tsqlParser.Declare_cursorContext,0)


        def fetch_cursor(self):
            return self.getTypedRuleContext(tsqlParser.Fetch_cursorContext,0)


        def OPEN(self):
            return self.getToken(tsqlParser.OPEN, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_cursor_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCursor_statement" ):
                listener.enterCursor_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCursor_statement" ):
                listener.exitCursor_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCursor_statement" ):
                return visitor.visitCursor_statement(self)
            else:
                return visitor.visitChildren(self)




    def cursor_statement(self):

        localctx = tsqlParser.Cursor_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 120, self.RULE_cursor_statement)
        try:
            self.state = 1375
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.CLOSE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1349
                self.match(tsqlParser.CLOSE)
                self.state = 1351
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,177,self._ctx)
                if la_ == 1:
                    self.state = 1350
                    self.match(tsqlParser.GLOBAL)


                self.state = 1353
                self.cursor_name()
                self.state = 1355
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,178,self._ctx)
                if la_ == 1:
                    self.state = 1354
                    self.match(tsqlParser.SEMI)


                pass
            elif token in [tsqlParser.DEALLOCATE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1357
                self.match(tsqlParser.DEALLOCATE)
                self.state = 1359
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,179,self._ctx)
                if la_ == 1:
                    self.state = 1358
                    self.match(tsqlParser.GLOBAL)


                self.state = 1361
                self.cursor_name()
                self.state = 1363
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,180,self._ctx)
                if la_ == 1:
                    self.state = 1362
                    self.match(tsqlParser.SEMI)


                pass
            elif token in [tsqlParser.DECLARE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1365
                self.declare_cursor()
                pass
            elif token in [tsqlParser.FETCH]:
                self.enterOuterAlt(localctx, 4)
                self.state = 1366
                self.fetch_cursor()
                pass
            elif token in [tsqlParser.OPEN]:
                self.enterOuterAlt(localctx, 5)
                self.state = 1367
                self.match(tsqlParser.OPEN)
                self.state = 1369
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,181,self._ctx)
                if la_ == 1:
                    self.state = 1368
                    self.match(tsqlParser.GLOBAL)


                self.state = 1371
                self.cursor_name()
                self.state = 1373
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,182,self._ctx)
                if la_ == 1:
                    self.state = 1372
                    self.match(tsqlParser.SEMI)


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Execute_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.return_status = None # Token

        def EXECUTE(self):
            return self.getToken(tsqlParser.EXECUTE, 0)

        def func_proc_name(self):
            return self.getTypedRuleContext(tsqlParser.Func_proc_nameContext,0)


        def execute_statement_arg(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Execute_statement_argContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Execute_statement_argContext,i)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def execute_var_string(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Execute_var_stringContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Execute_var_stringContext,i)


        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def LOGIN(self):
            return self.getToken(tsqlParser.LOGIN, 0)

        def USER(self):
            return self.getToken(tsqlParser.USER, 0)

        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_execute_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExecute_statement" ):
                listener.enterExecute_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExecute_statement" ):
                listener.exitExecute_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExecute_statement" ):
                return visitor.visitExecute_statement(self)
            else:
                return visitor.visitChildren(self)




    def execute_statement(self):

        localctx = tsqlParser.Execute_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 122, self.RULE_execute_statement)
        self._la = 0 # Token type
        try:
            self.state = 1418
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,192,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1377
                self.match(tsqlParser.EXECUTE)
                self.state = 1380
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.LOCAL_ID:
                    self.state = 1378
                    localctx.return_status = self.match(tsqlParser.LOCAL_ID)
                    self.state = 1379
                    self.match(tsqlParser.EQUAL)


                self.state = 1382
                self.func_proc_name()
                self.state = 1391
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,186,self._ctx)
                if la_ == 1:
                    self.state = 1383
                    self.execute_statement_arg()
                    self.state = 1388
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    while _la==tsqlParser.COMMA:
                        self.state = 1384
                        self.match(tsqlParser.COMMA)
                        self.state = 1385
                        self.execute_statement_arg()
                        self.state = 1390
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)



                self.state = 1394
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,187,self._ctx)
                if la_ == 1:
                    self.state = 1393
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1396
                self.match(tsqlParser.EXECUTE)
                self.state = 1397
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1398
                self.execute_var_string()
                self.state = 1403
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.PLUS:
                    self.state = 1399
                    self.match(tsqlParser.PLUS)
                    self.state = 1400
                    self.execute_var_string()
                    self.state = 1405
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 1406
                self.match(tsqlParser.RR_BRACKET)
                self.state = 1413
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,190,self._ctx)
                if la_ == 1:
                    self.state = 1408
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.AS:
                        self.state = 1407
                        self.match(tsqlParser.AS)


                    self.state = 1410
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.USER or _la==tsqlParser.LOGIN):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 1411
                    self.match(tsqlParser.EQUAL)
                    self.state = 1412
                    self.match(tsqlParser.STRING)


                self.state = 1416
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,191,self._ctx)
                if la_ == 1:
                    self.state = 1415
                    self.match(tsqlParser.SEMI)


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Execute_statement_argContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.parameter = None # Token

        def DEFAULT(self):
            return self.getToken(tsqlParser.DEFAULT, 0)

        def NULL(self):
            return self.getToken(tsqlParser.NULL, 0)

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def constant_LOCAL_ID(self):
            return self.getTypedRuleContext(tsqlParser.Constant_LOCAL_IDContext,0)


        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def OUTPUT(self):
            return self.getToken(tsqlParser.OUTPUT, 0)

        def OUT(self):
            return self.getToken(tsqlParser.OUT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_execute_statement_arg

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExecute_statement_arg" ):
                listener.enterExecute_statement_arg(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExecute_statement_arg" ):
                listener.exitExecute_statement_arg(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExecute_statement_arg" ):
                return visitor.visitExecute_statement_arg(self)
            else:
                return visitor.visitChildren(self)




    def execute_statement_arg(self):

        localctx = tsqlParser.Execute_statement_argContext(self, self._ctx, self.state)
        self.enterRule(localctx, 124, self.RULE_execute_statement_arg)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1422
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,193,self._ctx)
            if la_ == 1:
                self.state = 1420
                localctx.parameter = self.match(tsqlParser.LOCAL_ID)
                self.state = 1421
                self.match(tsqlParser.EQUAL)


            self.state = 1433
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.LOCAL_ID, tsqlParser.DECIMAL, tsqlParser.ID, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.PLUS, tsqlParser.MINUS]:
                self.state = 1426
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.LOCAL_ID, tsqlParser.DECIMAL, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.PLUS, tsqlParser.MINUS]:
                    self.state = 1424
                    self.constant_LOCAL_ID()
                    pass
                elif token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 1425
                    self.r_id()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 1429
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,195,self._ctx)
                if la_ == 1:
                    self.state = 1428
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.OUT or _la==tsqlParser.OUTPUT):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()


                pass
            elif token in [tsqlParser.DEFAULT]:
                self.state = 1431
                self.match(tsqlParser.DEFAULT)
                pass
            elif token in [tsqlParser.NULL]:
                self.state = 1432
                self.match(tsqlParser.NULL)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Execute_var_stringContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_execute_var_string

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExecute_var_string" ):
                listener.enterExecute_var_string(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExecute_var_string" ):
                listener.exitExecute_var_string(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExecute_var_string" ):
                return visitor.visitExecute_var_string(self)
            else:
                return visitor.visitChildren(self)




    def execute_var_string(self):

        localctx = tsqlParser.Execute_var_stringContext(self, self._ctx, self.state)
        self.enterRule(localctx, 126, self.RULE_execute_var_string)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1435
            _la = self._input.LA(1)
            if not(_la==tsqlParser.LOCAL_ID or _la==tsqlParser.STRING):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Security_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.on_id = None # Table_nameContext
            self.to_principal = None # R_idContext
            self.as_principal = None # R_idContext

        def execute_clause(self):
            return self.getTypedRuleContext(tsqlParser.Execute_clauseContext,0)


        def GRANT(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.GRANT)
            else:
                return self.getToken(tsqlParser.GRANT, i)

        def TO(self):
            return self.getToken(tsqlParser.TO, 0)

        def ALL(self):
            return self.getToken(tsqlParser.ALL, 0)

        def grant_permission(self):
            return self.getTypedRuleContext(tsqlParser.Grant_permissionContext,0)


        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def OPTION(self):
            return self.getToken(tsqlParser.OPTION, 0)

        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def PRIVILEGES(self):
            return self.getToken(tsqlParser.PRIVILEGES, 0)

        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def REVERT(self):
            return self.getToken(tsqlParser.REVERT, 0)

        def COOKIE(self):
            return self.getToken(tsqlParser.COOKIE, 0)

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_security_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSecurity_statement" ):
                listener.enterSecurity_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSecurity_statement" ):
                listener.exitSecurity_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSecurity_statement" ):
                return visitor.visitSecurity_statement(self)
            else:
                return visitor.visitChildren(self)




    def security_statement(self):

        localctx = tsqlParser.Security_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 128, self.RULE_security_statement)
        self._la = 0 # Token type
        try:
            self.state = 1485
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.EXECUTE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1437
                self.execute_clause()
                self.state = 1439
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,197,self._ctx)
                if la_ == 1:
                    self.state = 1438
                    self.match(tsqlParser.SEMI)


                pass
            elif token in [tsqlParser.GRANT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1441
                self.match(tsqlParser.GRANT)
                self.state = 1453
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.ALL]:
                    self.state = 1442
                    self.match(tsqlParser.ALL)
                    self.state = 1444
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.PRIVILEGES:
                        self.state = 1443
                        self.match(tsqlParser.PRIVILEGES)


                    pass
                elif token in [tsqlParser.ALTER, tsqlParser.CREATE, tsqlParser.EXECUTE, tsqlParser.INSERT, tsqlParser.REFERENCES, tsqlParser.SELECT, tsqlParser.VIEW, tsqlParser.CONTROL, tsqlParser.IMPERSONATE, tsqlParser.SHOWPLAN, tsqlParser.TAKE]:
                    self.state = 1446
                    self.grant_permission()
                    self.state = 1451
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.LR_BRACKET:
                        self.state = 1447
                        self.match(tsqlParser.LR_BRACKET)
                        self.state = 1448
                        self.column_name_list()
                        self.state = 1449
                        self.match(tsqlParser.RR_BRACKET)


                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 1457
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ON:
                    self.state = 1455
                    self.match(tsqlParser.ON)
                    self.state = 1456
                    localctx.on_id = self.table_name()


                self.state = 1459
                self.match(tsqlParser.TO)

                self.state = 1460
                localctx.to_principal = self.r_id()
                self.state = 1464
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,202,self._ctx)
                if la_ == 1:
                    self.state = 1461
                    self.match(tsqlParser.WITH)
                    self.state = 1462
                    self.match(tsqlParser.GRANT)
                    self.state = 1463
                    self.match(tsqlParser.OPTION)


                self.state = 1468
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.AS:
                    self.state = 1466
                    self.match(tsqlParser.AS)
                    self.state = 1467
                    localctx.as_principal = self.r_id()


                self.state = 1471
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,204,self._ctx)
                if la_ == 1:
                    self.state = 1470
                    self.match(tsqlParser.SEMI)


                pass
            elif token in [tsqlParser.REVERT]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1473
                self.match(tsqlParser.REVERT)
                self.state = 1480
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,205,self._ctx)
                if la_ == 1:
                    self.state = 1474
                    self.match(tsqlParser.LR_BRACKET)
                    self.state = 1475
                    self.match(tsqlParser.WITH)
                    self.state = 1476
                    self.match(tsqlParser.COOKIE)
                    self.state = 1477
                    self.match(tsqlParser.EQUAL)
                    self.state = 1478
                    self.match(tsqlParser.LOCAL_ID)
                    self.state = 1479
                    self.match(tsqlParser.RR_BRACKET)


                self.state = 1483
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,206,self._ctx)
                if la_ == 1:
                    self.state = 1482
                    self.match(tsqlParser.SEMI)


                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Grant_permissionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EXECUTE(self):
            return self.getToken(tsqlParser.EXECUTE, 0)

        def VIEW(self):
            return self.getToken(tsqlParser.VIEW, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def TAKE(self):
            return self.getToken(tsqlParser.TAKE, 0)

        def CONTROL(self):
            return self.getToken(tsqlParser.CONTROL, 0)

        def CREATE(self):
            return self.getToken(tsqlParser.CREATE, 0)

        def TABLE(self):
            return self.getToken(tsqlParser.TABLE, 0)

        def SHOWPLAN(self):
            return self.getToken(tsqlParser.SHOWPLAN, 0)

        def IMPERSONATE(self):
            return self.getToken(tsqlParser.IMPERSONATE, 0)

        def SELECT(self):
            return self.getToken(tsqlParser.SELECT, 0)

        def REFERENCES(self):
            return self.getToken(tsqlParser.REFERENCES, 0)

        def INSERT(self):
            return self.getToken(tsqlParser.INSERT, 0)

        def ALTER(self):
            return self.getToken(tsqlParser.ALTER, 0)

        def DATABASE(self):
            return self.getToken(tsqlParser.DATABASE, 0)

        def ANY(self):
            return self.getToken(tsqlParser.ANY, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_grant_permission

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGrant_permission" ):
                listener.enterGrant_permission(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGrant_permission" ):
                listener.exitGrant_permission(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGrant_permission" ):
                return visitor.visitGrant_permission(self)
            else:
                return visitor.visitChildren(self)




    def grant_permission(self):

        localctx = tsqlParser.Grant_permissionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 130, self.RULE_grant_permission)
        self._la = 0 # Token type
        try:
            self.state = 1513
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.EXECUTE]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1487
                self.match(tsqlParser.EXECUTE)
                pass
            elif token in [tsqlParser.VIEW]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1488
                self.match(tsqlParser.VIEW)
                self.state = 1489
                self.r_id()
                pass
            elif token in [tsqlParser.TAKE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 1490
                self.match(tsqlParser.TAKE)
                self.state = 1491
                self.r_id()
                pass
            elif token in [tsqlParser.CONTROL]:
                self.enterOuterAlt(localctx, 4)
                self.state = 1492
                self.match(tsqlParser.CONTROL)
                self.state = 1494
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                    self.state = 1493
                    self.r_id()


                pass
            elif token in [tsqlParser.CREATE]:
                self.enterOuterAlt(localctx, 5)
                self.state = 1496
                self.match(tsqlParser.CREATE)
                self.state = 1497
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TABLE or _la==tsqlParser.VIEW):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.SHOWPLAN]:
                self.enterOuterAlt(localctx, 6)
                self.state = 1498
                self.match(tsqlParser.SHOWPLAN)
                pass
            elif token in [tsqlParser.IMPERSONATE]:
                self.enterOuterAlt(localctx, 7)
                self.state = 1499
                self.match(tsqlParser.IMPERSONATE)
                pass
            elif token in [tsqlParser.SELECT]:
                self.enterOuterAlt(localctx, 8)
                self.state = 1500
                self.match(tsqlParser.SELECT)
                pass
            elif token in [tsqlParser.REFERENCES]:
                self.enterOuterAlt(localctx, 9)
                self.state = 1501
                self.match(tsqlParser.REFERENCES)
                pass
            elif token in [tsqlParser.INSERT]:
                self.enterOuterAlt(localctx, 10)
                self.state = 1502
                self.match(tsqlParser.INSERT)
                pass
            elif token in [tsqlParser.ALTER]:
                self.enterOuterAlt(localctx, 11)
                self.state = 1503
                self.match(tsqlParser.ALTER)
                self.state = 1511
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ANY or _la==tsqlParser.DATABASE or _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                    self.state = 1505
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.ANY:
                        self.state = 1504
                        self.match(tsqlParser.ANY)


                    self.state = 1509
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                        self.state = 1507
                        self.r_id()
                        pass
                    elif token in [tsqlParser.DATABASE]:
                        self.state = 1508
                        self.match(tsqlParser.DATABASE)
                        pass
                    else:
                        raise NoViableAltException(self)



                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Set_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.member_name = None # R_idContext

        def SET(self):
            return self.getToken(tsqlParser.SET, 0)

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def assignment_operator(self):
            return self.getTypedRuleContext(tsqlParser.Assignment_operatorContext,0)


        def CURSOR(self):
            return self.getToken(tsqlParser.CURSOR, 0)

        def declare_set_cursor_common(self):
            return self.getTypedRuleContext(tsqlParser.Declare_set_cursor_commonContext,0)


        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def READ(self):
            return self.getToken(tsqlParser.READ, 0)

        def ONLY(self):
            return self.getToken(tsqlParser.ONLY, 0)

        def UPDATE(self):
            return self.getToken(tsqlParser.UPDATE, 0)

        def OF(self):
            return self.getToken(tsqlParser.OF, 0)

        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def set_special(self):
            return self.getTypedRuleContext(tsqlParser.Set_specialContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_set_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSet_statement" ):
                listener.enterSet_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSet_statement" ):
                listener.exitSet_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSet_statement" ):
                return visitor.visitSet_statement(self)
            else:
                return visitor.visitChildren(self)




    def set_statement(self):

        localctx = tsqlParser.Set_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 132, self.RULE_set_statement)
        self._la = 0 # Token type
        try:
            self.state = 1554
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,220,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1515
                self.match(tsqlParser.SET)
                self.state = 1516
                self.match(tsqlParser.LOCAL_ID)
                self.state = 1519
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.DOT:
                    self.state = 1517
                    self.match(tsqlParser.DOT)
                    self.state = 1518
                    localctx.member_name = self.r_id()


                self.state = 1521
                self.match(tsqlParser.EQUAL)
                self.state = 1522
                self.expression(0)
                self.state = 1524
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,214,self._ctx)
                if la_ == 1:
                    self.state = 1523
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1526
                self.match(tsqlParser.SET)
                self.state = 1527
                self.match(tsqlParser.LOCAL_ID)
                self.state = 1528
                self.assignment_operator()
                self.state = 1529
                self.expression(0)
                self.state = 1531
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,215,self._ctx)
                if la_ == 1:
                    self.state = 1530
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1533
                self.match(tsqlParser.SET)
                self.state = 1534
                self.match(tsqlParser.LOCAL_ID)
                self.state = 1535
                self.match(tsqlParser.EQUAL)
                self.state = 1536
                self.match(tsqlParser.CURSOR)
                self.state = 1537
                self.declare_set_cursor_common()
                self.state = 1548
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FOR:
                    self.state = 1538
                    self.match(tsqlParser.FOR)
                    self.state = 1546
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [tsqlParser.READ]:
                        self.state = 1539
                        self.match(tsqlParser.READ)
                        self.state = 1540
                        self.match(tsqlParser.ONLY)
                        pass
                    elif token in [tsqlParser.UPDATE]:
                        self.state = 1541
                        self.match(tsqlParser.UPDATE)
                        self.state = 1544
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if _la==tsqlParser.OF:
                            self.state = 1542
                            self.match(tsqlParser.OF)
                            self.state = 1543
                            self.column_name_list()


                        pass
                    else:
                        raise NoViableAltException(self)



                self.state = 1551
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,219,self._ctx)
                if la_ == 1:
                    self.state = 1550
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1553
                self.set_special()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Transaction_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BEGIN(self):
            return self.getToken(tsqlParser.BEGIN, 0)

        def DISTRIBUTED(self):
            return self.getToken(tsqlParser.DISTRIBUTED, 0)

        def TRAN(self):
            return self.getToken(tsqlParser.TRAN, 0)

        def TRANSACTION(self):
            return self.getToken(tsqlParser.TRANSACTION, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def MARK(self):
            return self.getToken(tsqlParser.MARK, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def COMMIT(self):
            return self.getToken(tsqlParser.COMMIT, 0)

        def DELAYED_DURABILITY(self):
            return self.getToken(tsqlParser.DELAYED_DURABILITY, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def WORK(self):
            return self.getToken(tsqlParser.WORK, 0)

        def ROLLBACK(self):
            return self.getToken(tsqlParser.ROLLBACK, 0)

        def SAVE(self):
            return self.getToken(tsqlParser.SAVE, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_transaction_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTransaction_statement" ):
                listener.enterTransaction_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTransaction_statement" ):
                listener.exitTransaction_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTransaction_statement" ):
                return visitor.visitTransaction_statement(self)
            else:
                return visitor.visitChildren(self)




    def transaction_statement(self):

        localctx = tsqlParser.Transaction_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 134, self.RULE_transaction_statement)
        self._la = 0 # Token type
        try:
            self.state = 1633
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,239,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1556
                self.match(tsqlParser.BEGIN)
                self.state = 1557
                self.match(tsqlParser.DISTRIBUTED)
                self.state = 1558
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TRAN or _la==tsqlParser.TRANSACTION):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1561
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,221,self._ctx)
                if la_ == 1:
                    self.state = 1559
                    self.r_id()

                elif la_ == 2:
                    self.state = 1560
                    self.match(tsqlParser.LOCAL_ID)


                self.state = 1564
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,222,self._ctx)
                if la_ == 1:
                    self.state = 1563
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1566
                self.match(tsqlParser.BEGIN)
                self.state = 1567
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TRAN or _la==tsqlParser.TRANSACTION):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1577
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,225,self._ctx)
                if la_ == 1:
                    self.state = 1570
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                        self.state = 1568
                        self.r_id()
                        pass
                    elif token in [tsqlParser.LOCAL_ID]:
                        self.state = 1569
                        self.match(tsqlParser.LOCAL_ID)
                        pass
                    else:
                        raise NoViableAltException(self)

                    self.state = 1575
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,224,self._ctx)
                    if la_ == 1:
                        self.state = 1572
                        self.match(tsqlParser.WITH)
                        self.state = 1573
                        self.match(tsqlParser.MARK)
                        self.state = 1574
                        self.match(tsqlParser.STRING)




                self.state = 1580
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,226,self._ctx)
                if la_ == 1:
                    self.state = 1579
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1582
                self.match(tsqlParser.COMMIT)
                self.state = 1583
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TRAN or _la==tsqlParser.TRANSACTION):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1596
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,229,self._ctx)
                if la_ == 1:
                    self.state = 1586
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                        self.state = 1584
                        self.r_id()
                        pass
                    elif token in [tsqlParser.LOCAL_ID]:
                        self.state = 1585
                        self.match(tsqlParser.LOCAL_ID)
                        pass
                    else:
                        raise NoViableAltException(self)

                    self.state = 1594
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,228,self._ctx)
                    if la_ == 1:
                        self.state = 1588
                        self.match(tsqlParser.WITH)
                        self.state = 1589
                        self.match(tsqlParser.LR_BRACKET)
                        self.state = 1590
                        self.match(tsqlParser.DELAYED_DURABILITY)
                        self.state = 1591
                        self.match(tsqlParser.EQUAL)
                        self.state = 1592
                        _la = self._input.LA(1)
                        if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                            self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1593
                        self.match(tsqlParser.RR_BRACKET)




                self.state = 1599
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,230,self._ctx)
                if la_ == 1:
                    self.state = 1598
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1601
                self.match(tsqlParser.COMMIT)
                self.state = 1603
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,231,self._ctx)
                if la_ == 1:
                    self.state = 1602
                    self.match(tsqlParser.WORK)


                self.state = 1606
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,232,self._ctx)
                if la_ == 1:
                    self.state = 1605
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 1608
                self.match(tsqlParser.ROLLBACK)
                self.state = 1609
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TRAN or _la==tsqlParser.TRANSACTION):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1612
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,233,self._ctx)
                if la_ == 1:
                    self.state = 1610
                    self.r_id()

                elif la_ == 2:
                    self.state = 1611
                    self.match(tsqlParser.LOCAL_ID)


                self.state = 1615
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,234,self._ctx)
                if la_ == 1:
                    self.state = 1614
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 1617
                self.match(tsqlParser.ROLLBACK)
                self.state = 1619
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,235,self._ctx)
                if la_ == 1:
                    self.state = 1618
                    self.match(tsqlParser.WORK)


                self.state = 1622
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,236,self._ctx)
                if la_ == 1:
                    self.state = 1621
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 1624
                self.match(tsqlParser.SAVE)
                self.state = 1625
                _la = self._input.LA(1)
                if not(_la==tsqlParser.TRAN or _la==tsqlParser.TRANSACTION):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1628
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,237,self._ctx)
                if la_ == 1:
                    self.state = 1626
                    self.r_id()

                elif la_ == 2:
                    self.state = 1627
                    self.match(tsqlParser.LOCAL_ID)


                self.state = 1631
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,238,self._ctx)
                if la_ == 1:
                    self.state = 1630
                    self.match(tsqlParser.SEMI)


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Go_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.count = None # Token

        def GO(self):
            return self.getToken(tsqlParser.GO, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_go_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGo_statement" ):
                listener.enterGo_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGo_statement" ):
                listener.exitGo_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGo_statement" ):
                return visitor.visitGo_statement(self)
            else:
                return visitor.visitChildren(self)




    def go_statement(self):

        localctx = tsqlParser.Go_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 136, self.RULE_go_statement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1635
            self.match(tsqlParser.GO)
            self.state = 1637
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.DECIMAL:
                self.state = 1636
                localctx.count = self.match(tsqlParser.DECIMAL)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Use_statementContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.database = None # R_idContext

        def USE(self):
            return self.getToken(tsqlParser.USE, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_use_statement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUse_statement" ):
                listener.enterUse_statement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUse_statement" ):
                listener.exitUse_statement(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUse_statement" ):
                return visitor.visitUse_statement(self)
            else:
                return visitor.visitChildren(self)




    def use_statement(self):

        localctx = tsqlParser.Use_statementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 138, self.RULE_use_statement)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1639
            self.match(tsqlParser.USE)
            self.state = 1640
            localctx.database = self.r_id()
            self.state = 1642
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,241,self._ctx)
            if la_ == 1:
                self.state = 1641
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Execute_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.clause = None # Token

        def EXECUTE(self):
            return self.getToken(tsqlParser.EXECUTE, 0)

        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def CALLER(self):
            return self.getToken(tsqlParser.CALLER, 0)

        def SELF(self):
            return self.getToken(tsqlParser.SELF, 0)

        def OWNER(self):
            return self.getToken(tsqlParser.OWNER, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_execute_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExecute_clause" ):
                listener.enterExecute_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExecute_clause" ):
                listener.exitExecute_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExecute_clause" ):
                return visitor.visitExecute_clause(self)
            else:
                return visitor.visitChildren(self)




    def execute_clause(self):

        localctx = tsqlParser.Execute_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 140, self.RULE_execute_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1644
            self.match(tsqlParser.EXECUTE)
            self.state = 1645
            self.match(tsqlParser.AS)
            self.state = 1646
            localctx.clause = self._input.LT(1)
            _la = self._input.LA(1)
            if not(_la==tsqlParser.CALLER or _la==tsqlParser.OWNER or _la==tsqlParser.SELF or _la==tsqlParser.STRING):
                localctx.clause = self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Declare_localContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def data_type(self):
            return self.getTypedRuleContext(tsqlParser.Data_typeContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_declare_local

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDeclare_local" ):
                listener.enterDeclare_local(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDeclare_local" ):
                listener.exitDeclare_local(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDeclare_local" ):
                return visitor.visitDeclare_local(self)
            else:
                return visitor.visitChildren(self)




    def declare_local(self):

        localctx = tsqlParser.Declare_localContext(self, self._ctx, self.state)
        self.enterRule(localctx, 142, self.RULE_declare_local)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1648
            self.match(tsqlParser.LOCAL_ID)
            self.state = 1650
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.AS:
                self.state = 1649
                self.match(tsqlParser.AS)


            self.state = 1652
            self.data_type()
            self.state = 1655
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.EQUAL:
                self.state = 1653
                self.match(tsqlParser.EQUAL)
                self.state = 1654
                self.expression(0)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_type_definitionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TABLE(self):
            return self.getToken(tsqlParser.TABLE, 0)

        def column_def_table_constraints(self):
            return self.getTypedRuleContext(tsqlParser.Column_def_table_constraintsContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_type_definition

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_type_definition" ):
                listener.enterTable_type_definition(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_type_definition" ):
                listener.exitTable_type_definition(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_type_definition" ):
                return visitor.visitTable_type_definition(self)
            else:
                return visitor.visitChildren(self)




    def table_type_definition(self):

        localctx = tsqlParser.Table_type_definitionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 144, self.RULE_table_type_definition)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1657
            self.match(tsqlParser.TABLE)
            self.state = 1658
            self.match(tsqlParser.LR_BRACKET)
            self.state = 1659
            self.column_def_table_constraints()
            self.state = 1660
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_def_table_constraintsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def column_def_table_constraint(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Column_def_table_constraintContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Column_def_table_constraintContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_column_def_table_constraints

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_def_table_constraints" ):
                listener.enterColumn_def_table_constraints(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_def_table_constraints" ):
                listener.exitColumn_def_table_constraints(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_def_table_constraints" ):
                return visitor.visitColumn_def_table_constraints(self)
            else:
                return visitor.visitChildren(self)




    def column_def_table_constraints(self):

        localctx = tsqlParser.Column_def_table_constraintsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 146, self.RULE_column_def_table_constraints)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1662
            self.column_def_table_constraint()
            self.state = 1669
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,245,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 1664
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.COMMA:
                        self.state = 1663
                        self.match(tsqlParser.COMMA)


                    self.state = 1666
                    self.column_def_table_constraint() 
                self.state = 1671
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,245,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_def_table_constraintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def column_definition(self):
            return self.getTypedRuleContext(tsqlParser.Column_definitionContext,0)


        def table_constraint(self):
            return self.getTypedRuleContext(tsqlParser.Table_constraintContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_column_def_table_constraint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_def_table_constraint" ):
                listener.enterColumn_def_table_constraint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_def_table_constraint" ):
                listener.exitColumn_def_table_constraint(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_def_table_constraint" ):
                return visitor.visitColumn_def_table_constraint(self)
            else:
                return visitor.visitChildren(self)




    def column_def_table_constraint(self):

        localctx = tsqlParser.Column_def_table_constraintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 148, self.RULE_column_def_table_constraint)
        try:
            self.state = 1674
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1672
                self.column_definition()
                pass
            elif token in [tsqlParser.CHECK, tsqlParser.CONSTRAINT, tsqlParser.PRIMARY, tsqlParser.UNIQUE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1673
                self.table_constraint()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_definitionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.constraint = None # R_idContext
            self.seed = None # Token
            self.increment = None # Token

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def data_type(self):
            return self.getTypedRuleContext(tsqlParser.Data_typeContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def COLLATE(self):
            return self.getToken(tsqlParser.COLLATE, 0)

        def null_notnull(self):
            return self.getTypedRuleContext(tsqlParser.Null_notnullContext,0)


        def DEFAULT(self):
            return self.getToken(tsqlParser.DEFAULT, 0)

        def constant_expression(self):
            return self.getTypedRuleContext(tsqlParser.Constant_expressionContext,0)


        def IDENTITY(self):
            return self.getToken(tsqlParser.IDENTITY, 0)

        def ROWGUIDCOL(self):
            return self.getToken(tsqlParser.ROWGUIDCOL, 0)

        def column_constraint(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Column_constraintContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Column_constraintContext,i)


        def CONSTRAINT(self):
            return self.getToken(tsqlParser.CONSTRAINT, 0)

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def VALUES(self):
            return self.getToken(tsqlParser.VALUES, 0)

        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)

        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def REPLICATION(self):
            return self.getToken(tsqlParser.REPLICATION, 0)

        def DECIMAL(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.DECIMAL)
            else:
                return self.getToken(tsqlParser.DECIMAL, i)

        def getRuleIndex(self):
            return tsqlParser.RULE_column_definition

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_definition" ):
                listener.enterColumn_definition(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_definition" ):
                listener.exitColumn_definition(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_definition" ):
                return visitor.visitColumn_definition(self)
            else:
                return visitor.visitChildren(self)




    def column_definition(self):

        localctx = tsqlParser.Column_definitionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 150, self.RULE_column_definition)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1676
            self.r_id()
            self.state = 1680
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.state = 1677
                self.data_type()
                pass
            elif token in [tsqlParser.AS]:
                self.state = 1678
                self.match(tsqlParser.AS)
                self.state = 1679
                self.expression(0)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 1684
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.COLLATE:
                self.state = 1682
                self.match(tsqlParser.COLLATE)
                self.state = 1683
                self.r_id()


            self.state = 1687
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,249,self._ctx)
            if la_ == 1:
                self.state = 1686
                self.null_notnull()


            self.state = 1712
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,254,self._ctx)
            if la_ == 1:
                self.state = 1691
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.CONSTRAINT:
                    self.state = 1689
                    self.match(tsqlParser.CONSTRAINT)
                    self.state = 1690
                    localctx.constraint = self.r_id()


                self.state = 1693
                self.match(tsqlParser.DEFAULT)
                self.state = 1694
                self.constant_expression()
                self.state = 1697
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,251,self._ctx)
                if la_ == 1:
                    self.state = 1695
                    self.match(tsqlParser.WITH)
                    self.state = 1696
                    self.match(tsqlParser.VALUES)



            elif la_ == 2:
                self.state = 1699
                self.match(tsqlParser.IDENTITY)
                self.state = 1705
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,252,self._ctx)
                if la_ == 1:
                    self.state = 1700
                    self.match(tsqlParser.LR_BRACKET)
                    self.state = 1701
                    localctx.seed = self.match(tsqlParser.DECIMAL)
                    self.state = 1702
                    self.match(tsqlParser.COMMA)
                    self.state = 1703
                    localctx.increment = self.match(tsqlParser.DECIMAL)
                    self.state = 1704
                    self.match(tsqlParser.RR_BRACKET)


                self.state = 1710
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,253,self._ctx)
                if la_ == 1:
                    self.state = 1707
                    self.match(tsqlParser.NOT)
                    self.state = 1708
                    self.match(tsqlParser.FOR)
                    self.state = 1709
                    self.match(tsqlParser.REPLICATION)




            self.state = 1715
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ROWGUIDCOL:
                self.state = 1714
                self.match(tsqlParser.ROWGUIDCOL)


            self.state = 1720
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,256,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 1717
                    self.column_constraint() 
                self.state = 1722
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,256,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_constraintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CHECK(self):
            return self.getToken(tsqlParser.CHECK, 0)

        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)


        def CONSTRAINT(self):
            return self.getToken(tsqlParser.CONSTRAINT, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def null_notnull(self):
            return self.getTypedRuleContext(tsqlParser.Null_notnullContext,0)


        def PRIMARY(self):
            return self.getToken(tsqlParser.PRIMARY, 0)

        def KEY(self):
            return self.getToken(tsqlParser.KEY, 0)

        def UNIQUE(self):
            return self.getToken(tsqlParser.UNIQUE, 0)

        def clustered(self):
            return self.getTypedRuleContext(tsqlParser.ClusteredContext,0)


        def index_options(self):
            return self.getTypedRuleContext(tsqlParser.Index_optionsContext,0)


        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)

        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def REPLICATION(self):
            return self.getToken(tsqlParser.REPLICATION, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_column_constraint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_constraint" ):
                listener.enterColumn_constraint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_constraint" ):
                listener.exitColumn_constraint(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_constraint" ):
                return visitor.visitColumn_constraint(self)
            else:
                return visitor.visitChildren(self)




    def column_constraint(self):

        localctx = tsqlParser.Column_constraintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 152, self.RULE_column_constraint)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1725
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.CONSTRAINT:
                self.state = 1723
                self.match(tsqlParser.CONSTRAINT)
                self.state = 1724
                self.r_id()


            self.state = 1728
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.NOT or _la==tsqlParser.NULL:
                self.state = 1727
                self.null_notnull()


            self.state = 1751
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.PRIMARY, tsqlParser.UNIQUE]:
                self.state = 1733
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.PRIMARY]:
                    self.state = 1730
                    self.match(tsqlParser.PRIMARY)
                    self.state = 1731
                    self.match(tsqlParser.KEY)
                    pass
                elif token in [tsqlParser.UNIQUE]:
                    self.state = 1732
                    self.match(tsqlParser.UNIQUE)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 1736
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.CLUSTERED or _la==tsqlParser.NONCLUSTERED:
                    self.state = 1735
                    self.clustered()


                self.state = 1739
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,261,self._ctx)
                if la_ == 1:
                    self.state = 1738
                    self.index_options()


                pass
            elif token in [tsqlParser.CHECK]:
                self.state = 1741
                self.match(tsqlParser.CHECK)
                self.state = 1745
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.NOT:
                    self.state = 1742
                    self.match(tsqlParser.NOT)
                    self.state = 1743
                    self.match(tsqlParser.FOR)
                    self.state = 1744
                    self.match(tsqlParser.REPLICATION)


                self.state = 1747
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1748
                self.search_condition(0)
                self.state = 1749
                self.match(tsqlParser.RR_BRACKET)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_constraintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def CHECK(self):
            return self.getToken(tsqlParser.CHECK, 0)

        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)


        def CONSTRAINT(self):
            return self.getToken(tsqlParser.CONSTRAINT, 0)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def PRIMARY(self):
            return self.getToken(tsqlParser.PRIMARY, 0)

        def KEY(self):
            return self.getToken(tsqlParser.KEY, 0)

        def UNIQUE(self):
            return self.getToken(tsqlParser.UNIQUE, 0)

        def clustered(self):
            return self.getTypedRuleContext(tsqlParser.ClusteredContext,0)


        def index_options(self):
            return self.getTypedRuleContext(tsqlParser.Index_optionsContext,0)


        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)

        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def REPLICATION(self):
            return self.getToken(tsqlParser.REPLICATION, 0)

        def ASC(self):
            return self.getToken(tsqlParser.ASC, 0)

        def DESC(self):
            return self.getToken(tsqlParser.DESC, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_table_constraint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_constraint" ):
                listener.enterTable_constraint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_constraint" ):
                listener.exitTable_constraint(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_constraint" ):
                return visitor.visitTable_constraint(self)
            else:
                return visitor.visitChildren(self)




    def table_constraint(self):

        localctx = tsqlParser.Table_constraintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 154, self.RULE_table_constraint)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1755
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.CONSTRAINT:
                self.state = 1753
                self.match(tsqlParser.CONSTRAINT)
                self.state = 1754
                self.r_id()


            self.state = 1788
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.PRIMARY, tsqlParser.UNIQUE]:
                self.state = 1760
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.PRIMARY]:
                    self.state = 1757
                    self.match(tsqlParser.PRIMARY)
                    self.state = 1758
                    self.match(tsqlParser.KEY)
                    pass
                elif token in [tsqlParser.UNIQUE]:
                    self.state = 1759
                    self.match(tsqlParser.UNIQUE)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 1763
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.CLUSTERED or _la==tsqlParser.NONCLUSTERED:
                    self.state = 1762
                    self.clustered()


                self.state = 1765
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1766
                self.column_name_list()
                self.state = 1768
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ASC or _la==tsqlParser.DESC:
                    self.state = 1767
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.ASC or _la==tsqlParser.DESC):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()


                self.state = 1770
                self.match(tsqlParser.RR_BRACKET)
                self.state = 1772
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,268,self._ctx)
                if la_ == 1:
                    self.state = 1771
                    self.index_options()


                self.state = 1776
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ON:
                    self.state = 1774
                    self.match(tsqlParser.ON)
                    self.state = 1775
                    self.r_id()


                pass
            elif token in [tsqlParser.CHECK]:
                self.state = 1778
                self.match(tsqlParser.CHECK)
                self.state = 1782
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.NOT:
                    self.state = 1779
                    self.match(tsqlParser.NOT)
                    self.state = 1780
                    self.match(tsqlParser.FOR)
                    self.state = 1781
                    self.match(tsqlParser.REPLICATION)


                self.state = 1784
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1785
                self.search_condition(0)
                self.state = 1786
                self.match(tsqlParser.RR_BRACKET)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Index_optionsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def index_option(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Index_optionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Index_optionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_index_options

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIndex_options" ):
                listener.enterIndex_options(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIndex_options" ):
                listener.exitIndex_options(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitIndex_options" ):
                return visitor.visitIndex_options(self)
            else:
                return visitor.visitChildren(self)




    def index_options(self):

        localctx = tsqlParser.Index_optionsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 156, self.RULE_index_options)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1790
            self.match(tsqlParser.WITH)
            self.state = 1791
            self.match(tsqlParser.LR_BRACKET)
            self.state = 1792
            self.index_option()
            self.state = 1797
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 1793
                self.match(tsqlParser.COMMA)
                self.state = 1794
                self.index_option()
                self.state = 1799
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1800
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Index_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def simple_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Simple_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Simple_idContext,i)


        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_index_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIndex_option" ):
                listener.enterIndex_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIndex_option" ):
                listener.exitIndex_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitIndex_option" ):
                return visitor.visitIndex_option(self)
            else:
                return visitor.visitChildren(self)




    def index_option(self):

        localctx = tsqlParser.Index_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 158, self.RULE_index_option)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1802
            self.simple_id()
            self.state = 1803
            self.match(tsqlParser.EQUAL)
            self.state = 1807
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.ID]:
                self.state = 1804
                self.simple_id()
                pass
            elif token in [tsqlParser.OFF, tsqlParser.ON]:
                self.state = 1805
                self.on_off()
                pass
            elif token in [tsqlParser.DECIMAL]:
                self.state = 1806
                self.match(tsqlParser.DECIMAL)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Declare_cursorContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DECLARE(self):
            return self.getToken(tsqlParser.DECLARE, 0)

        def cursor_name(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_nameContext,0)


        def CURSOR(self):
            return self.getToken(tsqlParser.CURSOR, 0)

        def FOR(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.FOR)
            else:
                return self.getToken(tsqlParser.FOR, i)

        def select_statement(self):
            return self.getTypedRuleContext(tsqlParser.Select_statementContext,0)


        def declare_set_cursor_common(self):
            return self.getTypedRuleContext(tsqlParser.Declare_set_cursor_commonContext,0)


        def INSENSITIVE(self):
            return self.getToken(tsqlParser.INSENSITIVE, 0)

        def SCROLL(self):
            return self.getToken(tsqlParser.SCROLL, 0)

        def READ(self):
            return self.getToken(tsqlParser.READ, 0)

        def ONLY(self):
            return self.getToken(tsqlParser.ONLY, 0)

        def UPDATE(self):
            return self.getToken(tsqlParser.UPDATE, 0)

        def OF(self):
            return self.getToken(tsqlParser.OF, 0)

        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_declare_cursor

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDeclare_cursor" ):
                listener.enterDeclare_cursor(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDeclare_cursor" ):
                listener.exitDeclare_cursor(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDeclare_cursor" ):
                return visitor.visitDeclare_cursor(self)
            else:
                return visitor.visitChildren(self)




    def declare_cursor(self):

        localctx = tsqlParser.Declare_cursorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 160, self.RULE_declare_cursor)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1809
            self.match(tsqlParser.DECLARE)
            self.state = 1810
            self.cursor_name()
            self.state = 1842
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,281,self._ctx)
            if la_ == 1:
                self.state = 1811
                self.match(tsqlParser.CURSOR)
                self.state = 1821
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,276,self._ctx)
                if la_ == 1:
                    self.state = 1812
                    self.declare_set_cursor_common()
                    self.state = 1819
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.FOR:
                        self.state = 1813
                        self.match(tsqlParser.FOR)
                        self.state = 1814
                        self.match(tsqlParser.UPDATE)
                        self.state = 1817
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)
                        if _la==tsqlParser.OF:
                            self.state = 1815
                            self.match(tsqlParser.OF)
                            self.state = 1816
                            self.column_name_list()






                pass

            elif la_ == 2:
                self.state = 1824
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.INSENSITIVE:
                    self.state = 1823
                    self.match(tsqlParser.INSENSITIVE)


                self.state = 1827
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.SCROLL:
                    self.state = 1826
                    self.match(tsqlParser.SCROLL)


                self.state = 1829
                self.match(tsqlParser.CURSOR)
                self.state = 1830
                self.match(tsqlParser.FOR)
                self.state = 1831
                self.select_statement()
                self.state = 1840
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FOR:
                    self.state = 1832
                    self.match(tsqlParser.FOR)
                    self.state = 1838
                    self._errHandler.sync(self)
                    token = self._input.LA(1)
                    if token in [tsqlParser.READ]:
                        self.state = 1833
                        self.match(tsqlParser.READ)
                        self.state = 1834
                        self.match(tsqlParser.ONLY)
                        pass
                    elif token in [tsqlParser.UPDATE]:
                        self.state = 1835
                        self.match(tsqlParser.UPDATE)
                        pass
                    elif token in [tsqlParser.OF]:
                        self.state = 1836
                        self.match(tsqlParser.OF)
                        self.state = 1837
                        self.column_name_list()
                        pass
                    else:
                        raise NoViableAltException(self)



                pass


            self.state = 1845
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,282,self._ctx)
            if la_ == 1:
                self.state = 1844
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Declare_set_cursor_commonContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def select_statement(self):
            return self.getTypedRuleContext(tsqlParser.Select_statementContext,0)


        def TYPE_WARNING(self):
            return self.getToken(tsqlParser.TYPE_WARNING, 0)

        def LOCAL(self):
            return self.getToken(tsqlParser.LOCAL, 0)

        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def FORWARD_ONLY(self):
            return self.getToken(tsqlParser.FORWARD_ONLY, 0)

        def SCROLL(self):
            return self.getToken(tsqlParser.SCROLL, 0)

        def STATIC(self):
            return self.getToken(tsqlParser.STATIC, 0)

        def KEYSET(self):
            return self.getToken(tsqlParser.KEYSET, 0)

        def DYNAMIC(self):
            return self.getToken(tsqlParser.DYNAMIC, 0)

        def FAST_FORWARD(self):
            return self.getToken(tsqlParser.FAST_FORWARD, 0)

        def READ_ONLY(self):
            return self.getToken(tsqlParser.READ_ONLY, 0)

        def SCROLL_LOCKS(self):
            return self.getToken(tsqlParser.SCROLL_LOCKS, 0)

        def OPTIMISTIC(self):
            return self.getToken(tsqlParser.OPTIMISTIC, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_declare_set_cursor_common

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDeclare_set_cursor_common" ):
                listener.enterDeclare_set_cursor_common(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDeclare_set_cursor_common" ):
                listener.exitDeclare_set_cursor_common(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDeclare_set_cursor_common" ):
                return visitor.visitDeclare_set_cursor_common(self)
            else:
                return visitor.visitChildren(self)




    def declare_set_cursor_common(self):

        localctx = tsqlParser.Declare_set_cursor_commonContext(self, self._ctx, self.state)
        self.enterRule(localctx, 162, self.RULE_declare_set_cursor_common)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1848
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.GLOBAL or _la==tsqlParser.LOCAL:
                self.state = 1847
                _la = self._input.LA(1)
                if not(_la==tsqlParser.GLOBAL or _la==tsqlParser.LOCAL):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 1851
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FORWARD_ONLY or _la==tsqlParser.SCROLL:
                self.state = 1850
                _la = self._input.LA(1)
                if not(_la==tsqlParser.FORWARD_ONLY or _la==tsqlParser.SCROLL):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 1854
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if ((((_la - 248)) & ~0x3f) == 0 and ((1 << (_la - 248)) & ((1 << (tsqlParser.DYNAMIC - 248)) | (1 << (tsqlParser.FAST_FORWARD - 248)) | (1 << (tsqlParser.KEYSET - 248)))) != 0) or _la==tsqlParser.STATIC:
                self.state = 1853
                _la = self._input.LA(1)
                if not(((((_la - 248)) & ~0x3f) == 0 and ((1 << (_la - 248)) & ((1 << (tsqlParser.DYNAMIC - 248)) | (1 << (tsqlParser.FAST_FORWARD - 248)) | (1 << (tsqlParser.KEYSET - 248)))) != 0) or _la==tsqlParser.STATIC):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 1857
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if ((((_la - 320)) & ~0x3f) == 0 and ((1 << (_la - 320)) & ((1 << (tsqlParser.OPTIMISTIC - 320)) | (1 << (tsqlParser.READ_ONLY - 320)) | (1 << (tsqlParser.SCROLL_LOCKS - 320)))) != 0):
                self.state = 1856
                _la = self._input.LA(1)
                if not(((((_la - 320)) & ~0x3f) == 0 and ((1 << (_la - 320)) & ((1 << (tsqlParser.OPTIMISTIC - 320)) | (1 << (tsqlParser.READ_ONLY - 320)) | (1 << (tsqlParser.SCROLL_LOCKS - 320)))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 1860
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.TYPE_WARNING:
                self.state = 1859
                self.match(tsqlParser.TYPE_WARNING)


            self.state = 1862
            self.match(tsqlParser.FOR)
            self.state = 1863
            self.select_statement()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Fetch_cursorContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FETCH(self):
            return self.getToken(tsqlParser.FETCH, 0)

        def cursor_name(self):
            return self.getTypedRuleContext(tsqlParser.Cursor_nameContext,0)


        def FROM(self):
            return self.getToken(tsqlParser.FROM, 0)

        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def INTO(self):
            return self.getToken(tsqlParser.INTO, 0)

        def LOCAL_ID(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.LOCAL_ID)
            else:
                return self.getToken(tsqlParser.LOCAL_ID, i)

        def NEXT(self):
            return self.getToken(tsqlParser.NEXT, 0)

        def PRIOR(self):
            return self.getToken(tsqlParser.PRIOR, 0)

        def FIRST(self):
            return self.getToken(tsqlParser.FIRST, 0)

        def LAST(self):
            return self.getToken(tsqlParser.LAST, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def ABSOLUTE(self):
            return self.getToken(tsqlParser.ABSOLUTE, 0)

        def RELATIVE(self):
            return self.getToken(tsqlParser.RELATIVE, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_fetch_cursor

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFetch_cursor" ):
                listener.enterFetch_cursor(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFetch_cursor" ):
                listener.exitFetch_cursor(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFetch_cursor" ):
                return visitor.visitFetch_cursor(self)
            else:
                return visitor.visitChildren(self)




    def fetch_cursor(self):

        localctx = tsqlParser.Fetch_cursorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 164, self.RULE_fetch_cursor)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1865
            self.match(tsqlParser.FETCH)
            self.state = 1875
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,289,self._ctx)
            if la_ == 1:
                self.state = 1872
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.NEXT]:
                    self.state = 1866
                    self.match(tsqlParser.NEXT)
                    pass
                elif token in [tsqlParser.PRIOR]:
                    self.state = 1867
                    self.match(tsqlParser.PRIOR)
                    pass
                elif token in [tsqlParser.FIRST]:
                    self.state = 1868
                    self.match(tsqlParser.FIRST)
                    pass
                elif token in [tsqlParser.LAST]:
                    self.state = 1869
                    self.match(tsqlParser.LAST)
                    pass
                elif token in [tsqlParser.ABSOLUTE, tsqlParser.RELATIVE]:
                    self.state = 1870
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.ABSOLUTE or _la==tsqlParser.RELATIVE):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 1871
                    self.expression(0)
                    pass
                elif token in [tsqlParser.FROM]:
                    pass
                else:
                    pass
                self.state = 1874
                self.match(tsqlParser.FROM)


            self.state = 1878
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,290,self._ctx)
            if la_ == 1:
                self.state = 1877
                self.match(tsqlParser.GLOBAL)


            self.state = 1880
            self.cursor_name()
            self.state = 1890
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.INTO:
                self.state = 1881
                self.match(tsqlParser.INTO)
                self.state = 1882
                self.match(tsqlParser.LOCAL_ID)
                self.state = 1887
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 1883
                    self.match(tsqlParser.COMMA)
                    self.state = 1884
                    self.match(tsqlParser.LOCAL_ID)
                    self.state = 1889
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)



            self.state = 1893
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,293,self._ctx)
            if la_ == 1:
                self.state = 1892
                self.match(tsqlParser.SEMI)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Set_specialContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SET(self):
            return self.getToken(tsqlParser.SET, 0)

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def constant_LOCAL_ID(self):
            return self.getTypedRuleContext(tsqlParser.Constant_LOCAL_IDContext,0)


        def on_off(self):
            return self.getTypedRuleContext(tsqlParser.On_offContext,0)


        def TRANSACTION(self):
            return self.getToken(tsqlParser.TRANSACTION, 0)

        def ISOLATION(self):
            return self.getToken(tsqlParser.ISOLATION, 0)

        def LEVEL(self):
            return self.getToken(tsqlParser.LEVEL, 0)

        def READ(self):
            return self.getToken(tsqlParser.READ, 0)

        def UNCOMMITTED(self):
            return self.getToken(tsqlParser.UNCOMMITTED, 0)

        def COMMITTED(self):
            return self.getToken(tsqlParser.COMMITTED, 0)

        def REPEATABLE(self):
            return self.getToken(tsqlParser.REPEATABLE, 0)

        def SNAPSHOT(self):
            return self.getToken(tsqlParser.SNAPSHOT, 0)

        def SERIALIZABLE(self):
            return self.getToken(tsqlParser.SERIALIZABLE, 0)

        def IDENTITY_INSERT(self):
            return self.getToken(tsqlParser.IDENTITY_INSERT, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def ANSI_NULLS(self):
            return self.getToken(tsqlParser.ANSI_NULLS, 0)

        def QUOTED_IDENTIFIER(self):
            return self.getToken(tsqlParser.QUOTED_IDENTIFIER, 0)

        def ANSI_PADDING(self):
            return self.getToken(tsqlParser.ANSI_PADDING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_set_special

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSet_special" ):
                listener.enterSet_special(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSet_special" ):
                listener.exitSet_special(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSet_special" ):
                return visitor.visitSet_special(self)
            else:
                return visitor.visitChildren(self)




    def set_special(self):

        localctx = tsqlParser.Set_specialContext(self, self._ctx, self.state)
        self.enterRule(localctx, 166, self.RULE_set_special)
        try:
            self.state = 1938
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,299,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1895
                self.match(tsqlParser.SET)
                self.state = 1896
                self.r_id()
                self.state = 1900
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 1897
                    self.r_id()
                    pass
                elif token in [tsqlParser.LOCAL_ID, tsqlParser.DECIMAL, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.PLUS, tsqlParser.MINUS]:
                    self.state = 1898
                    self.constant_LOCAL_ID()
                    pass
                elif token in [tsqlParser.OFF, tsqlParser.ON]:
                    self.state = 1899
                    self.on_off()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 1903
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,295,self._ctx)
                if la_ == 1:
                    self.state = 1902
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1905
                self.match(tsqlParser.SET)
                self.state = 1906
                self.match(tsqlParser.TRANSACTION)
                self.state = 1907
                self.match(tsqlParser.ISOLATION)
                self.state = 1908
                self.match(tsqlParser.LEVEL)
                self.state = 1917
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,296,self._ctx)
                if la_ == 1:
                    self.state = 1909
                    self.match(tsqlParser.READ)
                    self.state = 1910
                    self.match(tsqlParser.UNCOMMITTED)
                    pass

                elif la_ == 2:
                    self.state = 1911
                    self.match(tsqlParser.READ)
                    self.state = 1912
                    self.match(tsqlParser.COMMITTED)
                    pass

                elif la_ == 3:
                    self.state = 1913
                    self.match(tsqlParser.REPEATABLE)
                    self.state = 1914
                    self.match(tsqlParser.READ)
                    pass

                elif la_ == 4:
                    self.state = 1915
                    self.match(tsqlParser.SNAPSHOT)
                    pass

                elif la_ == 5:
                    self.state = 1916
                    self.match(tsqlParser.SERIALIZABLE)
                    pass


                self.state = 1920
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,297,self._ctx)
                if la_ == 1:
                    self.state = 1919
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1922
                self.match(tsqlParser.SET)
                self.state = 1923
                self.match(tsqlParser.IDENTITY_INSERT)
                self.state = 1924
                self.table_name()
                self.state = 1925
                self.on_off()
                self.state = 1927
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,298,self._ctx)
                if la_ == 1:
                    self.state = 1926
                    self.match(tsqlParser.SEMI)


                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1929
                self.match(tsqlParser.SET)
                self.state = 1930
                self.match(tsqlParser.ANSI_NULLS)
                self.state = 1931
                self.on_off()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 1932
                self.match(tsqlParser.SET)
                self.state = 1933
                self.match(tsqlParser.QUOTED_IDENTIFIER)
                self.state = 1934
                self.on_off()
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 1935
                self.match(tsqlParser.SET)
                self.state = 1936
                self.match(tsqlParser.ANSI_PADDING)
                self.state = 1937
                self.on_off()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Constant_LOCAL_IDContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def constant(self):
            return self.getTypedRuleContext(tsqlParser.ConstantContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_constant_LOCAL_ID

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstant_LOCAL_ID" ):
                listener.enterConstant_LOCAL_ID(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstant_LOCAL_ID" ):
                listener.exitConstant_LOCAL_ID(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstant_LOCAL_ID" ):
                return visitor.visitConstant_LOCAL_ID(self)
            else:
                return visitor.visitChildren(self)




    def constant_LOCAL_ID(self):

        localctx = tsqlParser.Constant_LOCAL_IDContext(self, self._ctx, self.state)
        self.enterRule(localctx, 168, self.RULE_constant_LOCAL_ID)
        try:
            self.state = 1942
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.DECIMAL, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.PLUS, tsqlParser.MINUS]:
                self.enterOuterAlt(localctx, 1)
                self.state = 1940
                self.constant()
                pass
            elif token in [tsqlParser.LOCAL_ID]:
                self.enterOuterAlt(localctx, 2)
                self.state = 1941
                self.match(tsqlParser.LOCAL_ID)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ExpressionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_expression

     
        def copyFrom(self, ctx:ParserRuleContext):
            super().copyFrom(ctx)


    class Primitive_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def DEFAULT(self):
            return self.getToken(tsqlParser.DEFAULT, 0)
        def NULL(self):
            return self.getToken(tsqlParser.NULL, 0)
        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)
        def constant(self):
            return self.getTypedRuleContext(tsqlParser.ConstantContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPrimitive_expression" ):
                listener.enterPrimitive_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPrimitive_expression" ):
                listener.exitPrimitive_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPrimitive_expression" ):
                return visitor.visitPrimitive_expression(self)
            else:
                return visitor.visitChildren(self)


    class Subquery_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def subquery(self):
            return self.getTypedRuleContext(tsqlParser.SubqueryContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSubquery_expression" ):
                listener.enterSubquery_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSubquery_expression" ):
                listener.exitSubquery_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSubquery_expression" ):
                return visitor.visitSubquery_expression(self)
            else:
                return visitor.visitChildren(self)


    class Over_clause_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def over_clause(self):
            return self.getTypedRuleContext(tsqlParser.Over_clauseContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOver_clause_expression" ):
                listener.enterOver_clause_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOver_clause_expression" ):
                listener.exitOver_clause_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOver_clause_expression" ):
                return visitor.visitOver_clause_expression(self)
            else:
                return visitor.visitChildren(self)


    class Case_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.caseExpr = None # ExpressionContext
            self.elseExpr = None # ExpressionContext
            self.copyFrom(ctx)

        def CASE(self):
            return self.getToken(tsqlParser.CASE, 0)
        def END(self):
            return self.getToken(tsqlParser.END, 0)
        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)

        def switch_section(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Switch_sectionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Switch_sectionContext,i)

        def ELSE(self):
            return self.getToken(tsqlParser.ELSE, 0)
        def switch_search_condition_section(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Switch_search_condition_sectionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Switch_search_condition_sectionContext,i)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCase_expression" ):
                listener.enterCase_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCase_expression" ):
                listener.exitCase_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCase_expression" ):
                return visitor.visitCase_expression(self)
            else:
                return visitor.visitChildren(self)


    class Bracket_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBracket_expression" ):
                listener.enterBracket_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBracket_expression" ):
                listener.exitBracket_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBracket_expression" ):
                return visitor.visitBracket_expression(self)
            else:
                return visitor.visitChildren(self)


    class Binary_operator_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.left = None # ExpressionContext
            self.op = None # Token
            self.right = None # ExpressionContext
            self.copyFrom(ctx)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)

        def comparison_operator(self):
            return self.getTypedRuleContext(tsqlParser.Comparison_operatorContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBinary_operator_expression" ):
                listener.enterBinary_operator_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBinary_operator_expression" ):
                listener.exitBinary_operator_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBinary_operator_expression" ):
                return visitor.visitBinary_operator_expression(self)
            else:
                return visitor.visitChildren(self)


    class Unary_operator_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.op = None # Token
            self.copyFrom(ctx)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUnary_operator_expression" ):
                listener.enterUnary_operator_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUnary_operator_expression" ):
                listener.exitUnary_operator_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUnary_operator_expression" ):
                return visitor.visitUnary_operator_expression(self)
            else:
                return visitor.visitChildren(self)


    class Column_ref_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def full_column_name(self):
            return self.getTypedRuleContext(tsqlParser.Full_column_nameContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_ref_expression" ):
                listener.enterColumn_ref_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_ref_expression" ):
                listener.exitColumn_ref_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_ref_expression" ):
                return visitor.visitColumn_ref_expression(self)
            else:
                return visitor.visitChildren(self)


    class Function_call_expressionContext(ExpressionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.ExpressionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def function_call(self):
            return self.getTypedRuleContext(tsqlParser.Function_callContext,0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)

        def COLLATE(self):
            return self.getToken(tsqlParser.COLLATE, 0)
        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunction_call_expression" ):
                listener.enterFunction_call_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunction_call_expression" ):
                listener.exitFunction_call_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFunction_call_expression" ):
                return visitor.visitFunction_call_expression(self)
            else:
                return visitor.visitChildren(self)



    def expression(self, _p:int=0):
        _parentctx = self._ctx
        _parentState = self.state
        localctx = tsqlParser.ExpressionContext(self, self._ctx, _parentState)
        _prevctx = localctx
        _startState = 170
        self.enterRecursionRule(localctx, 170, self.RULE_expression, _p)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1989
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,305,self._ctx)
            if la_ == 1:
                localctx = tsqlParser.Primitive_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx

                self.state = 1945
                self.match(tsqlParser.DEFAULT)
                pass

            elif la_ == 2:
                localctx = tsqlParser.Primitive_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1946
                self.match(tsqlParser.NULL)
                pass

            elif la_ == 3:
                localctx = tsqlParser.Primitive_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1947
                self.match(tsqlParser.LOCAL_ID)
                pass

            elif la_ == 4:
                localctx = tsqlParser.Primitive_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1948
                self.constant()
                pass

            elif la_ == 5:
                localctx = tsqlParser.Function_call_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1949
                self.function_call()
                pass

            elif la_ == 6:
                localctx = tsqlParser.Case_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1950
                self.match(tsqlParser.CASE)
                self.state = 1951
                localctx.caseExpr = self.expression(0)
                self.state = 1953 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 1952
                    self.switch_section()
                    self.state = 1955 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==tsqlParser.WHEN):
                        break

                self.state = 1959
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ELSE:
                    self.state = 1957
                    self.match(tsqlParser.ELSE)
                    self.state = 1958
                    localctx.elseExpr = self.expression(0)


                self.state = 1961
                self.match(tsqlParser.END)
                pass

            elif la_ == 7:
                localctx = tsqlParser.Case_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1963
                self.match(tsqlParser.CASE)
                self.state = 1965 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while True:
                    self.state = 1964
                    self.switch_search_condition_section()
                    self.state = 1967 
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if not (_la==tsqlParser.WHEN):
                        break

                self.state = 1971
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ELSE:
                    self.state = 1969
                    self.match(tsqlParser.ELSE)
                    self.state = 1970
                    localctx.elseExpr = self.expression(0)


                self.state = 1973
                self.match(tsqlParser.END)
                pass

            elif la_ == 8:
                localctx = tsqlParser.Column_ref_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1975
                self.full_column_name()
                pass

            elif la_ == 9:
                localctx = tsqlParser.Bracket_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1976
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1977
                self.expression(0)
                self.state = 1978
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 10:
                localctx = tsqlParser.Subquery_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1980
                self.match(tsqlParser.LR_BRACKET)
                self.state = 1981
                self.subquery()
                self.state = 1982
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 11:
                localctx = tsqlParser.Unary_operator_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1984
                localctx.op = self.match(tsqlParser.BIT_NOT)
                self.state = 1985
                self.expression(6)
                pass

            elif la_ == 12:
                localctx = tsqlParser.Unary_operator_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1986
                localctx.op = self._input.LT(1)
                _la = self._input.LA(1)
                if not(_la==tsqlParser.PLUS or _la==tsqlParser.MINUS):
                    localctx.op = self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 1987
                self.expression(4)
                pass

            elif la_ == 13:
                localctx = tsqlParser.Over_clause_expressionContext(self, localctx)
                self._ctx = localctx
                _prevctx = localctx
                self.state = 1988
                self.over_clause()
                pass


            self._ctx.stop = self._input.LT(-1)
            self.state = 2006
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,307,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    if self._parseListeners is not None:
                        self.triggerExitRuleEvent()
                    _prevctx = localctx
                    self.state = 2004
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,306,self._ctx)
                    if la_ == 1:
                        localctx = tsqlParser.Binary_operator_expressionContext(self, tsqlParser.ExpressionContext(self, _parentctx, _parentState))
                        localctx.left = _prevctx
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1991
                        if not self.precpred(self._ctx, 5):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 5)")
                        self.state = 1992
                        localctx.op = self._input.LT(1)
                        _la = self._input.LA(1)
                        if not(((((_la - 431)) & ~0x3f) == 0 and ((1 << (_la - 431)) & ((1 << (tsqlParser.STAR - 431)) | (1 << (tsqlParser.DIVIDE - 431)) | (1 << (tsqlParser.MODULE - 431)))) != 0)):
                            localctx.op = self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1993
                        localctx.right = self.expression(6)
                        pass

                    elif la_ == 2:
                        localctx = tsqlParser.Binary_operator_expressionContext(self, tsqlParser.ExpressionContext(self, _parentctx, _parentState))
                        localctx.left = _prevctx
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1994
                        if not self.precpred(self._ctx, 3):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 3)")
                        self.state = 1995
                        localctx.op = self._input.LT(1)
                        _la = self._input.LA(1)
                        if not(((((_la - 434)) & ~0x3f) == 0 and ((1 << (_la - 434)) & ((1 << (tsqlParser.PLUS - 434)) | (1 << (tsqlParser.MINUS - 434)) | (1 << (tsqlParser.BIT_OR - 434)) | (1 << (tsqlParser.BIT_AND - 434)) | (1 << (tsqlParser.BIT_XOR - 434)))) != 0)):
                            localctx.op = self._errHandler.recoverInline(self)
                        else:
                            self._errHandler.reportMatch(self)
                            self.consume()
                        self.state = 1996
                        localctx.right = self.expression(4)
                        pass

                    elif la_ == 3:
                        localctx = tsqlParser.Binary_operator_expressionContext(self, tsqlParser.ExpressionContext(self, _parentctx, _parentState))
                        localctx.left = _prevctx
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 1997
                        if not self.precpred(self._ctx, 2):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 2)")
                        self.state = 1998
                        self.comparison_operator()
                        self.state = 1999
                        localctx.right = self.expression(3)
                        pass

                    elif la_ == 4:
                        localctx = tsqlParser.Function_call_expressionContext(self, tsqlParser.ExpressionContext(self, _parentctx, _parentState))
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_expression)
                        self.state = 2001
                        if not self.precpred(self._ctx, 12):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 12)")
                        self.state = 2002
                        self.match(tsqlParser.COLLATE)
                        self.state = 2003
                        self.r_id()
                        pass

             
                self.state = 2008
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,307,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.unrollRecursionContexts(_parentctx)
        return localctx

    class Constant_expressionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NULL(self):
            return self.getToken(tsqlParser.NULL, 0)

        def constant(self):
            return self.getTypedRuleContext(tsqlParser.ConstantContext,0)


        def function_call(self):
            return self.getTypedRuleContext(tsqlParser.Function_callContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def constant_expression(self):
            return self.getTypedRuleContext(tsqlParser.Constant_expressionContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_constant_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstant_expression" ):
                listener.enterConstant_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstant_expression" ):
                listener.exitConstant_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstant_expression" ):
                return visitor.visitConstant_expression(self)
            else:
                return visitor.visitChildren(self)




    def constant_expression(self):

        localctx = tsqlParser.Constant_expressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 172, self.RULE_constant_expression)
        try:
            self.state = 2017
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.NULL]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2009
                self.match(tsqlParser.NULL)
                pass
            elif token in [tsqlParser.DECIMAL, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.PLUS, tsqlParser.MINUS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2010
                self.constant()
                pass
            elif token in [tsqlParser.COALESCE, tsqlParser.CONVERT, tsqlParser.CURRENT_TIMESTAMP, tsqlParser.CURRENT_USER, tsqlParser.FORCESEEK, tsqlParser.IDENTITY, tsqlParser.LEFT, tsqlParser.NULLIF, tsqlParser.RIGHT, tsqlParser.SESSION_USER, tsqlParser.SYSTEM_USER, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.BINARY_CHECKSUM, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DATEADD, tsqlParser.DATEDIFF, tsqlParser.DATENAME, tsqlParser.DATEPART, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MIN_ACTIVE_ROWVERSION, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 3)
                self.state = 2011
                self.function_call()
                pass
            elif token in [tsqlParser.LOCAL_ID]:
                self.enterOuterAlt(localctx, 4)
                self.state = 2012
                self.match(tsqlParser.LOCAL_ID)
                pass
            elif token in [tsqlParser.LR_BRACKET]:
                self.enterOuterAlt(localctx, 5)
                self.state = 2013
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2014
                self.constant_expression()
                self.state = 2015
                self.match(tsqlParser.RR_BRACKET)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class SubqueryContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def select_statement(self):
            return self.getTypedRuleContext(tsqlParser.Select_statementContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_subquery

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSubquery" ):
                listener.enterSubquery(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSubquery" ):
                listener.exitSubquery(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSubquery" ):
                return visitor.visitSubquery(self)
            else:
                return visitor.visitChildren(self)




    def subquery(self):

        localctx = tsqlParser.SubqueryContext(self, self._ctx, self.state)
        self.enterRule(localctx, 174, self.RULE_subquery)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2019
            self.select_statement()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class With_expressionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def common_table_expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Common_table_expressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Common_table_expressionContext,i)


        def XMLNAMESPACES(self):
            return self.getToken(tsqlParser.XMLNAMESPACES, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_with_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWith_expression" ):
                listener.enterWith_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWith_expression" ):
                listener.exitWith_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWith_expression" ):
                return visitor.visitWith_expression(self)
            else:
                return visitor.visitChildren(self)




    def with_expression(self):

        localctx = tsqlParser.With_expressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 176, self.RULE_with_expression)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2021
            self.match(tsqlParser.WITH)
            self.state = 2024
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,309,self._ctx)
            if la_ == 1:
                self.state = 2022
                self.match(tsqlParser.XMLNAMESPACES)
                self.state = 2023
                self.match(tsqlParser.COMMA)


            self.state = 2026
            self.common_table_expression()
            self.state = 2031
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2027
                self.match(tsqlParser.COMMA)
                self.state = 2028
                self.common_table_expression()
                self.state = 2033
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Common_table_expressionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.expression_name = None # R_idContext

        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def select_statement(self):
            return self.getTypedRuleContext(tsqlParser.Select_statementContext,0)


        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def column_name_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_name_listContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_common_table_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCommon_table_expression" ):
                listener.enterCommon_table_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCommon_table_expression" ):
                listener.exitCommon_table_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCommon_table_expression" ):
                return visitor.visitCommon_table_expression(self)
            else:
                return visitor.visitChildren(self)




    def common_table_expression(self):

        localctx = tsqlParser.Common_table_expressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 178, self.RULE_common_table_expression)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2034
            localctx.expression_name = self.r_id()
            self.state = 2039
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.LR_BRACKET:
                self.state = 2035
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2036
                self.column_name_list()
                self.state = 2037
                self.match(tsqlParser.RR_BRACKET)


            self.state = 2041
            self.match(tsqlParser.AS)
            self.state = 2042
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2043
            self.select_statement()
            self.state = 2044
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Update_elemContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.udt_column_name = None # R_idContext
            self.method_name = None # R_idContext

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def full_column_name(self):
            return self.getTypedRuleContext(tsqlParser.Full_column_nameContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def assignment_operator(self):
            return self.getTypedRuleContext(tsqlParser.Assignment_operatorContext,0)


        def expression_list(self):
            return self.getTypedRuleContext(tsqlParser.Expression_listContext,0)


        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_update_elem

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUpdate_elem" ):
                listener.enterUpdate_elem(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUpdate_elem" ):
                listener.exitUpdate_elem(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUpdate_elem" ):
                return visitor.visitUpdate_elem(self)
            else:
                return visitor.visitChildren(self)




    def update_elem(self):

        localctx = tsqlParser.Update_elemContext(self, self._ctx, self.state)
        self.enterRule(localctx, 180, self.RULE_update_elem)
        try:
            self.state = 2062
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,314,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2048
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 2046
                    self.full_column_name()
                    pass
                elif token in [tsqlParser.LOCAL_ID]:
                    self.state = 2047
                    self.match(tsqlParser.LOCAL_ID)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 2052
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.EQUAL]:
                    self.state = 2050
                    self.match(tsqlParser.EQUAL)
                    pass
                elif token in [tsqlParser.PLUS_ASSIGN, tsqlParser.MINUS_ASSIGN, tsqlParser.MULT_ASSIGN, tsqlParser.DIV_ASSIGN, tsqlParser.MOD_ASSIGN, tsqlParser.AND_ASSIGN, tsqlParser.XOR_ASSIGN, tsqlParser.OR_ASSIGN]:
                    self.state = 2051
                    self.assignment_operator()
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 2054
                self.expression(0)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2055
                localctx.udt_column_name = self.r_id()
                self.state = 2056
                self.match(tsqlParser.DOT)
                self.state = 2057
                localctx.method_name = self.r_id()
                self.state = 2058
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2059
                self.expression_list()
                self.state = 2060
                self.match(tsqlParser.RR_BRACKET)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Search_condition_listContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def search_condition(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Search_conditionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Search_conditionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_search_condition_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSearch_condition_list" ):
                listener.enterSearch_condition_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSearch_condition_list" ):
                listener.exitSearch_condition_list(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSearch_condition_list" ):
                return visitor.visitSearch_condition_list(self)
            else:
                return visitor.visitChildren(self)




    def search_condition_list(self):

        localctx = tsqlParser.Search_condition_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 182, self.RULE_search_condition_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2064
            self.search_condition(0)
            self.state = 2069
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2065
                self.match(tsqlParser.COMMA)
                self.state = 2066
                self.search_condition(0)
                self.state = 2071
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Search_conditionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_search_condition

     
        def copyFrom(self, ctx:ParserRuleContext):
            super().copyFrom(ctx)


    class Search_cond_andContext(Search_conditionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Search_conditionContext
            super().__init__(parser)
            self.left = None # Search_conditionContext
            self.op = None # Token
            self.right = None # Search_conditionContext
            self.copyFrom(ctx)

        def search_condition(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Search_conditionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Search_conditionContext,i)

        def AND(self):
            return self.getToken(tsqlParser.AND, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSearch_cond_and" ):
                listener.enterSearch_cond_and(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSearch_cond_and" ):
                listener.exitSearch_cond_and(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSearch_cond_and" ):
                return visitor.visitSearch_cond_and(self)
            else:
                return visitor.visitChildren(self)


    class Search_cond_predContext(Search_conditionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Search_conditionContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def predicate(self):
            return self.getTypedRuleContext(tsqlParser.PredicateContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSearch_cond_pred" ):
                listener.enterSearch_cond_pred(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSearch_cond_pred" ):
                listener.exitSearch_cond_pred(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSearch_cond_pred" ):
                return visitor.visitSearch_cond_pred(self)
            else:
                return visitor.visitChildren(self)


    class Search_cond_orContext(Search_conditionContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Search_conditionContext
            super().__init__(parser)
            self.left = None # Search_conditionContext
            self.op = None # Token
            self.right = None # Search_conditionContext
            self.copyFrom(ctx)

        def search_condition(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Search_conditionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Search_conditionContext,i)

        def OR(self):
            return self.getToken(tsqlParser.OR, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSearch_cond_or" ):
                listener.enterSearch_cond_or(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSearch_cond_or" ):
                listener.exitSearch_cond_or(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSearch_cond_or" ):
                return visitor.visitSearch_cond_or(self)
            else:
                return visitor.visitChildren(self)



    def search_condition(self, _p:int=0):
        _parentctx = self._ctx
        _parentState = self.state
        localctx = tsqlParser.Search_conditionContext(self, self._ctx, _parentState)
        _prevctx = localctx
        _startState = 184
        self.enterRecursionRule(localctx, 184, self.RULE_search_condition, _p)
        try:
            self.enterOuterAlt(localctx, 1)
            localctx = tsqlParser.Search_cond_predContext(self, localctx)
            self._ctx = localctx
            _prevctx = localctx

            self.state = 2073
            self.predicate()
            self._ctx.stop = self._input.LT(-1)
            self.state = 2083
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,317,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    if self._parseListeners is not None:
                        self.triggerExitRuleEvent()
                    _prevctx = localctx
                    self.state = 2081
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,316,self._ctx)
                    if la_ == 1:
                        localctx = tsqlParser.Search_cond_andContext(self, tsqlParser.Search_conditionContext(self, _parentctx, _parentState))
                        localctx.left = _prevctx
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_search_condition)
                        self.state = 2075
                        if not self.precpred(self._ctx, 3):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 3)")
                        self.state = 2076
                        localctx.op = self.match(tsqlParser.AND)
                        self.state = 2077
                        localctx.right = self.search_condition(4)
                        pass

                    elif la_ == 2:
                        localctx = tsqlParser.Search_cond_orContext(self, tsqlParser.Search_conditionContext(self, _parentctx, _parentState))
                        localctx.left = _prevctx
                        self.pushNewRecursionContext(localctx, _startState, self.RULE_search_condition)
                        self.state = 2078
                        if not self.precpred(self._ctx, 2):
                            from antlr4.error.Errors import FailedPredicateException
                            raise FailedPredicateException(self, "self.precpred(self._ctx, 2)")
                        self.state = 2079
                        localctx.op = self.match(tsqlParser.OR)
                        self.state = 2080
                        localctx.right = self.search_condition(3)
                        pass

             
                self.state = 2085
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,317,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.unrollRecursionContexts(_parentctx)
        return localctx

    class PredicateContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_predicate

     
        def copyFrom(self, ctx:ParserRuleContext):
            super().copyFrom(ctx)



    class Unary_operator_expression3Context(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.op = None # Token
            self.expr = None # PredicateContext
            self.copyFrom(ctx)

        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)
        def predicate(self):
            return self.getTypedRuleContext(tsqlParser.PredicateContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUnary_operator_expression3" ):
                listener.enterUnary_operator_expression3(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUnary_operator_expression3" ):
                listener.exitUnary_operator_expression3(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUnary_operator_expression3" ):
                return visitor.visitUnary_operator_expression3(self)
            else:
                return visitor.visitChildren(self)


    class Binary_in_expressionContext(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.left = None # ExpressionContext
            self.op = None # Token
            self.copyFrom(ctx)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)

        def IN(self):
            return self.getToken(tsqlParser.IN, 0)
        def subquery(self):
            return self.getTypedRuleContext(tsqlParser.SubqueryContext,0)

        def expression_list(self):
            return self.getTypedRuleContext(tsqlParser.Expression_listContext,0)

        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBinary_in_expression" ):
                listener.enterBinary_in_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBinary_in_expression" ):
                listener.exitBinary_in_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBinary_in_expression" ):
                return visitor.visitBinary_in_expression(self)
            else:
                return visitor.visitChildren(self)


    class Binary_operator_expression2Context(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.left = None # ExpressionContext
            self.op = None # Comparison_operatorContext
            self.right = None # ExpressionContext
            self.copyFrom(ctx)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)

        def comparison_operator(self):
            return self.getTypedRuleContext(tsqlParser.Comparison_operatorContext,0)

        def IS(self):
            return self.getToken(tsqlParser.IS, 0)
        def null_notnull(self):
            return self.getTypedRuleContext(tsqlParser.Null_notnullContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBinary_operator_expression2" ):
                listener.enterBinary_operator_expression2(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBinary_operator_expression2" ):
                listener.exitBinary_operator_expression2(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBinary_operator_expression2" ):
                return visitor.visitBinary_operator_expression2(self)
            else:
                return visitor.visitChildren(self)


    class Sublink_expressionContext(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.test_expr = None # ExpressionContext
            self.op = None # Comparison_operatorContext
            self.pref = None # Token
            self.copyFrom(ctx)

        def subquery(self):
            return self.getTypedRuleContext(tsqlParser.SubqueryContext,0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)

        def comparison_operator(self):
            return self.getTypedRuleContext(tsqlParser.Comparison_operatorContext,0)

        def ALL(self):
            return self.getToken(tsqlParser.ALL, 0)
        def SOME(self):
            return self.getToken(tsqlParser.SOME, 0)
        def ANY(self):
            return self.getToken(tsqlParser.ANY, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSublink_expression" ):
                listener.enterSublink_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSublink_expression" ):
                listener.exitSublink_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSublink_expression" ):
                return visitor.visitSublink_expression(self)
            else:
                return visitor.visitChildren(self)


    class Bracket_search_expressionContext(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBracket_search_expression" ):
                listener.enterBracket_search_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBracket_search_expression" ):
                listener.exitBracket_search_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBracket_search_expression" ):
                return visitor.visitBracket_search_expression(self)
            else:
                return visitor.visitChildren(self)


    class Decimal_expressionContext(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDecimal_expression" ):
                listener.enterDecimal_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDecimal_expression" ):
                listener.exitDecimal_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDecimal_expression" ):
                return visitor.visitDecimal_expression(self)
            else:
                return visitor.visitChildren(self)


    class Unary_operator_expression2Context(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.op = None # Token
            self.expr = None # SubqueryContext
            self.copyFrom(ctx)

        def EXISTS(self):
            return self.getToken(tsqlParser.EXISTS, 0)
        def subquery(self):
            return self.getTypedRuleContext(tsqlParser.SubqueryContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUnary_operator_expression2" ):
                listener.enterUnary_operator_expression2(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUnary_operator_expression2" ):
                listener.exitUnary_operator_expression2(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUnary_operator_expression2" ):
                return visitor.visitUnary_operator_expression2(self)
            else:
                return visitor.visitChildren(self)


    class Binary_mod_expressionContext(PredicateContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.PredicateContext
            super().__init__(parser)
            self.left = None # ExpressionContext
            self.op = None # Token
            self._expression = None # ExpressionContext
            self.right = list() # of ExpressionContexts
            self.copyFrom(ctx)

        def AND(self):
            return self.getToken(tsqlParser.AND, 0)
        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)

        def BETWEEN(self):
            return self.getToken(tsqlParser.BETWEEN, 0)
        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)
        def LIKE(self):
            return self.getToken(tsqlParser.LIKE, 0)
        def ESCAPE(self):
            return self.getToken(tsqlParser.ESCAPE, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBinary_mod_expression" ):
                listener.enterBinary_mod_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBinary_mod_expression" ):
                listener.exitBinary_mod_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBinary_mod_expression" ):
                return visitor.visitBinary_mod_expression(self)
            else:
                return visitor.visitChildren(self)



    def predicate(self):

        localctx = tsqlParser.PredicateContext(self, self._ctx, self.state)
        self.enterRule(localctx, 186, self.RULE_predicate)
        self._la = 0 # Token type
        try:
            self.state = 2144
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,323,self._ctx)
            if la_ == 1:
                localctx = tsqlParser.Unary_operator_expression3Context(self, localctx)
                self.enterOuterAlt(localctx, 1)
                self.state = 2086
                localctx.op = self.match(tsqlParser.NOT)
                self.state = 2087
                localctx.expr = self.predicate()
                pass

            elif la_ == 2:
                localctx = tsqlParser.Unary_operator_expression2Context(self, localctx)
                self.enterOuterAlt(localctx, 2)
                self.state = 2088
                localctx.op = self.match(tsqlParser.EXISTS)
                self.state = 2089
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2090
                localctx.expr = self.subquery()
                self.state = 2091
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 3:
                localctx = tsqlParser.Binary_operator_expression2Context(self, localctx)
                self.enterOuterAlt(localctx, 3)
                self.state = 2093
                localctx.left = self.expression(0)
                self.state = 2094
                localctx.op = self.comparison_operator()
                self.state = 2095
                localctx.right = self.expression(0)
                pass

            elif la_ == 4:
                localctx = tsqlParser.Sublink_expressionContext(self, localctx)
                self.enterOuterAlt(localctx, 4)
                self.state = 2097
                localctx.test_expr = self.expression(0)
                self.state = 2098
                localctx.op = self.comparison_operator()
                self.state = 2099
                localctx.pref = self._input.LT(1)
                _la = self._input.LA(1)
                if not(_la==tsqlParser.ALL or _la==tsqlParser.ANY or _la==tsqlParser.SOME):
                    localctx.pref = self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2100
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2101
                self.subquery()
                self.state = 2102
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 5:
                localctx = tsqlParser.Binary_mod_expressionContext(self, localctx)
                self.enterOuterAlt(localctx, 5)
                self.state = 2104
                localctx.left = self.expression(0)
                self.state = 2106
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.NOT:
                    self.state = 2105
                    self.match(tsqlParser.NOT)


                self.state = 2108
                localctx.op = self.match(tsqlParser.BETWEEN)
                self.state = 2109
                localctx._expression = self.expression(0)
                localctx.right.append(localctx._expression)
                self.state = 2110
                self.match(tsqlParser.AND)
                self.state = 2111
                localctx._expression = self.expression(0)
                localctx.right.append(localctx._expression)
                pass

            elif la_ == 6:
                localctx = tsqlParser.Binary_in_expressionContext(self, localctx)
                self.enterOuterAlt(localctx, 6)
                self.state = 2113
                localctx.left = self.expression(0)
                self.state = 2115
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.NOT:
                    self.state = 2114
                    self.match(tsqlParser.NOT)


                self.state = 2117
                localctx.op = self.match(tsqlParser.IN)
                self.state = 2118
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2121
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,320,self._ctx)
                if la_ == 1:
                    self.state = 2119
                    self.subquery()
                    pass

                elif la_ == 2:
                    self.state = 2120
                    self.expression_list()
                    pass


                self.state = 2123
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 7:
                localctx = tsqlParser.Binary_mod_expressionContext(self, localctx)
                self.enterOuterAlt(localctx, 7)
                self.state = 2125
                localctx.left = self.expression(0)
                self.state = 2127
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.NOT:
                    self.state = 2126
                    self.match(tsqlParser.NOT)


                self.state = 2129
                localctx.op = self.match(tsqlParser.LIKE)
                self.state = 2130
                localctx._expression = self.expression(0)
                localctx.right.append(localctx._expression)
                self.state = 2133
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,322,self._ctx)
                if la_ == 1:
                    self.state = 2131
                    self.match(tsqlParser.ESCAPE)
                    self.state = 2132
                    localctx._expression = self.expression(0)
                    localctx.right.append(localctx._expression)


                pass

            elif la_ == 8:
                localctx = tsqlParser.Binary_operator_expression2Context(self, localctx)
                self.enterOuterAlt(localctx, 8)
                self.state = 2135
                self.expression(0)
                self.state = 2136
                self.match(tsqlParser.IS)
                self.state = 2137
                self.null_notnull()
                pass

            elif la_ == 9:
                localctx = tsqlParser.Bracket_search_expressionContext(self, localctx)
                self.enterOuterAlt(localctx, 9)
                self.state = 2139
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2140
                self.search_condition(0)
                self.state = 2141
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 10:
                localctx = tsqlParser.Decimal_expressionContext(self, localctx)
                self.enterOuterAlt(localctx, 10)
                self.state = 2143
                self.match(tsqlParser.DECIMAL)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Query_expressionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def query_specification(self):
            return self.getTypedRuleContext(tsqlParser.Query_specificationContext,0)


        def query_expression(self):
            return self.getTypedRuleContext(tsqlParser.Query_expressionContext,0)


        def union(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.UnionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.UnionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_query_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterQuery_expression" ):
                listener.enterQuery_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitQuery_expression" ):
                listener.exitQuery_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitQuery_expression" ):
                return visitor.visitQuery_expression(self)
            else:
                return visitor.visitChildren(self)




    def query_expression(self):

        localctx = tsqlParser.Query_expressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 188, self.RULE_query_expression)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2151
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.SELECT]:
                self.state = 2146
                self.query_specification()
                pass
            elif token in [tsqlParser.LR_BRACKET]:
                self.state = 2147
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2148
                self.query_expression()
                self.state = 2149
                self.match(tsqlParser.RR_BRACKET)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 2156
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,325,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 2153
                    self.union() 
                self.state = 2158
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,325,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class UnionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def UNION(self):
            return self.getToken(tsqlParser.UNION, 0)

        def EXCEPT(self):
            return self.getToken(tsqlParser.EXCEPT, 0)

        def INTERSECT(self):
            return self.getToken(tsqlParser.INTERSECT, 0)

        def query_specification(self):
            return self.getTypedRuleContext(tsqlParser.Query_specificationContext,0)


        def ALL(self):
            return self.getToken(tsqlParser.ALL, 0)

        def query_expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Query_expressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Query_expressionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_union

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUnion" ):
                listener.enterUnion(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUnion" ):
                listener.exitUnion(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitUnion" ):
                return visitor.visitUnion(self)
            else:
                return visitor.visitChildren(self)




    def union(self):

        localctx = tsqlParser.UnionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 190, self.RULE_union)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2165
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.UNION]:
                self.state = 2159
                self.match(tsqlParser.UNION)
                self.state = 2161
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ALL:
                    self.state = 2160
                    self.match(tsqlParser.ALL)


                pass
            elif token in [tsqlParser.EXCEPT]:
                self.state = 2163
                self.match(tsqlParser.EXCEPT)
                pass
            elif token in [tsqlParser.INTERSECT]:
                self.state = 2164
                self.match(tsqlParser.INTERSECT)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 2176
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.SELECT]:
                self.state = 2167
                self.query_specification()
                pass
            elif token in [tsqlParser.LR_BRACKET]:
                self.state = 2172 
                self._errHandler.sync(self)
                _alt = 1
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt == 1:
                        self.state = 2168
                        self.match(tsqlParser.LR_BRACKET)
                        self.state = 2169
                        self.query_expression()
                        self.state = 2170
                        self.match(tsqlParser.RR_BRACKET)

                    else:
                        raise NoViableAltException(self)
                    self.state = 2174 
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,328,self._ctx)

                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Query_specificationContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.pref = None # Token
            self.where = None # Search_conditionContext
            self.having = None # Search_conditionContext

        def SELECT(self):
            return self.getToken(tsqlParser.SELECT, 0)

        def select_list(self):
            return self.getTypedRuleContext(tsqlParser.Select_listContext,0)


        def top_clause(self):
            return self.getTypedRuleContext(tsqlParser.Top_clauseContext,0)


        def INTO(self):
            return self.getToken(tsqlParser.INTO, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def FROM(self):
            return self.getToken(tsqlParser.FROM, 0)

        def table_sources(self):
            return self.getTypedRuleContext(tsqlParser.Table_sourcesContext,0)


        def WHERE(self):
            return self.getToken(tsqlParser.WHERE, 0)

        def GROUP(self):
            return self.getToken(tsqlParser.GROUP, 0)

        def BY(self):
            return self.getToken(tsqlParser.BY, 0)

        def group_by_item(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Group_by_itemContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Group_by_itemContext,i)


        def HAVING(self):
            return self.getToken(tsqlParser.HAVING, 0)

        def search_condition(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Search_conditionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Search_conditionContext,i)


        def ALL(self):
            return self.getToken(tsqlParser.ALL, 0)

        def DISTINCT(self):
            return self.getToken(tsqlParser.DISTINCT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_query_specification

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterQuery_specification" ):
                listener.enterQuery_specification(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitQuery_specification" ):
                listener.exitQuery_specification(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitQuery_specification" ):
                return visitor.visitQuery_specification(self)
            else:
                return visitor.visitChildren(self)




    def query_specification(self):

        localctx = tsqlParser.Query_specificationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 192, self.RULE_query_specification)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2178
            self.match(tsqlParser.SELECT)
            self.state = 2180
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ALL or _la==tsqlParser.DISTINCT:
                self.state = 2179
                localctx.pref = self._input.LT(1)
                _la = self._input.LA(1)
                if not(_la==tsqlParser.ALL or _la==tsqlParser.DISTINCT):
                    localctx.pref = self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


            self.state = 2183
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.TOP:
                self.state = 2182
                self.top_clause()


            self.state = 2185
            self.select_list()
            self.state = 2188
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.INTO:
                self.state = 2186
                self.match(tsqlParser.INTO)
                self.state = 2187
                self.table_name()


            self.state = 2192
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FROM:
                self.state = 2190
                self.match(tsqlParser.FROM)
                self.state = 2191
                self.table_sources()


            self.state = 2196
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,334,self._ctx)
            if la_ == 1:
                self.state = 2194
                self.match(tsqlParser.WHERE)
                self.state = 2195
                localctx.where = self.search_condition(0)


            self.state = 2208
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,336,self._ctx)
            if la_ == 1:
                self.state = 2198
                self.match(tsqlParser.GROUP)
                self.state = 2199
                self.match(tsqlParser.BY)
                self.state = 2200
                self.group_by_item()
                self.state = 2205
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,335,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 2201
                        self.match(tsqlParser.COMMA)
                        self.state = 2202
                        self.group_by_item() 
                    self.state = 2207
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,335,self._ctx)



            self.state = 2212
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,337,self._ctx)
            if la_ == 1:
                self.state = 2210
                self.match(tsqlParser.HAVING)
                self.state = 2211
                localctx.having = self.search_condition(0)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Top_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TOP(self):
            return self.getToken(tsqlParser.TOP, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def PERCENT(self):
            return self.getToken(tsqlParser.PERCENT, 0)

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def TIES(self):
            return self.getToken(tsqlParser.TIES, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_top_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTop_clause" ):
                listener.enterTop_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTop_clause" ):
                listener.exitTop_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTop_clause" ):
                return visitor.visitTop_clause(self)
            else:
                return visitor.visitChildren(self)




    def top_clause(self):

        localctx = tsqlParser.Top_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 194, self.RULE_top_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2214
            self.match(tsqlParser.TOP)
            self.state = 2215
            self.expression(0)
            self.state = 2217
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.PERCENT:
                self.state = 2216
                self.match(tsqlParser.PERCENT)


            self.state = 2221
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 2219
                self.match(tsqlParser.WITH)
                self.state = 2220
                self.match(tsqlParser.TIES)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Order_by_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ORDER(self):
            return self.getToken(tsqlParser.ORDER, 0)

        def BY(self):
            return self.getToken(tsqlParser.BY, 0)

        def order_by_expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Order_by_expressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Order_by_expressionContext,i)


        def OFFSET(self):
            return self.getToken(tsqlParser.OFFSET, 0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)


        def ROW(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.ROW)
            else:
                return self.getToken(tsqlParser.ROW, i)

        def ROWS(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.ROWS)
            else:
                return self.getToken(tsqlParser.ROWS, i)

        def FETCH(self):
            return self.getToken(tsqlParser.FETCH, 0)

        def ONLY(self):
            return self.getToken(tsqlParser.ONLY, 0)

        def FIRST(self):
            return self.getToken(tsqlParser.FIRST, 0)

        def NEXT(self):
            return self.getToken(tsqlParser.NEXT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_order_by_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOrder_by_clause" ):
                listener.enterOrder_by_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOrder_by_clause" ):
                listener.exitOrder_by_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOrder_by_clause" ):
                return visitor.visitOrder_by_clause(self)
            else:
                return visitor.visitChildren(self)




    def order_by_clause(self):

        localctx = tsqlParser.Order_by_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 196, self.RULE_order_by_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2223
            self.match(tsqlParser.ORDER)
            self.state = 2224
            self.match(tsqlParser.BY)
            self.state = 2225
            self.order_by_expression()
            self.state = 2230
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,340,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 2226
                    self.match(tsqlParser.COMMA)
                    self.state = 2227
                    self.order_by_expression() 
                self.state = 2232
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,340,self._ctx)

            self.state = 2244
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,342,self._ctx)
            if la_ == 1:
                self.state = 2233
                self.match(tsqlParser.OFFSET)
                self.state = 2234
                self.expression(0)
                self.state = 2235
                _la = self._input.LA(1)
                if not(_la==tsqlParser.ROW or _la==tsqlParser.ROWS):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2242
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,341,self._ctx)
                if la_ == 1:
                    self.state = 2236
                    self.match(tsqlParser.FETCH)
                    self.state = 2237
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.FIRST or _la==tsqlParser.NEXT):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 2238
                    self.expression(0)
                    self.state = 2239
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.ROW or _la==tsqlParser.ROWS):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 2240
                    self.match(tsqlParser.ONLY)




        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class For_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def BROWSE(self):
            return self.getToken(tsqlParser.BROWSE, 0)

        def XML(self):
            return self.getToken(tsqlParser.XML, 0)

        def AUTO(self):
            return self.getToken(tsqlParser.AUTO, 0)

        def xml_common_directives(self):
            return self.getTypedRuleContext(tsqlParser.Xml_common_directivesContext,0)


        def PATH(self):
            return self.getToken(tsqlParser.PATH, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_for_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFor_clause" ):
                listener.enterFor_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFor_clause" ):
                listener.exitFor_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFor_clause" ):
                return visitor.visitFor_clause(self)
            else:
                return visitor.visitChildren(self)




    def for_clause(self):

        localctx = tsqlParser.For_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 198, self.RULE_for_clause)
        try:
            self.state = 2265
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,346,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2246
                self.match(tsqlParser.FOR)
                self.state = 2247
                self.match(tsqlParser.BROWSE)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2248
                self.match(tsqlParser.FOR)
                self.state = 2249
                self.match(tsqlParser.XML)
                self.state = 2250
                self.match(tsqlParser.AUTO)
                self.state = 2252
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,343,self._ctx)
                if la_ == 1:
                    self.state = 2251
                    self.xml_common_directives()


                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 2254
                self.match(tsqlParser.FOR)
                self.state = 2255
                self.match(tsqlParser.XML)
                self.state = 2256
                self.match(tsqlParser.PATH)
                self.state = 2260
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,344,self._ctx)
                if la_ == 1:
                    self.state = 2257
                    self.match(tsqlParser.LR_BRACKET)
                    self.state = 2258
                    self.match(tsqlParser.STRING)
                    self.state = 2259
                    self.match(tsqlParser.RR_BRACKET)


                self.state = 2263
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,345,self._ctx)
                if la_ == 1:
                    self.state = 2262
                    self.xml_common_directives()


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Xml_common_directivesContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BINARY(self):
            return self.getToken(tsqlParser.BINARY, 0)

        def BASE64(self):
            return self.getToken(tsqlParser.BASE64, 0)

        def TYPE(self):
            return self.getToken(tsqlParser.TYPE, 0)

        def ROOT(self):
            return self.getToken(tsqlParser.ROOT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_xml_common_directives

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXml_common_directives" ):
                listener.enterXml_common_directives(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXml_common_directives" ):
                listener.exitXml_common_directives(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitXml_common_directives" ):
                return visitor.visitXml_common_directives(self)
            else:
                return visitor.visitChildren(self)




    def xml_common_directives(self):

        localctx = tsqlParser.Xml_common_directivesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 200, self.RULE_xml_common_directives)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2267
            self.match(tsqlParser.COMMA)
            self.state = 2272
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.BINARY]:
                self.state = 2268
                self.match(tsqlParser.BINARY)
                self.state = 2269
                self.match(tsqlParser.BASE64)
                pass
            elif token in [tsqlParser.TYPE]:
                self.state = 2270
                self.match(tsqlParser.TYPE)
                pass
            elif token in [tsqlParser.ROOT]:
                self.state = 2271
                self.match(tsqlParser.ROOT)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Order_by_expressionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def ASC(self):
            return self.getToken(tsqlParser.ASC, 0)

        def DESC(self):
            return self.getToken(tsqlParser.DESC, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_order_by_expression

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOrder_by_expression" ):
                listener.enterOrder_by_expression(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOrder_by_expression" ):
                listener.exitOrder_by_expression(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOrder_by_expression" ):
                return visitor.visitOrder_by_expression(self)
            else:
                return visitor.visitChildren(self)




    def order_by_expression(self):

        localctx = tsqlParser.Order_by_expressionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 202, self.RULE_order_by_expression)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2274
            self.expression(0)
            self.state = 2276
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ASC or _la==tsqlParser.DESC:
                self.state = 2275
                _la = self._input.LA(1)
                if not(_la==tsqlParser.ASC or _la==tsqlParser.DESC):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Group_by_itemContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_group_by_item

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGroup_by_item" ):
                listener.enterGroup_by_item(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGroup_by_item" ):
                listener.exitGroup_by_item(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGroup_by_item" ):
                return visitor.visitGroup_by_item(self)
            else:
                return visitor.visitChildren(self)




    def group_by_item(self):

        localctx = tsqlParser.Group_by_itemContext(self, self._ctx, self.state)
        self.enterRule(localctx, 204, self.RULE_group_by_item)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2278
            self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Option_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OPTION(self):
            return self.getToken(tsqlParser.OPTION, 0)

        def option(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.OptionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.OptionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_option_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOption_clause" ):
                listener.enterOption_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOption_clause" ):
                listener.exitOption_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOption_clause" ):
                return visitor.visitOption_clause(self)
            else:
                return visitor.visitChildren(self)




    def option_clause(self):

        localctx = tsqlParser.Option_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 206, self.RULE_option_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2280
            self.match(tsqlParser.OPTION)
            self.state = 2281
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2282
            self.option()
            self.state = 2287
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2283
                self.match(tsqlParser.COMMA)
                self.state = 2284
                self.option()
                self.state = 2289
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 2290
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class OptionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.number_rows = None # Token
            self.number_of_processors = None # Token
            self.number_recursion = None # Token

        def FAST(self):
            return self.getToken(tsqlParser.FAST, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def GROUP(self):
            return self.getToken(tsqlParser.GROUP, 0)

        def HASH(self):
            return self.getToken(tsqlParser.HASH, 0)

        def ORDER(self):
            return self.getToken(tsqlParser.ORDER, 0)

        def UNION(self):
            return self.getToken(tsqlParser.UNION, 0)

        def MERGE(self):
            return self.getToken(tsqlParser.MERGE, 0)

        def CONCAT(self):
            return self.getToken(tsqlParser.CONCAT, 0)

        def JOIN(self):
            return self.getToken(tsqlParser.JOIN, 0)

        def LOOP(self):
            return self.getToken(tsqlParser.LOOP, 0)

        def EXPAND(self):
            return self.getToken(tsqlParser.EXPAND, 0)

        def VIEWS(self):
            return self.getToken(tsqlParser.VIEWS, 0)

        def FORCE(self):
            return self.getToken(tsqlParser.FORCE, 0)

        def IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX(self):
            return self.getToken(tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, 0)

        def KEEP(self):
            return self.getToken(tsqlParser.KEEP, 0)

        def PLAN(self):
            return self.getToken(tsqlParser.PLAN, 0)

        def KEEPFIXED(self):
            return self.getToken(tsqlParser.KEEPFIXED, 0)

        def MAXDOP(self):
            return self.getToken(tsqlParser.MAXDOP, 0)

        def MAXRECURSION(self):
            return self.getToken(tsqlParser.MAXRECURSION, 0)

        def OPTIMIZE(self):
            return self.getToken(tsqlParser.OPTIMIZE, 0)

        def FOR(self):
            return self.getToken(tsqlParser.FOR, 0)

        def optimize_for_arg(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Optimize_for_argContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Optimize_for_argContext,i)


        def UNKNOWN(self):
            return self.getToken(tsqlParser.UNKNOWN, 0)

        def PARAMETERIZATION(self):
            return self.getToken(tsqlParser.PARAMETERIZATION, 0)

        def SIMPLE(self):
            return self.getToken(tsqlParser.SIMPLE, 0)

        def FORCED(self):
            return self.getToken(tsqlParser.FORCED, 0)

        def RECOMPILE(self):
            return self.getToken(tsqlParser.RECOMPILE, 0)

        def ROBUST(self):
            return self.getToken(tsqlParser.ROBUST, 0)

        def USE(self):
            return self.getToken(tsqlParser.USE, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOption" ):
                listener.enterOption(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOption" ):
                listener.exitOption(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOption" ):
                return visitor.visitOption(self)
            else:
                return visitor.visitChildren(self)




    def option(self):

        localctx = tsqlParser.OptionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 208, self.RULE_option)
        self._la = 0 # Token type
        try:
            self.state = 2337
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,351,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2292
                self.match(tsqlParser.FAST)
                self.state = 2293
                localctx.number_rows = self.match(tsqlParser.DECIMAL)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2294
                _la = self._input.LA(1)
                if not(_la==tsqlParser.ORDER or _la==tsqlParser.HASH):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2295
                self.match(tsqlParser.GROUP)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 2296
                _la = self._input.LA(1)
                if not(_la==tsqlParser.MERGE or _la==tsqlParser.CONCAT or _la==tsqlParser.HASH):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2297
                self.match(tsqlParser.UNION)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 2298
                _la = self._input.LA(1)
                if not(_la==tsqlParser.MERGE or _la==tsqlParser.HASH or _la==tsqlParser.LOOP):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2299
                self.match(tsqlParser.JOIN)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 2300
                self.match(tsqlParser.EXPAND)
                self.state = 2301
                self.match(tsqlParser.VIEWS)
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 2302
                self.match(tsqlParser.FORCE)
                self.state = 2303
                self.match(tsqlParser.ORDER)
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 2304
                self.match(tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX)
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 2305
                self.match(tsqlParser.KEEP)
                self.state = 2306
                self.match(tsqlParser.PLAN)
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 2307
                self.match(tsqlParser.KEEPFIXED)
                self.state = 2308
                self.match(tsqlParser.PLAN)
                pass

            elif la_ == 10:
                self.enterOuterAlt(localctx, 10)
                self.state = 2309
                self.match(tsqlParser.MAXDOP)
                self.state = 2310
                localctx.number_of_processors = self.match(tsqlParser.DECIMAL)
                pass

            elif la_ == 11:
                self.enterOuterAlt(localctx, 11)
                self.state = 2311
                self.match(tsqlParser.MAXRECURSION)
                self.state = 2312
                localctx.number_recursion = self.match(tsqlParser.DECIMAL)
                pass

            elif la_ == 12:
                self.enterOuterAlt(localctx, 12)
                self.state = 2313
                self.match(tsqlParser.OPTIMIZE)
                self.state = 2314
                self.match(tsqlParser.FOR)
                self.state = 2315
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2316
                self.optimize_for_arg()
                self.state = 2321
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 2317
                    self.match(tsqlParser.COMMA)
                    self.state = 2318
                    self.optimize_for_arg()
                    self.state = 2323
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 2324
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 13:
                self.enterOuterAlt(localctx, 13)
                self.state = 2326
                self.match(tsqlParser.OPTIMIZE)
                self.state = 2327
                self.match(tsqlParser.FOR)
                self.state = 2328
                self.match(tsqlParser.UNKNOWN)
                pass

            elif la_ == 14:
                self.enterOuterAlt(localctx, 14)
                self.state = 2329
                self.match(tsqlParser.PARAMETERIZATION)
                self.state = 2330
                _la = self._input.LA(1)
                if not(_la==tsqlParser.FORCED or _la==tsqlParser.SIMPLE):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass

            elif la_ == 15:
                self.enterOuterAlt(localctx, 15)
                self.state = 2331
                self.match(tsqlParser.RECOMPILE)
                pass

            elif la_ == 16:
                self.enterOuterAlt(localctx, 16)
                self.state = 2332
                self.match(tsqlParser.ROBUST)
                self.state = 2333
                self.match(tsqlParser.PLAN)
                pass

            elif la_ == 17:
                self.enterOuterAlt(localctx, 17)
                self.state = 2334
                self.match(tsqlParser.USE)
                self.state = 2335
                self.match(tsqlParser.PLAN)
                self.state = 2336
                self.match(tsqlParser.STRING)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Optimize_for_argContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def UNKNOWN(self):
            return self.getToken(tsqlParser.UNKNOWN, 0)

        def constant(self):
            return self.getTypedRuleContext(tsqlParser.ConstantContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_optimize_for_arg

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOptimize_for_arg" ):
                listener.enterOptimize_for_arg(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOptimize_for_arg" ):
                listener.exitOptimize_for_arg(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOptimize_for_arg" ):
                return visitor.visitOptimize_for_arg(self)
            else:
                return visitor.visitChildren(self)




    def optimize_for_arg(self):

        localctx = tsqlParser.Optimize_for_argContext(self, self._ctx, self.state)
        self.enterRule(localctx, 210, self.RULE_optimize_for_arg)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2339
            self.match(tsqlParser.LOCAL_ID)
            self.state = 2343
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.UNKNOWN]:
                self.state = 2340
                self.match(tsqlParser.UNKNOWN)
                pass
            elif token in [tsqlParser.EQUAL]:
                self.state = 2341
                self.match(tsqlParser.EQUAL)
                self.state = 2342
                self.constant()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Select_listContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def select_list_elem(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Select_list_elemContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Select_list_elemContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_select_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSelect_list" ):
                listener.enterSelect_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSelect_list" ):
                listener.exitSelect_list(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSelect_list" ):
                return visitor.visitSelect_list(self)
            else:
                return visitor.visitChildren(self)




    def select_list(self):

        localctx = tsqlParser.Select_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 212, self.RULE_select_list)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2345
            self.select_list_elem()
            self.state = 2350
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,353,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 2346
                    self.match(tsqlParser.COMMA)
                    self.state = 2347
                    self.select_list_elem() 
                self.state = 2352
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,353,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Select_list_elemContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.alias = None # Column_aliasContext

        def a_star(self):
            return self.getTypedRuleContext(tsqlParser.A_starContext,0)


        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def IDENTITY(self):
            return self.getToken(tsqlParser.IDENTITY, 0)

        def ROWGUID(self):
            return self.getToken(tsqlParser.ROWGUID, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def column_alias(self):
            return self.getTypedRuleContext(tsqlParser.Column_aliasContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_select_list_elem

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSelect_list_elem" ):
                listener.enterSelect_list_elem(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSelect_list_elem" ):
                listener.exitSelect_list_elem(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSelect_list_elem" ):
                return visitor.visitSelect_list_elem(self)
            else:
                return visitor.visitChildren(self)




    def select_list_elem(self):

        localctx = tsqlParser.Select_list_elemContext(self, self._ctx, self.state)
        self.enterRule(localctx, 214, self.RULE_select_list_elem)
        self._la = 0 # Token type
        try:
            self.state = 2374
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,358,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2356
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                    self.state = 2353
                    self.table_name()
                    self.state = 2354
                    self.match(tsqlParser.DOT)


                self.state = 2361
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.STAR]:
                    self.state = 2358
                    self.a_star()
                    pass
                elif token in [tsqlParser.DOLLAR]:
                    self.state = 2359
                    self.match(tsqlParser.DOLLAR)
                    self.state = 2360
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.IDENTITY or _la==tsqlParser.ROWGUID):
                        self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    pass
                else:
                    raise NoViableAltException(self)

                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2363
                localctx.alias = self.column_alias()
                self.state = 2364
                self.match(tsqlParser.EQUAL)
                self.state = 2365
                self.expression(0)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 2367
                self.expression(0)
                self.state = 2372
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,357,self._ctx)
                if la_ == 1:
                    self.state = 2369
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.AS:
                        self.state = 2368
                        self.match(tsqlParser.AS)


                    self.state = 2371
                    localctx.alias = self.column_alias()


                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_sourcesContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_source(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Table_sourceContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Table_sourceContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_sources

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_sources" ):
                listener.enterTable_sources(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_sources" ):
                listener.exitTable_sources(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_sources" ):
                return visitor.visitTable_sources(self)
            else:
                return visitor.visitChildren(self)




    def table_sources(self):

        localctx = tsqlParser.Table_sourcesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 216, self.RULE_table_sources)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2376
            self.table_source()
            self.state = 2381
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,359,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 2377
                    self.match(tsqlParser.COMMA)
                    self.state = 2378
                    self.table_source() 
                self.state = 2383
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,359,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_sourceContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_source_item_joined(self):
            return self.getTypedRuleContext(tsqlParser.Table_source_item_joinedContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_source

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_source" ):
                listener.enterTable_source(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_source" ):
                listener.exitTable_source(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_source" ):
                return visitor.visitTable_source(self)
            else:
                return visitor.visitChildren(self)




    def table_source(self):

        localctx = tsqlParser.Table_sourceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 218, self.RULE_table_source)
        try:
            self.state = 2389
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,360,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2384
                self.table_source_item_joined()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2385
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2386
                self.table_source_item_joined()
                self.state = 2387
                self.match(tsqlParser.RR_BRACKET)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_source_item_joinedContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_source_item(self):
            return self.getTypedRuleContext(tsqlParser.Table_source_itemContext,0)


        def join_part(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Join_partContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Join_partContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_source_item_joined

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_source_item_joined" ):
                listener.enterTable_source_item_joined(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_source_item_joined" ):
                listener.exitTable_source_item_joined(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_source_item_joined" ):
                return visitor.visitTable_source_item_joined(self)
            else:
                return visitor.visitChildren(self)




    def table_source_item_joined(self):

        localctx = tsqlParser.Table_source_item_joinedContext(self, self._ctx, self.state)
        self.enterRule(localctx, 220, self.RULE_table_source_item_joined)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2391
            self.table_source_item()
            self.state = 2395
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,361,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 2392
                    self.join_part() 
                self.state = 2397
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,361,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_source_itemContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_name_with_hint(self):
            return self.getTypedRuleContext(tsqlParser.Table_name_with_hintContext,0)


        def as_table_alias(self):
            return self.getTypedRuleContext(tsqlParser.As_table_aliasContext,0)


        def rowset_function(self):
            return self.getTypedRuleContext(tsqlParser.Rowset_functionContext,0)


        def derived_table(self):
            return self.getTypedRuleContext(tsqlParser.Derived_tableContext,0)


        def column_alias_list(self):
            return self.getTypedRuleContext(tsqlParser.Column_alias_listContext,0)


        def change_table(self):
            return self.getTypedRuleContext(tsqlParser.Change_tableContext,0)


        def function_call(self):
            return self.getTypedRuleContext(tsqlParser.Function_callContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_table_source_item

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_source_item" ):
                listener.enterTable_source_item(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_source_item" ):
                listener.exitTable_source_item(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_source_item" ):
                return visitor.visitTable_source_item(self)
            else:
                return visitor.visitChildren(self)




    def table_source_item(self):

        localctx = tsqlParser.Table_source_itemContext(self, self._ctx, self.state)
        self.enterRule(localctx, 222, self.RULE_table_source_item)
        try:
            self.state = 2433
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,370,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2398
                self.table_name_with_hint()
                self.state = 2400
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,362,self._ctx)
                if la_ == 1:
                    self.state = 2399
                    self.as_table_alias()


                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2402
                self.rowset_function()
                self.state = 2404
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,363,self._ctx)
                if la_ == 1:
                    self.state = 2403
                    self.as_table_alias()


                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 2406
                self.derived_table()
                self.state = 2411
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,365,self._ctx)
                if la_ == 1:
                    self.state = 2407
                    self.as_table_alias()
                    self.state = 2409
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,364,self._ctx)
                    if la_ == 1:
                        self.state = 2408
                        self.column_alias_list()




                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 2413
                self.change_table()
                self.state = 2414
                self.as_table_alias()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 2416
                self.function_call()
                self.state = 2418
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,366,self._ctx)
                if la_ == 1:
                    self.state = 2417
                    self.as_table_alias()


                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 2420
                self.match(tsqlParser.LOCAL_ID)
                self.state = 2422
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,367,self._ctx)
                if la_ == 1:
                    self.state = 2421
                    self.as_table_alias()


                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 2424
                self.match(tsqlParser.LOCAL_ID)
                self.state = 2425
                self.match(tsqlParser.DOT)
                self.state = 2426
                self.function_call()
                self.state = 2431
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,369,self._ctx)
                if la_ == 1:
                    self.state = 2427
                    self.as_table_alias()
                    self.state = 2429
                    self._errHandler.sync(self)
                    la_ = self._interp.adaptivePredict(self._input,368,self._ctx)
                    if la_ == 1:
                        self.state = 2428
                        self.column_alias_list()




                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Change_tableContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CHANGETABLE(self):
            return self.getToken(tsqlParser.CHANGETABLE, 0)

        def CHANGES(self):
            return self.getToken(tsqlParser.CHANGES, 0)

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def NULL(self):
            return self.getToken(tsqlParser.NULL, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_change_table

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterChange_table" ):
                listener.enterChange_table(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitChange_table" ):
                listener.exitChange_table(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitChange_table" ):
                return visitor.visitChange_table(self)
            else:
                return visitor.visitChildren(self)




    def change_table(self):

        localctx = tsqlParser.Change_tableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 224, self.RULE_change_table)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2435
            self.match(tsqlParser.CHANGETABLE)
            self.state = 2436
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2437
            self.match(tsqlParser.CHANGES)
            self.state = 2438
            self.table_name()
            self.state = 2439
            self.match(tsqlParser.COMMA)
            self.state = 2440
            _la = self._input.LA(1)
            if not(_la==tsqlParser.NULL or _la==tsqlParser.LOCAL_ID or _la==tsqlParser.DECIMAL):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 2441
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Join_partContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.join_type = None # Token
            self.join_hint = None # Token

        def JOIN(self):
            return self.getToken(tsqlParser.JOIN, 0)

        def table_source(self):
            return self.getTypedRuleContext(tsqlParser.Table_sourceContext,0)


        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)


        def LEFT(self):
            return self.getToken(tsqlParser.LEFT, 0)

        def RIGHT(self):
            return self.getToken(tsqlParser.RIGHT, 0)

        def FULL(self):
            return self.getToken(tsqlParser.FULL, 0)

        def INNER(self):
            return self.getToken(tsqlParser.INNER, 0)

        def OUTER(self):
            return self.getToken(tsqlParser.OUTER, 0)

        def LOOP(self):
            return self.getToken(tsqlParser.LOOP, 0)

        def HASH(self):
            return self.getToken(tsqlParser.HASH, 0)

        def MERGE(self):
            return self.getToken(tsqlParser.MERGE, 0)

        def REMOTE(self):
            return self.getToken(tsqlParser.REMOTE, 0)

        def CROSS(self):
            return self.getToken(tsqlParser.CROSS, 0)

        def APPLY(self):
            return self.getToken(tsqlParser.APPLY, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_join_part

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterJoin_part" ):
                listener.enterJoin_part(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitJoin_part" ):
                listener.exitJoin_part(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitJoin_part" ):
                return visitor.visitJoin_part(self)
            else:
                return visitor.visitChildren(self)




    def join_part(self):

        localctx = tsqlParser.Join_partContext(self, self._ctx, self.state)
        self.enterRule(localctx, 226, self.RULE_join_part)
        self._la = 0 # Token type
        try:
            self.state = 2469
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,375,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2450
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.INNER, tsqlParser.JOIN, tsqlParser.MERGE, tsqlParser.HASH, tsqlParser.LOOP, tsqlParser.REMOTE]:
                    self.state = 2444
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.INNER:
                        self.state = 2443
                        self.match(tsqlParser.INNER)


                    pass
                elif token in [tsqlParser.FULL, tsqlParser.LEFT, tsqlParser.RIGHT]:
                    self.state = 2446
                    localctx.join_type = self._input.LT(1)
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.FULL or _la==tsqlParser.LEFT or _la==tsqlParser.RIGHT):
                        localctx.join_type = self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()
                    self.state = 2448
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.OUTER:
                        self.state = 2447
                        self.match(tsqlParser.OUTER)


                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 2453
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.MERGE or _la==tsqlParser.HASH or _la==tsqlParser.LOOP or _la==tsqlParser.REMOTE:
                    self.state = 2452
                    localctx.join_hint = self._input.LT(1)
                    _la = self._input.LA(1)
                    if not(_la==tsqlParser.MERGE or _la==tsqlParser.HASH or _la==tsqlParser.LOOP or _la==tsqlParser.REMOTE):
                        localctx.join_hint = self._errHandler.recoverInline(self)
                    else:
                        self._errHandler.reportMatch(self)
                        self.consume()


                self.state = 2455
                self.match(tsqlParser.JOIN)
                self.state = 2456
                self.table_source()
                self.state = 2457
                self.match(tsqlParser.ON)
                self.state = 2458
                self.search_condition(0)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2460
                self.match(tsqlParser.CROSS)
                self.state = 2461
                self.match(tsqlParser.JOIN)
                self.state = 2462
                self.table_source()
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 2463
                self.match(tsqlParser.CROSS)
                self.state = 2464
                self.match(tsqlParser.APPLY)
                self.state = 2465
                self.table_source()
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 2466
                self.match(tsqlParser.OUTER)
                self.state = 2467
                self.match(tsqlParser.APPLY)
                self.state = 2468
                self.table_source()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_name_with_hintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def with_table_hints(self):
            return self.getTypedRuleContext(tsqlParser.With_table_hintsContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_name_with_hint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_name_with_hint" ):
                listener.enterTable_name_with_hint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_name_with_hint" ):
                listener.exitTable_name_with_hint(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_name_with_hint" ):
                return visitor.visitTable_name_with_hint(self)
            else:
                return visitor.visitChildren(self)




    def table_name_with_hint(self):

        localctx = tsqlParser.Table_name_with_hintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 228, self.RULE_table_name_with_hint)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2471
            self.table_name()
            self.state = 2473
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,376,self._ctx)
            if la_ == 1:
                self.state = 2472
                self.with_table_hints()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Rowset_functionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.provider_name = None # Token
            self.connectionString = None # Token
            self.sql = None # Token
            self.data_file = None # Token

        def OPENROWSET(self):
            return self.getToken(tsqlParser.OPENROWSET, 0)

        def LR_BRACKET(self):
            return self.getToken(tsqlParser.LR_BRACKET, 0)

        def COMMA(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.COMMA)
            else:
                return self.getToken(tsqlParser.COMMA, i)

        def RR_BRACKET(self):
            return self.getToken(tsqlParser.RR_BRACKET, 0)

        def STRING(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.STRING)
            else:
                return self.getToken(tsqlParser.STRING, i)

        def BULK(self):
            return self.getToken(tsqlParser.BULK, 0)

        def bulk_option(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Bulk_optionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Bulk_optionContext,i)


        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_rowset_function

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRowset_function" ):
                listener.enterRowset_function(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRowset_function" ):
                listener.exitRowset_function(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRowset_function" ):
                return visitor.visitRowset_function(self)
            else:
                return visitor.visitChildren(self)




    def rowset_function(self):

        localctx = tsqlParser.Rowset_functionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 230, self.RULE_rowset_function)
        self._la = 0 # Token type
        try:
            self.state = 2501
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,379,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2475
                self.match(tsqlParser.OPENROWSET)
                self.state = 2476
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2477
                localctx.provider_name = self.match(tsqlParser.STRING)
                self.state = 2478
                self.match(tsqlParser.COMMA)
                self.state = 2479
                localctx.connectionString = self.match(tsqlParser.STRING)
                self.state = 2480
                self.match(tsqlParser.COMMA)
                self.state = 2481
                localctx.sql = self.match(tsqlParser.STRING)
                self.state = 2482
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2483
                self.match(tsqlParser.OPENROWSET)
                self.state = 2484
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2485
                self.match(tsqlParser.BULK)
                self.state = 2486
                localctx.data_file = self.match(tsqlParser.STRING)
                self.state = 2487
                self.match(tsqlParser.COMMA)
                self.state = 2497
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,378,self._ctx)
                if la_ == 1:
                    self.state = 2488
                    self.bulk_option()
                    self.state = 2493
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    while _la==tsqlParser.COMMA:
                        self.state = 2489
                        self.match(tsqlParser.COMMA)
                        self.state = 2490
                        self.bulk_option()
                        self.state = 2495
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)

                    pass

                elif la_ == 2:
                    self.state = 2496
                    self.r_id()
                    pass


                self.state = 2499
                self.match(tsqlParser.RR_BRACKET)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Bulk_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.bulk_option_value = None # Token

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_bulk_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBulk_option" ):
                listener.enterBulk_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBulk_option" ):
                listener.exitBulk_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBulk_option" ):
                return visitor.visitBulk_option(self)
            else:
                return visitor.visitChildren(self)




    def bulk_option(self):

        localctx = tsqlParser.Bulk_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 232, self.RULE_bulk_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2503
            self.r_id()
            self.state = 2504
            self.match(tsqlParser.EQUAL)
            self.state = 2505
            localctx.bulk_option_value = self._input.LT(1)
            _la = self._input.LA(1)
            if not(_la==tsqlParser.DECIMAL or _la==tsqlParser.STRING):
                localctx.bulk_option_value = self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Derived_tableContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def subquery(self):
            return self.getTypedRuleContext(tsqlParser.SubqueryContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_derived_table

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDerived_table" ):
                listener.enterDerived_table(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDerived_table" ):
                listener.exitDerived_table(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDerived_table" ):
                return visitor.visitDerived_table(self)
            else:
                return visitor.visitChildren(self)




    def derived_table(self):

        localctx = tsqlParser.Derived_tableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 234, self.RULE_derived_table)
        try:
            self.state = 2512
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,380,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2507
                self.subquery()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2508
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2509
                self.subquery()
                self.state = 2510
                self.match(tsqlParser.RR_BRACKET)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Function_callContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_function_call

     
        def copyFrom(self, ctx:ParserRuleContext):
            super().copyFrom(ctx)



    class Simple_callContext(Function_callContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Function_callContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def CHECKSUM(self):
            return self.getToken(tsqlParser.CHECKSUM, 0)
        def CURRENT_TIMESTAMP(self):
            return self.getToken(tsqlParser.CURRENT_TIMESTAMP, 0)
        def CURRENT_USER(self):
            return self.getToken(tsqlParser.CURRENT_USER, 0)
        def MIN_ACTIVE_ROWVERSION(self):
            return self.getToken(tsqlParser.MIN_ACTIVE_ROWVERSION, 0)
        def SESSION_USER(self):
            return self.getToken(tsqlParser.SESSION_USER, 0)
        def SYSTEM_USER(self):
            return self.getToken(tsqlParser.SYSTEM_USER, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSimple_call" ):
                listener.enterSimple_call(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSimple_call" ):
                listener.exitSimple_call(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSimple_call" ):
                return visitor.visitSimple_call(self)
            else:
                return visitor.visitChildren(self)


    class Rank_callContext(Function_callContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Function_callContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def ranking_windowed_function(self):
            return self.getTypedRuleContext(tsqlParser.Ranking_windowed_functionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRank_call" ):
                listener.enterRank_call(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRank_call" ):
                listener.exitRank_call(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRank_call" ):
                return visitor.visitRank_call(self)
            else:
                return visitor.visitChildren(self)


    class Cast_callContext(Function_callContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Function_callContext
            super().__init__(parser)
            self.alias = None # Data_typeContext
            self.copyFrom(ctx)

        def CAST(self):
            return self.getToken(tsqlParser.CAST, 0)
        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)

        def AS(self):
            return self.getToken(tsqlParser.AS, 0)
        def data_type(self):
            return self.getTypedRuleContext(tsqlParser.Data_typeContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCast_call" ):
                listener.enterCast_call(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCast_call" ):
                listener.exitCast_call(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCast_call" ):
                return visitor.visitCast_call(self)
            else:
                return visitor.visitChildren(self)


    class Standard_callContext(Function_callContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Function_callContext
            super().__init__(parser)
            self.style = None # ExpressionContext
            self.seed = None # Token
            self.increment = None # Token
            self.copyFrom(ctx)

        def scalar_function_name(self):
            return self.getTypedRuleContext(tsqlParser.Scalar_function_nameContext,0)

        def expression_list(self):
            return self.getTypedRuleContext(tsqlParser.Expression_listContext,0)

        def BINARY_CHECKSUM(self):
            return self.getToken(tsqlParser.BINARY_CHECKSUM, 0)
        def CONVERT(self):
            return self.getToken(tsqlParser.CONVERT, 0)
        def data_type(self):
            return self.getTypedRuleContext(tsqlParser.Data_typeContext,0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)

        def COALESCE(self):
            return self.getToken(tsqlParser.COALESCE, 0)
        def DATEADD(self):
            return self.getToken(tsqlParser.DATEADD, 0)
        def ID(self):
            return self.getToken(tsqlParser.ID, 0)
        def DATEDIFF(self):
            return self.getToken(tsqlParser.DATEDIFF, 0)
        def DATENAME(self):
            return self.getToken(tsqlParser.DATENAME, 0)
        def DATEPART(self):
            return self.getToken(tsqlParser.DATEPART, 0)
        def IDENTITY(self):
            return self.getToken(tsqlParser.IDENTITY, 0)
        def DECIMAL(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.DECIMAL)
            else:
                return self.getToken(tsqlParser.DECIMAL, i)
        def NULLIF(self):
            return self.getToken(tsqlParser.NULLIF, 0)

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStandard_call" ):
                listener.enterStandard_call(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStandard_call" ):
                listener.exitStandard_call(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStandard_call" ):
                return visitor.visitStandard_call(self)
            else:
                return visitor.visitChildren(self)


    class Aggregate_callContext(Function_callContext):

        def __init__(self, parser, ctx:ParserRuleContext): # actually a tsqlParser.Function_callContext
            super().__init__(parser)
            self.copyFrom(ctx)

        def aggregate_windowed_function(self):
            return self.getTypedRuleContext(tsqlParser.Aggregate_windowed_functionContext,0)


        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAggregate_call" ):
                listener.enterAggregate_call(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAggregate_call" ):
                listener.exitAggregate_call(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAggregate_call" ):
                return visitor.visitAggregate_call(self)
            else:
                return visitor.visitChildren(self)



    def function_call(self):

        localctx = tsqlParser.Function_callContext(self, self._ctx, self.state)
        self.enterRule(localctx, 236, self.RULE_function_call)
        self._la = 0 # Token type
        try:
            self.state = 2611
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,385,self._ctx)
            if la_ == 1:
                localctx = tsqlParser.Rank_callContext(self, localctx)
                self.enterOuterAlt(localctx, 1)
                self.state = 2514
                self.ranking_windowed_function()
                pass

            elif la_ == 2:
                localctx = tsqlParser.Aggregate_callContext(self, localctx)
                self.enterOuterAlt(localctx, 2)
                self.state = 2515
                self.aggregate_windowed_function()
                pass

            elif la_ == 3:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 3)
                self.state = 2516
                self.scalar_function_name()
                self.state = 2517
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2519
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & ((1 << tsqlParser.CASE) | (1 << tsqlParser.COALESCE) | (1 << tsqlParser.CONVERT) | (1 << tsqlParser.CURRENT_TIMESTAMP) | (1 << tsqlParser.CURRENT_USER) | (1 << tsqlParser.DEFAULT))) != 0) or ((((_la - 72)) & ~0x3f) == 0 and ((1 << (_la - 72)) & ((1 << (tsqlParser.FORCESEEK - 72)) | (1 << (tsqlParser.IDENTITY - 72)) | (1 << (tsqlParser.LEFT - 72)) | (1 << (tsqlParser.NULL - 72)) | (1 << (tsqlParser.NULLIF - 72)) | (1 << (tsqlParser.OVER - 72)))) != 0) or ((((_la - 145)) & ~0x3f) == 0 and ((1 << (_la - 145)) & ((1 << (tsqlParser.RIGHT - 145)) | (1 << (tsqlParser.SESSION_USER - 145)) | (1 << (tsqlParser.SYSTEM_USER - 145)) | (1 << (tsqlParser.ABSOLUTE - 145)) | (1 << (tsqlParser.APPLY - 145)) | (1 << (tsqlParser.AUTO - 145)))) != 0) or ((((_la - 210)) & ~0x3f) == 0 and ((1 << (_la - 210)) & ((1 << (tsqlParser.AVG - 210)) | (1 << (tsqlParser.BASE64 - 210)) | (1 << (tsqlParser.BINARY_CHECKSUM - 210)) | (1 << (tsqlParser.CALLER - 210)) | (1 << (tsqlParser.CAST - 210)) | (1 << (tsqlParser.CATCH - 210)) | (1 << (tsqlParser.CHECKSUM - 210)) | (1 << (tsqlParser.CHECKSUM_AGG - 210)) | (1 << (tsqlParser.COMMITTED - 210)) | (1 << (tsqlParser.CONCAT - 210)) | (1 << (tsqlParser.CONTROL - 210)) | (1 << (tsqlParser.COOKIE - 210)) | (1 << (tsqlParser.COUNT - 210)) | (1 << (tsqlParser.COUNT_BIG - 210)) | (1 << (tsqlParser.DATEADD - 210)) | (1 << (tsqlParser.DATEDIFF - 210)) | (1 << (tsqlParser.DATENAME - 210)) | (1 << (tsqlParser.DATEPART - 210)) | (1 << (tsqlParser.DELAY - 210)) | (1 << (tsqlParser.DELETED - 210)) | (1 << (tsqlParser.DENSE_RANK - 210)) | (1 << (tsqlParser.DISABLE - 210)) | (1 << (tsqlParser.DYNAMIC - 210)) | (1 << (tsqlParser.ENCRYPTION - 210)) | (1 << (tsqlParser.EXPAND - 210)) | (1 << (tsqlParser.FAST - 210)) | (1 << (tsqlParser.FAST_FORWARD - 210)) | (1 << (tsqlParser.FIRST - 210)) | (1 << (tsqlParser.FOLLOWING - 210)) | (1 << (tsqlParser.FORCE - 210)) | (1 << (tsqlParser.FORCED - 210)) | (1 << (tsqlParser.FORWARD_ONLY - 210)) | (1 << (tsqlParser.FULLSCAN - 210)) | (1 << (tsqlParser.GLOBAL - 210)) | (1 << (tsqlParser.GO - 210)) | (1 << (tsqlParser.GROUPING - 210)) | (1 << (tsqlParser.GROUPING_ID - 210)) | (1 << (tsqlParser.HASH - 210)))) != 0) or ((((_la - 274)) & ~0x3f) == 0 and ((1 << (_la - 274)) & ((1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 274)) | (1 << (tsqlParser.IMPERSONATE - 274)) | (1 << (tsqlParser.INSENSITIVE - 274)) | (1 << (tsqlParser.INSERTED - 274)) | (1 << (tsqlParser.ISOLATION - 274)) | (1 << (tsqlParser.KEEP - 274)) | (1 << (tsqlParser.KEEPFIXED - 274)) | (1 << (tsqlParser.KEYSET - 274)) | (1 << (tsqlParser.LAST - 274)) | (1 << (tsqlParser.LEVEL - 274)) | (1 << (tsqlParser.LOCAL - 274)) | (1 << (tsqlParser.LOCK_ESCALATION - 274)) | (1 << (tsqlParser.LOGIN - 274)) | (1 << (tsqlParser.LOOP - 274)) | (1 << (tsqlParser.MARK - 274)) | (1 << (tsqlParser.MAX - 274)) | (1 << (tsqlParser.MAXDOP - 274)) | (1 << (tsqlParser.MAXRECURSION - 274)) | (1 << (tsqlParser.MIN - 274)) | (1 << (tsqlParser.MIN_ACTIVE_ROWVERSION - 274)) | (1 << (tsqlParser.MODIFY - 274)) | (1 << (tsqlParser.NAME - 274)) | (1 << (tsqlParser.NEXT - 274)) | (1 << (tsqlParser.NOCOUNT - 274)) | (1 << (tsqlParser.NOEXPAND - 274)) | (1 << (tsqlParser.NORECOMPUTE - 274)) | (1 << (tsqlParser.NTILE - 274)) | (1 << (tsqlParser.NUMBER - 274)) | (1 << (tsqlParser.OFFSET - 274)) | (1 << (tsqlParser.ONLINE - 274)) | (1 << (tsqlParser.ONLY - 274)) | (1 << (tsqlParser.OPTIMISTIC - 274)) | (1 << (tsqlParser.OPTIMIZE - 274)) | (1 << (tsqlParser.OUT - 274)) | (1 << (tsqlParser.OUTPUT - 274)) | (1 << (tsqlParser.OWNER - 274)) | (1 << (tsqlParser.PARAMETERIZATION - 274)) | (1 << (tsqlParser.PARTITION - 274)) | (1 << (tsqlParser.PATH - 274)) | (1 << (tsqlParser.PRECEDING - 274)) | (1 << (tsqlParser.PRIOR - 274)) | (1 << (tsqlParser.PRIVILEGES - 274)) | (1 << (tsqlParser.RANGE - 274)) | (1 << (tsqlParser.RANK - 274)) | (1 << (tsqlParser.READONLY - 274)) | (1 << (tsqlParser.READ_ONLY - 274)))) != 0) or ((((_la - 339)) & ~0x3f) == 0 and ((1 << (_la - 339)) & ((1 << (tsqlParser.RECOMPILE - 339)) | (1 << (tsqlParser.RELATIVE - 339)) | (1 << (tsqlParser.REMOTE - 339)) | (1 << (tsqlParser.REPEATABLE - 339)) | (1 << (tsqlParser.ROBUST - 339)) | (1 << (tsqlParser.ROOT - 339)) | (1 << (tsqlParser.ROW - 339)) | (1 << (tsqlParser.ROWGUID - 339)) | (1 << (tsqlParser.ROWS - 339)) | (1 << (tsqlParser.ROW_NUMBER - 339)) | (1 << (tsqlParser.SAMPLE - 339)) | (1 << (tsqlParser.SCHEMABINDING - 339)) | (1 << (tsqlParser.SCROLL - 339)) | (1 << (tsqlParser.SCROLL_LOCKS - 339)) | (1 << (tsqlParser.SELF - 339)) | (1 << (tsqlParser.SERIALIZABLE - 339)) | (1 << (tsqlParser.SIMPLE - 339)) | (1 << (tsqlParser.SIZE - 339)) | (1 << (tsqlParser.SNAPSHOT - 339)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 339)) | (1 << (tsqlParser.STATIC - 339)) | (1 << (tsqlParser.STATS_STREAM - 339)) | (1 << (tsqlParser.STDEV - 339)) | (1 << (tsqlParser.STDEVP - 339)) | (1 << (tsqlParser.SUM - 339)) | (1 << (tsqlParser.TEXTIMAGE_ON - 339)) | (1 << (tsqlParser.THROW - 339)) | (1 << (tsqlParser.TIES - 339)) | (1 << (tsqlParser.TIME - 339)) | (1 << (tsqlParser.TRY - 339)) | (1 << (tsqlParser.TYPE - 339)) | (1 << (tsqlParser.TYPE_WARNING - 339)) | (1 << (tsqlParser.UNBOUNDED - 339)) | (1 << (tsqlParser.UNCOMMITTED - 339)) | (1 << (tsqlParser.UNKNOWN - 339)) | (1 << (tsqlParser.USING - 339)) | (1 << (tsqlParser.VAR - 339)) | (1 << (tsqlParser.VARP - 339)) | (1 << (tsqlParser.VIEWS - 339)) | (1 << (tsqlParser.VIEW_METADATA - 339)) | (1 << (tsqlParser.WORK - 339)) | (1 << (tsqlParser.XML - 339)) | (1 << (tsqlParser.XMLNAMESPACES - 339)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 339)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 339)) | (1 << (tsqlParser.LOCAL_ID - 339)))) != 0) or ((((_la - 403)) & ~0x3f) == 0 and ((1 << (_la - 403)) & ((1 << (tsqlParser.DECIMAL - 403)) | (1 << (tsqlParser.ID - 403)) | (1 << (tsqlParser.STRING - 403)) | (1 << (tsqlParser.BINARY - 403)) | (1 << (tsqlParser.FLOAT - 403)) | (1 << (tsqlParser.REAL - 403)) | (1 << (tsqlParser.DOLLAR - 403)) | (1 << (tsqlParser.LR_BRACKET - 403)) | (1 << (tsqlParser.PLUS - 403)) | (1 << (tsqlParser.MINUS - 403)) | (1 << (tsqlParser.BIT_NOT - 403)))) != 0):
                    self.state = 2518
                    self.expression_list()


                self.state = 2521
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 4:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 4)
                self.state = 2523
                self.match(tsqlParser.BINARY_CHECKSUM)
                self.state = 2524
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2525
                self.match(tsqlParser.STAR)
                self.state = 2526
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 5:
                localctx = tsqlParser.Cast_callContext(self, localctx)
                self.enterOuterAlt(localctx, 5)
                self.state = 2527
                self.match(tsqlParser.CAST)
                self.state = 2528
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2529
                self.expression(0)
                self.state = 2530
                self.match(tsqlParser.AS)
                self.state = 2531
                localctx.alias = self.data_type()
                self.state = 2532
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 6:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 6)
                self.state = 2534
                self.match(tsqlParser.CONVERT)
                self.state = 2535
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2536
                self.data_type()
                self.state = 2537
                self.match(tsqlParser.COMMA)
                self.state = 2538
                self.expression(0)
                self.state = 2541
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 2539
                    self.match(tsqlParser.COMMA)
                    self.state = 2540
                    localctx.style = self.expression(0)


                self.state = 2543
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 7:
                localctx = tsqlParser.Simple_callContext(self, localctx)
                self.enterOuterAlt(localctx, 7)
                self.state = 2545
                self.match(tsqlParser.CHECKSUM)
                self.state = 2546
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2547
                self.match(tsqlParser.STAR)
                self.state = 2548
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 8:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 8)
                self.state = 2549
                self.match(tsqlParser.COALESCE)
                self.state = 2550
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2551
                self.expression_list()
                self.state = 2552
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 9:
                localctx = tsqlParser.Simple_callContext(self, localctx)
                self.enterOuterAlt(localctx, 9)
                self.state = 2554
                self.match(tsqlParser.CURRENT_TIMESTAMP)
                pass

            elif la_ == 10:
                localctx = tsqlParser.Simple_callContext(self, localctx)
                self.enterOuterAlt(localctx, 10)
                self.state = 2555
                self.match(tsqlParser.CURRENT_USER)
                pass

            elif la_ == 11:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 11)
                self.state = 2556
                self.match(tsqlParser.DATEADD)
                self.state = 2557
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2558
                self.match(tsqlParser.ID)
                self.state = 2559
                self.match(tsqlParser.COMMA)
                self.state = 2560
                self.expression(0)
                self.state = 2561
                self.match(tsqlParser.COMMA)
                self.state = 2562
                self.expression(0)
                self.state = 2563
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 12:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 12)
                self.state = 2565
                self.match(tsqlParser.DATEDIFF)
                self.state = 2566
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2567
                self.match(tsqlParser.ID)
                self.state = 2568
                self.match(tsqlParser.COMMA)
                self.state = 2569
                self.expression(0)
                self.state = 2570
                self.match(tsqlParser.COMMA)
                self.state = 2571
                self.expression(0)
                self.state = 2572
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 13:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 13)
                self.state = 2574
                self.match(tsqlParser.DATENAME)
                self.state = 2575
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2576
                self.match(tsqlParser.ID)
                self.state = 2577
                self.match(tsqlParser.COMMA)
                self.state = 2578
                self.expression(0)
                self.state = 2579
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 14:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 14)
                self.state = 2581
                self.match(tsqlParser.DATEPART)
                self.state = 2582
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2583
                self.match(tsqlParser.ID)
                self.state = 2584
                self.match(tsqlParser.COMMA)
                self.state = 2585
                self.expression(0)
                self.state = 2586
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 15:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 15)
                self.state = 2588
                self.match(tsqlParser.IDENTITY)
                self.state = 2589
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2590
                self.data_type()
                self.state = 2593
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,383,self._ctx)
                if la_ == 1:
                    self.state = 2591
                    self.match(tsqlParser.COMMA)
                    self.state = 2592
                    localctx.seed = self.match(tsqlParser.DECIMAL)


                self.state = 2597
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 2595
                    self.match(tsqlParser.COMMA)
                    self.state = 2596
                    localctx.increment = self.match(tsqlParser.DECIMAL)


                self.state = 2599
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 16:
                localctx = tsqlParser.Simple_callContext(self, localctx)
                self.enterOuterAlt(localctx, 16)
                self.state = 2601
                self.match(tsqlParser.MIN_ACTIVE_ROWVERSION)
                pass

            elif la_ == 17:
                localctx = tsqlParser.Standard_callContext(self, localctx)
                self.enterOuterAlt(localctx, 17)
                self.state = 2602
                self.match(tsqlParser.NULLIF)
                self.state = 2603
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2604
                self.expression(0)
                self.state = 2605
                self.match(tsqlParser.COMMA)
                self.state = 2606
                self.expression(0)
                self.state = 2607
                self.match(tsqlParser.RR_BRACKET)
                pass

            elif la_ == 18:
                localctx = tsqlParser.Simple_callContext(self, localctx)
                self.enterOuterAlt(localctx, 18)
                self.state = 2609
                self.match(tsqlParser.SESSION_USER)
                pass

            elif la_ == 19:
                localctx = tsqlParser.Simple_callContext(self, localctx)
                self.enterOuterAlt(localctx, 19)
                self.state = 2610
                self.match(tsqlParser.SYSTEM_USER)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Switch_sectionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.whenExpr = None # ExpressionContext
            self.thenExpr = None # ExpressionContext

        def WHEN(self):
            return self.getToken(tsqlParser.WHEN, 0)

        def THEN(self):
            return self.getToken(tsqlParser.THEN, 0)

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_switch_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSwitch_section" ):
                listener.enterSwitch_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSwitch_section" ):
                listener.exitSwitch_section(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSwitch_section" ):
                return visitor.visitSwitch_section(self)
            else:
                return visitor.visitChildren(self)




    def switch_section(self):

        localctx = tsqlParser.Switch_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 238, self.RULE_switch_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2613
            self.match(tsqlParser.WHEN)
            self.state = 2614
            localctx.whenExpr = self.expression(0)
            self.state = 2615
            self.match(tsqlParser.THEN)
            self.state = 2616
            localctx.thenExpr = self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Switch_search_condition_sectionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.whenExpr = None # Search_conditionContext
            self.thenExpr = None # ExpressionContext

        def WHEN(self):
            return self.getToken(tsqlParser.WHEN, 0)

        def THEN(self):
            return self.getToken(tsqlParser.THEN, 0)

        def search_condition(self):
            return self.getTypedRuleContext(tsqlParser.Search_conditionContext,0)


        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_switch_search_condition_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSwitch_search_condition_section" ):
                listener.enterSwitch_search_condition_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSwitch_search_condition_section" ):
                listener.exitSwitch_search_condition_section(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSwitch_search_condition_section" ):
                return visitor.visitSwitch_search_condition_section(self)
            else:
                return visitor.visitChildren(self)




    def switch_search_condition_section(self):

        localctx = tsqlParser.Switch_search_condition_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 240, self.RULE_switch_search_condition_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2618
            self.match(tsqlParser.WHEN)
            self.state = 2619
            localctx.whenExpr = self.search_condition(0)
            self.state = 2620
            self.match(tsqlParser.THEN)
            self.state = 2621
            localctx.thenExpr = self.expression(0)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class As_table_aliasContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_alias(self):
            return self.getTypedRuleContext(tsqlParser.Table_aliasContext,0)


        def AS(self):
            return self.getToken(tsqlParser.AS, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_as_table_alias

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAs_table_alias" ):
                listener.enterAs_table_alias(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAs_table_alias" ):
                listener.exitAs_table_alias(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAs_table_alias" ):
                return visitor.visitAs_table_alias(self)
            else:
                return visitor.visitChildren(self)




    def as_table_alias(self):

        localctx = tsqlParser.As_table_aliasContext(self, self._ctx, self.state)
        self.enterRule(localctx, 242, self.RULE_as_table_alias)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2624
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.AS:
                self.state = 2623
                self.match(tsqlParser.AS)


            self.state = 2626
            self.table_alias()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_aliasContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def with_table_hints(self):
            return self.getTypedRuleContext(tsqlParser.With_table_hintsContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_alias

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_alias" ):
                listener.enterTable_alias(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_alias" ):
                listener.exitTable_alias(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_alias" ):
                return visitor.visitTable_alias(self)
            else:
                return visitor.visitChildren(self)




    def table_alias(self):

        localctx = tsqlParser.Table_aliasContext(self, self._ctx, self.state)
        self.enterRule(localctx, 244, self.RULE_table_alias)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2628
            self.r_id()
            self.state = 2630
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,387,self._ctx)
            if la_ == 1:
                self.state = 2629
                self.with_table_hints()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class With_table_hintsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def table_hint(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Table_hintContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Table_hintContext,i)


        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_with_table_hints

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWith_table_hints" ):
                listener.enterWith_table_hints(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWith_table_hints" ):
                listener.exitWith_table_hints(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWith_table_hints" ):
                return visitor.visitWith_table_hints(self)
            else:
                return visitor.visitChildren(self)




    def with_table_hints(self):

        localctx = tsqlParser.With_table_hintsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 246, self.RULE_with_table_hints)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2633
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.WITH:
                self.state = 2632
                self.match(tsqlParser.WITH)


            self.state = 2635
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2636
            self.table_hint()
            self.state = 2641
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2637
                self.match(tsqlParser.COMMA)
                self.state = 2638
                self.table_hint()
                self.state = 2643
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 2644
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Insert_with_table_hintsContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def WITH(self):
            return self.getToken(tsqlParser.WITH, 0)

        def table_hint(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Table_hintContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Table_hintContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_insert_with_table_hints

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInsert_with_table_hints" ):
                listener.enterInsert_with_table_hints(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInsert_with_table_hints" ):
                listener.exitInsert_with_table_hints(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInsert_with_table_hints" ):
                return visitor.visitInsert_with_table_hints(self)
            else:
                return visitor.visitChildren(self)




    def insert_with_table_hints(self):

        localctx = tsqlParser.Insert_with_table_hintsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 248, self.RULE_insert_with_table_hints)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2646
            self.match(tsqlParser.WITH)
            self.state = 2647
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2648
            self.table_hint()
            self.state = 2653
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2649
                self.match(tsqlParser.COMMA)
                self.state = 2650
                self.table_hint()
                self.state = 2655
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 2656
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_hintContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NOEXPAND(self):
            return self.getToken(tsqlParser.NOEXPAND, 0)

        def INDEX(self):
            return self.getToken(tsqlParser.INDEX, 0)

        def index_value(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Index_valueContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Index_valueContext,i)


        def FORCESEEK(self):
            return self.getToken(tsqlParser.FORCESEEK, 0)

        def SERIALIZABLE(self):
            return self.getToken(tsqlParser.SERIALIZABLE, 0)

        def SNAPSHOT(self):
            return self.getToken(tsqlParser.SNAPSHOT, 0)

        def SPATIAL_WINDOW_MAX_CELLS(self):
            return self.getToken(tsqlParser.SPATIAL_WINDOW_MAX_CELLS, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def ID(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.ID)
            else:
                return self.getToken(tsqlParser.ID, i)

        def getRuleIndex(self):
            return tsqlParser.RULE_table_hint

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_hint" ):
                listener.enterTable_hint(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_hint" ):
                listener.exitTable_hint(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_hint" ):
                return visitor.visitTable_hint(self)
            else:
                return visitor.visitChildren(self)




    def table_hint(self):

        localctx = tsqlParser.Table_hintContext(self, self._ctx, self.state)
        self.enterRule(localctx, 250, self.RULE_table_hint)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2659
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.NOEXPAND:
                self.state = 2658
                self.match(tsqlParser.NOEXPAND)


            self.state = 2699
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,395,self._ctx)
            if la_ == 1:
                self.state = 2661
                self.match(tsqlParser.INDEX)
                self.state = 2662
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2663
                self.index_value()
                self.state = 2668
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                while _la==tsqlParser.COMMA:
                    self.state = 2664
                    self.match(tsqlParser.COMMA)
                    self.state = 2665
                    self.index_value()
                    self.state = 2670
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)

                self.state = 2671
                self.match(tsqlParser.RR_BRACKET)

            elif la_ == 2:
                self.state = 2673
                self.match(tsqlParser.INDEX)
                self.state = 2674
                self.match(tsqlParser.EQUAL)
                self.state = 2675
                self.index_value()

            elif la_ == 3:
                self.state = 2676
                self.match(tsqlParser.FORCESEEK)
                self.state = 2691
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.LR_BRACKET:
                    self.state = 2677
                    self.match(tsqlParser.LR_BRACKET)
                    self.state = 2678
                    self.index_value()
                    self.state = 2679
                    self.match(tsqlParser.LR_BRACKET)
                    self.state = 2680
                    self.match(tsqlParser.ID)
                    self.state = 2685
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    while _la==tsqlParser.COMMA:
                        self.state = 2681
                        self.match(tsqlParser.COMMA)
                        self.state = 2682
                        self.match(tsqlParser.ID)
                        self.state = 2687
                        self._errHandler.sync(self)
                        _la = self._input.LA(1)

                    self.state = 2688
                    self.match(tsqlParser.RR_BRACKET)
                    self.state = 2689
                    self.match(tsqlParser.RR_BRACKET)



            elif la_ == 4:
                self.state = 2693
                self.match(tsqlParser.SERIALIZABLE)

            elif la_ == 5:
                self.state = 2694
                self.match(tsqlParser.SNAPSHOT)

            elif la_ == 6:
                self.state = 2695
                self.match(tsqlParser.SPATIAL_WINDOW_MAX_CELLS)
                self.state = 2696
                self.match(tsqlParser.EQUAL)
                self.state = 2697
                self.match(tsqlParser.DECIMAL)

            elif la_ == 7:
                self.state = 2698
                self.match(tsqlParser.ID)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Index_valueContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_index_value

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIndex_value" ):
                listener.enterIndex_value(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIndex_value" ):
                listener.exitIndex_value(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitIndex_value" ):
                return visitor.visitIndex_value(self)
            else:
                return visitor.visitChildren(self)




    def index_value(self):

        localctx = tsqlParser.Index_valueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 252, self.RULE_index_value)
        try:
            self.state = 2703
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2701
                self.r_id()
                pass
            elif token in [tsqlParser.DECIMAL]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2702
                self.match(tsqlParser.DECIMAL)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_alias_listContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def column_alias(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Column_aliasContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Column_aliasContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_column_alias_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_alias_list" ):
                listener.enterColumn_alias_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_alias_list" ):
                listener.exitColumn_alias_list(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_alias_list" ):
                return visitor.visitColumn_alias_list(self)
            else:
                return visitor.visitChildren(self)




    def column_alias_list(self):

        localctx = tsqlParser.Column_alias_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 254, self.RULE_column_alias_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2705
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2706
            self.column_alias()
            self.state = 2711
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2707
                self.match(tsqlParser.COMMA)
                self.state = 2708
                self.column_alias()
                self.state = 2713
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 2714
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_aliasContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_column_alias

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_alias" ):
                listener.enterColumn_alias(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_alias" ):
                listener.exitColumn_alias(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_alias" ):
                return visitor.visitColumn_alias(self)
            else:
                return visitor.visitChildren(self)




    def column_alias(self):

        localctx = tsqlParser.Column_aliasContext(self, self._ctx, self.state)
        self.enterRule(localctx, 256, self.RULE_column_alias)
        try:
            self.state = 2718
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2716
                self.r_id()
                pass
            elif token in [tsqlParser.STRING]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2717
                self.match(tsqlParser.STRING)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class A_starContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_a_star

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterA_star" ):
                listener.enterA_star(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitA_star" ):
                listener.exitA_star(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitA_star" ):
                return visitor.visitA_star(self)
            else:
                return visitor.visitChildren(self)




    def a_star(self):

        localctx = tsqlParser.A_starContext(self, self._ctx, self.state)
        self.enterRule(localctx, 258, self.RULE_a_star)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2720
            self.match(tsqlParser.STAR)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_value_constructorContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def VALUES(self):
            return self.getToken(tsqlParser.VALUES, 0)

        def expression_list(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Expression_listContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Expression_listContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_value_constructor

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_value_constructor" ):
                listener.enterTable_value_constructor(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_value_constructor" ):
                listener.exitTable_value_constructor(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_value_constructor" ):
                return visitor.visitTable_value_constructor(self)
            else:
                return visitor.visitChildren(self)




    def table_value_constructor(self):

        localctx = tsqlParser.Table_value_constructorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 260, self.RULE_table_value_constructor)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2722
            self.match(tsqlParser.VALUES)
            self.state = 2723
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2724
            self.expression_list()
            self.state = 2725
            self.match(tsqlParser.RR_BRACKET)
            self.state = 2733
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2726
                self.match(tsqlParser.COMMA)
                self.state = 2727
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2728
                self.expression_list()
                self.state = 2729
                self.match(tsqlParser.RR_BRACKET)
                self.state = 2735
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Expression_listContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def expression(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.ExpressionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.ExpressionContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_expression_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExpression_list" ):
                listener.enterExpression_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExpression_list" ):
                listener.exitExpression_list(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitExpression_list" ):
                return visitor.visitExpression_list(self)
            else:
                return visitor.visitChildren(self)




    def expression_list(self):

        localctx = tsqlParser.Expression_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 262, self.RULE_expression_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2736
            self.expression(0)
            self.state = 2741
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 2737
                self.match(tsqlParser.COMMA)
                self.state = 2738
                self.expression(0)
                self.state = 2743
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Ranking_windowed_functionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def over_clause(self):
            return self.getTypedRuleContext(tsqlParser.Over_clauseContext,0)


        def RANK(self):
            return self.getToken(tsqlParser.RANK, 0)

        def DENSE_RANK(self):
            return self.getToken(tsqlParser.DENSE_RANK, 0)

        def ROW_NUMBER(self):
            return self.getToken(tsqlParser.ROW_NUMBER, 0)

        def NTILE(self):
            return self.getToken(tsqlParser.NTILE, 0)

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_ranking_windowed_function

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRanking_windowed_function" ):
                listener.enterRanking_windowed_function(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRanking_windowed_function" ):
                listener.exitRanking_windowed_function(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRanking_windowed_function" ):
                return visitor.visitRanking_windowed_function(self)
            else:
                return visitor.visitChildren(self)




    def ranking_windowed_function(self):

        localctx = tsqlParser.Ranking_windowed_functionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 264, self.RULE_ranking_windowed_function)
        self._la = 0 # Token type
        try:
            self.state = 2754
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.DENSE_RANK, tsqlParser.RANK, tsqlParser.ROW_NUMBER]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2744
                _la = self._input.LA(1)
                if not(_la==tsqlParser.DENSE_RANK or _la==tsqlParser.RANK or _la==tsqlParser.ROW_NUMBER):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2745
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2746
                self.match(tsqlParser.RR_BRACKET)
                self.state = 2747
                self.over_clause()
                pass
            elif token in [tsqlParser.NTILE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2748
                self.match(tsqlParser.NTILE)
                self.state = 2749
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2750
                self.expression(0)
                self.state = 2751
                self.match(tsqlParser.RR_BRACKET)
                self.state = 2752
                self.over_clause()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Aggregate_windowed_functionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.args = None # Token

        def expression(self):
            return self.getTypedRuleContext(tsqlParser.ExpressionContext,0)


        def AVG(self):
            return self.getToken(tsqlParser.AVG, 0)

        def MAX(self):
            return self.getToken(tsqlParser.MAX, 0)

        def MIN(self):
            return self.getToken(tsqlParser.MIN, 0)

        def SUM(self):
            return self.getToken(tsqlParser.SUM, 0)

        def STDEV(self):
            return self.getToken(tsqlParser.STDEV, 0)

        def STDEVP(self):
            return self.getToken(tsqlParser.STDEVP, 0)

        def VAR(self):
            return self.getToken(tsqlParser.VAR, 0)

        def VARP(self):
            return self.getToken(tsqlParser.VARP, 0)

        def all_distinct(self):
            return self.getTypedRuleContext(tsqlParser.All_distinctContext,0)


        def over_clause(self):
            return self.getTypedRuleContext(tsqlParser.Over_clauseContext,0)


        def COUNT(self):
            return self.getToken(tsqlParser.COUNT, 0)

        def COUNT_BIG(self):
            return self.getToken(tsqlParser.COUNT_BIG, 0)

        def CHECKSUM_AGG(self):
            return self.getToken(tsqlParser.CHECKSUM_AGG, 0)

        def GROUPING(self):
            return self.getToken(tsqlParser.GROUPING, 0)

        def GROUPING_ID(self):
            return self.getToken(tsqlParser.GROUPING_ID, 0)

        def expression_list(self):
            return self.getTypedRuleContext(tsqlParser.Expression_listContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_aggregate_windowed_function

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAggregate_windowed_function" ):
                listener.enterAggregate_windowed_function(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAggregate_windowed_function" ):
                listener.exitAggregate_windowed_function(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAggregate_windowed_function" ):
                return visitor.visitAggregate_windowed_function(self)
            else:
                return visitor.visitChildren(self)




    def aggregate_windowed_function(self):

        localctx = tsqlParser.Aggregate_windowed_functionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 266, self.RULE_aggregate_windowed_function)
        self._la = 0 # Token type
        try:
            self.state = 2797
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.AVG, tsqlParser.MAX, tsqlParser.MIN, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.VAR, tsqlParser.VARP]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2756
                _la = self._input.LA(1)
                if not(_la==tsqlParser.AVG or _la==tsqlParser.MAX or _la==tsqlParser.MIN or ((((_la - 367)) & ~0x3f) == 0 and ((1 << (_la - 367)) & ((1 << (tsqlParser.STDEV - 367)) | (1 << (tsqlParser.STDEVP - 367)) | (1 << (tsqlParser.SUM - 367)) | (1 << (tsqlParser.VAR - 367)) | (1 << (tsqlParser.VARP - 367)))) != 0)):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2757
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2759
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ALL or _la==tsqlParser.DISTINCT:
                    self.state = 2758
                    self.all_distinct()


                self.state = 2761
                self.expression(0)
                self.state = 2762
                self.match(tsqlParser.RR_BRACKET)
                self.state = 2764
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,403,self._ctx)
                if la_ == 1:
                    self.state = 2763
                    self.over_clause()


                pass
            elif token in [tsqlParser.COUNT, tsqlParser.COUNT_BIG]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2766
                _la = self._input.LA(1)
                if not(_la==tsqlParser.COUNT or _la==tsqlParser.COUNT_BIG):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 2767
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2773
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.STAR]:
                    self.state = 2768
                    localctx.args = self.match(tsqlParser.STAR)
                    pass
                elif token in [tsqlParser.ALL, tsqlParser.CASE, tsqlParser.COALESCE, tsqlParser.CONVERT, tsqlParser.CURRENT_TIMESTAMP, tsqlParser.CURRENT_USER, tsqlParser.DEFAULT, tsqlParser.DISTINCT, tsqlParser.FORCESEEK, tsqlParser.IDENTITY, tsqlParser.LEFT, tsqlParser.NULL, tsqlParser.NULLIF, tsqlParser.OVER, tsqlParser.RIGHT, tsqlParser.SESSION_USER, tsqlParser.SYSTEM_USER, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.BINARY_CHECKSUM, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DATEADD, tsqlParser.DATEDIFF, tsqlParser.DATENAME, tsqlParser.DATEPART, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MIN_ACTIVE_ROWVERSION, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.LOCAL_ID, tsqlParser.DECIMAL, tsqlParser.ID, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.LR_BRACKET, tsqlParser.PLUS, tsqlParser.MINUS, tsqlParser.BIT_NOT]:
                    self.state = 2770
                    self._errHandler.sync(self)
                    _la = self._input.LA(1)
                    if _la==tsqlParser.ALL or _la==tsqlParser.DISTINCT:
                        self.state = 2769
                        self.all_distinct()


                    self.state = 2772
                    self.expression(0)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 2775
                self.match(tsqlParser.RR_BRACKET)
                self.state = 2777
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,406,self._ctx)
                if la_ == 1:
                    self.state = 2776
                    self.over_clause()


                pass
            elif token in [tsqlParser.CHECKSUM_AGG]:
                self.enterOuterAlt(localctx, 3)
                self.state = 2779
                self.match(tsqlParser.CHECKSUM_AGG)
                self.state = 2780
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2782
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.ALL or _la==tsqlParser.DISTINCT:
                    self.state = 2781
                    self.all_distinct()


                self.state = 2784
                self.expression(0)
                self.state = 2785
                self.match(tsqlParser.RR_BRACKET)
                pass
            elif token in [tsqlParser.GROUPING]:
                self.enterOuterAlt(localctx, 4)
                self.state = 2787
                self.match(tsqlParser.GROUPING)
                self.state = 2788
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2789
                self.expression(0)
                self.state = 2790
                self.match(tsqlParser.RR_BRACKET)
                pass
            elif token in [tsqlParser.GROUPING_ID]:
                self.enterOuterAlt(localctx, 5)
                self.state = 2792
                self.match(tsqlParser.GROUPING_ID)
                self.state = 2793
                self.match(tsqlParser.LR_BRACKET)
                self.state = 2794
                self.expression_list()
                self.state = 2795
                self.match(tsqlParser.RR_BRACKET)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class All_distinctContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ALL(self):
            return self.getToken(tsqlParser.ALL, 0)

        def DISTINCT(self):
            return self.getToken(tsqlParser.DISTINCT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_all_distinct

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAll_distinct" ):
                listener.enterAll_distinct(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAll_distinct" ):
                listener.exitAll_distinct(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAll_distinct" ):
                return visitor.visitAll_distinct(self)
            else:
                return visitor.visitChildren(self)




    def all_distinct(self):

        localctx = tsqlParser.All_distinctContext(self, self._ctx, self.state)
        self.enterRule(localctx, 268, self.RULE_all_distinct)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2799
            _la = self._input.LA(1)
            if not(_la==tsqlParser.ALL or _la==tsqlParser.DISTINCT):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Over_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OVER(self):
            return self.getToken(tsqlParser.OVER, 0)

        def PARTITION(self):
            return self.getToken(tsqlParser.PARTITION, 0)

        def BY(self):
            return self.getToken(tsqlParser.BY, 0)

        def expression_list(self):
            return self.getTypedRuleContext(tsqlParser.Expression_listContext,0)


        def order_by_clause(self):
            return self.getTypedRuleContext(tsqlParser.Order_by_clauseContext,0)


        def row_or_range_clause(self):
            return self.getTypedRuleContext(tsqlParser.Row_or_range_clauseContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_over_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOver_clause" ):
                listener.enterOver_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOver_clause" ):
                listener.exitOver_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOver_clause" ):
                return visitor.visitOver_clause(self)
            else:
                return visitor.visitChildren(self)




    def over_clause(self):

        localctx = tsqlParser.Over_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 270, self.RULE_over_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2801
            self.match(tsqlParser.OVER)
            self.state = 2802
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2806
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.PARTITION:
                self.state = 2803
                self.match(tsqlParser.PARTITION)
                self.state = 2804
                self.match(tsqlParser.BY)
                self.state = 2805
                self.expression_list()


            self.state = 2809
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.ORDER:
                self.state = 2808
                self.order_by_clause()


            self.state = 2812
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.RANGE or _la==tsqlParser.ROWS:
                self.state = 2811
                self.row_or_range_clause()


            self.state = 2814
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Row_or_range_clauseContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def window_frame_extent(self):
            return self.getTypedRuleContext(tsqlParser.Window_frame_extentContext,0)


        def ROWS(self):
            return self.getToken(tsqlParser.ROWS, 0)

        def RANGE(self):
            return self.getToken(tsqlParser.RANGE, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_row_or_range_clause

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRow_or_range_clause" ):
                listener.enterRow_or_range_clause(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRow_or_range_clause" ):
                listener.exitRow_or_range_clause(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRow_or_range_clause" ):
                return visitor.visitRow_or_range_clause(self)
            else:
                return visitor.visitChildren(self)




    def row_or_range_clause(self):

        localctx = tsqlParser.Row_or_range_clauseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 272, self.RULE_row_or_range_clause)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2816
            _la = self._input.LA(1)
            if not(_la==tsqlParser.RANGE or _la==tsqlParser.ROWS):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 2817
            self.window_frame_extent()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Window_frame_extentContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def window_frame_preceding(self):
            return self.getTypedRuleContext(tsqlParser.Window_frame_precedingContext,0)


        def BETWEEN(self):
            return self.getToken(tsqlParser.BETWEEN, 0)

        def window_frame_bound(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Window_frame_boundContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Window_frame_boundContext,i)


        def AND(self):
            return self.getToken(tsqlParser.AND, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_window_frame_extent

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWindow_frame_extent" ):
                listener.enterWindow_frame_extent(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWindow_frame_extent" ):
                listener.exitWindow_frame_extent(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWindow_frame_extent" ):
                return visitor.visitWindow_frame_extent(self)
            else:
                return visitor.visitChildren(self)




    def window_frame_extent(self):

        localctx = tsqlParser.Window_frame_extentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 274, self.RULE_window_frame_extent)
        try:
            self.state = 2825
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.CURRENT, tsqlParser.UNBOUNDED, tsqlParser.DECIMAL]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2819
                self.window_frame_preceding()
                pass
            elif token in [tsqlParser.BETWEEN]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2820
                self.match(tsqlParser.BETWEEN)
                self.state = 2821
                self.window_frame_bound()
                self.state = 2822
                self.match(tsqlParser.AND)
                self.state = 2823
                self.window_frame_bound()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Window_frame_boundContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def window_frame_preceding(self):
            return self.getTypedRuleContext(tsqlParser.Window_frame_precedingContext,0)


        def window_frame_following(self):
            return self.getTypedRuleContext(tsqlParser.Window_frame_followingContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_window_frame_bound

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWindow_frame_bound" ):
                listener.enterWindow_frame_bound(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWindow_frame_bound" ):
                listener.exitWindow_frame_bound(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWindow_frame_bound" ):
                return visitor.visitWindow_frame_bound(self)
            else:
                return visitor.visitChildren(self)




    def window_frame_bound(self):

        localctx = tsqlParser.Window_frame_boundContext(self, self._ctx, self.state)
        self.enterRule(localctx, 276, self.RULE_window_frame_bound)
        try:
            self.state = 2829
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,413,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 2827
                self.window_frame_preceding()
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 2828
                self.window_frame_following()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Window_frame_precedingContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def UNBOUNDED(self):
            return self.getToken(tsqlParser.UNBOUNDED, 0)

        def PRECEDING(self):
            return self.getToken(tsqlParser.PRECEDING, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def CURRENT(self):
            return self.getToken(tsqlParser.CURRENT, 0)

        def ROW(self):
            return self.getToken(tsqlParser.ROW, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_window_frame_preceding

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWindow_frame_preceding" ):
                listener.enterWindow_frame_preceding(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWindow_frame_preceding" ):
                listener.exitWindow_frame_preceding(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWindow_frame_preceding" ):
                return visitor.visitWindow_frame_preceding(self)
            else:
                return visitor.visitChildren(self)




    def window_frame_preceding(self):

        localctx = tsqlParser.Window_frame_precedingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 278, self.RULE_window_frame_preceding)
        try:
            self.state = 2837
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.UNBOUNDED]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2831
                self.match(tsqlParser.UNBOUNDED)
                self.state = 2832
                self.match(tsqlParser.PRECEDING)
                pass
            elif token in [tsqlParser.DECIMAL]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2833
                self.match(tsqlParser.DECIMAL)
                self.state = 2834
                self.match(tsqlParser.PRECEDING)
                pass
            elif token in [tsqlParser.CURRENT]:
                self.enterOuterAlt(localctx, 3)
                self.state = 2835
                self.match(tsqlParser.CURRENT)
                self.state = 2836
                self.match(tsqlParser.ROW)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Window_frame_followingContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def UNBOUNDED(self):
            return self.getToken(tsqlParser.UNBOUNDED, 0)

        def FOLLOWING(self):
            return self.getToken(tsqlParser.FOLLOWING, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_window_frame_following

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWindow_frame_following" ):
                listener.enterWindow_frame_following(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWindow_frame_following" ):
                listener.exitWindow_frame_following(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWindow_frame_following" ):
                return visitor.visitWindow_frame_following(self)
            else:
                return visitor.visitChildren(self)




    def window_frame_following(self):

        localctx = tsqlParser.Window_frame_followingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 280, self.RULE_window_frame_following)
        try:
            self.state = 2843
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.UNBOUNDED]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2839
                self.match(tsqlParser.UNBOUNDED)
                self.state = 2840
                self.match(tsqlParser.FOLLOWING)
                pass
            elif token in [tsqlParser.DECIMAL]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2841
                self.match(tsqlParser.DECIMAL)
                self.state = 2842
                self.match(tsqlParser.FOLLOWING)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Create_database_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILESTREAM(self):
            return self.getToken(tsqlParser.FILESTREAM, 0)

        def database_filestream_option(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.Database_filestream_optionContext)
            else:
                return self.getTypedRuleContext(tsqlParser.Database_filestream_optionContext,i)


        def DEFAULT_LANGUAGE(self):
            return self.getToken(tsqlParser.DEFAULT_LANGUAGE, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def DEFAULT_FULLTEXT_LANGUAGE(self):
            return self.getToken(tsqlParser.DEFAULT_FULLTEXT_LANGUAGE, 0)

        def NESTED_TRIGGERS(self):
            return self.getToken(tsqlParser.NESTED_TRIGGERS, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def TRANSFORM_NOISE_WORDS(self):
            return self.getToken(tsqlParser.TRANSFORM_NOISE_WORDS, 0)

        def TWO_DIGIT_YEAR_CUTOFF(self):
            return self.getToken(tsqlParser.TWO_DIGIT_YEAR_CUTOFF, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def DB_CHAINING(self):
            return self.getToken(tsqlParser.DB_CHAINING, 0)

        def TRUSTWORTHY(self):
            return self.getToken(tsqlParser.TRUSTWORTHY, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_create_database_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreate_database_option" ):
                listener.enterCreate_database_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreate_database_option" ):
                listener.exitCreate_database_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCreate_database_option" ):
                return visitor.visitCreate_database_option(self)
            else:
                return visitor.visitChildren(self)




    def create_database_option(self):

        localctx = tsqlParser.Create_database_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 282, self.RULE_create_database_option)
        self._la = 0 # Token type
        try:
            self.state = 2879
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FILESTREAM]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2845
                self.match(tsqlParser.FILESTREAM)

                self.state = 2846
                self.database_filestream_option()
                self.state = 2851
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,416,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 2847
                        self.match(tsqlParser.COMMA)
                        self.state = 2848
                        self.database_filestream_option() 
                    self.state = 2853
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,416,self._ctx)

                pass
            elif token in [tsqlParser.DEFAULT_LANGUAGE]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2854
                self.match(tsqlParser.DEFAULT_LANGUAGE)
                self.state = 2855
                self.match(tsqlParser.EQUAL)
                self.state = 2858
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 2856
                    self.r_id()
                    pass
                elif token in [tsqlParser.STRING]:
                    self.state = 2857
                    self.match(tsqlParser.STRING)
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            elif token in [tsqlParser.DEFAULT_FULLTEXT_LANGUAGE]:
                self.enterOuterAlt(localctx, 3)
                self.state = 2860
                self.match(tsqlParser.DEFAULT_FULLTEXT_LANGUAGE)
                self.state = 2861
                self.match(tsqlParser.EQUAL)
                self.state = 2864
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                    self.state = 2862
                    self.r_id()
                    pass
                elif token in [tsqlParser.STRING]:
                    self.state = 2863
                    self.match(tsqlParser.STRING)
                    pass
                else:
                    raise NoViableAltException(self)

                pass
            elif token in [tsqlParser.NESTED_TRIGGERS]:
                self.enterOuterAlt(localctx, 4)
                self.state = 2866
                self.match(tsqlParser.NESTED_TRIGGERS)
                self.state = 2867
                self.match(tsqlParser.EQUAL)
                self.state = 2868
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.TRANSFORM_NOISE_WORDS]:
                self.enterOuterAlt(localctx, 5)
                self.state = 2869
                self.match(tsqlParser.TRANSFORM_NOISE_WORDS)
                self.state = 2870
                self.match(tsqlParser.EQUAL)
                self.state = 2871
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.TWO_DIGIT_YEAR_CUTOFF]:
                self.enterOuterAlt(localctx, 6)
                self.state = 2872
                self.match(tsqlParser.TWO_DIGIT_YEAR_CUTOFF)
                self.state = 2873
                self.match(tsqlParser.EQUAL)
                self.state = 2874
                self.match(tsqlParser.DECIMAL)
                pass
            elif token in [tsqlParser.DB_CHAINING]:
                self.enterOuterAlt(localctx, 7)
                self.state = 2875
                self.match(tsqlParser.DB_CHAINING)
                self.state = 2876
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.TRUSTWORTHY]:
                self.enterOuterAlt(localctx, 8)
                self.state = 2877
                self.match(tsqlParser.TRUSTWORTHY)
                self.state = 2878
                _la = self._input.LA(1)
                if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Database_filestream_optionContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LR_BRACKET(self):
            return self.getToken(tsqlParser.LR_BRACKET, 0)

        def RR_BRACKET(self):
            return self.getToken(tsqlParser.RR_BRACKET, 0)

        def NON_TRANSACTED_ACCESS(self):
            return self.getToken(tsqlParser.NON_TRANSACTED_ACCESS, 0)

        def EQUAL(self):
            return self.getToken(tsqlParser.EQUAL, 0)

        def DIRECTORY_NAME(self):
            return self.getToken(tsqlParser.DIRECTORY_NAME, 0)

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def READ_ONLY(self):
            return self.getToken(tsqlParser.READ_ONLY, 0)

        def FULL(self):
            return self.getToken(tsqlParser.FULL, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_database_filestream_option

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDatabase_filestream_option" ):
                listener.enterDatabase_filestream_option(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDatabase_filestream_option" ):
                listener.exitDatabase_filestream_option(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDatabase_filestream_option" ):
                return visitor.visitDatabase_filestream_option(self)
            else:
                return visitor.visitChildren(self)




    def database_filestream_option(self):

        localctx = tsqlParser.Database_filestream_optionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 284, self.RULE_database_filestream_option)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2881
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2888
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.NON_TRANSACTED_ACCESS]:
                self.state = 2882
                self.match(tsqlParser.NON_TRANSACTED_ACCESS)
                self.state = 2883
                self.match(tsqlParser.EQUAL)
                self.state = 2884
                _la = self._input.LA(1)
                if not(_la==tsqlParser.FULL or _la==tsqlParser.OFF or _la==tsqlParser.READ_ONLY):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass
            elif token in [tsqlParser.DIRECTORY_NAME]:
                self.state = 2885
                self.match(tsqlParser.DIRECTORY_NAME)
                self.state = 2886
                self.match(tsqlParser.EQUAL)
                self.state = 2887
                self.match(tsqlParser.STRING)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 2890
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Database_file_specContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def file_group(self):
            return self.getTypedRuleContext(tsqlParser.File_groupContext,0)


        def file_spec(self):
            return self.getTypedRuleContext(tsqlParser.File_specContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_database_file_spec

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDatabase_file_spec" ):
                listener.enterDatabase_file_spec(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDatabase_file_spec" ):
                listener.exitDatabase_file_spec(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDatabase_file_spec" ):
                return visitor.visitDatabase_file_spec(self)
            else:
                return visitor.visitChildren(self)




    def database_file_spec(self):

        localctx = tsqlParser.Database_file_specContext(self, self._ctx, self.state)
        self.enterRule(localctx, 286, self.RULE_database_file_spec)
        try:
            self.state = 2894
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FILEGROUP]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2892
                self.file_group()
                pass
            elif token in [tsqlParser.LR_BRACKET]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2893
                self.file_spec()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class File_groupContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILEGROUP(self):
            return self.getToken(tsqlParser.FILEGROUP, 0)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def file_spec(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.File_specContext)
            else:
                return self.getTypedRuleContext(tsqlParser.File_specContext,i)


        def CONTAINS(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.CONTAINS)
            else:
                return self.getToken(tsqlParser.CONTAINS, i)

        def FILESTREAM(self):
            return self.getToken(tsqlParser.FILESTREAM, 0)

        def DEFAULT(self):
            return self.getToken(tsqlParser.DEFAULT, 0)

        def MEMORY_OPTIMIZED_DATA(self):
            return self.getToken(tsqlParser.MEMORY_OPTIMIZED_DATA, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_file_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_group" ):
                listener.enterFile_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_group" ):
                listener.exitFile_group(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFile_group" ):
                return visitor.visitFile_group(self)
            else:
                return visitor.visitChildren(self)




    def file_group(self):

        localctx = tsqlParser.File_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 288, self.RULE_file_group)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2896
            self.match(tsqlParser.FILEGROUP)
            self.state = 2897
            self.r_id()
            self.state = 2900
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,422,self._ctx)
            if la_ == 1:
                self.state = 2898
                self.match(tsqlParser.CONTAINS)
                self.state = 2899
                self.match(tsqlParser.FILESTREAM)


            self.state = 2903
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.DEFAULT:
                self.state = 2902
                self.match(tsqlParser.DEFAULT)


            self.state = 2907
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.CONTAINS:
                self.state = 2905
                self.match(tsqlParser.CONTAINS)
                self.state = 2906
                self.match(tsqlParser.MEMORY_OPTIMIZED_DATA)


            self.state = 2909
            self.file_spec()
            self.state = 2914
            self._errHandler.sync(self)
            _alt = self._interp.adaptivePredict(self._input,425,self._ctx)
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt==1:
                    self.state = 2910
                    self.match(tsqlParser.COMMA)
                    self.state = 2911
                    self.file_spec() 
                self.state = 2916
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,425,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class File_specContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.r_file = None # Token

        def LR_BRACKET(self):
            return self.getToken(tsqlParser.LR_BRACKET, 0)

        def NAME(self):
            return self.getToken(tsqlParser.NAME, 0)

        def EQUAL(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.EQUAL)
            else:
                return self.getToken(tsqlParser.EQUAL, i)

        def FILENAME(self):
            return self.getToken(tsqlParser.FILENAME, 0)

        def RR_BRACKET(self):
            return self.getToken(tsqlParser.RR_BRACKET, 0)

        def STRING(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.STRING)
            else:
                return self.getToken(tsqlParser.STRING, i)

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def SIZE(self):
            return self.getToken(tsqlParser.SIZE, 0)

        def file_size(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.File_sizeContext)
            else:
                return self.getTypedRuleContext(tsqlParser.File_sizeContext,i)


        def MAXSIZE(self):
            return self.getToken(tsqlParser.MAXSIZE, 0)

        def FILEGROWTH(self):
            return self.getToken(tsqlParser.FILEGROWTH, 0)

        def UNLIMITED(self):
            return self.getToken(tsqlParser.UNLIMITED, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_file_spec

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_spec" ):
                listener.enterFile_spec(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_spec" ):
                listener.exitFile_spec(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFile_spec" ):
                return visitor.visitFile_spec(self)
            else:
                return visitor.visitChildren(self)




    def file_spec(self):

        localctx = tsqlParser.File_specContext(self, self._ctx, self.state)
        self.enterRule(localctx, 290, self.RULE_file_spec)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2917
            self.match(tsqlParser.LR_BRACKET)
            self.state = 2918
            self.match(tsqlParser.NAME)
            self.state = 2919
            self.match(tsqlParser.EQUAL)
            self.state = 2922
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.state = 2920
                self.r_id()
                pass
            elif token in [tsqlParser.STRING]:
                self.state = 2921
                self.match(tsqlParser.STRING)
                pass
            else:
                raise NoViableAltException(self)

            self.state = 2925
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.COMMA:
                self.state = 2924
                self.match(tsqlParser.COMMA)


            self.state = 2927
            self.match(tsqlParser.FILENAME)
            self.state = 2928
            self.match(tsqlParser.EQUAL)
            self.state = 2929
            localctx.r_file = self.match(tsqlParser.STRING)
            self.state = 2931
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.COMMA:
                self.state = 2930
                self.match(tsqlParser.COMMA)


            self.state = 2939
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.SIZE:
                self.state = 2933
                self.match(tsqlParser.SIZE)
                self.state = 2934
                self.match(tsqlParser.EQUAL)
                self.state = 2935
                self.file_size()
                self.state = 2937
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 2936
                    self.match(tsqlParser.COMMA)




            self.state = 2950
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.MAXSIZE:
                self.state = 2941
                self.match(tsqlParser.MAXSIZE)
                self.state = 2942
                self.match(tsqlParser.EQUAL)
                self.state = 2945
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [tsqlParser.DECIMAL]:
                    self.state = 2943
                    self.file_size()
                    pass
                elif token in [tsqlParser.UNLIMITED]:
                    self.state = 2944
                    self.match(tsqlParser.UNLIMITED)
                    pass
                else:
                    raise NoViableAltException(self)

                self.state = 2948
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 2947
                    self.match(tsqlParser.COMMA)




            self.state = 2958
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.FILEGROWTH:
                self.state = 2952
                self.match(tsqlParser.FILEGROWTH)
                self.state = 2953
                self.match(tsqlParser.EQUAL)
                self.state = 2954
                self.file_size()
                self.state = 2956
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 2955
                    self.match(tsqlParser.COMMA)




            self.state = 2960
            self.match(tsqlParser.RR_BRACKET)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Full_table_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.server = None # R_idContext
            self.database = None # R_idContext
            self.schema = None # R_idContext
            self.table = None # R_idContext

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_full_table_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFull_table_name" ):
                listener.enterFull_table_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFull_table_name" ):
                listener.exitFull_table_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFull_table_name" ):
                return visitor.visitFull_table_name(self)
            else:
                return visitor.visitChildren(self)




    def full_table_name(self):

        localctx = tsqlParser.Full_table_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 292, self.RULE_full_table_name)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2979
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,437,self._ctx)
            if la_ == 1:
                self.state = 2962
                localctx.server = self.r_id()
                self.state = 2963
                self.match(tsqlParser.DOT)
                self.state = 2964
                localctx.database = self.r_id()
                self.state = 2965
                self.match(tsqlParser.DOT)
                self.state = 2966
                localctx.schema = self.r_id()
                self.state = 2967
                self.match(tsqlParser.DOT)

            elif la_ == 2:
                self.state = 2969
                localctx.database = self.r_id()
                self.state = 2970
                self.match(tsqlParser.DOT)
                self.state = 2972
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                    self.state = 2971
                    localctx.schema = self.r_id()


                self.state = 2974
                self.match(tsqlParser.DOT)

            elif la_ == 3:
                self.state = 2976
                localctx.schema = self.r_id()
                self.state = 2977
                self.match(tsqlParser.DOT)


            self.state = 2981
            localctx.table = self.r_id()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Table_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.database = None # R_idContext
            self.schema = None # R_idContext
            self.table = None # R_idContext

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_table_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTable_name" ):
                listener.enterTable_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTable_name" ):
                listener.exitTable_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTable_name" ):
                return visitor.visitTable_name(self)
            else:
                return visitor.visitChildren(self)




    def table_name(self):

        localctx = tsqlParser.Table_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 294, self.RULE_table_name)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2993
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,439,self._ctx)
            if la_ == 1:
                self.state = 2983
                localctx.database = self.r_id()
                self.state = 2984
                self.match(tsqlParser.DOT)
                self.state = 2986
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                    self.state = 2985
                    localctx.schema = self.r_id()


                self.state = 2988
                self.match(tsqlParser.DOT)

            elif la_ == 2:
                self.state = 2990
                localctx.schema = self.r_id()
                self.state = 2991
                self.match(tsqlParser.DOT)


            self.state = 2995
            localctx.table = self.r_id()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Simple_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.schema = None # R_idContext
            self.name = None # R_idContext

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_simple_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSimple_name" ):
                listener.enterSimple_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSimple_name" ):
                listener.exitSimple_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSimple_name" ):
                return visitor.visitSimple_name(self)
            else:
                return visitor.visitChildren(self)




    def simple_name(self):

        localctx = tsqlParser.Simple_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 296, self.RULE_simple_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3000
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,440,self._ctx)
            if la_ == 1:
                self.state = 2997
                localctx.schema = self.r_id()
                self.state = 2998
                self.match(tsqlParser.DOT)


            self.state = 3002
            localctx.name = self.r_id()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Func_proc_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.database = None # R_idContext
            self.schema = None # R_idContext
            self.procedure = None # R_idContext

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_func_proc_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunc_proc_name" ):
                listener.enterFunc_proc_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunc_proc_name" ):
                listener.exitFunc_proc_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFunc_proc_name" ):
                return visitor.visitFunc_proc_name(self)
            else:
                return visitor.visitChildren(self)




    def func_proc_name(self):

        localctx = tsqlParser.Func_proc_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 298, self.RULE_func_proc_name)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3014
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,442,self._ctx)
            if la_ == 1:
                self.state = 3004
                localctx.database = self.r_id()
                self.state = 3005
                self.match(tsqlParser.DOT)
                self.state = 3007
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.DOUBLE_QUOTE_ID - 388)) | (1 << (tsqlParser.SQUARE_BRACKET_ID - 388)) | (1 << (tsqlParser.ID - 388)))) != 0):
                    self.state = 3006
                    localctx.schema = self.r_id()


                self.state = 3009
                self.match(tsqlParser.DOT)

            elif la_ == 2:
                self.state = 3011
                localctx.schema = self.r_id()
                self.state = 3012
                self.match(tsqlParser.DOT)


            self.state = 3016
            localctx.procedure = self.r_id()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Ddl_objectContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def full_table_name(self):
            return self.getTypedRuleContext(tsqlParser.Full_table_nameContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_ddl_object

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDdl_object" ):
                listener.enterDdl_object(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDdl_object" ):
                listener.exitDdl_object(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDdl_object" ):
                return visitor.visitDdl_object(self)
            else:
                return visitor.visitChildren(self)




    def ddl_object(self):

        localctx = tsqlParser.Ddl_objectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 300, self.RULE_ddl_object)
        try:
            self.state = 3020
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 3018
                self.full_table_name()
                pass
            elif token in [tsqlParser.LOCAL_ID]:
                self.enterOuterAlt(localctx, 2)
                self.state = 3019
                self.match(tsqlParser.LOCAL_ID)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Full_column_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.table = None # Table_nameContext
            self.name = None # R_idContext

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def table_name(self):
            return self.getTypedRuleContext(tsqlParser.Table_nameContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_full_column_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFull_column_name" ):
                listener.enterFull_column_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFull_column_name" ):
                listener.exitFull_column_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFull_column_name" ):
                return visitor.visitFull_column_name(self)
            else:
                return visitor.visitChildren(self)




    def full_column_name(self):

        localctx = tsqlParser.Full_column_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 302, self.RULE_full_column_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3025
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,444,self._ctx)
            if la_ == 1:
                self.state = 3022
                localctx.table = self.table_name()
                self.state = 3023
                self.match(tsqlParser.DOT)


            self.state = 3027
            localctx.name = self.r_id()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Column_name_listContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def r_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(tsqlParser.R_idContext)
            else:
                return self.getTypedRuleContext(tsqlParser.R_idContext,i)


        def getRuleIndex(self):
            return tsqlParser.RULE_column_name_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColumn_name_list" ):
                listener.enterColumn_name_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColumn_name_list" ):
                listener.exitColumn_name_list(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColumn_name_list" ):
                return visitor.visitColumn_name_list(self)
            else:
                return visitor.visitChildren(self)




    def column_name_list(self):

        localctx = tsqlParser.Column_name_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 304, self.RULE_column_name_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3029
            self.r_id()
            self.state = 3034
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==tsqlParser.COMMA:
                self.state = 3030
                self.match(tsqlParser.COMMA)
                self.state = 3031
                self.r_id()
                self.state = 3036
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Cursor_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def LOCAL_ID(self):
            return self.getToken(tsqlParser.LOCAL_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_cursor_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCursor_name" ):
                listener.enterCursor_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCursor_name" ):
                listener.exitCursor_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCursor_name" ):
                return visitor.visitCursor_name(self)
            else:
                return visitor.visitChildren(self)




    def cursor_name(self):

        localctx = tsqlParser.Cursor_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 306, self.RULE_cursor_name)
        try:
            self.state = 3039
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 3037
                self.r_id()
                pass
            elif token in [tsqlParser.LOCAL_ID]:
                self.enterOuterAlt(localctx, 2)
                self.state = 3038
                self.match(tsqlParser.LOCAL_ID)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class On_offContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ON(self):
            return self.getToken(tsqlParser.ON, 0)

        def OFF(self):
            return self.getToken(tsqlParser.OFF, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_on_off

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOn_off" ):
                listener.enterOn_off(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOn_off" ):
                listener.exitOn_off(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitOn_off" ):
                return visitor.visitOn_off(self)
            else:
                return visitor.visitChildren(self)




    def on_off(self):

        localctx = tsqlParser.On_offContext(self, self._ctx, self.state)
        self.enterRule(localctx, 308, self.RULE_on_off)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3041
            _la = self._input.LA(1)
            if not(_la==tsqlParser.OFF or _la==tsqlParser.ON):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ClusteredContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CLUSTERED(self):
            return self.getToken(tsqlParser.CLUSTERED, 0)

        def NONCLUSTERED(self):
            return self.getToken(tsqlParser.NONCLUSTERED, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_clustered

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClustered" ):
                listener.enterClustered(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClustered" ):
                listener.exitClustered(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitClustered" ):
                return visitor.visitClustered(self)
            else:
                return visitor.visitChildren(self)




    def clustered(self):

        localctx = tsqlParser.ClusteredContext(self, self._ctx, self.state)
        self.enterRule(localctx, 310, self.RULE_clustered)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3043
            _la = self._input.LA(1)
            if not(_la==tsqlParser.CLUSTERED or _la==tsqlParser.NONCLUSTERED):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Null_notnullContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NULL(self):
            return self.getToken(tsqlParser.NULL, 0)

        def NOT(self):
            return self.getToken(tsqlParser.NOT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_null_notnull

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNull_notnull" ):
                listener.enterNull_notnull(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNull_notnull" ):
                listener.exitNull_notnull(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitNull_notnull" ):
                return visitor.visitNull_notnull(self)
            else:
                return visitor.visitChildren(self)




    def null_notnull(self):

        localctx = tsqlParser.Null_notnullContext(self, self._ctx, self.state)
        self.enterRule(localctx, 312, self.RULE_null_notnull)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3046
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==tsqlParser.NOT:
                self.state = 3045
                self.match(tsqlParser.NOT)


            self.state = 3048
            self.match(tsqlParser.NULL)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Scalar_function_nameContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def func_proc_name(self):
            return self.getTypedRuleContext(tsqlParser.Func_proc_nameContext,0)


        def RIGHT(self):
            return self.getToken(tsqlParser.RIGHT, 0)

        def LEFT(self):
            return self.getToken(tsqlParser.LEFT, 0)

        def BINARY_CHECKSUM(self):
            return self.getToken(tsqlParser.BINARY_CHECKSUM, 0)

        def CHECKSUM(self):
            return self.getToken(tsqlParser.CHECKSUM, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_scalar_function_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterScalar_function_name" ):
                listener.enterScalar_function_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitScalar_function_name" ):
                listener.exitScalar_function_name(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitScalar_function_name" ):
                return visitor.visitScalar_function_name(self)
            else:
                return visitor.visitChildren(self)




    def scalar_function_name(self):

        localctx = tsqlParser.Scalar_function_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 314, self.RULE_scalar_function_name)
        try:
            self.state = 3055
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.DOUBLE_QUOTE_ID, tsqlParser.SQUARE_BRACKET_ID, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 3050
                self.func_proc_name()
                pass
            elif token in [tsqlParser.RIGHT]:
                self.enterOuterAlt(localctx, 2)
                self.state = 3051
                self.match(tsqlParser.RIGHT)
                pass
            elif token in [tsqlParser.LEFT]:
                self.enterOuterAlt(localctx, 3)
                self.state = 3052
                self.match(tsqlParser.LEFT)
                pass
            elif token in [tsqlParser.BINARY_CHECKSUM]:
                self.enterOuterAlt(localctx, 4)
                self.state = 3053
                self.match(tsqlParser.BINARY_CHECKSUM)
                pass
            elif token in [tsqlParser.CHECKSUM]:
                self.enterOuterAlt(localctx, 5)
                self.state = 3054
                self.match(tsqlParser.CHECKSUM)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Data_typeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def r_id(self):
            return self.getTypedRuleContext(tsqlParser.R_idContext,0)


        def IDENTITY(self):
            return self.getToken(tsqlParser.IDENTITY, 0)

        def DECIMAL(self, i:int=None):
            if i is None:
                return self.getTokens(tsqlParser.DECIMAL)
            else:
                return self.getToken(tsqlParser.DECIMAL, i)

        def MAX(self):
            return self.getToken(tsqlParser.MAX, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_data_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterData_type" ):
                listener.enterData_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitData_type" ):
                listener.exitData_type(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitData_type" ):
                return visitor.visitData_type(self)
            else:
                return visitor.visitChildren(self)




    def data_type(self):

        localctx = tsqlParser.Data_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 316, self.RULE_data_type)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3057
            self.r_id()
            self.state = 3059
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,449,self._ctx)
            if la_ == 1:
                self.state = 3058
                self.match(tsqlParser.IDENTITY)


            self.state = 3068
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,451,self._ctx)
            if la_ == 1:
                self.state = 3061
                self.match(tsqlParser.LR_BRACKET)
                self.state = 3062
                _la = self._input.LA(1)
                if not(_la==tsqlParser.MAX or _la==tsqlParser.DECIMAL):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                self.state = 3065
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.COMMA:
                    self.state = 3063
                    self.match(tsqlParser.COMMA)
                    self.state = 3064
                    self.match(tsqlParser.DECIMAL)


                self.state = 3067
                self.match(tsqlParser.RR_BRACKET)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Default_valueContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NULL(self):
            return self.getToken(tsqlParser.NULL, 0)

        def constant(self):
            return self.getTypedRuleContext(tsqlParser.ConstantContext,0)


        def getRuleIndex(self):
            return tsqlParser.RULE_default_value

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDefault_value" ):
                listener.enterDefault_value(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDefault_value" ):
                listener.exitDefault_value(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitDefault_value" ):
                return visitor.visitDefault_value(self)
            else:
                return visitor.visitChildren(self)




    def default_value(self):

        localctx = tsqlParser.Default_valueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 318, self.RULE_default_value)
        try:
            self.state = 3072
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.NULL]:
                self.enterOuterAlt(localctx, 1)
                self.state = 3070
                self.match(tsqlParser.NULL)
                pass
            elif token in [tsqlParser.DECIMAL, tsqlParser.STRING, tsqlParser.BINARY, tsqlParser.FLOAT, tsqlParser.REAL, tsqlParser.DOLLAR, tsqlParser.PLUS, tsqlParser.MINUS]:
                self.enterOuterAlt(localctx, 2)
                self.state = 3071
                self.constant()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class ConstantContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser
            self.dollar = None # Token

        def STRING(self):
            return self.getToken(tsqlParser.STRING, 0)

        def BINARY(self):
            return self.getToken(tsqlParser.BINARY, 0)

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def sign(self):
            return self.getTypedRuleContext(tsqlParser.SignContext,0)


        def REAL(self):
            return self.getToken(tsqlParser.REAL, 0)

        def FLOAT(self):
            return self.getToken(tsqlParser.FLOAT, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_constant

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterConstant" ):
                listener.enterConstant(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitConstant" ):
                listener.exitConstant(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitConstant" ):
                return visitor.visitConstant(self)
            else:
                return visitor.visitChildren(self)




    def constant(self):

        localctx = tsqlParser.ConstantContext(self, self._ctx, self.state)
        self.enterRule(localctx, 320, self.RULE_constant)
        self._la = 0 # Token type
        try:
            self.state = 3089
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,456,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 3074
                self.match(tsqlParser.STRING)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 3075
                self.match(tsqlParser.BINARY)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 3077
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PLUS or _la==tsqlParser.MINUS:
                    self.state = 3076
                    self.sign()


                self.state = 3079
                self.match(tsqlParser.DECIMAL)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 3081
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PLUS or _la==tsqlParser.MINUS:
                    self.state = 3080
                    self.sign()


                self.state = 3083
                _la = self._input.LA(1)
                if not(_la==tsqlParser.FLOAT or _la==tsqlParser.REAL):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 3085
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==tsqlParser.PLUS or _la==tsqlParser.MINUS:
                    self.state = 3084
                    self.sign()


                self.state = 3087
                localctx.dollar = self.match(tsqlParser.DOLLAR)
                self.state = 3088
                _la = self._input.LA(1)
                if not(_la==tsqlParser.DECIMAL or _la==tsqlParser.FLOAT):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class SignContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_sign

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSign" ):
                listener.enterSign(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSign" ):
                listener.exitSign(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSign" ):
                return visitor.visitSign(self)
            else:
                return visitor.visitChildren(self)




    def sign(self):

        localctx = tsqlParser.SignContext(self, self._ctx, self.state)
        self.enterRule(localctx, 322, self.RULE_sign)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3091
            _la = self._input.LA(1)
            if not(_la==tsqlParser.PLUS or _la==tsqlParser.MINUS):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class R_idContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def simple_id(self):
            return self.getTypedRuleContext(tsqlParser.Simple_idContext,0)


        def DOUBLE_QUOTE_ID(self):
            return self.getToken(tsqlParser.DOUBLE_QUOTE_ID, 0)

        def SQUARE_BRACKET_ID(self):
            return self.getToken(tsqlParser.SQUARE_BRACKET_ID, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_r_id

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterR_id" ):
                listener.enterR_id(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitR_id" ):
                listener.exitR_id(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitR_id" ):
                return visitor.visitR_id(self)
            else:
                return visitor.visitChildren(self)




    def r_id(self):

        localctx = tsqlParser.R_idContext(self, self._ctx, self.state)
        self.enterRule(localctx, 324, self.RULE_r_id)
        try:
            self.state = 3096
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [tsqlParser.FORCESEEK, tsqlParser.ABSOLUTE, tsqlParser.APPLY, tsqlParser.AUTO, tsqlParser.AVG, tsqlParser.BASE64, tsqlParser.CALLER, tsqlParser.CAST, tsqlParser.CATCH, tsqlParser.CHECKSUM_AGG, tsqlParser.COMMITTED, tsqlParser.CONCAT, tsqlParser.CONTROL, tsqlParser.COOKIE, tsqlParser.COUNT, tsqlParser.COUNT_BIG, tsqlParser.DELAY, tsqlParser.DELETED, tsqlParser.DENSE_RANK, tsqlParser.DISABLE, tsqlParser.DYNAMIC, tsqlParser.ENCRYPTION, tsqlParser.EXPAND, tsqlParser.FAST, tsqlParser.FAST_FORWARD, tsqlParser.FIRST, tsqlParser.FOLLOWING, tsqlParser.FORCE, tsqlParser.FORCED, tsqlParser.FORWARD_ONLY, tsqlParser.FULLSCAN, tsqlParser.GLOBAL, tsqlParser.GO, tsqlParser.GROUPING, tsqlParser.GROUPING_ID, tsqlParser.HASH, tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, tsqlParser.IMPERSONATE, tsqlParser.INSENSITIVE, tsqlParser.INSERTED, tsqlParser.ISOLATION, tsqlParser.KEEP, tsqlParser.KEEPFIXED, tsqlParser.KEYSET, tsqlParser.LAST, tsqlParser.LEVEL, tsqlParser.LOCAL, tsqlParser.LOCK_ESCALATION, tsqlParser.LOGIN, tsqlParser.LOOP, tsqlParser.MARK, tsqlParser.MAX, tsqlParser.MAXDOP, tsqlParser.MAXRECURSION, tsqlParser.MIN, tsqlParser.MODIFY, tsqlParser.NAME, tsqlParser.NEXT, tsqlParser.NOCOUNT, tsqlParser.NOEXPAND, tsqlParser.NORECOMPUTE, tsqlParser.NTILE, tsqlParser.NUMBER, tsqlParser.OFFSET, tsqlParser.ONLINE, tsqlParser.ONLY, tsqlParser.OPTIMISTIC, tsqlParser.OPTIMIZE, tsqlParser.OUT, tsqlParser.OUTPUT, tsqlParser.OWNER, tsqlParser.PARAMETERIZATION, tsqlParser.PARTITION, tsqlParser.PATH, tsqlParser.PRECEDING, tsqlParser.PRIOR, tsqlParser.PRIVILEGES, tsqlParser.RANGE, tsqlParser.RANK, tsqlParser.READONLY, tsqlParser.READ_ONLY, tsqlParser.RECOMPILE, tsqlParser.RELATIVE, tsqlParser.REMOTE, tsqlParser.REPEATABLE, tsqlParser.ROBUST, tsqlParser.ROOT, tsqlParser.ROW, tsqlParser.ROWGUID, tsqlParser.ROWS, tsqlParser.ROW_NUMBER, tsqlParser.SAMPLE, tsqlParser.SCHEMABINDING, tsqlParser.SCROLL, tsqlParser.SCROLL_LOCKS, tsqlParser.SELF, tsqlParser.SERIALIZABLE, tsqlParser.SIMPLE, tsqlParser.SIZE, tsqlParser.SNAPSHOT, tsqlParser.SPATIAL_WINDOW_MAX_CELLS, tsqlParser.STATIC, tsqlParser.STATS_STREAM, tsqlParser.STDEV, tsqlParser.STDEVP, tsqlParser.SUM, tsqlParser.TEXTIMAGE_ON, tsqlParser.THROW, tsqlParser.TIES, tsqlParser.TIME, tsqlParser.TRY, tsqlParser.TYPE, tsqlParser.TYPE_WARNING, tsqlParser.UNBOUNDED, tsqlParser.UNCOMMITTED, tsqlParser.UNKNOWN, tsqlParser.USING, tsqlParser.VAR, tsqlParser.VARP, tsqlParser.VIEWS, tsqlParser.VIEW_METADATA, tsqlParser.WORK, tsqlParser.XML, tsqlParser.XMLNAMESPACES, tsqlParser.ID]:
                self.enterOuterAlt(localctx, 1)
                self.state = 3093
                self.simple_id()
                pass
            elif token in [tsqlParser.DOUBLE_QUOTE_ID]:
                self.enterOuterAlt(localctx, 2)
                self.state = 3094
                self.match(tsqlParser.DOUBLE_QUOTE_ID)
                pass
            elif token in [tsqlParser.SQUARE_BRACKET_ID]:
                self.enterOuterAlt(localctx, 3)
                self.state = 3095
                self.match(tsqlParser.SQUARE_BRACKET_ID)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Simple_idContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ID(self):
            return self.getToken(tsqlParser.ID, 0)

        def ABSOLUTE(self):
            return self.getToken(tsqlParser.ABSOLUTE, 0)

        def APPLY(self):
            return self.getToken(tsqlParser.APPLY, 0)

        def AUTO(self):
            return self.getToken(tsqlParser.AUTO, 0)

        def AVG(self):
            return self.getToken(tsqlParser.AVG, 0)

        def BASE64(self):
            return self.getToken(tsqlParser.BASE64, 0)

        def CALLER(self):
            return self.getToken(tsqlParser.CALLER, 0)

        def CAST(self):
            return self.getToken(tsqlParser.CAST, 0)

        def CATCH(self):
            return self.getToken(tsqlParser.CATCH, 0)

        def CHECKSUM_AGG(self):
            return self.getToken(tsqlParser.CHECKSUM_AGG, 0)

        def COMMITTED(self):
            return self.getToken(tsqlParser.COMMITTED, 0)

        def CONCAT(self):
            return self.getToken(tsqlParser.CONCAT, 0)

        def CONTROL(self):
            return self.getToken(tsqlParser.CONTROL, 0)

        def COOKIE(self):
            return self.getToken(tsqlParser.COOKIE, 0)

        def COUNT(self):
            return self.getToken(tsqlParser.COUNT, 0)

        def COUNT_BIG(self):
            return self.getToken(tsqlParser.COUNT_BIG, 0)

        def DELAY(self):
            return self.getToken(tsqlParser.DELAY, 0)

        def DELETED(self):
            return self.getToken(tsqlParser.DELETED, 0)

        def DENSE_RANK(self):
            return self.getToken(tsqlParser.DENSE_RANK, 0)

        def DISABLE(self):
            return self.getToken(tsqlParser.DISABLE, 0)

        def DYNAMIC(self):
            return self.getToken(tsqlParser.DYNAMIC, 0)

        def ENCRYPTION(self):
            return self.getToken(tsqlParser.ENCRYPTION, 0)

        def EXPAND(self):
            return self.getToken(tsqlParser.EXPAND, 0)

        def FAST(self):
            return self.getToken(tsqlParser.FAST, 0)

        def FAST_FORWARD(self):
            return self.getToken(tsqlParser.FAST_FORWARD, 0)

        def FIRST(self):
            return self.getToken(tsqlParser.FIRST, 0)

        def FOLLOWING(self):
            return self.getToken(tsqlParser.FOLLOWING, 0)

        def FORCE(self):
            return self.getToken(tsqlParser.FORCE, 0)

        def FORCESEEK(self):
            return self.getToken(tsqlParser.FORCESEEK, 0)

        def FORWARD_ONLY(self):
            return self.getToken(tsqlParser.FORWARD_ONLY, 0)

        def FULLSCAN(self):
            return self.getToken(tsqlParser.FULLSCAN, 0)

        def GLOBAL(self):
            return self.getToken(tsqlParser.GLOBAL, 0)

        def GO(self):
            return self.getToken(tsqlParser.GO, 0)

        def GROUPING(self):
            return self.getToken(tsqlParser.GROUPING, 0)

        def GROUPING_ID(self):
            return self.getToken(tsqlParser.GROUPING_ID, 0)

        def HASH(self):
            return self.getToken(tsqlParser.HASH, 0)

        def IMPERSONATE(self):
            return self.getToken(tsqlParser.IMPERSONATE, 0)

        def INSENSITIVE(self):
            return self.getToken(tsqlParser.INSENSITIVE, 0)

        def INSERTED(self):
            return self.getToken(tsqlParser.INSERTED, 0)

        def ISOLATION(self):
            return self.getToken(tsqlParser.ISOLATION, 0)

        def KEEP(self):
            return self.getToken(tsqlParser.KEEP, 0)

        def KEEPFIXED(self):
            return self.getToken(tsqlParser.KEEPFIXED, 0)

        def FORCED(self):
            return self.getToken(tsqlParser.FORCED, 0)

        def KEYSET(self):
            return self.getToken(tsqlParser.KEYSET, 0)

        def IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX(self):
            return self.getToken(tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX, 0)

        def LAST(self):
            return self.getToken(tsqlParser.LAST, 0)

        def LEVEL(self):
            return self.getToken(tsqlParser.LEVEL, 0)

        def LOCAL(self):
            return self.getToken(tsqlParser.LOCAL, 0)

        def LOCK_ESCALATION(self):
            return self.getToken(tsqlParser.LOCK_ESCALATION, 0)

        def LOGIN(self):
            return self.getToken(tsqlParser.LOGIN, 0)

        def LOOP(self):
            return self.getToken(tsqlParser.LOOP, 0)

        def MARK(self):
            return self.getToken(tsqlParser.MARK, 0)

        def MAX(self):
            return self.getToken(tsqlParser.MAX, 0)

        def MAXDOP(self):
            return self.getToken(tsqlParser.MAXDOP, 0)

        def MAXRECURSION(self):
            return self.getToken(tsqlParser.MAXRECURSION, 0)

        def MIN(self):
            return self.getToken(tsqlParser.MIN, 0)

        def MODIFY(self):
            return self.getToken(tsqlParser.MODIFY, 0)

        def NAME(self):
            return self.getToken(tsqlParser.NAME, 0)

        def NEXT(self):
            return self.getToken(tsqlParser.NEXT, 0)

        def NOCOUNT(self):
            return self.getToken(tsqlParser.NOCOUNT, 0)

        def NOEXPAND(self):
            return self.getToken(tsqlParser.NOEXPAND, 0)

        def NORECOMPUTE(self):
            return self.getToken(tsqlParser.NORECOMPUTE, 0)

        def NTILE(self):
            return self.getToken(tsqlParser.NTILE, 0)

        def NUMBER(self):
            return self.getToken(tsqlParser.NUMBER, 0)

        def OFFSET(self):
            return self.getToken(tsqlParser.OFFSET, 0)

        def ONLINE(self):
            return self.getToken(tsqlParser.ONLINE, 0)

        def ONLY(self):
            return self.getToken(tsqlParser.ONLY, 0)

        def OPTIMISTIC(self):
            return self.getToken(tsqlParser.OPTIMISTIC, 0)

        def OPTIMIZE(self):
            return self.getToken(tsqlParser.OPTIMIZE, 0)

        def OUT(self):
            return self.getToken(tsqlParser.OUT, 0)

        def OUTPUT(self):
            return self.getToken(tsqlParser.OUTPUT, 0)

        def OWNER(self):
            return self.getToken(tsqlParser.OWNER, 0)

        def PARAMETERIZATION(self):
            return self.getToken(tsqlParser.PARAMETERIZATION, 0)

        def PARTITION(self):
            return self.getToken(tsqlParser.PARTITION, 0)

        def PATH(self):
            return self.getToken(tsqlParser.PATH, 0)

        def PRECEDING(self):
            return self.getToken(tsqlParser.PRECEDING, 0)

        def PRIOR(self):
            return self.getToken(tsqlParser.PRIOR, 0)

        def PRIVILEGES(self):
            return self.getToken(tsqlParser.PRIVILEGES, 0)

        def RANGE(self):
            return self.getToken(tsqlParser.RANGE, 0)

        def RANK(self):
            return self.getToken(tsqlParser.RANK, 0)

        def READONLY(self):
            return self.getToken(tsqlParser.READONLY, 0)

        def READ_ONLY(self):
            return self.getToken(tsqlParser.READ_ONLY, 0)

        def RECOMPILE(self):
            return self.getToken(tsqlParser.RECOMPILE, 0)

        def RELATIVE(self):
            return self.getToken(tsqlParser.RELATIVE, 0)

        def REMOTE(self):
            return self.getToken(tsqlParser.REMOTE, 0)

        def REPEATABLE(self):
            return self.getToken(tsqlParser.REPEATABLE, 0)

        def ROBUST(self):
            return self.getToken(tsqlParser.ROBUST, 0)

        def ROOT(self):
            return self.getToken(tsqlParser.ROOT, 0)

        def ROW(self):
            return self.getToken(tsqlParser.ROW, 0)

        def ROWGUID(self):
            return self.getToken(tsqlParser.ROWGUID, 0)

        def ROWS(self):
            return self.getToken(tsqlParser.ROWS, 0)

        def ROW_NUMBER(self):
            return self.getToken(tsqlParser.ROW_NUMBER, 0)

        def SAMPLE(self):
            return self.getToken(tsqlParser.SAMPLE, 0)

        def SCHEMABINDING(self):
            return self.getToken(tsqlParser.SCHEMABINDING, 0)

        def SCROLL(self):
            return self.getToken(tsqlParser.SCROLL, 0)

        def SCROLL_LOCKS(self):
            return self.getToken(tsqlParser.SCROLL_LOCKS, 0)

        def SELF(self):
            return self.getToken(tsqlParser.SELF, 0)

        def SERIALIZABLE(self):
            return self.getToken(tsqlParser.SERIALIZABLE, 0)

        def SIMPLE(self):
            return self.getToken(tsqlParser.SIMPLE, 0)

        def SIZE(self):
            return self.getToken(tsqlParser.SIZE, 0)

        def SNAPSHOT(self):
            return self.getToken(tsqlParser.SNAPSHOT, 0)

        def SPATIAL_WINDOW_MAX_CELLS(self):
            return self.getToken(tsqlParser.SPATIAL_WINDOW_MAX_CELLS, 0)

        def STATIC(self):
            return self.getToken(tsqlParser.STATIC, 0)

        def STATS_STREAM(self):
            return self.getToken(tsqlParser.STATS_STREAM, 0)

        def STDEV(self):
            return self.getToken(tsqlParser.STDEV, 0)

        def STDEVP(self):
            return self.getToken(tsqlParser.STDEVP, 0)

        def SUM(self):
            return self.getToken(tsqlParser.SUM, 0)

        def TEXTIMAGE_ON(self):
            return self.getToken(tsqlParser.TEXTIMAGE_ON, 0)

        def THROW(self):
            return self.getToken(tsqlParser.THROW, 0)

        def TIES(self):
            return self.getToken(tsqlParser.TIES, 0)

        def TIME(self):
            return self.getToken(tsqlParser.TIME, 0)

        def TRY(self):
            return self.getToken(tsqlParser.TRY, 0)

        def TYPE(self):
            return self.getToken(tsqlParser.TYPE, 0)

        def TYPE_WARNING(self):
            return self.getToken(tsqlParser.TYPE_WARNING, 0)

        def UNBOUNDED(self):
            return self.getToken(tsqlParser.UNBOUNDED, 0)

        def UNCOMMITTED(self):
            return self.getToken(tsqlParser.UNCOMMITTED, 0)

        def UNKNOWN(self):
            return self.getToken(tsqlParser.UNKNOWN, 0)

        def USING(self):
            return self.getToken(tsqlParser.USING, 0)

        def VAR(self):
            return self.getToken(tsqlParser.VAR, 0)

        def VARP(self):
            return self.getToken(tsqlParser.VARP, 0)

        def VIEW_METADATA(self):
            return self.getToken(tsqlParser.VIEW_METADATA, 0)

        def VIEWS(self):
            return self.getToken(tsqlParser.VIEWS, 0)

        def WORK(self):
            return self.getToken(tsqlParser.WORK, 0)

        def XML(self):
            return self.getToken(tsqlParser.XML, 0)

        def XMLNAMESPACES(self):
            return self.getToken(tsqlParser.XMLNAMESPACES, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_simple_id

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSimple_id" ):
                listener.enterSimple_id(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSimple_id" ):
                listener.exitSimple_id(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSimple_id" ):
                return visitor.visitSimple_id(self)
            else:
                return visitor.visitChildren(self)




    def simple_id(self):

        localctx = tsqlParser.Simple_idContext(self, self._ctx, self.state)
        self.enterRule(localctx, 326, self.RULE_simple_id)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3098
            _la = self._input.LA(1)
            if not(_la==tsqlParser.FORCESEEK or ((((_la - 193)) & ~0x3f) == 0 and ((1 << (_la - 193)) & ((1 << (tsqlParser.ABSOLUTE - 193)) | (1 << (tsqlParser.APPLY - 193)) | (1 << (tsqlParser.AUTO - 193)) | (1 << (tsqlParser.AVG - 193)) | (1 << (tsqlParser.BASE64 - 193)) | (1 << (tsqlParser.CALLER - 193)) | (1 << (tsqlParser.CAST - 193)) | (1 << (tsqlParser.CATCH - 193)) | (1 << (tsqlParser.CHECKSUM_AGG - 193)) | (1 << (tsqlParser.COMMITTED - 193)) | (1 << (tsqlParser.CONCAT - 193)) | (1 << (tsqlParser.CONTROL - 193)) | (1 << (tsqlParser.COOKIE - 193)) | (1 << (tsqlParser.COUNT - 193)) | (1 << (tsqlParser.COUNT_BIG - 193)) | (1 << (tsqlParser.DELAY - 193)) | (1 << (tsqlParser.DELETED - 193)) | (1 << (tsqlParser.DENSE_RANK - 193)) | (1 << (tsqlParser.DISABLE - 193)) | (1 << (tsqlParser.DYNAMIC - 193)) | (1 << (tsqlParser.ENCRYPTION - 193)) | (1 << (tsqlParser.EXPAND - 193)) | (1 << (tsqlParser.FAST - 193)) | (1 << (tsqlParser.FAST_FORWARD - 193)))) != 0) or ((((_la - 259)) & ~0x3f) == 0 and ((1 << (_la - 259)) & ((1 << (tsqlParser.FIRST - 259)) | (1 << (tsqlParser.FOLLOWING - 259)) | (1 << (tsqlParser.FORCE - 259)) | (1 << (tsqlParser.FORCED - 259)) | (1 << (tsqlParser.FORWARD_ONLY - 259)) | (1 << (tsqlParser.FULLSCAN - 259)) | (1 << (tsqlParser.GLOBAL - 259)) | (1 << (tsqlParser.GO - 259)) | (1 << (tsqlParser.GROUPING - 259)) | (1 << (tsqlParser.GROUPING_ID - 259)) | (1 << (tsqlParser.HASH - 259)) | (1 << (tsqlParser.IGNORE_NONCLUSTERED_COLUMNSTORE_INDEX - 259)) | (1 << (tsqlParser.IMPERSONATE - 259)) | (1 << (tsqlParser.INSENSITIVE - 259)) | (1 << (tsqlParser.INSERTED - 259)) | (1 << (tsqlParser.ISOLATION - 259)) | (1 << (tsqlParser.KEEP - 259)) | (1 << (tsqlParser.KEEPFIXED - 259)) | (1 << (tsqlParser.KEYSET - 259)) | (1 << (tsqlParser.LAST - 259)) | (1 << (tsqlParser.LEVEL - 259)) | (1 << (tsqlParser.LOCAL - 259)) | (1 << (tsqlParser.LOCK_ESCALATION - 259)) | (1 << (tsqlParser.LOGIN - 259)) | (1 << (tsqlParser.LOOP - 259)) | (1 << (tsqlParser.MARK - 259)) | (1 << (tsqlParser.MAX - 259)) | (1 << (tsqlParser.MAXDOP - 259)) | (1 << (tsqlParser.MAXRECURSION - 259)) | (1 << (tsqlParser.MIN - 259)) | (1 << (tsqlParser.MODIFY - 259)) | (1 << (tsqlParser.NAME - 259)) | (1 << (tsqlParser.NEXT - 259)) | (1 << (tsqlParser.NOCOUNT - 259)) | (1 << (tsqlParser.NOEXPAND - 259)) | (1 << (tsqlParser.NORECOMPUTE - 259)) | (1 << (tsqlParser.NTILE - 259)) | (1 << (tsqlParser.NUMBER - 259)) | (1 << (tsqlParser.OFFSET - 259)) | (1 << (tsqlParser.ONLINE - 259)) | (1 << (tsqlParser.ONLY - 259)) | (1 << (tsqlParser.OPTIMISTIC - 259)) | (1 << (tsqlParser.OPTIMIZE - 259)) | (1 << (tsqlParser.OUT - 259)))) != 0) or ((((_la - 323)) & ~0x3f) == 0 and ((1 << (_la - 323)) & ((1 << (tsqlParser.OUTPUT - 323)) | (1 << (tsqlParser.OWNER - 323)) | (1 << (tsqlParser.PARAMETERIZATION - 323)) | (1 << (tsqlParser.PARTITION - 323)) | (1 << (tsqlParser.PATH - 323)) | (1 << (tsqlParser.PRECEDING - 323)) | (1 << (tsqlParser.PRIOR - 323)) | (1 << (tsqlParser.PRIVILEGES - 323)) | (1 << (tsqlParser.RANGE - 323)) | (1 << (tsqlParser.RANK - 323)) | (1 << (tsqlParser.READONLY - 323)) | (1 << (tsqlParser.READ_ONLY - 323)) | (1 << (tsqlParser.RECOMPILE - 323)) | (1 << (tsqlParser.RELATIVE - 323)) | (1 << (tsqlParser.REMOTE - 323)) | (1 << (tsqlParser.REPEATABLE - 323)) | (1 << (tsqlParser.ROBUST - 323)) | (1 << (tsqlParser.ROOT - 323)) | (1 << (tsqlParser.ROW - 323)) | (1 << (tsqlParser.ROWGUID - 323)) | (1 << (tsqlParser.ROWS - 323)) | (1 << (tsqlParser.ROW_NUMBER - 323)) | (1 << (tsqlParser.SAMPLE - 323)) | (1 << (tsqlParser.SCHEMABINDING - 323)) | (1 << (tsqlParser.SCROLL - 323)) | (1 << (tsqlParser.SCROLL_LOCKS - 323)) | (1 << (tsqlParser.SELF - 323)) | (1 << (tsqlParser.SERIALIZABLE - 323)) | (1 << (tsqlParser.SIMPLE - 323)) | (1 << (tsqlParser.SIZE - 323)) | (1 << (tsqlParser.SNAPSHOT - 323)) | (1 << (tsqlParser.SPATIAL_WINDOW_MAX_CELLS - 323)) | (1 << (tsqlParser.STATIC - 323)) | (1 << (tsqlParser.STATS_STREAM - 323)) | (1 << (tsqlParser.STDEV - 323)) | (1 << (tsqlParser.STDEVP - 323)) | (1 << (tsqlParser.SUM - 323)) | (1 << (tsqlParser.TEXTIMAGE_ON - 323)) | (1 << (tsqlParser.THROW - 323)) | (1 << (tsqlParser.TIES - 323)) | (1 << (tsqlParser.TIME - 323)) | (1 << (tsqlParser.TRY - 323)) | (1 << (tsqlParser.TYPE - 323)) | (1 << (tsqlParser.TYPE_WARNING - 323)) | (1 << (tsqlParser.UNBOUNDED - 323)) | (1 << (tsqlParser.UNCOMMITTED - 323)) | (1 << (tsqlParser.UNKNOWN - 323)))) != 0) or ((((_la - 388)) & ~0x3f) == 0 and ((1 << (_la - 388)) & ((1 << (tsqlParser.USING - 388)) | (1 << (tsqlParser.VAR - 388)) | (1 << (tsqlParser.VARP - 388)) | (1 << (tsqlParser.VIEWS - 388)) | (1 << (tsqlParser.VIEW_METADATA - 388)) | (1 << (tsqlParser.WORK - 388)) | (1 << (tsqlParser.XML - 388)) | (1 << (tsqlParser.XMLNAMESPACES - 388)) | (1 << (tsqlParser.ID - 388)))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Comparison_operatorContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_comparison_operator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterComparison_operator" ):
                listener.enterComparison_operator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitComparison_operator" ):
                listener.exitComparison_operator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitComparison_operator" ):
                return visitor.visitComparison_operator(self)
            else:
                return visitor.visitChildren(self)




    def comparison_operator(self):

        localctx = tsqlParser.Comparison_operatorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 328, self.RULE_comparison_operator)
        try:
            self.state = 3115
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,458,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 3100
                self.match(tsqlParser.EQUAL)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 3101
                self.match(tsqlParser.GREATER)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 3102
                self.match(tsqlParser.LESS)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 3103
                self.match(tsqlParser.LESS)
                self.state = 3104
                self.match(tsqlParser.EQUAL)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 3105
                self.match(tsqlParser.GREATER)
                self.state = 3106
                self.match(tsqlParser.EQUAL)
                pass

            elif la_ == 6:
                self.enterOuterAlt(localctx, 6)
                self.state = 3107
                self.match(tsqlParser.LESS)
                self.state = 3108
                self.match(tsqlParser.GREATER)
                pass

            elif la_ == 7:
                self.enterOuterAlt(localctx, 7)
                self.state = 3109
                self.match(tsqlParser.EXCLAMATION)
                self.state = 3110
                self.match(tsqlParser.EQUAL)
                pass

            elif la_ == 8:
                self.enterOuterAlt(localctx, 8)
                self.state = 3111
                self.match(tsqlParser.EXCLAMATION)
                self.state = 3112
                self.match(tsqlParser.GREATER)
                pass

            elif la_ == 9:
                self.enterOuterAlt(localctx, 9)
                self.state = 3113
                self.match(tsqlParser.EXCLAMATION)
                self.state = 3114
                self.match(tsqlParser.LESS)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class Assignment_operatorContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return tsqlParser.RULE_assignment_operator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAssignment_operator" ):
                listener.enterAssignment_operator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAssignment_operator" ):
                listener.exitAssignment_operator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAssignment_operator" ):
                return visitor.visitAssignment_operator(self)
            else:
                return visitor.visitChildren(self)




    def assignment_operator(self):

        localctx = tsqlParser.Assignment_operatorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 330, self.RULE_assignment_operator)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3117
            _la = self._input.LA(1)
            if not(((((_la - 413)) & ~0x3f) == 0 and ((1 << (_la - 413)) & ((1 << (tsqlParser.PLUS_ASSIGN - 413)) | (1 << (tsqlParser.MINUS_ASSIGN - 413)) | (1 << (tsqlParser.MULT_ASSIGN - 413)) | (1 << (tsqlParser.DIV_ASSIGN - 413)) | (1 << (tsqlParser.MOD_ASSIGN - 413)) | (1 << (tsqlParser.AND_ASSIGN - 413)) | (1 << (tsqlParser.XOR_ASSIGN - 413)) | (1 << (tsqlParser.OR_ASSIGN - 413)))) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx

    class File_sizeContext(ParserRuleContext):

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DECIMAL(self):
            return self.getToken(tsqlParser.DECIMAL, 0)

        def KB(self):
            return self.getToken(tsqlParser.KB, 0)

        def MB(self):
            return self.getToken(tsqlParser.MB, 0)

        def GB(self):
            return self.getToken(tsqlParser.GB, 0)

        def TB(self):
            return self.getToken(tsqlParser.TB, 0)

        def getRuleIndex(self):
            return tsqlParser.RULE_file_size

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_size" ):
                listener.enterFile_size(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_size" ):
                listener.exitFile_size(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFile_size" ):
                return visitor.visitFile_size(self)
            else:
                return visitor.visitChildren(self)




    def file_size(self):

        localctx = tsqlParser.File_sizeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 332, self.RULE_file_size)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 3119
            self.match(tsqlParser.DECIMAL)
            self.state = 3121
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if ((((_la - 265)) & ~0x3f) == 0 and ((1 << (_la - 265)) & ((1 << (tsqlParser.GB - 265)) | (1 << (tsqlParser.KB - 265)) | (1 << (tsqlParser.MB - 265)))) != 0) or _la==tsqlParser.TB or _la==tsqlParser.MODULE:
                self.state = 3120
                _la = self._input.LA(1)
                if not(((((_la - 265)) & ~0x3f) == 0 and ((1 << (_la - 265)) & ((1 << (tsqlParser.GB - 265)) | (1 << (tsqlParser.KB - 265)) | (1 << (tsqlParser.MB - 265)))) != 0) or _la==tsqlParser.TB or _la==tsqlParser.MODULE):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx



    def sempred(self, localctx:RuleContext, ruleIndex:int, predIndex:int):
        if self._predicates == None:
            self._predicates = dict()
        self._predicates[85] = self.expression_sempred
        self._predicates[92] = self.search_condition_sempred
        pred = self._predicates.get(ruleIndex, None)
        if pred is None:
            raise Exception("No predicate with index:" + str(ruleIndex))
        else:
            return pred(localctx, predIndex)

    def expression_sempred(self, localctx:ExpressionContext, predIndex:int):
            if predIndex == 0:
                return self.precpred(self._ctx, 5)
         

            if predIndex == 1:
                return self.precpred(self._ctx, 3)
         

            if predIndex == 2:
                return self.precpred(self._ctx, 2)
         

            if predIndex == 3:
                return self.precpred(self._ctx, 12)
         

    def search_condition_sempred(self, localctx:Search_conditionContext, predIndex:int):
            if predIndex == 4:
                return self.precpred(self._ctx, 3)
         

            if predIndex == 5:
                return self.precpred(self._ctx, 2)
         




